// (c) 2019-2020 Takamitsu Endo
//
// This file is part of EnvelopedSine.
//
// EnvelopedSine is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// EnvelopedSine is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with EnvelopedSine.  If not, see <https://www.gnu.org/licenses/>.

#include "parameter.hpp"
#include "../common/dsp/constants.hpp"

using namespace SomeDSP;

IntScale<double> Scales::boolScale(1);
LinearScale<double> Scales::defaultScale(0.0, 1.0);

LogScale<double> Scales::envelopeA(0.0, 16.0, 0.5, 0.5);
LogScale<double> Scales::envelopeD(0.0, 4.0, 0.5, 0.5);
DecibelScale<double> Scales::gainDecibel(-40.0, 0.0, true);
LogScale<double> Scales::saturation(0.5, 5.0, 0.5, 2.0);

LogScale<double> Scales::gain(0.0, 32.0, 0.5, 8.0);
LinearScale<double> Scales::gainBoost(1.0, 8.0);

LinearScale<double> Scales::masterOctave(-4.0, 4.0);
LinearScale<double> Scales::equalTemperament(1.0, 60.0);
LinearScale<double> Scales::pitchMultiply(0.001, 4.0);
LinearScale<double> Scales::pitchModulo(0.0, 60.0);

IntScale<double> Scales::seed(16777215); // 2^24 - 1
LinearScale<double> Scales::randomGain(0.0, 4.0);
LogScale<double> Scales::randomFrequency(0.0, 1.0, 0.5, 0.1);
LinearScale<double> Scales::randomAttack(0.0, 1.0);
LinearScale<double> Scales::randomDecay(0.0, 1.0);
LinearScale<double> Scales::randomSaturation(0.0, 1.0);
LinearScale<double> Scales::randomPhase(0.0, 1.0);

LogScale<double> Scales::overtoneExpand(0.01, 4.0, 0.4, 1.0);
LinearScale<double> Scales::overtoneShift(0.0, 64.0);

LogScale<double> Scales::envelopeMultiplier(0.001, 4.0, 0.4, 1.0);
LinearScale<double> Scales::gainPower(0.001, 16.0);

LogScale<double> Scales::phaserFrequency(0.004, 16.0, 0.5, 2.0);
IntScale<double> Scales::phaserTempoNumerator(255);
IntScale<double> Scales::phaserTempoDenominator(255);
LogScale<double> Scales::phaserFrequencyMultiplier(0.0, 16.0, 0.5, 1.0);
LinearScale<double> Scales::phaserFeedback(-1.0, 1.0);
LogScale<double> Scales::phaserRange(0.0, 128.0, 0.5, 32.0);
LinearScale<double> Scales::phaserPhase(0.0, twopi);
IntScale<double> Scales::phaserStage(15);

IntScale<double> Scales::nVoice(5);
LogScale<double> Scales::smoothness(0.0, 0.5, 0.1, 0.04);

// Generated from preset dump. This works, but hard coding preset data is seriously bad.
#ifndef TEST_BUILD

void GlobalParameter::loadProgram(uint32_t index)
{
  using ID = ParameterID::ID;

  switch (index) {
    default:
      resetParameter();
      break;

    case presetDefault: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.0);
      value[ID::attack0 + 6]->setFromNormalized(0.0);
      value[ID::attack0 + 7]->setFromNormalized(0.0);
      value[ID::attack0 + 8]->setFromNormalized(0.0);
      value[ID::attack0 + 9]->setFromNormalized(0.0);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.0);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.0);
      value[ID::attack0 + 14]->setFromNormalized(0.0);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.0);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.0);
      value[ID::attack0 + 22]->setFromNormalized(0.0);
      value[ID::attack0 + 23]->setFromNormalized(0.0);
      value[ID::attack0 + 24]->setFromNormalized(0.0);
      value[ID::attack0 + 25]->setFromNormalized(0.0);
      value[ID::attack0 + 26]->setFromNormalized(0.0);
      value[ID::attack0 + 27]->setFromNormalized(0.0);
      value[ID::attack0 + 28]->setFromNormalized(0.0);
      value[ID::attack0 + 29]->setFromNormalized(0.0);
      value[ID::attack0 + 30]->setFromNormalized(0.0);
      value[ID::attack0 + 31]->setFromNormalized(0.0);
      value[ID::attack0 + 32]->setFromNormalized(0.0);
      value[ID::attack0 + 33]->setFromNormalized(0.0);
      value[ID::attack0 + 34]->setFromNormalized(0.0);
      value[ID::attack0 + 35]->setFromNormalized(0.0);
      value[ID::attack0 + 36]->setFromNormalized(0.0);
      value[ID::attack0 + 37]->setFromNormalized(0.0);
      value[ID::attack0 + 38]->setFromNormalized(0.0);
      value[ID::attack0 + 39]->setFromNormalized(0.0);
      value[ID::attack0 + 40]->setFromNormalized(0.0);
      value[ID::attack0 + 41]->setFromNormalized(0.0);
      value[ID::attack0 + 42]->setFromNormalized(0.0);
      value[ID::attack0 + 43]->setFromNormalized(0.0);
      value[ID::attack0 + 44]->setFromNormalized(0.0);
      value[ID::attack0 + 45]->setFromNormalized(0.0);
      value[ID::attack0 + 46]->setFromNormalized(0.0);
      value[ID::attack0 + 47]->setFromNormalized(0.0);
      value[ID::attack0 + 48]->setFromNormalized(0.0);
      value[ID::attack0 + 49]->setFromNormalized(0.0);
      value[ID::attack0 + 50]->setFromNormalized(0.0);
      value[ID::attack0 + 51]->setFromNormalized(0.0);
      value[ID::attack0 + 52]->setFromNormalized(0.0);
      value[ID::attack0 + 53]->setFromNormalized(0.0);
      value[ID::attack0 + 54]->setFromNormalized(0.0);
      value[ID::attack0 + 55]->setFromNormalized(0.0);
      value[ID::attack0 + 56]->setFromNormalized(0.0);
      value[ID::attack0 + 57]->setFromNormalized(0.0);
      value[ID::attack0 + 58]->setFromNormalized(0.0);
      value[ID::attack0 + 59]->setFromNormalized(0.0);
      value[ID::attack0 + 60]->setFromNormalized(0.0);
      value[ID::attack0 + 61]->setFromNormalized(0.0);
      value[ID::attack0 + 62]->setFromNormalized(0.0);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.5);
      value[ID::decay0 + 1]->setFromNormalized(0.5);
      value[ID::decay0 + 2]->setFromNormalized(0.5);
      value[ID::decay0 + 3]->setFromNormalized(0.5);
      value[ID::decay0 + 4]->setFromNormalized(0.5);
      value[ID::decay0 + 5]->setFromNormalized(0.5);
      value[ID::decay0 + 6]->setFromNormalized(0.5);
      value[ID::decay0 + 7]->setFromNormalized(0.5);
      value[ID::decay0 + 8]->setFromNormalized(0.5);
      value[ID::decay0 + 9]->setFromNormalized(0.5);
      value[ID::decay0 + 10]->setFromNormalized(0.5);
      value[ID::decay0 + 11]->setFromNormalized(0.5);
      value[ID::decay0 + 12]->setFromNormalized(0.5);
      value[ID::decay0 + 13]->setFromNormalized(0.5);
      value[ID::decay0 + 14]->setFromNormalized(0.5);
      value[ID::decay0 + 15]->setFromNormalized(0.5);
      value[ID::decay0 + 16]->setFromNormalized(0.5);
      value[ID::decay0 + 17]->setFromNormalized(0.5);
      value[ID::decay0 + 18]->setFromNormalized(0.5);
      value[ID::decay0 + 19]->setFromNormalized(0.5);
      value[ID::decay0 + 20]->setFromNormalized(0.5);
      value[ID::decay0 + 21]->setFromNormalized(0.5);
      value[ID::decay0 + 22]->setFromNormalized(0.5);
      value[ID::decay0 + 23]->setFromNormalized(0.5);
      value[ID::decay0 + 24]->setFromNormalized(0.5);
      value[ID::decay0 + 25]->setFromNormalized(0.5);
      value[ID::decay0 + 26]->setFromNormalized(0.5);
      value[ID::decay0 + 27]->setFromNormalized(0.5);
      value[ID::decay0 + 28]->setFromNormalized(0.5);
      value[ID::decay0 + 29]->setFromNormalized(0.5);
      value[ID::decay0 + 30]->setFromNormalized(0.5);
      value[ID::decay0 + 31]->setFromNormalized(0.5);
      value[ID::decay0 + 32]->setFromNormalized(0.5);
      value[ID::decay0 + 33]->setFromNormalized(0.5);
      value[ID::decay0 + 34]->setFromNormalized(0.5);
      value[ID::decay0 + 35]->setFromNormalized(0.5);
      value[ID::decay0 + 36]->setFromNormalized(0.5);
      value[ID::decay0 + 37]->setFromNormalized(0.5);
      value[ID::decay0 + 38]->setFromNormalized(0.5);
      value[ID::decay0 + 39]->setFromNormalized(0.5);
      value[ID::decay0 + 40]->setFromNormalized(0.5);
      value[ID::decay0 + 41]->setFromNormalized(0.5);
      value[ID::decay0 + 42]->setFromNormalized(0.5);
      value[ID::decay0 + 43]->setFromNormalized(0.5);
      value[ID::decay0 + 44]->setFromNormalized(0.5);
      value[ID::decay0 + 45]->setFromNormalized(0.5);
      value[ID::decay0 + 46]->setFromNormalized(0.5);
      value[ID::decay0 + 47]->setFromNormalized(0.5);
      value[ID::decay0 + 48]->setFromNormalized(0.5);
      value[ID::decay0 + 49]->setFromNormalized(0.5);
      value[ID::decay0 + 50]->setFromNormalized(0.5);
      value[ID::decay0 + 51]->setFromNormalized(0.5);
      value[ID::decay0 + 52]->setFromNormalized(0.5);
      value[ID::decay0 + 53]->setFromNormalized(0.5);
      value[ID::decay0 + 54]->setFromNormalized(0.5);
      value[ID::decay0 + 55]->setFromNormalized(0.5);
      value[ID::decay0 + 56]->setFromNormalized(0.5);
      value[ID::decay0 + 57]->setFromNormalized(0.5);
      value[ID::decay0 + 58]->setFromNormalized(0.5);
      value[ID::decay0 + 59]->setFromNormalized(0.5);
      value[ID::decay0 + 60]->setFromNormalized(0.5);
      value[ID::decay0 + 61]->setFromNormalized(0.5);
      value[ID::decay0 + 62]->setFromNormalized(0.5);
      value[ID::decay0 + 63]->setFromNormalized(0.5);
      value[ID::overtone0 + 0]->setFromNormalized(1.0);
      value[ID::overtone0 + 1]->setFromNormalized(0.8494850021680094);
      value[ID::overtone0 + 2]->setFromNormalized(0.7614393726401688);
      value[ID::overtone0 + 3]->setFromNormalized(0.6989700043360187);
      value[ID::overtone0 + 4]->setFromNormalized(0.6505149978319906);
      value[ID::overtone0 + 5]->setFromNormalized(0.6109243748081781);
      value[ID::overtone0 + 6]->setFromNormalized(0.5774509799928716);
      value[ID::overtone0 + 7]->setFromNormalized(0.5484550065040282);
      value[ID::overtone0 + 8]->setFromNormalized(0.5228787452803376);
      value[ID::overtone0 + 9]->setFromNormalized(0.5);
      value[ID::overtone0 + 10]->setFromNormalized(0.47930365742088743);
      value[ID::overtone0 + 11]->setFromNormalized(0.46040937697618756);
      value[ID::overtone0 + 12]->setFromNormalized(0.44302832384658164);
      value[ID::overtone0 + 13]->setFromNormalized(0.426935982160881);
      value[ID::overtone0 + 14]->setFromNormalized(0.4119543704721593);
      value[ID::overtone0 + 15]->setFromNormalized(0.3979400086720375);
      value[ID::overtone0 + 16]->setFromNormalized(0.38477553931086295);
      value[ID::overtone0 + 17]->setFromNormalized(0.3723637474483469);
      value[ID::overtone0 + 18]->setFromNormalized(0.36062319952358546);
      value[ID::overtone0 + 19]->setFromNormalized(0.3494850021680094);
      value[ID::overtone0 + 20]->setFromNormalized(0.33889035263304024);
      value[ID::overtone0 + 21]->setFromNormalized(0.3287886595888968);
      value[ID::overtone0 + 22]->setFromNormalized(0.31913608199120347);
      value[ID::overtone0 + 23]->setFromNormalized(0.3098943791441968);
      value[ID::overtone0 + 24]->setFromNormalized(0.30102999566398125);
      value[ID::overtone0 + 25]->setFromNormalized(0.2925133260145909);
      value[ID::overtone0 + 26]->setFromNormalized(0.2843181179205062);
      value[ID::overtone0 + 27]->setFromNormalized(0.2764209843288903);
      value[ID::overtone0 + 28]->setFromNormalized(0.268801001050522);
      value[ID::overtone0 + 29]->setFromNormalized(0.2614393726401687);
      value[ID::overtone0 + 30]->setFromNormalized(0.25431915308286357);
      value[ID::overtone0 + 31]->setFromNormalized(0.24742501084004687);
      value[ID::overtone0 + 32]->setFromNormalized(0.2407430300610561);
      value[ID::overtone0 + 33]->setFromNormalized(0.23426054147887232);
      value[ID::overtone0 + 34]->setFromNormalized(0.22796597782486216);
      value[ID::overtone0 + 35]->setFromNormalized(0.22184874961635623);
      value[ID::overtone0 + 36]->setFromNormalized(0.2158991379665025);
      value[ID::overtone0 + 37]->setFromNormalized(0.21010820169159494);
      value[ID::overtone0 + 38]->setFromNormalized(0.20446769648675023);
      value[ID::overtone0 + 39]->setFromNormalized(0.1989700043360189);
      value[ID::overtone0 + 40]->setFromNormalized(0.19360807164013227);
      value[ID::overtone0 + 41]->setFromNormalized(0.18837535480104978);
      value[ID::overtone0 + 42]->setFromNormalized(0.18326577221020662);
      value[ID::overtone0 + 43]->setFromNormalized(0.17827366175690623);
      value[ID::overtone0 + 44]->setFromNormalized(0.1733937431123282);
      value[ID::overtone0 + 45]->setFromNormalized(0.168621084159213);
      value[ID::overtone0 + 46]->setFromNormalized(0.16395107103214118);
      value[ID::overtone0 + 47]->setFromNormalized(0.15937938131220636);
      value[ID::overtone0 + 48]->setFromNormalized(0.15490195998574324);
      value[ID::overtone0 + 49]->setFromNormalized(0.15051499783199063);
      value[ID::overtone0 + 50]->setFromNormalized(0.1462149119510318);
      value[ID::overtone0 + 51]->setFromNormalized(0.14199832818260044);
      value[ID::overtone0 + 52]->setFromNormalized(0.1378620651996055);
      value[ID::overtone0 + 53]->setFromNormalized(0.13380312008851564);
      value[ID::overtone0 + 54]->setFromNormalized(0.1298186552528781);
      value[ID::overtone0 + 55]->setFromNormalized(0.12590598649689982);
      value[ID::overtone0 + 56]->setFromNormalized(0.12206257216375427);
      value[ID::overtone0 + 57]->setFromNormalized(0.11828600321853137);
      value[ID::overtone0 + 58]->setFromNormalized(0.11457399417892784);
      value[ID::overtone0 + 59]->setFromNormalized(0.11092437480817825);
      value[ID::overtone0 + 60]->setFromNormalized(0.10733508249461661);
      value[ID::overtone0 + 61]->setFromNormalized(0.10380415525087301);
      value[ID::overtone0 + 62]->setFromNormalized(0.10032972527320912);
      value[ID::overtone0 + 63]->setFromNormalized(0.09691001300805642);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000002);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case preset3and7: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.0);
      value[ID::attack0 + 6]->setFromNormalized(0.0);
      value[ID::attack0 + 7]->setFromNormalized(0.0);
      value[ID::attack0 + 8]->setFromNormalized(0.0);
      value[ID::attack0 + 9]->setFromNormalized(0.0);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.0);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.0);
      value[ID::attack0 + 14]->setFromNormalized(0.0);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.0);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.0);
      value[ID::attack0 + 22]->setFromNormalized(0.0);
      value[ID::attack0 + 23]->setFromNormalized(0.0);
      value[ID::attack0 + 24]->setFromNormalized(0.0);
      value[ID::attack0 + 25]->setFromNormalized(0.0);
      value[ID::attack0 + 26]->setFromNormalized(0.0);
      value[ID::attack0 + 27]->setFromNormalized(0.0);
      value[ID::attack0 + 28]->setFromNormalized(0.0);
      value[ID::attack0 + 29]->setFromNormalized(0.0);
      value[ID::attack0 + 30]->setFromNormalized(0.0);
      value[ID::attack0 + 31]->setFromNormalized(0.0);
      value[ID::attack0 + 32]->setFromNormalized(0.0);
      value[ID::attack0 + 33]->setFromNormalized(0.0);
      value[ID::attack0 + 34]->setFromNormalized(0.0);
      value[ID::attack0 + 35]->setFromNormalized(0.0);
      value[ID::attack0 + 36]->setFromNormalized(0.0);
      value[ID::attack0 + 37]->setFromNormalized(0.0);
      value[ID::attack0 + 38]->setFromNormalized(0.0);
      value[ID::attack0 + 39]->setFromNormalized(0.0);
      value[ID::attack0 + 40]->setFromNormalized(0.0);
      value[ID::attack0 + 41]->setFromNormalized(0.0);
      value[ID::attack0 + 42]->setFromNormalized(0.0);
      value[ID::attack0 + 43]->setFromNormalized(0.0);
      value[ID::attack0 + 44]->setFromNormalized(0.0);
      value[ID::attack0 + 45]->setFromNormalized(0.0);
      value[ID::attack0 + 46]->setFromNormalized(0.0);
      value[ID::attack0 + 47]->setFromNormalized(0.0);
      value[ID::attack0 + 48]->setFromNormalized(0.0);
      value[ID::attack0 + 49]->setFromNormalized(0.0);
      value[ID::attack0 + 50]->setFromNormalized(0.0);
      value[ID::attack0 + 51]->setFromNormalized(0.0);
      value[ID::attack0 + 52]->setFromNormalized(0.0);
      value[ID::attack0 + 53]->setFromNormalized(0.0);
      value[ID::attack0 + 54]->setFromNormalized(0.0);
      value[ID::attack0 + 55]->setFromNormalized(0.0);
      value[ID::attack0 + 56]->setFromNormalized(0.0);
      value[ID::attack0 + 57]->setFromNormalized(0.0);
      value[ID::attack0 + 58]->setFromNormalized(0.0);
      value[ID::attack0 + 59]->setFromNormalized(0.0);
      value[ID::attack0 + 60]->setFromNormalized(0.0);
      value[ID::attack0 + 61]->setFromNormalized(0.0);
      value[ID::attack0 + 62]->setFromNormalized(0.0);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.5);
      value[ID::decay0 + 1]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 2]->setFromNormalized(0.29571428571428576);
      value[ID::decay0 + 3]->setFromNormalized(0.34285714285714286);
      value[ID::decay0 + 4]->setFromNormalized(0.37857142857142856);
      value[ID::decay0 + 5]->setFromNormalized(0.38571428571428573);
      value[ID::decay0 + 6]->setFromNormalized(0.44999999999999996);
      value[ID::decay0 + 7]->setFromNormalized(0.4928571428571429);
      value[ID::decay0 + 8]->setFromNormalized(0.49500000000000005);
      value[ID::decay0 + 9]->setFromNormalized(0.5785714285714285);
      value[ID::decay0 + 10]->setFromNormalized(0.6357142857142857);
      value[ID::decay0 + 11]->setFromNormalized(0.597857142857143);
      value[ID::decay0 + 12]->setFromNormalized(0.7);
      value[ID::decay0 + 13]->setFromNormalized(0.7);
      value[ID::decay0 + 14]->setFromNormalized(0.6492857142857142);
      value[ID::decay0 + 15]->setFromNormalized(0.8142857142857143);
      value[ID::decay0 + 16]->setFromNormalized(0.8642857142857143);
      value[ID::decay0 + 17]->setFromNormalized(0.7842857142857144);
      value[ID::decay0 + 18]->setFromNormalized(0.8714285714285714);
      value[ID::decay0 + 19]->setFromNormalized(0.8428571428571429);
      value[ID::decay0 + 20]->setFromNormalized(0.6878571428571428);
      value[ID::decay0 + 21]->setFromNormalized(0.7214285714285714);
      value[ID::decay0 + 22]->setFromNormalized(0.6642857142857144);
      value[ID::decay0 + 23]->setFromNormalized(0.5528571428571429);
      value[ID::decay0 + 24]->setFromNormalized(0.5071428571428571);
      value[ID::decay0 + 25]->setFromNormalized(0.4714285714285714);
      value[ID::decay0 + 26]->setFromNormalized(0.3342857142857143);
      value[ID::decay0 + 27]->setFromNormalized(0.3285714285714286);
      value[ID::decay0 + 28]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 29]->setFromNormalized(0.28285714285714286);
      value[ID::decay0 + 30]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 31]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 32]->setFromNormalized(0.28928571428571426);
      value[ID::decay0 + 33]->setFromNormalized(0.5);
      value[ID::decay0 + 34]->setFromNormalized(0.37857142857142856);
      value[ID::decay0 + 35]->setFromNormalized(0.3921428571428572);
      value[ID::decay0 + 36]->setFromNormalized(0.5);
      value[ID::decay0 + 37]->setFromNormalized(0.4928571428571429);
      value[ID::decay0 + 38]->setFromNormalized(0.5142857142857142);
      value[ID::decay0 + 39]->setFromNormalized(0.5);
      value[ID::decay0 + 40]->setFromNormalized(0.6714285714285715);
      value[ID::decay0 + 41]->setFromNormalized(0.6557142857142858);
      value[ID::decay0 + 42]->setFromNormalized(0.7);
      value[ID::decay0 + 43]->setFromNormalized(0.6142857142857143);
      value[ID::decay0 + 44]->setFromNormalized(0.47571428571428576);
      value[ID::decay0 + 45]->setFromNormalized(0.37142857142857144);
      value[ID::decay0 + 46]->setFromNormalized(0.27142857142857146);
      value[ID::decay0 + 47]->setFromNormalized(0.19285714285714287);
      value[ID::decay0 + 48]->setFromNormalized(0.19285714285714284);
      value[ID::decay0 + 49]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 50]->setFromNormalized(0.2121428571428572);
      value[ID::decay0 + 51]->setFromNormalized(0.37857142857142856);
      value[ID::decay0 + 52]->setFromNormalized(0.47857142857142854);
      value[ID::decay0 + 53]->setFromNormalized(0.5271428571428571);
      value[ID::decay0 + 54]->setFromNormalized(0.6571428571428571);
      value[ID::decay0 + 55]->setFromNormalized(0.5);
      value[ID::decay0 + 56]->setFromNormalized(0.765);
      value[ID::decay0 + 57]->setFromNormalized(0.85);
      value[ID::decay0 + 58]->setFromNormalized(0.7928571428571428);
      value[ID::decay0 + 59]->setFromNormalized(0.6942857142857143);
      value[ID::decay0 + 60]->setFromNormalized(0.6642857142857144);
      value[ID::decay0 + 61]->setFromNormalized(0.6285714285714286);
      value[ID::decay0 + 62]->setFromNormalized(0.5078571428571429);
      value[ID::decay0 + 63]->setFromNormalized(0.5071428571428571);
      value[ID::overtone0 + 0]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 1]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 2]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 3]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 4]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 5]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 6]->setFromNormalized(0.8480090659447688);
      value[ID::overtone0 + 7]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 8]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 9]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 10]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 11]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 12]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 13]->setFromNormalized(0.8480090659447688);
      value[ID::overtone0 + 14]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 15]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 16]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 17]->setFromNormalized(0.9267845687534562);
      value[ID::overtone0 + 18]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 19]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 20]->setFromNormalized(1.0);
      value[ID::overtone0 + 21]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 22]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 23]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 24]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 25]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 26]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 27]->setFromNormalized(0.8480090659447688);
      value[ID::overtone0 + 28]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 29]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 30]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 31]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 32]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 33]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 34]->setFromNormalized(0.8480090659447688);
      value[ID::overtone0 + 35]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 36]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 37]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 38]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 39]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 40]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 41]->setFromNormalized(1.0);
      value[ID::overtone0 + 42]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 43]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 44]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 45]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 46]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 47]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 48]->setFromNormalized(0.8480090659447688);
      value[ID::overtone0 + 49]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 50]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 51]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 52]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 53]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 54]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 55]->setFromNormalized(0.8480090659447688);
      value[ID::overtone0 + 56]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 57]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 58]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 59]->setFromNormalized(0.9261515017449096);
      value[ID::overtone0 + 60]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 61]->setFromNormalized(0.014780882941434648);
      value[ID::overtone0 + 62]->setFromNormalized(1.0);
      value[ID::overtone0 + 63]->setFromNormalized(0.014780882941434648);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5399998426437378);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.5600000619888306);
      value[ID::phaserFrequency]->setFromNormalized(0.23199991881847384);
      value[ID::phaserFeedback]->setFromNormalized(0.8480000495910645);
      value[ID::phaserRange]->setFromNormalized(0.7520000338554382);
      value[ID::phaserMin]->setFromNormalized(1.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(0);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case preset5n: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.0);
      value[ID::attack0 + 6]->setFromNormalized(0.0);
      value[ID::attack0 + 7]->setFromNormalized(0.0);
      value[ID::attack0 + 8]->setFromNormalized(0.0);
      value[ID::attack0 + 9]->setFromNormalized(0.0);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.0);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.0);
      value[ID::attack0 + 14]->setFromNormalized(0.0);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.0);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.0);
      value[ID::attack0 + 22]->setFromNormalized(0.0);
      value[ID::attack0 + 23]->setFromNormalized(0.0);
      value[ID::attack0 + 24]->setFromNormalized(0.0);
      value[ID::attack0 + 25]->setFromNormalized(0.0);
      value[ID::attack0 + 26]->setFromNormalized(0.0);
      value[ID::attack0 + 27]->setFromNormalized(0.0);
      value[ID::attack0 + 28]->setFromNormalized(0.0);
      value[ID::attack0 + 29]->setFromNormalized(0.0);
      value[ID::attack0 + 30]->setFromNormalized(0.0);
      value[ID::attack0 + 31]->setFromNormalized(0.0);
      value[ID::attack0 + 32]->setFromNormalized(0.0);
      value[ID::attack0 + 33]->setFromNormalized(0.0);
      value[ID::attack0 + 34]->setFromNormalized(0.0);
      value[ID::attack0 + 35]->setFromNormalized(0.0);
      value[ID::attack0 + 36]->setFromNormalized(0.0);
      value[ID::attack0 + 37]->setFromNormalized(0.0);
      value[ID::attack0 + 38]->setFromNormalized(0.07142857142857138);
      value[ID::attack0 + 39]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 40]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 41]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 42]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 43]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 44]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 45]->setFromNormalized(0.2571428571428571);
      value[ID::attack0 + 46]->setFromNormalized(0.2571428571428571);
      value[ID::attack0 + 47]->setFromNormalized(0.24999999999999997);
      value[ID::attack0 + 48]->setFromNormalized(0.2285714285714285);
      value[ID::attack0 + 49]->setFromNormalized(0.1928571428571428);
      value[ID::attack0 + 50]->setFromNormalized(0.17142857142857135);
      value[ID::attack0 + 51]->setFromNormalized(0.15);
      value[ID::attack0 + 52]->setFromNormalized(0.17857142857142858);
      value[ID::attack0 + 53]->setFromNormalized(0.17857142857142858);
      value[ID::attack0 + 54]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 55]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 56]->setFromNormalized(0.21428571428571427);
      value[ID::attack0 + 57]->setFromNormalized(0.2214285714285714);
      value[ID::attack0 + 58]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 59]->setFromNormalized(0.2285714285714285);
      value[ID::attack0 + 60]->setFromNormalized(0.16428571428571423);
      value[ID::attack0 + 61]->setFromNormalized(0.12857142857142856);
      value[ID::attack0 + 62]->setFromNormalized(0.10714285714285708);
      value[ID::attack0 + 63]->setFromNormalized(0.028571428571428574);
      value[ID::decay0 + 0]->setFromNormalized(0.6571428571428571);
      value[ID::decay0 + 1]->setFromNormalized(0.0);
      value[ID::decay0 + 2]->setFromNormalized(0.0);
      value[ID::decay0 + 3]->setFromNormalized(0.0);
      value[ID::decay0 + 4]->setFromNormalized(0.25);
      value[ID::decay0 + 5]->setFromNormalized(0.0);
      value[ID::decay0 + 6]->setFromNormalized(0.0);
      value[ID::decay0 + 7]->setFromNormalized(0.0);
      value[ID::decay0 + 8]->setFromNormalized(0.0);
      value[ID::decay0 + 9]->setFromNormalized(0.6);
      value[ID::decay0 + 10]->setFromNormalized(0.0);
      value[ID::decay0 + 11]->setFromNormalized(0.0);
      value[ID::decay0 + 12]->setFromNormalized(0.0);
      value[ID::decay0 + 13]->setFromNormalized(0.0);
      value[ID::decay0 + 14]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 15]->setFromNormalized(0.0);
      value[ID::decay0 + 16]->setFromNormalized(0.0);
      value[ID::decay0 + 17]->setFromNormalized(0.0);
      value[ID::decay0 + 18]->setFromNormalized(0.0);
      value[ID::decay0 + 19]->setFromNormalized(0.44285714285714284);
      value[ID::decay0 + 20]->setFromNormalized(0.0);
      value[ID::decay0 + 21]->setFromNormalized(0.0);
      value[ID::decay0 + 22]->setFromNormalized(0.0);
      value[ID::decay0 + 23]->setFromNormalized(0.0);
      value[ID::decay0 + 24]->setFromNormalized(0.2785714285714286);
      value[ID::decay0 + 25]->setFromNormalized(0.0);
      value[ID::decay0 + 26]->setFromNormalized(0.0);
      value[ID::decay0 + 27]->setFromNormalized(0.0);
      value[ID::decay0 + 28]->setFromNormalized(0.0);
      value[ID::decay0 + 29]->setFromNormalized(0.2571428571428571);
      value[ID::decay0 + 30]->setFromNormalized(0.0);
      value[ID::decay0 + 31]->setFromNormalized(0.0);
      value[ID::decay0 + 32]->setFromNormalized(0.0);
      value[ID::decay0 + 33]->setFromNormalized(0.0);
      value[ID::decay0 + 34]->setFromNormalized(0.0);
      value[ID::decay0 + 35]->setFromNormalized(0.0);
      value[ID::decay0 + 36]->setFromNormalized(0.0);
      value[ID::decay0 + 37]->setFromNormalized(0.0);
      value[ID::decay0 + 38]->setFromNormalized(0.0);
      value[ID::decay0 + 39]->setFromNormalized(0.0);
      value[ID::decay0 + 40]->setFromNormalized(0.0);
      value[ID::decay0 + 41]->setFromNormalized(0.0);
      value[ID::decay0 + 42]->setFromNormalized(0.0);
      value[ID::decay0 + 43]->setFromNormalized(0.0);
      value[ID::decay0 + 44]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 45]->setFromNormalized(0.0);
      value[ID::decay0 + 46]->setFromNormalized(0.0);
      value[ID::decay0 + 47]->setFromNormalized(0.0);
      value[ID::decay0 + 48]->setFromNormalized(0.0);
      value[ID::decay0 + 49]->setFromNormalized(0.19285714285714284);
      value[ID::decay0 + 50]->setFromNormalized(0.0);
      value[ID::decay0 + 51]->setFromNormalized(0.0);
      value[ID::decay0 + 52]->setFromNormalized(0.0);
      value[ID::decay0 + 53]->setFromNormalized(0.0);
      value[ID::decay0 + 54]->setFromNormalized(0.2785714285714286);
      value[ID::decay0 + 55]->setFromNormalized(0.0);
      value[ID::decay0 + 56]->setFromNormalized(0.0);
      value[ID::decay0 + 57]->setFromNormalized(0.0);
      value[ID::decay0 + 58]->setFromNormalized(0.0);
      value[ID::decay0 + 59]->setFromNormalized(0.08571428571428576);
      value[ID::decay0 + 60]->setFromNormalized(0.0);
      value[ID::decay0 + 61]->setFromNormalized(0.0);
      value[ID::decay0 + 62]->setFromNormalized(0.0);
      value[ID::decay0 + 63]->setFromNormalized(0.0);
      value[ID::overtone0 + 0]->setFromNormalized(1.0);
      value[ID::overtone0 + 1]->setFromNormalized(0.0);
      value[ID::overtone0 + 2]->setFromNormalized(0.0);
      value[ID::overtone0 + 3]->setFromNormalized(0.0);
      value[ID::overtone0 + 4]->setFromNormalized(0.9928571428571429);
      value[ID::overtone0 + 5]->setFromNormalized(0.0);
      value[ID::overtone0 + 6]->setFromNormalized(0.0);
      value[ID::overtone0 + 7]->setFromNormalized(0.0);
      value[ID::overtone0 + 8]->setFromNormalized(0.0);
      value[ID::overtone0 + 9]->setFromNormalized(0.4357142857142858);
      value[ID::overtone0 + 10]->setFromNormalized(0.0);
      value[ID::overtone0 + 11]->setFromNormalized(0.0);
      value[ID::overtone0 + 12]->setFromNormalized(0.0);
      value[ID::overtone0 + 13]->setFromNormalized(0.0);
      value[ID::overtone0 + 14]->setFromNormalized(0.9142857142857143);
      value[ID::overtone0 + 15]->setFromNormalized(0.0);
      value[ID::overtone0 + 16]->setFromNormalized(0.0);
      value[ID::overtone0 + 17]->setFromNormalized(0.0);
      value[ID::overtone0 + 18]->setFromNormalized(0.0);
      value[ID::overtone0 + 19]->setFromNormalized(0.5428571428571429);
      value[ID::overtone0 + 20]->setFromNormalized(0.0);
      value[ID::overtone0 + 21]->setFromNormalized(0.0);
      value[ID::overtone0 + 22]->setFromNormalized(0.0);
      value[ID::overtone0 + 23]->setFromNormalized(0.0);
      value[ID::overtone0 + 24]->setFromNormalized(0.5857142857142856);
      value[ID::overtone0 + 25]->setFromNormalized(0.0);
      value[ID::overtone0 + 26]->setFromNormalized(0.0);
      value[ID::overtone0 + 27]->setFromNormalized(0.0);
      value[ID::overtone0 + 28]->setFromNormalized(0.0);
      value[ID::overtone0 + 29]->setFromNormalized(0.3642857142857143);
      value[ID::overtone0 + 30]->setFromNormalized(0.0);
      value[ID::overtone0 + 31]->setFromNormalized(0.0);
      value[ID::overtone0 + 32]->setFromNormalized(0.0);
      value[ID::overtone0 + 33]->setFromNormalized(0.0);
      value[ID::overtone0 + 34]->setFromNormalized(0.0);
      value[ID::overtone0 + 35]->setFromNormalized(0.0);
      value[ID::overtone0 + 36]->setFromNormalized(0.0);
      value[ID::overtone0 + 37]->setFromNormalized(0.0);
      value[ID::overtone0 + 38]->setFromNormalized(0.0);
      value[ID::overtone0 + 39]->setFromNormalized(0.0);
      value[ID::overtone0 + 40]->setFromNormalized(0.0071428571428571175);
      value[ID::overtone0 + 41]->setFromNormalized(0.0);
      value[ID::overtone0 + 42]->setFromNormalized(0.0);
      value[ID::overtone0 + 43]->setFromNormalized(0.0);
      value[ID::overtone0 + 44]->setFromNormalized(0.11428571428571424);
      value[ID::overtone0 + 45]->setFromNormalized(0.0);
      value[ID::overtone0 + 46]->setFromNormalized(0.0);
      value[ID::overtone0 + 47]->setFromNormalized(0.0);
      value[ID::overtone0 + 48]->setFromNormalized(0.0);
      value[ID::overtone0 + 49]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 50]->setFromNormalized(0.0);
      value[ID::overtone0 + 51]->setFromNormalized(0.0);
      value[ID::overtone0 + 52]->setFromNormalized(0.0);
      value[ID::overtone0 + 53]->setFromNormalized(0.0);
      value[ID::overtone0 + 54]->setFromNormalized(0.25);
      value[ID::overtone0 + 55]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 56]->setFromNormalized(0.0);
      value[ID::overtone0 + 57]->setFromNormalized(0.0);
      value[ID::overtone0 + 58]->setFromNormalized(0.0);
      value[ID::overtone0 + 59]->setFromNormalized(0.09285714285714289);
      value[ID::overtone0 + 60]->setFromNormalized(0.0);
      value[ID::overtone0 + 61]->setFromNormalized(0.0);
      value[ID::overtone0 + 62]->setFromNormalized(0.0);
      value[ID::overtone0 + 63]->setFromNormalized(0.0);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.03571428571428569);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.5);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.19285714285714278);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.12857142857142853);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(1.0);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.7360000610351562);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetAquatic: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.028571428571428574);
      value[ID::attack0 + 1]->setFromNormalized(0.5357142857142857);
      value[ID::attack0 + 2]->setFromNormalized(0.6071428571428572);
      value[ID::attack0 + 3]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 4]->setFromNormalized(0.6571428571428571);
      value[ID::attack0 + 5]->setFromNormalized(0.10591517857142861);
      value[ID::attack0 + 6]->setFromNormalized(0.7214285714285714);
      value[ID::attack0 + 7]->setFromNormalized(0.7357142857142858);
      value[ID::attack0 + 8]->setFromNormalized(0.7928571428571428);
      value[ID::attack0 + 9]->setFromNormalized(0.8);
      value[ID::attack0 + 10]->setFromNormalized(0.8142857142857143);
      value[ID::attack0 + 11]->setFromNormalized(0.85);
      value[ID::attack0 + 12]->setFromNormalized(0.8714285714285714);
      value[ID::attack0 + 13]->setFromNormalized(0.24341517857142855);
      value[ID::attack0 + 14]->setFromNormalized(0.9142857142857143);
      value[ID::attack0 + 15]->setFromNormalized(0.9142857142857143);
      value[ID::attack0 + 16]->setFromNormalized(0.95);
      value[ID::attack0 + 17]->setFromNormalized(0.9642857142857143);
      value[ID::attack0 + 18]->setFromNormalized(0.9714285714285714);
      value[ID::attack0 + 19]->setFromNormalized(0.3465401785714286);
      value[ID::attack0 + 20]->setFromNormalized(0.9857142857142858);
      value[ID::attack0 + 21]->setFromNormalized(0.9857142857142858);
      value[ID::attack0 + 22]->setFromNormalized(0.9857142857142858);
      value[ID::attack0 + 23]->setFromNormalized(0.9857142857142858);
      value[ID::attack0 + 24]->setFromNormalized(0.9857142857142858);
      value[ID::attack0 + 25]->setFromNormalized(0.95);
      value[ID::attack0 + 26]->setFromNormalized(0.9142857142857143);
      value[ID::attack0 + 27]->setFromNormalized(0.8857142857142857);
      value[ID::attack0 + 28]->setFromNormalized(0.8357142857142857);
      value[ID::attack0 + 29]->setFromNormalized(0.8214285714285714);
      value[ID::attack0 + 30]->setFromNormalized(0.7857142857142857);
      value[ID::attack0 + 31]->setFromNormalized(0.7214285714285714);
      value[ID::attack0 + 32]->setFromNormalized(0.7);
      value[ID::attack0 + 33]->setFromNormalized(0.6642857142857144);
      value[ID::attack0 + 34]->setFromNormalized(0.65);
      value[ID::attack0 + 35]->setFromNormalized(0.6071428571428572);
      value[ID::attack0 + 36]->setFromNormalized(0.5642857142857143);
      value[ID::attack0 + 37]->setFromNormalized(0.5285714285714286);
      value[ID::attack0 + 38]->setFromNormalized(0.5785714285714285);
      value[ID::attack0 + 39]->setFromNormalized(0.5785714285714285);
      value[ID::attack0 + 40]->setFromNormalized(0.6);
      value[ID::attack0 + 41]->setFromNormalized(0.6142857142857143);
      value[ID::attack0 + 42]->setFromNormalized(0.6357142857142857);
      value[ID::attack0 + 43]->setFromNormalized(0.65);
      value[ID::attack0 + 44]->setFromNormalized(0.6571428571428571);
      value[ID::attack0 + 45]->setFromNormalized(0.6714285714285715);
      value[ID::attack0 + 46]->setFromNormalized(0.7);
      value[ID::attack0 + 47]->setFromNormalized(0.7);
      value[ID::attack0 + 48]->setFromNormalized(0.7071428571428571);
      value[ID::attack0 + 49]->setFromNormalized(0.7214285714285714);
      value[ID::attack0 + 50]->setFromNormalized(0.7357142857142858);
      value[ID::attack0 + 51]->setFromNormalized(0.75);
      value[ID::attack0 + 52]->setFromNormalized(0.7785714285714286);
      value[ID::attack0 + 53]->setFromNormalized(0.7785714285714286);
      value[ID::attack0 + 54]->setFromNormalized(0.7857142857142857);
      value[ID::attack0 + 55]->setFromNormalized(0.8071428571428572);
      value[ID::attack0 + 56]->setFromNormalized(0.8071428571428572);
      value[ID::attack0 + 57]->setFromNormalized(0.8285714285714285);
      value[ID::attack0 + 58]->setFromNormalized(0.8357142857142857);
      value[ID::attack0 + 59]->setFromNormalized(0.8642857142857143);
      value[ID::attack0 + 60]->setFromNormalized(0.8857142857142857);
      value[ID::attack0 + 61]->setFromNormalized(0.02142857142857146);
      value[ID::attack0 + 62]->setFromNormalized(0.014285714285714231);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.021428571428571467);
      value[ID::decay0 + 1]->setFromNormalized(0.0);
      value[ID::decay0 + 2]->setFromNormalized(0.0);
      value[ID::decay0 + 3]->setFromNormalized(0.0714285714285714);
      value[ID::decay0 + 4]->setFromNormalized(0.33571428571428574);
      value[ID::decay0 + 5]->setFromNormalized(0.4714285714285714);
      value[ID::decay0 + 6]->setFromNormalized(0.6142857142857143);
      value[ID::decay0 + 7]->setFromNormalized(0.7142857142857143);
      value[ID::decay0 + 8]->setFromNormalized(0.15000000000000002);
      value[ID::decay0 + 9]->setFromNormalized(0.0);
      value[ID::decay0 + 10]->setFromNormalized(0.0);
      value[ID::decay0 + 11]->setFromNormalized(0.0);
      value[ID::decay0 + 12]->setFromNormalized(0.0);
      value[ID::decay0 + 13]->setFromNormalized(0.0);
      value[ID::decay0 + 14]->setFromNormalized(0.0);
      value[ID::decay0 + 15]->setFromNormalized(0.0);
      value[ID::decay0 + 16]->setFromNormalized(0.0904017857142857);
      value[ID::decay0 + 17]->setFromNormalized(0.07857142857142864);
      value[ID::decay0 + 18]->setFromNormalized(0.18571428571428572);
      value[ID::decay0 + 19]->setFromNormalized(0.34285714285714286);
      value[ID::decay0 + 20]->setFromNormalized(0.44999999999999996);
      value[ID::decay0 + 21]->setFromNormalized(0.5714285714285714);
      value[ID::decay0 + 22]->setFromNormalized(0.7357142857142858);
      value[ID::decay0 + 23]->setFromNormalized(0.4714285714285714);
      value[ID::decay0 + 24]->setFromNormalized(0.27142857142857146);
      value[ID::decay0 + 25]->setFromNormalized(0.014285714285714237);
      value[ID::decay0 + 26]->setFromNormalized(0.0);
      value[ID::decay0 + 27]->setFromNormalized(0.014285714285714237);
      value[ID::decay0 + 28]->setFromNormalized(0.15000000000000002);
      value[ID::decay0 + 29]->setFromNormalized(0.3214285714285714);
      value[ID::decay0 + 30]->setFromNormalized(0.40714285714285714);
      value[ID::decay0 + 31]->setFromNormalized(0.5142857142857142);
      value[ID::decay0 + 32]->setFromNormalized(0.5785714285714285);
      value[ID::decay0 + 33]->setFromNormalized(0.7714285714285715);
      value[ID::decay0 + 34]->setFromNormalized(0.6071428571428572);
      value[ID::decay0 + 35]->setFromNormalized(0.3857142857142857);
      value[ID::decay0 + 36]->setFromNormalized(0.1785714285714286);
      value[ID::decay0 + 37]->setFromNormalized(0.035714285714285705);
      value[ID::decay0 + 38]->setFromNormalized(0.13571428571428568);
      value[ID::decay0 + 39]->setFromNormalized(0.25);
      value[ID::decay0 + 40]->setFromNormalized(0.4712508610316686);
      value[ID::decay0 + 41]->setFromNormalized(0.4714285714285714);
      value[ID::decay0 + 42]->setFromNormalized(0.5428571428571429);
      value[ID::decay0 + 43]->setFromNormalized(0.65);
      value[ID::decay0 + 44]->setFromNormalized(0.7357142857142858);
      value[ID::decay0 + 45]->setFromNormalized(0.9);
      value[ID::decay0 + 46]->setFromNormalized(0.8214285714285714);
      value[ID::decay0 + 47]->setFromNormalized(0.7214285714285714);
      value[ID::decay0 + 48]->setFromNormalized(0.6);
      value[ID::decay0 + 49]->setFromNormalized(0.5142857142857142);
      value[ID::decay0 + 50]->setFromNormalized(0.40714285714285714);
      value[ID::decay0 + 51]->setFromNormalized(0.34285714285714286);
      value[ID::decay0 + 52]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 53]->setFromNormalized(0.11428571428571434);
      value[ID::decay0 + 54]->setFromNormalized(0.0642857142857143);
      value[ID::decay0 + 55]->setFromNormalized(0.014285714285714237);
      value[ID::decay0 + 56]->setFromNormalized(0.12142857142857146);
      value[ID::decay0 + 57]->setFromNormalized(0.20714285714285718);
      value[ID::decay0 + 58]->setFromNormalized(0.3285714285714286);
      value[ID::decay0 + 59]->setFromNormalized(0.3642857142857143);
      value[ID::decay0 + 60]->setFromNormalized(0.41428571428571426);
      value[ID::decay0 + 61]->setFromNormalized(0.5071428571428571);
      value[ID::decay0 + 62]->setFromNormalized(0.6214285714285714);
      value[ID::decay0 + 63]->setFromNormalized(0.6785714285714286);
      value[ID::overtone0 + 0]->setFromNormalized(0.06428571428571424);
      value[ID::overtone0 + 1]->setFromNormalized(0.0);
      value[ID::overtone0 + 2]->setFromNormalized(0.0);
      value[ID::overtone0 + 3]->setFromNormalized(0.3285714285714286);
      value[ID::overtone0 + 4]->setFromNormalized(0.3571428571428571);
      value[ID::overtone0 + 5]->setFromNormalized(0.34285714285714286);
      value[ID::overtone0 + 6]->setFromNormalized(0.31428571428571417);
      value[ID::overtone0 + 7]->setFromNormalized(0.2928571428571427);
      value[ID::overtone0 + 8]->setFromNormalized(0.25);
      value[ID::overtone0 + 9]->setFromNormalized(0.22142857142857145);
      value[ID::overtone0 + 10]->setFromNormalized(0.17857142857142866);
      value[ID::overtone0 + 11]->setFromNormalized(0.17857142857142866);
      value[ID::overtone0 + 12]->setFromNormalized(0.01883664812360486);
      value[ID::overtone0 + 13]->setFromNormalized(0.03600256783621649);
      value[ID::overtone0 + 14]->setFromNormalized(0.05316848754882812);
      value[ID::overtone0 + 15]->setFromNormalized(0.07033440726143976);
      value[ID::overtone0 + 16]->setFromNormalized(0.08750032697405138);
      value[ID::overtone0 + 17]->setFromNormalized(0.10466624668666284);
      value[ID::overtone0 + 18]->setFromNormalized(0.12183216639927448);
      value[ID::overtone0 + 19]->setFromNormalized(0.1389980861118861);
      value[ID::overtone0 + 20]->setFromNormalized(0.15616400582449774);
      value[ID::overtone0 + 21]->setFromNormalized(0.17332992553710938);
      value[ID::overtone0 + 22]->setFromNormalized(0.19049584524972102);
      value[ID::overtone0 + 23]->setFromNormalized(0.20766176496233246);
      value[ID::overtone0 + 24]->setFromNormalized(0.22482768467494418);
      value[ID::overtone0 + 25]->setFromNormalized(0.24199360438755582);
      value[ID::overtone0 + 26]->setFromNormalized(0.2591595241001673);
      value[ID::overtone0 + 27]->setFromNormalized(0.2763254438127789);
      value[ID::overtone0 + 28]->setFromNormalized(0.2934913635253906);
      value[ID::overtone0 + 29]->setFromNormalized(0.31065728323800224);
      value[ID::overtone0 + 30]->setFromNormalized(0.3278232029506139);
      value[ID::overtone0 + 31]->setFromNormalized(0.34498912266322534);
      value[ID::overtone0 + 32]->setFromNormalized(0.36215504237583707);
      value[ID::overtone0 + 33]->setFromNormalized(0.3793209620884487);
      value[ID::overtone0 + 34]->setFromNormalized(0.3964868818010602);
      value[ID::overtone0 + 35]->setFromNormalized(0.4136528015136719);
      value[ID::overtone0 + 36]->setFromNormalized(0.4308187212262835);
      value[ID::overtone0 + 37]->setFromNormalized(0.4479846409388951);
      value[ID::overtone0 + 38]->setFromNormalized(0.4651505606515068);
      value[ID::overtone0 + 39]->setFromNormalized(0.48231648036411834);
      value[ID::overtone0 + 40]->setFromNormalized(0.49948240007672995);
      value[ID::overtone0 + 41]->setFromNormalized(0.5166483197893414);
      value[ID::overtone0 + 42]->setFromNormalized(0.5338142395019532);
      value[ID::overtone0 + 43]->setFromNormalized(0.5509801592145647);
      value[ID::overtone0 + 44]->setFromNormalized(0.5681460516793387);
      value[ID::overtone0 + 45]->setFromNormalized(0.5853119441441128);
      value[ID::overtone0 + 46]->setFromNormalized(0.6024778366088868);
      value[ID::overtone0 + 47]->setFromNormalized(0.6196437290736607);
      value[ID::overtone0 + 48]->setFromNormalized(0.6368096215384347);
      value[ID::overtone0 + 49]->setFromNormalized(0.6539755140032086);
      value[ID::overtone0 + 50]->setFromNormalized(0.6711414064679827);
      value[ID::overtone0 + 51]->setFromNormalized(0.6883072989327568);
      value[ID::overtone0 + 52]->setFromNormalized(0.7054731913975307);
      value[ID::overtone0 + 53]->setFromNormalized(0.7226390838623047);
      value[ID::overtone0 + 54]->setFromNormalized(0.7398049763270786);
      value[ID::overtone0 + 55]->setFromNormalized(0.7569708687918527);
      value[ID::overtone0 + 56]->setFromNormalized(0.7741367476327079);
      value[ID::overtone0 + 57]->setFromNormalized(0.7913026400974819);
      value[ID::overtone0 + 58]->setFromNormalized(0.8084685325622558);
      value[ID::overtone0 + 59]->setFromNormalized(0.8256344250270299);
      value[ID::overtone0 + 60]->setFromNormalized(0.8428003174918037);
      value[ID::overtone0 + 61]->setFromNormalized(0.859966209956578);
      value[ID::overtone0 + 62]->setFromNormalized(0.8771321024213519);
      value[ID::overtone0 + 63]->setFromNormalized(0.8857142857142858);
      value[ID::saturation0 + 0]->setFromNormalized(0.5914189915034549);
      value[ID::saturation0 + 1]->setFromNormalized(0.5664635864645727);
      value[ID::saturation0 + 2]->setFromNormalized(0.9104702003056846);
      value[ID::saturation0 + 3]->setFromNormalized(0.2696594581667282);
      value[ID::saturation0 + 4]->setFromNormalized(0.629335102462605);
      value[ID::saturation0 + 5]->setFromNormalized(0.1663739482621849);
      value[ID::saturation0 + 6]->setFromNormalized(0.18044883826221744);
      value[ID::saturation0 + 7]->setFromNormalized(0.17152970808665488);
      value[ID::saturation0 + 8]->setFromNormalized(0.8922070995652307);
      value[ID::saturation0 + 9]->setFromNormalized(0.06142784012088196);
      value[ID::saturation0 + 10]->setFromNormalized(0.7177005090398673);
      value[ID::saturation0 + 11]->setFromNormalized(0.007601092278871333);
      value[ID::saturation0 + 12]->setFromNormalized(0.9209332970506156);
      value[ID::saturation0 + 13]->setFromNormalized(0.2446806393335284);
      value[ID::saturation0 + 14]->setFromNormalized(0.13440442224140609);
      value[ID::saturation0 + 15]->setFromNormalized(0.6176437692933889);
      value[ID::saturation0 + 16]->setFromNormalized(0.9453700216753789);
      value[ID::saturation0 + 17]->setFromNormalized(0.5179443369541423);
      value[ID::saturation0 + 18]->setFromNormalized(0.732484807892713);
      value[ID::saturation0 + 19]->setFromNormalized(0.955927992002375);
      value[ID::saturation0 + 20]->setFromNormalized(0.36652149484639784);
      value[ID::saturation0 + 21]->setFromNormalized(0.9374249350811925);
      value[ID::saturation0 + 22]->setFromNormalized(0.0121838035422894);
      value[ID::saturation0 + 23]->setFromNormalized(0.9618288527039796);
      value[ID::saturation0 + 24]->setFromNormalized(0.5858199291439198);
      value[ID::saturation0 + 25]->setFromNormalized(0.40125328110684816);
      value[ID::saturation0 + 26]->setFromNormalized(0.8889575925191008);
      value[ID::saturation0 + 27]->setFromNormalized(0.7825064116348424);
      value[ID::saturation0 + 28]->setFromNormalized(0.30466304935907973);
      value[ID::saturation0 + 29]->setFromNormalized(0.057017651125357345);
      value[ID::saturation0 + 30]->setFromNormalized(0.8398917835407516);
      value[ID::saturation0 + 31]->setFromNormalized(0.029197570047148878);
      value[ID::saturation0 + 32]->setFromNormalized(0.9416792181201791);
      value[ID::saturation0 + 33]->setFromNormalized(0.28462258092559184);
      value[ID::saturation0 + 34]->setFromNormalized(0.7466669975043446);
      value[ID::saturation0 + 35]->setFromNormalized(0.8720361718014187);
      value[ID::saturation0 + 36]->setFromNormalized(0.2670547251320909);
      value[ID::saturation0 + 37]->setFromNormalized(0.5381868638289407);
      value[ID::saturation0 + 38]->setFromNormalized(0.12417945716216185);
      value[ID::saturation0 + 39]->setFromNormalized(0.822026058004704);
      value[ID::saturation0 + 40]->setFromNormalized(0.23562409790619326);
      value[ID::saturation0 + 41]->setFromNormalized(0.9034895973893994);
      value[ID::saturation0 + 42]->setFromNormalized(0.4170677564382637);
      value[ID::saturation0 + 43]->setFromNormalized(0.9430286666328824);
      value[ID::saturation0 + 44]->setFromNormalized(0.40891020408821754);
      value[ID::saturation0 + 45]->setFromNormalized(0.09123920310034732);
      value[ID::saturation0 + 46]->setFromNormalized(0.11715157831739988);
      value[ID::saturation0 + 47]->setFromNormalized(0.3676653731270992);
      value[ID::saturation0 + 48]->setFromNormalized(0.25646490105535746);
      value[ID::saturation0 + 49]->setFromNormalized(0.5467101276947499);
      value[ID::saturation0 + 50]->setFromNormalized(0.1281798164202661);
      value[ID::saturation0 + 51]->setFromNormalized(0.1716880816611616);
      value[ID::saturation0 + 52]->setFromNormalized(0.4195705563691751);
      value[ID::saturation0 + 53]->setFromNormalized(0.15852894486886748);
      value[ID::saturation0 + 54]->setFromNormalized(0.7062059456530333);
      value[ID::saturation0 + 55]->setFromNormalized(0.19124043501431987);
      value[ID::saturation0 + 56]->setFromNormalized(0.2456686851780786);
      value[ID::saturation0 + 57]->setFromNormalized(0.9862777614746614);
      value[ID::saturation0 + 58]->setFromNormalized(0.616672083775061);
      value[ID::saturation0 + 59]->setFromNormalized(0.6441037412366558);
      value[ID::saturation0 + 60]->setFromNormalized(0.7946963700812018);
      value[ID::saturation0 + 61]->setFromNormalized(0.020659083683799186);
      value[ID::saturation0 + 62]->setFromNormalized(0.6835549866518948);
      value[ID::saturation0 + 63]->setFromNormalized(0.43100353649512624);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.23800000548362732);
      value[ID::pitchMultiply]->setFromNormalized(0.017999999225139618);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.4599999785423279);
      value[ID::randomDecay]->setFromNormalized(0.18799997866153717);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.20000003278255463);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.23799994587898254);
      value[ID::attackMultiplier]->setFromNormalized(0.6120001077651978);
      value[ID::decayMultiplier]->setFromNormalized(0.9200000762939453);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(0.0);
      value[ID::phaserMix]->setFromNormalized(0.9960000514984131);
      value[ID::phaserFrequency]->setFromNormalized(0.9040002226829529);
      value[ID::phaserFeedback]->setFromNormalized(0.8959999680519104);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.6400001049041748);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetAround9: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.0);
      value[ID::attack0 + 6]->setFromNormalized(0.07857142857142858);
      value[ID::attack0 + 7]->setFromNormalized(0.09999999999999994);
      value[ID::attack0 + 8]->setFromNormalized(0.22142857142857134);
      value[ID::attack0 + 9]->setFromNormalized(0.95);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.33571428571428574);
      value[ID::attack0 + 12]->setFromNormalized(0.24999999999999992);
      value[ID::attack0 + 13]->setFromNormalized(0.16428571428571417);
      value[ID::attack0 + 14]->setFromNormalized(0.1214285714285714);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.04999999999999995);
      value[ID::attack0 + 17]->setFromNormalized(0.05695484706333699);
      value[ID::attack0 + 18]->setFromNormalized(0.07086465018136137);
      value[ID::attack0 + 19]->setFromNormalized(0.08477445329938596);
      value[ID::attack0 + 20]->setFromNormalized(0.09868425641741055);
      value[ID::attack0 + 21]->setFromNormalized(0.11259400503975983);
      value[ID::attack0 + 22]->setFromNormalized(0.12650375366210936);
      value[ID::attack0 + 23]->setFromNormalized(0.14041350228445865);
      value[ID::attack0 + 24]->setFromNormalized(0.1543232509068076);
      value[ID::attack0 + 25]->setFromNormalized(0.16823299952915732);
      value[ID::attack0 + 26]->setFromNormalized(0.18214274815150627);
      value[ID::attack0 + 27]->setFromNormalized(0.19605249677385567);
      value[ID::attack0 + 28]->setFromNormalized(0.20996224539620495);
      value[ID::attack0 + 29]->setFromNormalized(0.22387199401855434);
      value[ID::attack0 + 30]->setFromNormalized(0.23778174264090363);
      value[ID::attack0 + 31]->setFromNormalized(0.2516914912632533);
      value[ID::attack0 + 32]->setFromNormalized(0.2656012398856027);
      value[ID::attack0 + 33]->setFromNormalized(0.279510988507952);
      value[ID::attack0 + 34]->setFromNormalized(0.29342073713030137);
      value[ID::attack0 + 35]->setFromNormalized(0.30733048575265065);
      value[ID::attack0 + 36]->setFromNormalized(0.3142857142857143);
      value[ID::attack0 + 37]->setFromNormalized(0.30892857142857144);
      value[ID::attack0 + 38]->setFromNormalized(0.29821428571428577);
      value[ID::attack0 + 39]->setFromNormalized(0.2875);
      value[ID::attack0 + 40]->setFromNormalized(0.2767857142857143);
      value[ID::attack0 + 41]->setFromNormalized(0.2660714285714286);
      value[ID::attack0 + 42]->setFromNormalized(0.25535714285714284);
      value[ID::attack0 + 43]->setFromNormalized(0.24464285714285677);
      value[ID::attack0 + 44]->setFromNormalized(0.23392857142857099);
      value[ID::attack0 + 45]->setFromNormalized(0.2232142857142853);
      value[ID::attack0 + 46]->setFromNormalized(0.21249999999999963);
      value[ID::attack0 + 47]->setFromNormalized(0.20178571428571385);
      value[ID::attack0 + 48]->setFromNormalized(0.19107142857142817);
      value[ID::attack0 + 49]->setFromNormalized(0.1803571428571425);
      value[ID::attack0 + 50]->setFromNormalized(0.1696428571428567);
      value[ID::attack0 + 51]->setFromNormalized(0.15892857142857103);
      value[ID::attack0 + 52]->setFromNormalized(0.14821428571428544);
      value[ID::attack0 + 53]->setFromNormalized(0.13749999999999984);
      value[ID::attack0 + 54]->setFromNormalized(0.1267857142857142);
      value[ID::attack0 + 55]->setFromNormalized(0.11607142857142841);
      value[ID::attack0 + 56]->setFromNormalized(0.10535714285714262);
      value[ID::attack0 + 57]->setFromNormalized(0.09464285714285695);
      value[ID::attack0 + 58]->setFromNormalized(0.08392857142857127);
      value[ID::attack0 + 59]->setFromNormalized(0.07321428571428548);
      value[ID::attack0 + 60]->setFromNormalized(0.0624999999999999);
      value[ID::attack0 + 61]->setFromNormalized(0.05178571428571423);
      value[ID::attack0 + 62]->setFromNormalized(0.04107142857142844);
      value[ID::attack0 + 63]->setFromNormalized(0.0357142857142856);
      value[ID::decay0 + 0]->setFromNormalized(0.9857142857142858);
      value[ID::decay0 + 1]->setFromNormalized(0.2571428571428571);
      value[ID::decay0 + 2]->setFromNormalized(0.25562062944684705);
      value[ID::decay0 + 3]->setFromNormalized(0.2525761195591518);
      value[ID::decay0 + 4]->setFromNormalized(0.2495316096714565);
      value[ID::decay0 + 5]->setFromNormalized(0.24648709978376115);
      value[ID::decay0 + 6]->setFromNormalized(0.3642857142857143);
      value[ID::decay0 + 7]->setFromNormalized(0.7428571428571429);
      value[ID::decay0 + 8]->setFromNormalized(0.9642857142857143);
      value[ID::decay0 + 9]->setFromNormalized(0.85);
      value[ID::decay0 + 10]->setFromNormalized(0.2312645503452846);
      value[ID::decay0 + 11]->setFromNormalized(0.22822004045758926);
      value[ID::decay0 + 12]->setFromNormalized(0.22517553056989395);
      value[ID::decay0 + 13]->setFromNormalized(0.22213102068219873);
      value[ID::decay0 + 14]->setFromNormalized(0.21908651079450336);
      value[ID::decay0 + 15]->setFromNormalized(0.21604200090680803);
      value[ID::decay0 + 16]->setFromNormalized(0.2129974910191127);
      value[ID::decay0 + 17]->setFromNormalized(0.20995298113141736);
      value[ID::decay0 + 18]->setFromNormalized(0.20690847124372214);
      value[ID::decay0 + 19]->setFromNormalized(0.2038639613560272);
      value[ID::decay0 + 20]->setFromNormalized(0.20081945146833163);
      value[ID::decay0 + 21]->setFromNormalized(0.19777494158063613);
      value[ID::decay0 + 22]->setFromNormalized(0.19473043169294083);
      value[ID::decay0 + 23]->setFromNormalized(0.19168592180524557);
      value[ID::decay0 + 24]->setFromNormalized(0.18864141191755024);
      value[ID::decay0 + 25]->setFromNormalized(0.1855969020298549);
      value[ID::decay0 + 26]->setFromNormalized(0.18255239214215957);
      value[ID::decay0 + 27]->setFromNormalized(0.17950788225446423);
      value[ID::decay0 + 28]->setFromNormalized(0.176463372366769);
      value[ID::decay0 + 29]->setFromNormalized(0.17341886247907373);
      value[ID::decay0 + 30]->setFromNormalized(0.17037435259137837);
      value[ID::decay0 + 31]->setFromNormalized(0.167329842703683);
      value[ID::decay0 + 32]->setFromNormalized(0.16428533281598767);
      value[ID::decay0 + 33]->setFromNormalized(0.16124082292829245);
      value[ID::decay0 + 34]->setFromNormalized(0.15819631304059711);
      value[ID::decay0 + 35]->setFromNormalized(0.15515180315290178);
      value[ID::decay0 + 36]->setFromNormalized(0.15210729326520644);
      value[ID::decay0 + 37]->setFromNormalized(0.1490627833775111);
      value[ID::decay0 + 38]->setFromNormalized(0.1460182734898159);
      value[ID::decay0 + 39]->setFromNormalized(0.14297376360212055);
      value[ID::decay0 + 40]->setFromNormalized(0.13992925371442522);
      value[ID::decay0 + 41]->setFromNormalized(0.13688474382672988);
      value[ID::decay0 + 42]->setFromNormalized(0.13384023393903455);
      value[ID::decay0 + 43]->setFromNormalized(0.13079572405133932);
      value[ID::decay0 + 44]->setFromNormalized(0.127751214163644);
      value[ID::decay0 + 45]->setFromNormalized(0.12470670427594885);
      value[ID::decay0 + 46]->setFromNormalized(0.12166219438825351);
      value[ID::decay0 + 47]->setFromNormalized(0.11861768450055814);
      value[ID::decay0 + 48]->setFromNormalized(0.11557317461286278);
      value[ID::decay0 + 49]->setFromNormalized(0.11252866472516743);
      value[ID::decay0 + 50]->setFromNormalized(0.10948415483747213);
      value[ID::decay0 + 51]->setFromNormalized(0.10643964494977676);
      value[ID::decay0 + 52]->setFromNormalized(0.10339513506208156);
      value[ID::decay0 + 53]->setFromNormalized(0.1003506251743862);
      value[ID::decay0 + 54]->setFromNormalized(0.09730611528669088);
      value[ID::decay0 + 55]->setFromNormalized(0.09426160539899553);
      value[ID::decay0 + 56]->setFromNormalized(0.09121709551130024);
      value[ID::decay0 + 57]->setFromNormalized(0.08817258562360505);
      value[ID::decay0 + 58]->setFromNormalized(0.08512802124023437);
      value[ID::decay0 + 59]->setFromNormalized(0.0820835658482143);
      value[ID::decay0 + 60]->setFromNormalized(0.07903911045619418);
      value[ID::decay0 + 61]->setFromNormalized(0.07599465506417415);
      value[ID::decay0 + 62]->setFromNormalized(0.07295019967215406);
      value[ID::decay0 + 63]->setFromNormalized(0.0714285714285714);
      value[ID::overtone0 + 0]->setFromNormalized(1.0);
      value[ID::overtone0 + 1]->setFromNormalized(0.1);
      value[ID::overtone0 + 2]->setFromNormalized(0.09918033054896772);
      value[ID::overtone0 + 3]->setFromNormalized(0.09754099164690296);
      value[ID::overtone0 + 4]->setFromNormalized(0.27142857142857135);
      value[ID::overtone0 + 5]->setFromNormalized(0.40714285714285714);
      value[ID::overtone0 + 6]->setFromNormalized(0.7142857142857143);
      value[ID::overtone0 + 7]->setFromNormalized(0.9428571428571428);
      value[ID::overtone0 + 8]->setFromNormalized(0.8357142857142857);
      value[ID::overtone0 + 9]->setFromNormalized(0.85);
      value[ID::overtone0 + 10]->setFromNormalized(0.08606561933244983);
      value[ID::overtone0 + 11]->setFromNormalized(0.0844262259347099);
      value[ID::overtone0 + 12]->setFromNormalized(0.08278688703264514);
      value[ID::overtone0 + 13]->setFromNormalized(0.08114754813058038);
      value[ID::overtone0 + 14]->setFromNormalized(0.07950820922851562);
      value[ID::overtone0 + 15]->setFromNormalized(0.07786887032645087);
      value[ID::overtone0 + 16]->setFromNormalized(0.1);
      value[ID::overtone0 + 17]->setFromNormalized(0.10625);
      value[ID::overtone0 + 18]->setFromNormalized(0.11875);
      value[ID::overtone0 + 19]->setFromNormalized(0.13125);
      value[ID::overtone0 + 20]->setFromNormalized(0.14375);
      value[ID::overtone0 + 21]->setFromNormalized(0.15625);
      value[ID::overtone0 + 22]->setFromNormalized(0.16875);
      value[ID::overtone0 + 23]->setFromNormalized(0.18125);
      value[ID::overtone0 + 24]->setFromNormalized(0.19375);
      value[ID::overtone0 + 25]->setFromNormalized(0.20624999999999982);
      value[ID::overtone0 + 26]->setFromNormalized(0.21875);
      value[ID::overtone0 + 27]->setFromNormalized(0.23125);
      value[ID::overtone0 + 28]->setFromNormalized(0.2437499999999999);
      value[ID::overtone0 + 29]->setFromNormalized(0.25625);
      value[ID::overtone0 + 30]->setFromNormalized(0.2687499999999998);
      value[ID::overtone0 + 31]->setFromNormalized(0.28125);
      value[ID::overtone0 + 32]->setFromNormalized(0.29375);
      value[ID::overtone0 + 33]->setFromNormalized(0.2999999999999998);
      value[ID::overtone0 + 34]->setFromNormalized(0.29261905125209253);
      value[ID::overtone0 + 35]->setFromNormalized(0.27785715375627795);
      value[ID::overtone0 + 36]->setFromNormalized(0.2630952562604632);
      value[ID::overtone0 + 37]->setFromNormalized(0.24833335876464835);
      value[ID::overtone0 + 38]->setFromNormalized(0.23357146126883369);
      value[ID::overtone0 + 39]->setFromNormalized(0.21880956377301874);
      value[ID::overtone0 + 40]->setFromNormalized(0.20404766627720416);
      value[ID::overtone0 + 41]->setFromNormalized(0.18928576878138942);
      value[ID::overtone0 + 42]->setFromNormalized(0.17452387128557484);
      value[ID::overtone0 + 43]->setFromNormalized(0.1597619737897599);
      value[ID::overtone0 + 44]->setFromNormalized(0.14500007629394532);
      value[ID::overtone0 + 45]->setFromNormalized(0.13023817879813054);
      value[ID::overtone0 + 46]->setFromNormalized(0.1154762813023158);
      value[ID::overtone0 + 47]->setFromNormalized(0.10071438380650104);
      value[ID::overtone0 + 48]->setFromNormalized(0.08595248631068646);
      value[ID::overtone0 + 49]->setFromNormalized(0.07857142857142865);
      value[ID::overtone0 + 50]->setFromNormalized(0.02049200875418524);
      value[ID::overtone0 + 51]->setFromNormalized(0.018852669852120484);
      value[ID::overtone0 + 52]->setFromNormalized(0.017213330950055904);
      value[ID::overtone0 + 53]->setFromNormalized(0.01557399204799097);
      value[ID::overtone0 + 54]->setFromNormalized(0.01393465314592639);
      value[ID::overtone0 + 55]->setFromNormalized(0.012295314243861455);
      value[ID::overtone0 + 56]->setFromNormalized(0.010655975341796875);
      value[ID::overtone0 + 57]->setFromNormalized(0.009016636439732117);
      value[ID::overtone0 + 58]->setFromNormalized(0.00737729753766736);
      value[ID::overtone0 + 59]->setFromNormalized(0.005737958635602602);
      value[ID::overtone0 + 60]->setFromNormalized(0.004098619733538022);
      value[ID::overtone0 + 61]->setFromNormalized(0.002459280831473265);
      value[ID::overtone0 + 62]->setFromNormalized(0.0008199419294085075);
      value[ID::overtone0 + 63]->setFromNormalized(0.0);
      value[ID::saturation0 + 0]->setFromNormalized(0.2428571428571428);
      value[ID::saturation0 + 1]->setFromNormalized(0.2928571428571428);
      value[ID::saturation0 + 2]->setFromNormalized(0.3214285714285714);
      value[ID::saturation0 + 3]->setFromNormalized(0.3928571428571429);
      value[ID::saturation0 + 4]->setFromNormalized(0.6071428571428572);
      value[ID::saturation0 + 5]->setFromNormalized(0.7);
      value[ID::saturation0 + 6]->setFromNormalized(0.6714285714285715);
      value[ID::saturation0 + 7]->setFromNormalized(0.5785714285714285);
      value[ID::saturation0 + 8]->setFromNormalized(0.457142857142857);
      value[ID::saturation0 + 9]->setFromNormalized(0.3357142857142857);
      value[ID::saturation0 + 10]->setFromNormalized(0.22142857142857136);
      value[ID::saturation0 + 11]->setFromNormalized(0.12857142857142853);
      value[ID::saturation0 + 12]->setFromNormalized(0.06428571428571424);
      value[ID::saturation0 + 13]->setFromNormalized(0.028571428571428564);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.5759999752044678);
      value[ID::randomFrequency]->setFromNormalized(0.22400012612342837);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.6240001320838928);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.16400018334388733);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.3744414150714874);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetAtCs5: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.02193875994001115);
      value[ID::attack0 + 4]->setFromNormalized(0.0964286259242466);
      value[ID::attack0 + 5]->setFromNormalized(0.17091843741280685);
      value[ID::attack0 + 6]->setFromNormalized(0.24540824890136712);
      value[ID::attack0 + 7]->setFromNormalized(0.3198980603899274);
      value[ID::attack0 + 8]->setFromNormalized(0.3571428571428571);
      value[ID::attack0 + 9]->setFromNormalized(0.44285714285714284);
      value[ID::attack0 + 10]->setFromNormalized(0.35);
      value[ID::attack0 + 11]->setFromNormalized(0.2285714285714285);
      value[ID::attack0 + 12]->setFromNormalized(0.12142857142857143);
      value[ID::attack0 + 13]->setFromNormalized(0.057142857142857155);
      value[ID::attack0 + 14]->setFromNormalized(0.02142857142857146);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.0);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.03571428571428569);
      value[ID::attack0 + 22]->setFromNormalized(0.09285714285714285);
      value[ID::attack0 + 23]->setFromNormalized(0.17142857142857135);
      value[ID::attack0 + 24]->setFromNormalized(0.27142857142857146);
      value[ID::attack0 + 25]->setFromNormalized(0.44999999999999996);
      value[ID::attack0 + 26]->setFromNormalized(0.3928571428571429);
      value[ID::attack0 + 27]->setFromNormalized(0.3571428571428571);
      value[ID::attack0 + 28]->setFromNormalized(0.30714285714285716);
      value[ID::attack0 + 29]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 30]->setFromNormalized(0.2571428571428571);
      value[ID::attack0 + 31]->setFromNormalized(0.2571428571428571);
      value[ID::attack0 + 32]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 33]->setFromNormalized(0.21428571428571427);
      value[ID::attack0 + 34]->setFromNormalized(0.15);
      value[ID::attack0 + 35]->setFromNormalized(0.07142857142857138);
      value[ID::attack0 + 36]->setFromNormalized(0.0);
      value[ID::attack0 + 37]->setFromNormalized(0.0);
      value[ID::attack0 + 38]->setFromNormalized(0.0);
      value[ID::attack0 + 39]->setFromNormalized(0.0);
      value[ID::attack0 + 40]->setFromNormalized(0.0);
      value[ID::attack0 + 41]->setFromNormalized(0.0);
      value[ID::attack0 + 42]->setFromNormalized(0.0);
      value[ID::attack0 + 43]->setFromNormalized(0.0);
      value[ID::attack0 + 44]->setFromNormalized(0.0);
      value[ID::attack0 + 45]->setFromNormalized(0.0);
      value[ID::attack0 + 46]->setFromNormalized(0.0);
      value[ID::attack0 + 47]->setFromNormalized(0.0);
      value[ID::attack0 + 48]->setFromNormalized(0.0);
      value[ID::attack0 + 49]->setFromNormalized(0.0);
      value[ID::attack0 + 50]->setFromNormalized(0.0);
      value[ID::attack0 + 51]->setFromNormalized(0.0);
      value[ID::attack0 + 52]->setFromNormalized(0.0);
      value[ID::attack0 + 53]->setFromNormalized(0.0);
      value[ID::attack0 + 54]->setFromNormalized(0.0);
      value[ID::attack0 + 55]->setFromNormalized(0.0);
      value[ID::attack0 + 56]->setFromNormalized(0.0);
      value[ID::attack0 + 57]->setFromNormalized(0.0);
      value[ID::attack0 + 58]->setFromNormalized(0.0);
      value[ID::attack0 + 59]->setFromNormalized(0.0);
      value[ID::attack0 + 60]->setFromNormalized(0.0);
      value[ID::attack0 + 61]->setFromNormalized(0.0);
      value[ID::attack0 + 62]->setFromNormalized(0.0);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(1.0);
      value[ID::decay0 + 1]->setFromNormalized(1.0);
      value[ID::decay0 + 2]->setFromNormalized(1.0);
      value[ID::decay0 + 3]->setFromNormalized(1.0);
      value[ID::decay0 + 4]->setFromNormalized(1.0);
      value[ID::decay0 + 5]->setFromNormalized(1.0);
      value[ID::decay0 + 6]->setFromNormalized(1.0);
      value[ID::decay0 + 7]->setFromNormalized(1.0);
      value[ID::decay0 + 8]->setFromNormalized(1.0);
      value[ID::decay0 + 9]->setFromNormalized(1.0);
      value[ID::decay0 + 10]->setFromNormalized(1.0);
      value[ID::decay0 + 11]->setFromNormalized(1.0);
      value[ID::decay0 + 12]->setFromNormalized(1.0);
      value[ID::decay0 + 13]->setFromNormalized(1.0);
      value[ID::decay0 + 14]->setFromNormalized(1.0);
      value[ID::decay0 + 15]->setFromNormalized(1.0);
      value[ID::decay0 + 16]->setFromNormalized(1.0);
      value[ID::decay0 + 17]->setFromNormalized(1.0);
      value[ID::decay0 + 18]->setFromNormalized(1.0);
      value[ID::decay0 + 19]->setFromNormalized(1.0);
      value[ID::decay0 + 20]->setFromNormalized(1.0);
      value[ID::decay0 + 21]->setFromNormalized(1.0);
      value[ID::decay0 + 22]->setFromNormalized(1.0);
      value[ID::decay0 + 23]->setFromNormalized(1.0);
      value[ID::decay0 + 24]->setFromNormalized(1.0);
      value[ID::decay0 + 25]->setFromNormalized(1.0);
      value[ID::decay0 + 26]->setFromNormalized(1.0);
      value[ID::decay0 + 27]->setFromNormalized(1.0);
      value[ID::decay0 + 28]->setFromNormalized(1.0);
      value[ID::decay0 + 29]->setFromNormalized(1.0);
      value[ID::decay0 + 30]->setFromNormalized(1.0);
      value[ID::decay0 + 31]->setFromNormalized(1.0);
      value[ID::decay0 + 32]->setFromNormalized(1.0);
      value[ID::decay0 + 33]->setFromNormalized(1.0);
      value[ID::decay0 + 34]->setFromNormalized(1.0);
      value[ID::decay0 + 35]->setFromNormalized(1.0);
      value[ID::decay0 + 36]->setFromNormalized(1.0);
      value[ID::decay0 + 37]->setFromNormalized(1.0);
      value[ID::decay0 + 38]->setFromNormalized(1.0);
      value[ID::decay0 + 39]->setFromNormalized(1.0);
      value[ID::decay0 + 40]->setFromNormalized(1.0);
      value[ID::decay0 + 41]->setFromNormalized(1.0);
      value[ID::decay0 + 42]->setFromNormalized(1.0);
      value[ID::decay0 + 43]->setFromNormalized(1.0);
      value[ID::decay0 + 44]->setFromNormalized(1.0);
      value[ID::decay0 + 45]->setFromNormalized(1.0);
      value[ID::decay0 + 46]->setFromNormalized(1.0);
      value[ID::decay0 + 47]->setFromNormalized(1.0);
      value[ID::decay0 + 48]->setFromNormalized(1.0);
      value[ID::decay0 + 49]->setFromNormalized(1.0);
      value[ID::decay0 + 50]->setFromNormalized(1.0);
      value[ID::decay0 + 51]->setFromNormalized(1.0);
      value[ID::decay0 + 52]->setFromNormalized(1.0);
      value[ID::decay0 + 53]->setFromNormalized(1.0);
      value[ID::decay0 + 54]->setFromNormalized(1.0);
      value[ID::decay0 + 55]->setFromNormalized(1.0);
      value[ID::decay0 + 56]->setFromNormalized(1.0);
      value[ID::decay0 + 57]->setFromNormalized(1.0);
      value[ID::decay0 + 58]->setFromNormalized(1.0);
      value[ID::decay0 + 59]->setFromNormalized(1.0);
      value[ID::decay0 + 60]->setFromNormalized(1.0);
      value[ID::decay0 + 61]->setFromNormalized(1.0);
      value[ID::decay0 + 62]->setFromNormalized(1.0);
      value[ID::decay0 + 63]->setFromNormalized(1.0);
      value[ID::overtone0 + 0]->setFromNormalized(1.0);
      value[ID::overtone0 + 1]->setFromNormalized(1.0);
      value[ID::overtone0 + 2]->setFromNormalized(1.0);
      value[ID::overtone0 + 3]->setFromNormalized(1.0);
      value[ID::overtone0 + 4]->setFromNormalized(1.0);
      value[ID::overtone0 + 5]->setFromNormalized(0.8714285714285716);
      value[ID::overtone0 + 6]->setFromNormalized(0.7571428571428571);
      value[ID::overtone0 + 7]->setFromNormalized(0.65);
      value[ID::overtone0 + 8]->setFromNormalized(0.55);
      value[ID::overtone0 + 9]->setFromNormalized(0.4714285714285714);
      value[ID::overtone0 + 10]->setFromNormalized(0.41428571428571426);
      value[ID::overtone0 + 11]->setFromNormalized(0.3857142857142857);
      value[ID::overtone0 + 12]->setFromNormalized(0.37857142857142856);
      value[ID::overtone0 + 13]->setFromNormalized(0.3767142704554967);
      value[ID::overtone0 + 14]->setFromNormalized(0.37300000871930805);
      value[ID::overtone0 + 15]->setFromNormalized(0.36928574698311945);
      value[ID::overtone0 + 16]->setFromNormalized(0.3655714852469307);
      value[ID::overtone0 + 17]->setFromNormalized(0.3618572235107421);
      value[ID::overtone0 + 18]->setFromNormalized(0.3581429617745536);
      value[ID::overtone0 + 19]->setFromNormalized(0.3544287000383649);
      value[ID::overtone0 + 20]->setFromNormalized(0.3507144383021763);
      value[ID::overtone0 + 21]->setFromNormalized(0.3470001765659876);
      value[ID::overtone0 + 22]->setFromNormalized(0.34328591482979914);
      value[ID::overtone0 + 23]->setFromNormalized(0.3395716530936105);
      value[ID::overtone0 + 24]->setFromNormalized(0.3358573913574219);
      value[ID::overtone0 + 25]->setFromNormalized(0.33214312962123316);
      value[ID::overtone0 + 26]->setFromNormalized(0.32842886788504455);
      value[ID::overtone0 + 27]->setFromNormalized(0.32471460614885606);
      value[ID::overtone0 + 28]->setFromNormalized(0.32100034441266745);
      value[ID::overtone0 + 29]->setFromNormalized(0.31728608267647873);
      value[ID::overtone0 + 30]->setFromNormalized(0.31357182094029);
      value[ID::overtone0 + 31]->setFromNormalized(0.3098575592041016);
      value[ID::overtone0 + 32]->setFromNormalized(0.3061432974679129);
      value[ID::overtone0 + 33]->setFromNormalized(0.3024290357317243);
      value[ID::overtone0 + 34]->setFromNormalized(0.2987147739955356);
      value[ID::overtone0 + 35]->setFromNormalized(0.295000512259347);
      value[ID::overtone0 + 36]->setFromNormalized(0.2912862505231585);
      value[ID::overtone0 + 37]->setFromNormalized(0.2875719887869699);
      value[ID::overtone0 + 38]->setFromNormalized(0.28385772705078116);
      value[ID::overtone0 + 39]->setFromNormalized(0.2801434653145927);
      value[ID::overtone0 + 40]->setFromNormalized(0.27642920357840406);
      value[ID::overtone0 + 41]->setFromNormalized(0.27271494184221545);
      value[ID::overtone0 + 42]->setFromNormalized(0.26900068010602673);
      value[ID::overtone0 + 43]->setFromNormalized(0.265286418369838);
      value[ID::overtone0 + 44]->setFromNormalized(0.2615721566336494);
      value[ID::overtone0 + 45]->setFromNormalized(0.2578578948974609);
      value[ID::overtone0 + 46]->setFromNormalized(0.2541436331612723);
      value[ID::overtone0 + 47]->setFromNormalized(0.2504293714250836);
      value[ID::overtone0 + 48]->setFromNormalized(0.24671510968889515);
      value[ID::overtone0 + 49]->setFromNormalized(0.24300084795270652);
      value[ID::overtone0 + 50]->setFromNormalized(0.23928658621651788);
      value[ID::overtone0 + 51]->setFromNormalized(0.23557232448032916);
      value[ID::overtone0 + 52]->setFromNormalized(0.23185806274414053);
      value[ID::overtone0 + 53]->setFromNormalized(0.2281438010079521);
      value[ID::overtone0 + 54]->setFromNormalized(0.22442953927176337);
      value[ID::overtone0 + 55]->setFromNormalized(0.22071527753557474);
      value[ID::overtone0 + 56]->setFromNormalized(0.21700101579938602);
      value[ID::overtone0 + 57]->setFromNormalized(0.21328675406319758);
      value[ID::overtone0 + 58]->setFromNormalized(0.20957249232700895);
      value[ID::overtone0 + 59]->setFromNormalized(0.2058582305908203);
      value[ID::overtone0 + 60]->setFromNormalized(0.2021439688546316);
      value[ID::overtone0 + 61]->setFromNormalized(0.19842970711844304);
      value[ID::overtone0 + 62]->setFromNormalized(0.19471544538225452);
      value[ID::overtone0 + 63]->setFromNormalized(0.1928571428571429);
      value[ID::saturation0 + 0]->setFromNormalized(1.0);
      value[ID::saturation0 + 1]->setFromNormalized(1.0);
      value[ID::saturation0 + 2]->setFromNormalized(1.0);
      value[ID::saturation0 + 3]->setFromNormalized(1.0);
      value[ID::saturation0 + 4]->setFromNormalized(1.0);
      value[ID::saturation0 + 5]->setFromNormalized(1.0);
      value[ID::saturation0 + 6]->setFromNormalized(1.0);
      value[ID::saturation0 + 7]->setFromNormalized(1.0);
      value[ID::saturation0 + 8]->setFromNormalized(1.0);
      value[ID::saturation0 + 9]->setFromNormalized(1.0);
      value[ID::saturation0 + 10]->setFromNormalized(1.0);
      value[ID::saturation0 + 11]->setFromNormalized(1.0);
      value[ID::saturation0 + 12]->setFromNormalized(1.0);
      value[ID::saturation0 + 13]->setFromNormalized(1.0);
      value[ID::saturation0 + 14]->setFromNormalized(1.0);
      value[ID::saturation0 + 15]->setFromNormalized(1.0);
      value[ID::saturation0 + 16]->setFromNormalized(1.0);
      value[ID::saturation0 + 17]->setFromNormalized(1.0);
      value[ID::saturation0 + 18]->setFromNormalized(1.0);
      value[ID::saturation0 + 19]->setFromNormalized(1.0);
      value[ID::saturation0 + 20]->setFromNormalized(1.0);
      value[ID::saturation0 + 21]->setFromNormalized(1.0);
      value[ID::saturation0 + 22]->setFromNormalized(1.0);
      value[ID::saturation0 + 23]->setFromNormalized(1.0);
      value[ID::saturation0 + 24]->setFromNormalized(1.0);
      value[ID::saturation0 + 25]->setFromNormalized(1.0);
      value[ID::saturation0 + 26]->setFromNormalized(1.0);
      value[ID::saturation0 + 27]->setFromNormalized(1.0);
      value[ID::saturation0 + 28]->setFromNormalized(1.0);
      value[ID::saturation0 + 29]->setFromNormalized(1.0);
      value[ID::saturation0 + 30]->setFromNormalized(1.0);
      value[ID::saturation0 + 31]->setFromNormalized(1.0);
      value[ID::saturation0 + 32]->setFromNormalized(1.0);
      value[ID::saturation0 + 33]->setFromNormalized(1.0);
      value[ID::saturation0 + 34]->setFromNormalized(1.0);
      value[ID::saturation0 + 35]->setFromNormalized(1.0);
      value[ID::saturation0 + 36]->setFromNormalized(1.0);
      value[ID::saturation0 + 37]->setFromNormalized(1.0);
      value[ID::saturation0 + 38]->setFromNormalized(1.0);
      value[ID::saturation0 + 39]->setFromNormalized(1.0);
      value[ID::saturation0 + 40]->setFromNormalized(1.0);
      value[ID::saturation0 + 41]->setFromNormalized(1.0);
      value[ID::saturation0 + 42]->setFromNormalized(1.0);
      value[ID::saturation0 + 43]->setFromNormalized(1.0);
      value[ID::saturation0 + 44]->setFromNormalized(1.0);
      value[ID::saturation0 + 45]->setFromNormalized(1.0);
      value[ID::saturation0 + 46]->setFromNormalized(1.0);
      value[ID::saturation0 + 47]->setFromNormalized(1.0);
      value[ID::saturation0 + 48]->setFromNormalized(1.0);
      value[ID::saturation0 + 49]->setFromNormalized(1.0);
      value[ID::saturation0 + 50]->setFromNormalized(1.0);
      value[ID::saturation0 + 51]->setFromNormalized(1.0);
      value[ID::saturation0 + 52]->setFromNormalized(1.0);
      value[ID::saturation0 + 53]->setFromNormalized(1.0);
      value[ID::saturation0 + 54]->setFromNormalized(1.0);
      value[ID::saturation0 + 55]->setFromNormalized(1.0);
      value[ID::saturation0 + 56]->setFromNormalized(1.0);
      value[ID::saturation0 + 57]->setFromNormalized(1.0);
      value[ID::saturation0 + 58]->setFromNormalized(1.0);
      value[ID::saturation0 + 59]->setFromNormalized(1.0);
      value[ID::saturation0 + 60]->setFromNormalized(1.0);
      value[ID::saturation0 + 61]->setFromNormalized(1.0);
      value[ID::saturation0 + 62]->setFromNormalized(1.0);
      value[ID::saturation0 + 63]->setFromNormalized(1.0);
      value[ID::gain]->setFromNormalized(0.4600001871585846);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5120010375976562);
      value[ID::pitchMultiply]->setFromNormalized(0.2498124539852142);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.09600000828504564);
      value[ID::randomAttack]->setFromNormalized(0.28800004720687866);
      value[ID::randomDecay]->setFromNormalized(0.5720005035400391);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.9280000329017639);
      value[ID::overtoneExpand]->setFromNormalized(0.4000000059604645);
      value[ID::overtoneShift]->setFromNormalized(0.39399969577789307);
      value[ID::attackMultiplier]->setFromNormalized(0.07999997586011887);
      value[ID::decayMultiplier]->setFromNormalized(0.10000021755695343);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.6759999394416809);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.07999997586011887);
      value[ID::phaserFrequency]->setFromNormalized(1.0);
      value[ID::phaserFeedback]->setFromNormalized(0.5239995718002319);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(1.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(1.0);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.7880001068115234);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetBlur: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.014121308296814013);
      value[ID::attack0 + 1]->setFromNormalized(0.026920599982578446);
      value[ID::attack0 + 2]->setFromNormalized(0.040056638816795324);
      value[ID::attack0 + 3]->setFromNormalized(0.056316218770236286);
      value[ID::attack0 + 4]->setFromNormalized(0.07443039880919942);
      value[ID::attack0 + 5]->setFromNormalized(0.08560000985832726);
      value[ID::attack0 + 6]->setFromNormalized(0.09678289755299228);
      value[ID::attack0 + 7]->setFromNormalized(0.10499373129925248);
      value[ID::attack0 + 8]->setFromNormalized(0.10715640819735682);
      value[ID::attack0 + 9]->setFromNormalized(0.15074122456133307);
      value[ID::attack0 + 10]->setFromNormalized(0.15195369211724627);
      value[ID::attack0 + 11]->setFromNormalized(0.15311796503631514);
      value[ID::attack0 + 12]->setFromNormalized(0.15571351775814266);
      value[ID::attack0 + 13]->setFromNormalized(0.16280672784090408);
      value[ID::attack0 + 14]->setFromNormalized(0.175245274992152);
      value[ID::attack0 + 15]->setFromNormalized(0.1852556898906342);
      value[ID::attack0 + 16]->setFromNormalized(0.19147119894044126);
      value[ID::attack0 + 17]->setFromNormalized(0.21823563692360756);
      value[ID::attack0 + 18]->setFromNormalized(0.22182371117042574);
      value[ID::attack0 + 19]->setFromNormalized(0.24164387943042806);
      value[ID::attack0 + 20]->setFromNormalized(0.2528097855332523);
      value[ID::attack0 + 21]->setFromNormalized(0.2594947300270145);
      value[ID::attack0 + 22]->setFromNormalized(0.26605800904563087);
      value[ID::attack0 + 23]->setFromNormalized(0.33496123551133644);
      value[ID::attack0 + 24]->setFromNormalized(0.3451794080375423);
      value[ID::attack0 + 25]->setFromNormalized(0.37950350152000045);
      value[ID::attack0 + 26]->setFromNormalized(0.41483157228053796);
      value[ID::attack0 + 27]->setFromNormalized(0.4165220753293518);
      value[ID::attack0 + 28]->setFromNormalized(0.42218709916992886);
      value[ID::attack0 + 29]->setFromNormalized(0.4395944541163598);
      value[ID::attack0 + 30]->setFromNormalized(0.44867646310250264);
      value[ID::attack0 + 31]->setFromNormalized(0.46893203038789477);
      value[ID::attack0 + 32]->setFromNormalized(0.5196186446086741);
      value[ID::attack0 + 33]->setFromNormalized(0.5295554059455473);
      value[ID::attack0 + 34]->setFromNormalized(0.5313076555399621);
      value[ID::attack0 + 35]->setFromNormalized(0.5317422554997236);
      value[ID::attack0 + 36]->setFromNormalized(0.5377527528266378);
      value[ID::attack0 + 37]->setFromNormalized(0.5535888368902113);
      value[ID::attack0 + 38]->setFromNormalized(0.5539656522685187);
      value[ID::attack0 + 39]->setFromNormalized(0.5715768618300536);
      value[ID::attack0 + 40]->setFromNormalized(0.5741432298285928);
      value[ID::attack0 + 41]->setFromNormalized(0.5741976730634704);
      value[ID::attack0 + 42]->setFromNormalized(0.5763666887628615);
      value[ID::attack0 + 43]->setFromNormalized(0.5891822945768159);
      value[ID::attack0 + 44]->setFromNormalized(0.592297279618868);
      value[ID::attack0 + 45]->setFromNormalized(0.6060492286950374);
      value[ID::attack0 + 46]->setFromNormalized(0.6640830556573247);
      value[ID::attack0 + 47]->setFromNormalized(0.6677088934825481);
      value[ID::attack0 + 48]->setFromNormalized(0.6962352838826465);
      value[ID::attack0 + 49]->setFromNormalized(0.7065298093272464);
      value[ID::attack0 + 50]->setFromNormalized(0.7185769090635721);
      value[ID::attack0 + 51]->setFromNormalized(0.7323403795290048);
      value[ID::attack0 + 52]->setFromNormalized(0.7340256345483844);
      value[ID::attack0 + 53]->setFromNormalized(0.7389076059994935);
      value[ID::attack0 + 54]->setFromNormalized(0.7431638255259344);
      value[ID::attack0 + 55]->setFromNormalized(0.7569901157942692);
      value[ID::attack0 + 56]->setFromNormalized(0.8328117798060365);
      value[ID::attack0 + 57]->setFromNormalized(0.844539983573125);
      value[ID::attack0 + 58]->setFromNormalized(0.8455806384907142);
      value[ID::attack0 + 59]->setFromNormalized(0.8508187450051716);
      value[ID::attack0 + 60]->setFromNormalized(0.851158836848083);
      value[ID::attack0 + 61]->setFromNormalized(0.895914049407469);
      value[ID::attack0 + 62]->setFromNormalized(0.905794479397609);
      value[ID::attack0 + 63]->setFromNormalized(0.9730139647041445);
      value[ID::decay0 + 0]->setFromNormalized(0.006784780953286885);
      value[ID::decay0 + 1]->setFromNormalized(0.021290887588557243);
      value[ID::decay0 + 2]->setFromNormalized(0.04277270078482343);
      value[ID::decay0 + 3]->setFromNormalized(0.05549931032654477);
      value[ID::decay0 + 4]->setFromNormalized(0.05746192511487303);
      value[ID::decay0 + 5]->setFromNormalized(0.0713328304882132);
      value[ID::decay0 + 6]->setFromNormalized(0.08764867011376572);
      value[ID::decay0 + 7]->setFromNormalized(0.09111202746570236);
      value[ID::decay0 + 8]->setFromNormalized(0.12152582459658086);
      value[ID::decay0 + 9]->setFromNormalized(0.1359822181778828);
      value[ID::decay0 + 10]->setFromNormalized(0.13833548990063915);
      value[ID::decay0 + 11]->setFromNormalized(0.1533582875034175);
      value[ID::decay0 + 12]->setFromNormalized(0.16699645797850818);
      value[ID::decay0 + 13]->setFromNormalized(0.173399113159932);
      value[ID::decay0 + 14]->setFromNormalized(0.1994447843997046);
      value[ID::decay0 + 15]->setFromNormalized(0.21637947742232014);
      value[ID::decay0 + 16]->setFromNormalized(0.2229633212775135);
      value[ID::decay0 + 17]->setFromNormalized(0.23464314498795683);
      value[ID::decay0 + 18]->setFromNormalized(0.23968003549864694);
      value[ID::decay0 + 19]->setFromNormalized(0.24654737263629736);
      value[ID::decay0 + 20]->setFromNormalized(0.24919990224121244);
      value[ID::decay0 + 21]->setFromNormalized(0.25511636551655004);
      value[ID::decay0 + 22]->setFromNormalized(0.28131737167656196);
      value[ID::decay0 + 23]->setFromNormalized(0.28286700503042495);
      value[ID::decay0 + 24]->setFromNormalized(0.28327730232082987);
      value[ID::decay0 + 25]->setFromNormalized(0.30072977274006835);
      value[ID::decay0 + 26]->setFromNormalized(0.3151595848901147);
      value[ID::decay0 + 27]->setFromNormalized(0.3492461051637729);
      value[ID::decay0 + 28]->setFromNormalized(0.35140632969370295);
      value[ID::decay0 + 29]->setFromNormalized(0.35206395927061346);
      value[ID::decay0 + 30]->setFromNormalized(0.3565745259153325);
      value[ID::decay0 + 31]->setFromNormalized(0.3929128905723006);
      value[ID::decay0 + 32]->setFromNormalized(0.39918450448546067);
      value[ID::decay0 + 33]->setFromNormalized(0.4065250095336249);
      value[ID::decay0 + 34]->setFromNormalized(0.40700839317272686);
      value[ID::decay0 + 35]->setFromNormalized(0.41747939362888214);
      value[ID::decay0 + 36]->setFromNormalized(0.4391466930163408);
      value[ID::decay0 + 37]->setFromNormalized(0.4587814099254108);
      value[ID::decay0 + 38]->setFromNormalized(0.46853187066722296);
      value[ID::decay0 + 39]->setFromNormalized(0.47645316718130787);
      value[ID::decay0 + 40]->setFromNormalized(0.49028786952516573);
      value[ID::decay0 + 41]->setFromNormalized(0.495113096472517);
      value[ID::decay0 + 42]->setFromNormalized(0.4988308165370967);
      value[ID::decay0 + 43]->setFromNormalized(0.5211143152275397);
      value[ID::decay0 + 44]->setFromNormalized(0.5333934808740465);
      value[ID::decay0 + 45]->setFromNormalized(0.5515035840517983);
      value[ID::decay0 + 46]->setFromNormalized(0.5653382426221034);
      value[ID::decay0 + 47]->setFromNormalized(0.5834463924691854);
      value[ID::decay0 + 48]->setFromNormalized(0.5903641282533371);
      value[ID::decay0 + 49]->setFromNormalized(0.6098673460366605);
      value[ID::decay0 + 50]->setFromNormalized(0.6388500793855096);
      value[ID::decay0 + 51]->setFromNormalized(0.6672121109654516);
      value[ID::decay0 + 52]->setFromNormalized(0.6892328220193157);
      value[ID::decay0 + 53]->setFromNormalized(0.6968291947420475);
      value[ID::decay0 + 54]->setFromNormalized(0.716000042649385);
      value[ID::decay0 + 55]->setFromNormalized(0.7688278303185833);
      value[ID::decay0 + 56]->setFromNormalized(0.7800633265825615);
      value[ID::decay0 + 57]->setFromNormalized(0.7865386208021633);
      value[ID::decay0 + 58]->setFromNormalized(0.8066567014650016);
      value[ID::decay0 + 59]->setFromNormalized(0.8483214097485495);
      value[ID::decay0 + 60]->setFromNormalized(0.8533602822678266);
      value[ID::decay0 + 61]->setFromNormalized(0.8674569774927592);
      value[ID::decay0 + 62]->setFromNormalized(0.9685845801103256);
      value[ID::decay0 + 63]->setFromNormalized(0.9762430429221548);
      value[ID::overtone0 + 0]->setFromNormalized(0.0034913187890550645);
      value[ID::overtone0 + 1]->setFromNormalized(0.03894951973949858);
      value[ID::overtone0 + 2]->setFromNormalized(0.044915070786342604);
      value[ID::overtone0 + 3]->setFromNormalized(0.05427665789373073);
      value[ID::overtone0 + 4]->setFromNormalized(0.06145635610935134);
      value[ID::overtone0 + 5]->setFromNormalized(0.08538540278250917);
      value[ID::overtone0 + 6]->setFromNormalized(0.08974285239258908);
      value[ID::overtone0 + 7]->setFromNormalized(0.0948180820747325);
      value[ID::overtone0 + 8]->setFromNormalized(0.11217872157210654);
      value[ID::overtone0 + 9]->setFromNormalized(0.1532052808244721);
      value[ID::overtone0 + 10]->setFromNormalized(0.1575391178337462);
      value[ID::overtone0 + 11]->setFromNormalized(0.16036948396076856);
      value[ID::overtone0 + 12]->setFromNormalized(0.18047501028701857);
      value[ID::overtone0 + 13]->setFromNormalized(0.18285226882217992);
      value[ID::overtone0 + 14]->setFromNormalized(0.1945422656511262);
      value[ID::overtone0 + 15]->setFromNormalized(0.22680970884854715);
      value[ID::overtone0 + 16]->setFromNormalized(0.23333953122874984);
      value[ID::overtone0 + 17]->setFromNormalized(0.23935708333739206);
      value[ID::overtone0 + 18]->setFromNormalized(0.2396226202729589);
      value[ID::overtone0 + 19]->setFromNormalized(0.24914136300022696);
      value[ID::overtone0 + 20]->setFromNormalized(0.2589306345326162);
      value[ID::overtone0 + 21]->setFromNormalized(0.26350621736924673);
      value[ID::overtone0 + 22]->setFromNormalized(0.26897032876255744);
      value[ID::overtone0 + 23]->setFromNormalized(0.29259702791589726);
      value[ID::overtone0 + 24]->setFromNormalized(0.3095887202037762);
      value[ID::overtone0 + 25]->setFromNormalized(0.31021339231299977);
      value[ID::overtone0 + 26]->setFromNormalized(0.33612913452173065);
      value[ID::overtone0 + 27]->setFromNormalized(0.33660943765986406);
      value[ID::overtone0 + 28]->setFromNormalized(0.3688415426994238);
      value[ID::overtone0 + 29]->setFromNormalized(0.3756181140583621);
      value[ID::overtone0 + 30]->setFromNormalized(0.3995934971631727);
      value[ID::overtone0 + 31]->setFromNormalized(0.40448446752195943);
      value[ID::overtone0 + 32]->setFromNormalized(0.4216855653892079);
      value[ID::overtone0 + 33]->setFromNormalized(0.43335443996000117);
      value[ID::overtone0 + 34]->setFromNormalized(0.4488325772340339);
      value[ID::overtone0 + 35]->setFromNormalized(0.46171436669258786);
      value[ID::overtone0 + 36]->setFromNormalized(0.4666840874732515);
      value[ID::overtone0 + 37]->setFromNormalized(0.47683630841275015);
      value[ID::overtone0 + 38]->setFromNormalized(0.4801450267879619);
      value[ID::overtone0 + 39]->setFromNormalized(0.49833632472127976);
      value[ID::overtone0 + 40]->setFromNormalized(0.547311467480826);
      value[ID::overtone0 + 41]->setFromNormalized(0.6124472501210492);
      value[ID::overtone0 + 42]->setFromNormalized(0.6233502065864289);
      value[ID::overtone0 + 43]->setFromNormalized(0.6298394547515667);
      value[ID::overtone0 + 44]->setFromNormalized(0.6756567651314861);
      value[ID::overtone0 + 45]->setFromNormalized(0.6956241153950321);
      value[ID::overtone0 + 46]->setFromNormalized(0.7040723146126938);
      value[ID::overtone0 + 47]->setFromNormalized(0.7054309489852446);
      value[ID::overtone0 + 48]->setFromNormalized(0.7314015580274352);
      value[ID::overtone0 + 49]->setFromNormalized(0.7538993130899906);
      value[ID::overtone0 + 50]->setFromNormalized(0.7625475760733442);
      value[ID::overtone0 + 51]->setFromNormalized(0.7867609442803691);
      value[ID::overtone0 + 52]->setFromNormalized(0.7878635151700517);
      value[ID::overtone0 + 53]->setFromNormalized(0.843534167785857);
      value[ID::overtone0 + 54]->setFromNormalized(0.8501322920075591);
      value[ID::overtone0 + 55]->setFromNormalized(0.8797971829228837);
      value[ID::overtone0 + 56]->setFromNormalized(0.8825694074691757);
      value[ID::overtone0 + 57]->setFromNormalized(0.8908294393925595);
      value[ID::overtone0 + 58]->setFromNormalized(0.8990374669715362);
      value[ID::overtone0 + 59]->setFromNormalized(0.9164534670604227);
      value[ID::overtone0 + 60]->setFromNormalized(0.9358893056310906);
      value[ID::overtone0 + 61]->setFromNormalized(0.9463420681128939);
      value[ID::overtone0 + 62]->setFromNormalized(0.9602061588502471);
      value[ID::overtone0 + 63]->setFromNormalized(0.9687664775391612);
      value[ID::saturation0 + 0]->setFromNormalized(0.8600207777094183);
      value[ID::saturation0 + 1]->setFromNormalized(0.6332908060793832);
      value[ID::saturation0 + 2]->setFromNormalized(0.9576880549011234);
      value[ID::saturation0 + 3]->setFromNormalized(0.1848528784647645);
      value[ID::saturation0 + 4]->setFromNormalized(0.13363869056495892);
      value[ID::saturation0 + 5]->setFromNormalized(0.5742484272882197);
      value[ID::saturation0 + 6]->setFromNormalized(0.30988084333732907);
      value[ID::saturation0 + 7]->setFromNormalized(0.5346629342774628);
      value[ID::saturation0 + 8]->setFromNormalized(0.4302321598437946);
      value[ID::saturation0 + 9]->setFromNormalized(0.5556253198126307);
      value[ID::saturation0 + 10]->setFromNormalized(0.8287387446700952);
      value[ID::saturation0 + 11]->setFromNormalized(0.19881146568852529);
      value[ID::saturation0 + 12]->setFromNormalized(0.42458007032157447);
      value[ID::saturation0 + 13]->setFromNormalized(0.8112898011661718);
      value[ID::saturation0 + 14]->setFromNormalized(0.41124721384696195);
      value[ID::saturation0 + 15]->setFromNormalized(0.146529220314955);
      value[ID::saturation0 + 16]->setFromNormalized(0.7905490118714185);
      value[ID::saturation0 + 17]->setFromNormalized(0.253513808477887);
      value[ID::saturation0 + 18]->setFromNormalized(0.8928701420156432);
      value[ID::saturation0 + 19]->setFromNormalized(0.47849109995380834);
      value[ID::saturation0 + 20]->setFromNormalized(0.12066435764388361);
      value[ID::saturation0 + 21]->setFromNormalized(0.98469125120366);
      value[ID::saturation0 + 22]->setFromNormalized(0.8195739505037709);
      value[ID::saturation0 + 23]->setFromNormalized(0.3275532485317214);
      value[ID::saturation0 + 24]->setFromNormalized(0.6468351564189772);
      value[ID::saturation0 + 25]->setFromNormalized(0.21376584971245144);
      value[ID::saturation0 + 26]->setFromNormalized(0.541762326041517);
      value[ID::saturation0 + 27]->setFromNormalized(0.779050099303904);
      value[ID::saturation0 + 28]->setFromNormalized(0.7525038897343723);
      value[ID::saturation0 + 29]->setFromNormalized(0.41507352692958965);
      value[ID::saturation0 + 30]->setFromNormalized(0.44038070270257434);
      value[ID::saturation0 + 31]->setFromNormalized(0.41124119659087005);
      value[ID::saturation0 + 32]->setFromNormalized(0.6136066669431393);
      value[ID::saturation0 + 33]->setFromNormalized(0.7492006255414059);
      value[ID::saturation0 + 34]->setFromNormalized(0.7879054928877555);
      value[ID::saturation0 + 35]->setFromNormalized(0.45956001415380937);
      value[ID::saturation0 + 36]->setFromNormalized(0.7864441452233394);
      value[ID::saturation0 + 37]->setFromNormalized(0.7928571428571428);
      value[ID::saturation0 + 38]->setFromNormalized(0.9142857142857141);
      value[ID::saturation0 + 39]->setFromNormalized(0.9260132421007058);
      value[ID::saturation0 + 40]->setFromNormalized(0.812523566284142);
      value[ID::saturation0 + 41]->setFromNormalized(0.6622298110192053);
      value[ID::saturation0 + 42]->setFromNormalized(0.537447440620622);
      value[ID::saturation0 + 43]->setFromNormalized(0.21886219650600075);
      value[ID::saturation0 + 44]->setFromNormalized(0.22169180585209128);
      value[ID::saturation0 + 45]->setFromNormalized(0.586679262076442);
      value[ID::saturation0 + 46]->setFromNormalized(0.6694525468877426);
      value[ID::saturation0 + 47]->setFromNormalized(0.23819061705993713);
      value[ID::saturation0 + 48]->setFromNormalized(0.4354847579337013);
      value[ID::saturation0 + 49]->setFromNormalized(0.5781142111535307);
      value[ID::saturation0 + 50]->setFromNormalized(0.639193240240316);
      value[ID::saturation0 + 51]->setFromNormalized(0.9475983872179267);
      value[ID::saturation0 + 52]->setFromNormalized(0.37809880725820577);
      value[ID::saturation0 + 53]->setFromNormalized(0.37990439936429105);
      value[ID::saturation0 + 54]->setFromNormalized(0.7649772307113996);
      value[ID::saturation0 + 55]->setFromNormalized(0.27699472008171205);
      value[ID::saturation0 + 56]->setFromNormalized(0.6214285714285714);
      value[ID::saturation0 + 57]->setFromNormalized(0.31428571428571433);
      value[ID::saturation0 + 58]->setFromNormalized(0.2857142857142857);
      value[ID::saturation0 + 59]->setFromNormalized(0.41428571428571426);
      value[ID::saturation0 + 60]->setFromNormalized(0.5714285714285714);
      value[ID::saturation0 + 61]->setFromNormalized(0.9003288563068129);
      value[ID::saturation0 + 62]->setFromNormalized(0.6658827308087278);
      value[ID::saturation0 + 63]->setFromNormalized(0.8753467858786917);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.3720000088214874);
      value[ID::pitchMultiply]->setFromNormalized(0.0158124677836895);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.32399997115135193);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.8799999952316284);
      value[ID::randomPhase]->setFromNormalized(1.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.20800000429153442);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.0640000030398369);
      value[ID::phaserFeedback]->setFromNormalized(0.944000244140625);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.6920000314712524);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(6);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000002);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetGlassCup: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.3183704134145011);
      value[ID::attack0 + 1]->setFromNormalized(0.2706229370528766);
      value[ID::attack0 + 2]->setFromNormalized(0.5056419639347406);
      value[ID::attack0 + 3]->setFromNormalized(0.6694737427492533);
      value[ID::attack0 + 4]->setFromNormalized(0.6494124384625594);
      value[ID::attack0 + 5]->setFromNormalized(0.5368645398313442);
      value[ID::attack0 + 6]->setFromNormalized(0.5379501014986019);
      value[ID::attack0 + 7]->setFromNormalized(0.1607608256359033);
      value[ID::attack0 + 8]->setFromNormalized(0.2107232766195629);
      value[ID::attack0 + 9]->setFromNormalized(0.821496555126126);
      value[ID::attack0 + 10]->setFromNormalized(0.4658190000320971);
      value[ID::attack0 + 11]->setFromNormalized(0.027775817383886393);
      value[ID::attack0 + 12]->setFromNormalized(0.6483626775240942);
      value[ID::attack0 + 13]->setFromNormalized(0.2264365103944338);
      value[ID::attack0 + 14]->setFromNormalized(0.3584490174299041);
      value[ID::attack0 + 15]->setFromNormalized(0.19350136100730736);
      value[ID::attack0 + 16]->setFromNormalized(0.4164146010636704);
      value[ID::attack0 + 17]->setFromNormalized(0.8569066398170592);
      value[ID::attack0 + 18]->setFromNormalized(0.6822634016627075);
      value[ID::attack0 + 19]->setFromNormalized(0.8119991086100989);
      value[ID::attack0 + 20]->setFromNormalized(0.24054361186320874);
      value[ID::attack0 + 21]->setFromNormalized(0.21773022829394745);
      value[ID::attack0 + 22]->setFromNormalized(0.3831770689803326);
      value[ID::attack0 + 23]->setFromNormalized(0.27455979381571727);
      value[ID::attack0 + 24]->setFromNormalized(0.8451373569581418);
      value[ID::attack0 + 25]->setFromNormalized(0.9255372269135941);
      value[ID::attack0 + 26]->setFromNormalized(0.5473202182811722);
      value[ID::attack0 + 27]->setFromNormalized(0.8725619851697255);
      value[ID::attack0 + 28]->setFromNormalized(0.16498307079058674);
      value[ID::attack0 + 29]->setFromNormalized(0.28707985831461913);
      value[ID::attack0 + 30]->setFromNormalized(0.4728459973280637);
      value[ID::attack0 + 31]->setFromNormalized(0.13651537303716355);
      value[ID::attack0 + 32]->setFromNormalized(0.20790013014028258);
      value[ID::attack0 + 33]->setFromNormalized(0.4017727277103641);
      value[ID::attack0 + 34]->setFromNormalized(0.3600653385337094);
      value[ID::attack0 + 35]->setFromNormalized(0.7893363319261388);
      value[ID::attack0 + 36]->setFromNormalized(0.4449011151026061);
      value[ID::attack0 + 37]->setFromNormalized(0.46659855055302835);
      value[ID::attack0 + 38]->setFromNormalized(0.8405889281066887);
      value[ID::attack0 + 39]->setFromNormalized(0.07221092485134752);
      value[ID::attack0 + 40]->setFromNormalized(0.5938220958890567);
      value[ID::attack0 + 41]->setFromNormalized(0.3703561476441632);
      value[ID::attack0 + 42]->setFromNormalized(0.9891643535856983);
      value[ID::attack0 + 43]->setFromNormalized(0.9107517326151933);
      value[ID::attack0 + 44]->setFromNormalized(0.7979054905030281);
      value[ID::attack0 + 45]->setFromNormalized(0.8235197130510139);
      value[ID::attack0 + 46]->setFromNormalized(0.2959497044701074);
      value[ID::attack0 + 47]->setFromNormalized(0.5310714559213583);
      value[ID::attack0 + 48]->setFromNormalized(0.19757354854927617);
      value[ID::attack0 + 49]->setFromNormalized(0.6657215370762088);
      value[ID::attack0 + 50]->setFromNormalized(0.6206228188678214);
      value[ID::attack0 + 51]->setFromNormalized(0.44568147831245974);
      value[ID::attack0 + 52]->setFromNormalized(0.14686789284781263);
      value[ID::attack0 + 53]->setFromNormalized(0.13695597631892956);
      value[ID::attack0 + 54]->setFromNormalized(0.6843068028202842);
      value[ID::attack0 + 55]->setFromNormalized(0.6598205827306345);
      value[ID::attack0 + 56]->setFromNormalized(0.8965313166786697);
      value[ID::attack0 + 57]->setFromNormalized(0.9682555385101054);
      value[ID::attack0 + 58]->setFromNormalized(0.02144421783573773);
      value[ID::attack0 + 59]->setFromNormalized(0.20628693457217734);
      value[ID::attack0 + 60]->setFromNormalized(0.5227275095678665);
      value[ID::attack0 + 61]->setFromNormalized(0.9875325105437072);
      value[ID::attack0 + 62]->setFromNormalized(0.3639663155864005);
      value[ID::attack0 + 63]->setFromNormalized(0.2025299908585572);
      value[ID::decay0 + 0]->setFromNormalized(0.5);
      value[ID::decay0 + 1]->setFromNormalized(0.5071428571428571);
      value[ID::decay0 + 2]->setFromNormalized(0.40714285714285714);
      value[ID::decay0 + 3]->setFromNormalized(0.3214285714285714);
      value[ID::decay0 + 4]->setFromNormalized(0.2571428571428571);
      value[ID::decay0 + 5]->setFromNormalized(0.21428571428571433);
      value[ID::decay0 + 6]->setFromNormalized(0.11428571428571434);
      value[ID::decay0 + 7]->setFromNormalized(0.10714285714285711);
      value[ID::decay0 + 8]->setFromNormalized(0.13571428571428568);
      value[ID::decay0 + 9]->setFromNormalized(0.20714285714285718);
      value[ID::decay0 + 10]->setFromNormalized(0.2571428571428571);
      value[ID::decay0 + 11]->setFromNormalized(0.2928571428571428);
      value[ID::decay0 + 12]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 13]->setFromNormalized(0.37142857142857144);
      value[ID::decay0 + 14]->setFromNormalized(0.3928571428571429);
      value[ID::decay0 + 15]->setFromNormalized(0.3928571428571429);
      value[ID::decay0 + 16]->setFromNormalized(0.3928571428571429);
      value[ID::decay0 + 17]->setFromNormalized(0.35);
      value[ID::decay0 + 18]->setFromNormalized(0.34285714285714286);
      value[ID::decay0 + 19]->setFromNormalized(0.5);
      value[ID::decay0 + 20]->setFromNormalized(0.2928571428571428);
      value[ID::decay0 + 21]->setFromNormalized(0.2785714285714286);
      value[ID::decay0 + 22]->setFromNormalized(0.2571428571428571);
      value[ID::decay0 + 23]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 24]->setFromNormalized(0.15000000000000002);
      value[ID::decay0 + 25]->setFromNormalized(0.12857142857142856);
      value[ID::decay0 + 26]->setFromNormalized(0.12857142857142856);
      value[ID::decay0 + 27]->setFromNormalized(0.21428571428571433);
      value[ID::decay0 + 28]->setFromNormalized(0.3214285714285714);
      value[ID::decay0 + 29]->setFromNormalized(0.3214285714285714);
      value[ID::decay0 + 30]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 31]->setFromNormalized(0.2571428571428571);
      value[ID::decay0 + 32]->setFromNormalized(0.20714285714285718);
      value[ID::decay0 + 33]->setFromNormalized(0.19285714285714284);
      value[ID::decay0 + 34]->setFromNormalized(0.1785714285714286);
      value[ID::decay0 + 35]->setFromNormalized(0.5);
      value[ID::decay0 + 36]->setFromNormalized(0.12142857142857146);
      value[ID::decay0 + 37]->setFromNormalized(0.07857142857142864);
      value[ID::decay0 + 38]->setFromNormalized(0.0714285714285714);
      value[ID::decay0 + 39]->setFromNormalized(0.05000000000000005);
      value[ID::decay0 + 40]->setFromNormalized(0.028571428571428584);
      value[ID::decay0 + 41]->setFromNormalized(0.04285714285714282);
      value[ID::decay0 + 42]->setFromNormalized(0.13571428571428568);
      value[ID::decay0 + 43]->setFromNormalized(0.16428571428571428);
      value[ID::decay0 + 44]->setFromNormalized(0.27142857142857146);
      value[ID::decay0 + 45]->setFromNormalized(0.3285714285714286);
      value[ID::decay0 + 46]->setFromNormalized(0.37857142857142856);
      value[ID::decay0 + 47]->setFromNormalized(0.37857142857142856);
      value[ID::decay0 + 48]->setFromNormalized(0.37857142857142856);
      value[ID::decay0 + 49]->setFromNormalized(0.37857142857142856);
      value[ID::decay0 + 50]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 51]->setFromNormalized(0.27142857142857146);
      value[ID::decay0 + 52]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 53]->setFromNormalized(0.19285714285714284);
      value[ID::decay0 + 54]->setFromNormalized(0.16428571428571428);
      value[ID::decay0 + 55]->setFromNormalized(0.15000000000000002);
      value[ID::decay0 + 56]->setFromNormalized(0.1428571428571429);
      value[ID::decay0 + 57]->setFromNormalized(0.5);
      value[ID::decay0 + 58]->setFromNormalized(0.12857142857142856);
      value[ID::decay0 + 59]->setFromNormalized(0.11428571428571434);
      value[ID::decay0 + 60]->setFromNormalized(0.08571428571428576);
      value[ID::decay0 + 61]->setFromNormalized(0.05000000000000005);
      value[ID::decay0 + 62]->setFromNormalized(0.0);
      value[ID::decay0 + 63]->setFromNormalized(0.0);
      value[ID::overtone0 + 0]->setFromNormalized(0.2355882712377344);
      value[ID::overtone0 + 1]->setFromNormalized(0.35623359968427015);
      value[ID::overtone0 + 2]->setFromNormalized(0.008751618020600916);
      value[ID::overtone0 + 3]->setFromNormalized(0.7903386643476377);
      value[ID::overtone0 + 4]->setFromNormalized(0.5497916669602669);
      value[ID::overtone0 + 5]->setFromNormalized(0.9364561913754411);
      value[ID::overtone0 + 6]->setFromNormalized(0.1256312409580536);
      value[ID::overtone0 + 7]->setFromNormalized(0.4428852854114044);
      value[ID::overtone0 + 8]->setFromNormalized(0.4043938157721313);
      value[ID::overtone0 + 9]->setFromNormalized(0.9225803397430937);
      value[ID::overtone0 + 10]->setFromNormalized(0.7885544639627402);
      value[ID::overtone0 + 11]->setFromNormalized(0.5452132360515312);
      value[ID::overtone0 + 12]->setFromNormalized(0.20456493438474954);
      value[ID::overtone0 + 13]->setFromNormalized(0.37796987781800856);
      value[ID::overtone0 + 14]->setFromNormalized(0.6765011520224089);
      value[ID::overtone0 + 15]->setFromNormalized(0.18498467045249606);
      value[ID::overtone0 + 16]->setFromNormalized(0.2623144970361069);
      value[ID::overtone0 + 17]->setFromNormalized(0.8563504769205228);
      value[ID::overtone0 + 18]->setFromNormalized(0.40749864321979146);
      value[ID::overtone0 + 19]->setFromNormalized(0.35776642561878713);
      value[ID::overtone0 + 20]->setFromNormalized(0.3310744033989096);
      value[ID::overtone0 + 21]->setFromNormalized(0.28869522328847286);
      value[ID::overtone0 + 22]->setFromNormalized(0.2609575049669017);
      value[ID::overtone0 + 23]->setFromNormalized(0.7202385059571725);
      value[ID::overtone0 + 24]->setFromNormalized(0.8240455486856458);
      value[ID::overtone0 + 25]->setFromNormalized(0.5580034587829628);
      value[ID::overtone0 + 26]->setFromNormalized(0.8602400746309593);
      value[ID::overtone0 + 27]->setFromNormalized(0.5141685784187096);
      value[ID::overtone0 + 28]->setFromNormalized(0.34893487294400183);
      value[ID::overtone0 + 29]->setFromNormalized(0.4807182804799349);
      value[ID::overtone0 + 30]->setFromNormalized(0.7260451521551703);
      value[ID::overtone0 + 31]->setFromNormalized(0.819528323196697);
      value[ID::overtone0 + 32]->setFromNormalized(0.20600303406082973);
      value[ID::overtone0 + 33]->setFromNormalized(0.11196928258104659);
      value[ID::overtone0 + 34]->setFromNormalized(0.5838506459925714);
      value[ID::overtone0 + 35]->setFromNormalized(0.7454607516267702);
      value[ID::overtone0 + 36]->setFromNormalized(0.5919669048510104);
      value[ID::overtone0 + 37]->setFromNormalized(0.22264414897869322);
      value[ID::overtone0 + 38]->setFromNormalized(0.18588526516988946);
      value[ID::overtone0 + 39]->setFromNormalized(0.07623250932044226);
      value[ID::overtone0 + 40]->setFromNormalized(0.867569133171459);
      value[ID::overtone0 + 41]->setFromNormalized(0.22006301283262744);
      value[ID::overtone0 + 42]->setFromNormalized(0.9352334103939377);
      value[ID::overtone0 + 43]->setFromNormalized(0.18379799746574044);
      value[ID::overtone0 + 44]->setFromNormalized(0.27386947805118433);
      value[ID::overtone0 + 45]->setFromNormalized(0.6842514671507376);
      value[ID::overtone0 + 46]->setFromNormalized(0.7941170770150776);
      value[ID::overtone0 + 47]->setFromNormalized(0.27997837199876174);
      value[ID::overtone0 + 48]->setFromNormalized(0.17057402516072617);
      value[ID::overtone0 + 49]->setFromNormalized(0.10175948915041566);
      value[ID::overtone0 + 50]->setFromNormalized(0.13751981752833392);
      value[ID::overtone0 + 51]->setFromNormalized(0.32869494293961976);
      value[ID::overtone0 + 52]->setFromNormalized(0.2981562591251857);
      value[ID::overtone0 + 53]->setFromNormalized(0.36480198681872045);
      value[ID::overtone0 + 54]->setFromNormalized(0.9569505747221655);
      value[ID::overtone0 + 55]->setFromNormalized(0.9679633501116145);
      value[ID::overtone0 + 56]->setFromNormalized(0.553953689919498);
      value[ID::overtone0 + 57]->setFromNormalized(0.6805565814875132);
      value[ID::overtone0 + 58]->setFromNormalized(0.7893214029520625);
      value[ID::overtone0 + 59]->setFromNormalized(0.5580778391100976);
      value[ID::overtone0 + 60]->setFromNormalized(0.9161521551456422);
      value[ID::overtone0 + 61]->setFromNormalized(0.0777104429117994);
      value[ID::overtone0 + 62]->setFromNormalized(0.874462851018626);
      value[ID::overtone0 + 63]->setFromNormalized(0.1639834762146121);
      value[ID::saturation0 + 0]->setFromNormalized(0.2124496391358645);
      value[ID::saturation0 + 1]->setFromNormalized(0.09252970506977565);
      value[ID::saturation0 + 2]->setFromNormalized(0.31640297975844517);
      value[ID::saturation0 + 3]->setFromNormalized(0.8143197020190603);
      value[ID::saturation0 + 4]->setFromNormalized(0.2533467585040342);
      value[ID::saturation0 + 5]->setFromNormalized(0.06488217904846605);
      value[ID::saturation0 + 6]->setFromNormalized(0.25530432455116214);
      value[ID::saturation0 + 7]->setFromNormalized(0.4061096860901912);
      value[ID::saturation0 + 8]->setFromNormalized(0.5336479530810329);
      value[ID::saturation0 + 9]->setFromNormalized(0.4274533927619923);
      value[ID::saturation0 + 10]->setFromNormalized(0.9319419591574153);
      value[ID::saturation0 + 11]->setFromNormalized(0.5813793677670938);
      value[ID::saturation0 + 12]->setFromNormalized(0.7396985366339922);
      value[ID::saturation0 + 13]->setFromNormalized(0.33388952183111187);
      value[ID::saturation0 + 14]->setFromNormalized(0.6872463366641914);
      value[ID::saturation0 + 15]->setFromNormalized(0.6916565494110741);
      value[ID::saturation0 + 16]->setFromNormalized(0.05610013397544133);
      value[ID::saturation0 + 17]->setFromNormalized(0.16961976719683675);
      value[ID::saturation0 + 18]->setFromNormalized(0.41017829372075254);
      value[ID::saturation0 + 19]->setFromNormalized(0.4309600836022856);
      value[ID::saturation0 + 20]->setFromNormalized(0.5063866545451627);
      value[ID::saturation0 + 21]->setFromNormalized(0.22571696218173953);
      value[ID::saturation0 + 22]->setFromNormalized(0.32494630689074544);
      value[ID::saturation0 + 23]->setFromNormalized(0.3759981328194546);
      value[ID::saturation0 + 24]->setFromNormalized(0.47485375654622813);
      value[ID::saturation0 + 25]->setFromNormalized(0.18286649686322612);
      value[ID::saturation0 + 26]->setFromNormalized(0.6662435710262571);
      value[ID::saturation0 + 27]->setFromNormalized(0.39846683252084203);
      value[ID::saturation0 + 28]->setFromNormalized(0.5640030713664608);
      value[ID::saturation0 + 29]->setFromNormalized(0.5847211525267361);
      value[ID::saturation0 + 30]->setFromNormalized(0.6858752918059833);
      value[ID::saturation0 + 31]->setFromNormalized(0.03202041432500888);
      value[ID::saturation0 + 32]->setFromNormalized(0.3807754802449561);
      value[ID::saturation0 + 33]->setFromNormalized(0.9781053225117896);
      value[ID::saturation0 + 34]->setFromNormalized(0.5140014438731846);
      value[ID::saturation0 + 35]->setFromNormalized(0.9194332836502012);
      value[ID::saturation0 + 36]->setFromNormalized(0.44476651992041144);
      value[ID::saturation0 + 37]->setFromNormalized(0.7210776673776955);
      value[ID::saturation0 + 38]->setFromNormalized(0.151717495913488);
      value[ID::saturation0 + 39]->setFromNormalized(0.31579221308875044);
      value[ID::saturation0 + 40]->setFromNormalized(0.9343604260477212);
      value[ID::saturation0 + 41]->setFromNormalized(0.3979543221914063);
      value[ID::saturation0 + 42]->setFromNormalized(0.5492886040115731);
      value[ID::saturation0 + 43]->setFromNormalized(0.4984580145749372);
      value[ID::saturation0 + 44]->setFromNormalized(0.07096399276738515);
      value[ID::saturation0 + 45]->setFromNormalized(0.9378305812130485);
      value[ID::saturation0 + 46]->setFromNormalized(0.8527418303329583);
      value[ID::saturation0 + 47]->setFromNormalized(0.24915166246631992);
      value[ID::saturation0 + 48]->setFromNormalized(0.5015913293140276);
      value[ID::saturation0 + 49]->setFromNormalized(0.5383694532246944);
      value[ID::saturation0 + 50]->setFromNormalized(0.5726591286023013);
      value[ID::saturation0 + 51]->setFromNormalized(0.38220183523516593);
      value[ID::saturation0 + 52]->setFromNormalized(0.4952321035911614);
      value[ID::saturation0 + 53]->setFromNormalized(0.9340382655330779);
      value[ID::saturation0 + 54]->setFromNormalized(0.6516206941377648);
      value[ID::saturation0 + 55]->setFromNormalized(0.6909652353973602);
      value[ID::saturation0 + 56]->setFromNormalized(0.733482272949529);
      value[ID::saturation0 + 57]->setFromNormalized(0.11789151756635438);
      value[ID::saturation0 + 58]->setFromNormalized(0.07483339933449566);
      value[ID::saturation0 + 59]->setFromNormalized(0.4569948159452915);
      value[ID::saturation0 + 60]->setFromNormalized(0.27302849783372934);
      value[ID::saturation0 + 61]->setFromNormalized(0.8757008625914628);
      value[ID::saturation0 + 62]->setFromNormalized(0.4014441759861231);
      value[ID::saturation0 + 63]->setFromNormalized(0.6036507336707004);
      value[ID::gain]->setFromNormalized(0.768000066280365);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.4620005190372467);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.2679999768733978);
      value[ID::randomFrequency]->setFromNormalized(0.364000141620636);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.12199999392032623);
      value[ID::attackMultiplier]->setFromNormalized(0.4199999868869781);
      value[ID::decayMultiplier]->setFromNormalized(0.16399994492530823);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetHighFrequency: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(1.0);
      value[ID::attack0 + 1]->setFromNormalized(1.0);
      value[ID::attack0 + 2]->setFromNormalized(1.0);
      value[ID::attack0 + 3]->setFromNormalized(1.0);
      value[ID::attack0 + 4]->setFromNormalized(1.0);
      value[ID::attack0 + 5]->setFromNormalized(1.0);
      value[ID::attack0 + 6]->setFromNormalized(1.0);
      value[ID::attack0 + 7]->setFromNormalized(1.0);
      value[ID::attack0 + 8]->setFromNormalized(1.0);
      value[ID::attack0 + 9]->setFromNormalized(1.0);
      value[ID::attack0 + 10]->setFromNormalized(1.0);
      value[ID::attack0 + 11]->setFromNormalized(1.0);
      value[ID::attack0 + 12]->setFromNormalized(1.0);
      value[ID::attack0 + 13]->setFromNormalized(1.0);
      value[ID::attack0 + 14]->setFromNormalized(1.0);
      value[ID::attack0 + 15]->setFromNormalized(1.0);
      value[ID::attack0 + 16]->setFromNormalized(1.0);
      value[ID::attack0 + 17]->setFromNormalized(1.0);
      value[ID::attack0 + 18]->setFromNormalized(1.0);
      value[ID::attack0 + 19]->setFromNormalized(1.0);
      value[ID::attack0 + 20]->setFromNormalized(1.0);
      value[ID::attack0 + 21]->setFromNormalized(1.0);
      value[ID::attack0 + 22]->setFromNormalized(1.0);
      value[ID::attack0 + 23]->setFromNormalized(1.0);
      value[ID::attack0 + 24]->setFromNormalized(1.0);
      value[ID::attack0 + 25]->setFromNormalized(1.0);
      value[ID::attack0 + 26]->setFromNormalized(1.0);
      value[ID::attack0 + 27]->setFromNormalized(1.0);
      value[ID::attack0 + 28]->setFromNormalized(1.0);
      value[ID::attack0 + 29]->setFromNormalized(1.0);
      value[ID::attack0 + 30]->setFromNormalized(1.0);
      value[ID::attack0 + 31]->setFromNormalized(1.0);
      value[ID::attack0 + 32]->setFromNormalized(1.0);
      value[ID::attack0 + 33]->setFromNormalized(1.0);
      value[ID::attack0 + 34]->setFromNormalized(1.0);
      value[ID::attack0 + 35]->setFromNormalized(1.0);
      value[ID::attack0 + 36]->setFromNormalized(1.0);
      value[ID::attack0 + 37]->setFromNormalized(1.0);
      value[ID::attack0 + 38]->setFromNormalized(1.0);
      value[ID::attack0 + 39]->setFromNormalized(1.0);
      value[ID::attack0 + 40]->setFromNormalized(1.0);
      value[ID::attack0 + 41]->setFromNormalized(1.0);
      value[ID::attack0 + 42]->setFromNormalized(1.0);
      value[ID::attack0 + 43]->setFromNormalized(1.0);
      value[ID::attack0 + 44]->setFromNormalized(1.0);
      value[ID::attack0 + 45]->setFromNormalized(1.0);
      value[ID::attack0 + 46]->setFromNormalized(1.0);
      value[ID::attack0 + 47]->setFromNormalized(1.0);
      value[ID::attack0 + 48]->setFromNormalized(1.0);
      value[ID::attack0 + 49]->setFromNormalized(1.0);
      value[ID::attack0 + 50]->setFromNormalized(1.0);
      value[ID::attack0 + 51]->setFromNormalized(1.0);
      value[ID::attack0 + 52]->setFromNormalized(1.0);
      value[ID::attack0 + 53]->setFromNormalized(1.0);
      value[ID::attack0 + 54]->setFromNormalized(1.0);
      value[ID::attack0 + 55]->setFromNormalized(1.0);
      value[ID::attack0 + 56]->setFromNormalized(1.0);
      value[ID::attack0 + 57]->setFromNormalized(1.0);
      value[ID::attack0 + 58]->setFromNormalized(1.0);
      value[ID::attack0 + 59]->setFromNormalized(1.0);
      value[ID::attack0 + 60]->setFromNormalized(1.0);
      value[ID::attack0 + 61]->setFromNormalized(1.0);
      value[ID::attack0 + 62]->setFromNormalized(1.0);
      value[ID::attack0 + 63]->setFromNormalized(1.0);
      value[ID::decay0 + 0]->setFromNormalized(1.0);
      value[ID::decay0 + 1]->setFromNormalized(1.0);
      value[ID::decay0 + 2]->setFromNormalized(1.0);
      value[ID::decay0 + 3]->setFromNormalized(1.0);
      value[ID::decay0 + 4]->setFromNormalized(1.0);
      value[ID::decay0 + 5]->setFromNormalized(1.0);
      value[ID::decay0 + 6]->setFromNormalized(1.0);
      value[ID::decay0 + 7]->setFromNormalized(1.0);
      value[ID::decay0 + 8]->setFromNormalized(1.0);
      value[ID::decay0 + 9]->setFromNormalized(1.0);
      value[ID::decay0 + 10]->setFromNormalized(1.0);
      value[ID::decay0 + 11]->setFromNormalized(1.0);
      value[ID::decay0 + 12]->setFromNormalized(1.0);
      value[ID::decay0 + 13]->setFromNormalized(1.0);
      value[ID::decay0 + 14]->setFromNormalized(1.0);
      value[ID::decay0 + 15]->setFromNormalized(1.0);
      value[ID::decay0 + 16]->setFromNormalized(1.0);
      value[ID::decay0 + 17]->setFromNormalized(1.0);
      value[ID::decay0 + 18]->setFromNormalized(1.0);
      value[ID::decay0 + 19]->setFromNormalized(1.0);
      value[ID::decay0 + 20]->setFromNormalized(1.0);
      value[ID::decay0 + 21]->setFromNormalized(1.0);
      value[ID::decay0 + 22]->setFromNormalized(1.0);
      value[ID::decay0 + 23]->setFromNormalized(1.0);
      value[ID::decay0 + 24]->setFromNormalized(1.0);
      value[ID::decay0 + 25]->setFromNormalized(1.0);
      value[ID::decay0 + 26]->setFromNormalized(1.0);
      value[ID::decay0 + 27]->setFromNormalized(1.0);
      value[ID::decay0 + 28]->setFromNormalized(1.0);
      value[ID::decay0 + 29]->setFromNormalized(1.0);
      value[ID::decay0 + 30]->setFromNormalized(1.0);
      value[ID::decay0 + 31]->setFromNormalized(1.0);
      value[ID::decay0 + 32]->setFromNormalized(1.0);
      value[ID::decay0 + 33]->setFromNormalized(1.0);
      value[ID::decay0 + 34]->setFromNormalized(1.0);
      value[ID::decay0 + 35]->setFromNormalized(1.0);
      value[ID::decay0 + 36]->setFromNormalized(1.0);
      value[ID::decay0 + 37]->setFromNormalized(1.0);
      value[ID::decay0 + 38]->setFromNormalized(1.0);
      value[ID::decay0 + 39]->setFromNormalized(1.0);
      value[ID::decay0 + 40]->setFromNormalized(1.0);
      value[ID::decay0 + 41]->setFromNormalized(1.0);
      value[ID::decay0 + 42]->setFromNormalized(1.0);
      value[ID::decay0 + 43]->setFromNormalized(1.0);
      value[ID::decay0 + 44]->setFromNormalized(1.0);
      value[ID::decay0 + 45]->setFromNormalized(1.0);
      value[ID::decay0 + 46]->setFromNormalized(1.0);
      value[ID::decay0 + 47]->setFromNormalized(1.0);
      value[ID::decay0 + 48]->setFromNormalized(1.0);
      value[ID::decay0 + 49]->setFromNormalized(1.0);
      value[ID::decay0 + 50]->setFromNormalized(1.0);
      value[ID::decay0 + 51]->setFromNormalized(1.0);
      value[ID::decay0 + 52]->setFromNormalized(1.0);
      value[ID::decay0 + 53]->setFromNormalized(1.0);
      value[ID::decay0 + 54]->setFromNormalized(1.0);
      value[ID::decay0 + 55]->setFromNormalized(1.0);
      value[ID::decay0 + 56]->setFromNormalized(1.0);
      value[ID::decay0 + 57]->setFromNormalized(1.0);
      value[ID::decay0 + 58]->setFromNormalized(1.0);
      value[ID::decay0 + 59]->setFromNormalized(1.0);
      value[ID::decay0 + 60]->setFromNormalized(1.0);
      value[ID::decay0 + 61]->setFromNormalized(1.0);
      value[ID::decay0 + 62]->setFromNormalized(1.0);
      value[ID::decay0 + 63]->setFromNormalized(1.0);
      value[ID::overtone0 + 0]->setFromNormalized(1.0);
      value[ID::overtone0 + 1]->setFromNormalized(1.0);
      value[ID::overtone0 + 2]->setFromNormalized(1.0);
      value[ID::overtone0 + 3]->setFromNormalized(1.0);
      value[ID::overtone0 + 4]->setFromNormalized(1.0);
      value[ID::overtone0 + 5]->setFromNormalized(1.0);
      value[ID::overtone0 + 6]->setFromNormalized(1.0);
      value[ID::overtone0 + 7]->setFromNormalized(1.0);
      value[ID::overtone0 + 8]->setFromNormalized(1.0);
      value[ID::overtone0 + 9]->setFromNormalized(1.0);
      value[ID::overtone0 + 10]->setFromNormalized(1.0);
      value[ID::overtone0 + 11]->setFromNormalized(1.0);
      value[ID::overtone0 + 12]->setFromNormalized(1.0);
      value[ID::overtone0 + 13]->setFromNormalized(1.0);
      value[ID::overtone0 + 14]->setFromNormalized(1.0);
      value[ID::overtone0 + 15]->setFromNormalized(1.0);
      value[ID::overtone0 + 16]->setFromNormalized(1.0);
      value[ID::overtone0 + 17]->setFromNormalized(1.0);
      value[ID::overtone0 + 18]->setFromNormalized(1.0);
      value[ID::overtone0 + 19]->setFromNormalized(1.0);
      value[ID::overtone0 + 20]->setFromNormalized(1.0);
      value[ID::overtone0 + 21]->setFromNormalized(1.0);
      value[ID::overtone0 + 22]->setFromNormalized(1.0);
      value[ID::overtone0 + 23]->setFromNormalized(1.0);
      value[ID::overtone0 + 24]->setFromNormalized(1.0);
      value[ID::overtone0 + 25]->setFromNormalized(1.0);
      value[ID::overtone0 + 26]->setFromNormalized(1.0);
      value[ID::overtone0 + 27]->setFromNormalized(1.0);
      value[ID::overtone0 + 28]->setFromNormalized(1.0);
      value[ID::overtone0 + 29]->setFromNormalized(1.0);
      value[ID::overtone0 + 30]->setFromNormalized(1.0);
      value[ID::overtone0 + 31]->setFromNormalized(1.0);
      value[ID::overtone0 + 32]->setFromNormalized(1.0);
      value[ID::overtone0 + 33]->setFromNormalized(1.0);
      value[ID::overtone0 + 34]->setFromNormalized(1.0);
      value[ID::overtone0 + 35]->setFromNormalized(1.0);
      value[ID::overtone0 + 36]->setFromNormalized(1.0);
      value[ID::overtone0 + 37]->setFromNormalized(1.0);
      value[ID::overtone0 + 38]->setFromNormalized(1.0);
      value[ID::overtone0 + 39]->setFromNormalized(1.0);
      value[ID::overtone0 + 40]->setFromNormalized(1.0);
      value[ID::overtone0 + 41]->setFromNormalized(1.0);
      value[ID::overtone0 + 42]->setFromNormalized(1.0);
      value[ID::overtone0 + 43]->setFromNormalized(1.0);
      value[ID::overtone0 + 44]->setFromNormalized(1.0);
      value[ID::overtone0 + 45]->setFromNormalized(1.0);
      value[ID::overtone0 + 46]->setFromNormalized(1.0);
      value[ID::overtone0 + 47]->setFromNormalized(1.0);
      value[ID::overtone0 + 48]->setFromNormalized(1.0);
      value[ID::overtone0 + 49]->setFromNormalized(1.0);
      value[ID::overtone0 + 50]->setFromNormalized(1.0);
      value[ID::overtone0 + 51]->setFromNormalized(1.0);
      value[ID::overtone0 + 52]->setFromNormalized(1.0);
      value[ID::overtone0 + 53]->setFromNormalized(1.0);
      value[ID::overtone0 + 54]->setFromNormalized(1.0);
      value[ID::overtone0 + 55]->setFromNormalized(1.0);
      value[ID::overtone0 + 56]->setFromNormalized(1.0);
      value[ID::overtone0 + 57]->setFromNormalized(1.0);
      value[ID::overtone0 + 58]->setFromNormalized(1.0);
      value[ID::overtone0 + 59]->setFromNormalized(1.0);
      value[ID::overtone0 + 60]->setFromNormalized(1.0);
      value[ID::overtone0 + 61]->setFromNormalized(1.0);
      value[ID::overtone0 + 62]->setFromNormalized(1.0);
      value[ID::overtone0 + 63]->setFromNormalized(1.0);
      value[ID::saturation0 + 0]->setFromNormalized(1.0);
      value[ID::saturation0 + 1]->setFromNormalized(1.0);
      value[ID::saturation0 + 2]->setFromNormalized(1.0);
      value[ID::saturation0 + 3]->setFromNormalized(1.0);
      value[ID::saturation0 + 4]->setFromNormalized(1.0);
      value[ID::saturation0 + 5]->setFromNormalized(1.0);
      value[ID::saturation0 + 6]->setFromNormalized(1.0);
      value[ID::saturation0 + 7]->setFromNormalized(1.0);
      value[ID::saturation0 + 8]->setFromNormalized(1.0);
      value[ID::saturation0 + 9]->setFromNormalized(1.0);
      value[ID::saturation0 + 10]->setFromNormalized(1.0);
      value[ID::saturation0 + 11]->setFromNormalized(1.0);
      value[ID::saturation0 + 12]->setFromNormalized(1.0);
      value[ID::saturation0 + 13]->setFromNormalized(1.0);
      value[ID::saturation0 + 14]->setFromNormalized(1.0);
      value[ID::saturation0 + 15]->setFromNormalized(1.0);
      value[ID::saturation0 + 16]->setFromNormalized(1.0);
      value[ID::saturation0 + 17]->setFromNormalized(1.0);
      value[ID::saturation0 + 18]->setFromNormalized(1.0);
      value[ID::saturation0 + 19]->setFromNormalized(1.0);
      value[ID::saturation0 + 20]->setFromNormalized(1.0);
      value[ID::saturation0 + 21]->setFromNormalized(1.0);
      value[ID::saturation0 + 22]->setFromNormalized(1.0);
      value[ID::saturation0 + 23]->setFromNormalized(1.0);
      value[ID::saturation0 + 24]->setFromNormalized(1.0);
      value[ID::saturation0 + 25]->setFromNormalized(1.0);
      value[ID::saturation0 + 26]->setFromNormalized(1.0);
      value[ID::saturation0 + 27]->setFromNormalized(1.0);
      value[ID::saturation0 + 28]->setFromNormalized(1.0);
      value[ID::saturation0 + 29]->setFromNormalized(1.0);
      value[ID::saturation0 + 30]->setFromNormalized(1.0);
      value[ID::saturation0 + 31]->setFromNormalized(1.0);
      value[ID::saturation0 + 32]->setFromNormalized(1.0);
      value[ID::saturation0 + 33]->setFromNormalized(1.0);
      value[ID::saturation0 + 34]->setFromNormalized(1.0);
      value[ID::saturation0 + 35]->setFromNormalized(1.0);
      value[ID::saturation0 + 36]->setFromNormalized(1.0);
      value[ID::saturation0 + 37]->setFromNormalized(1.0);
      value[ID::saturation0 + 38]->setFromNormalized(1.0);
      value[ID::saturation0 + 39]->setFromNormalized(1.0);
      value[ID::saturation0 + 40]->setFromNormalized(1.0);
      value[ID::saturation0 + 41]->setFromNormalized(1.0);
      value[ID::saturation0 + 42]->setFromNormalized(1.0);
      value[ID::saturation0 + 43]->setFromNormalized(1.0);
      value[ID::saturation0 + 44]->setFromNormalized(1.0);
      value[ID::saturation0 + 45]->setFromNormalized(1.0);
      value[ID::saturation0 + 46]->setFromNormalized(1.0);
      value[ID::saturation0 + 47]->setFromNormalized(1.0);
      value[ID::saturation0 + 48]->setFromNormalized(1.0);
      value[ID::saturation0 + 49]->setFromNormalized(1.0);
      value[ID::saturation0 + 50]->setFromNormalized(1.0);
      value[ID::saturation0 + 51]->setFromNormalized(1.0);
      value[ID::saturation0 + 52]->setFromNormalized(1.0);
      value[ID::saturation0 + 53]->setFromNormalized(1.0);
      value[ID::saturation0 + 54]->setFromNormalized(1.0);
      value[ID::saturation0 + 55]->setFromNormalized(1.0);
      value[ID::saturation0 + 56]->setFromNormalized(1.0);
      value[ID::saturation0 + 57]->setFromNormalized(1.0);
      value[ID::saturation0 + 58]->setFromNormalized(1.0);
      value[ID::saturation0 + 59]->setFromNormalized(1.0);
      value[ID::saturation0 + 60]->setFromNormalized(1.0);
      value[ID::saturation0 + 61]->setFromNormalized(1.0);
      value[ID::saturation0 + 62]->setFromNormalized(1.0);
      value[ID::saturation0 + 63]->setFromNormalized(1.0);
      value[ID::gain]->setFromNormalized(0.17200003564357758);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(1);
      value[ID::masterOctave]->setFromNormalized(1.0);
      value[ID::pitchMultiply]->setFromNormalized(1.0);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(1.0);
      value[ID::randomFrequency]->setFromNormalized(1.0);
      value[ID::randomAttack]->setFromNormalized(1.0);
      value[ID::randomDecay]->setFromNormalized(1.0);
      value[ID::randomSaturation]->setFromNormalized(1.0);
      value[ID::randomPhase]->setFromNormalized(1.0);
      value[ID::overtoneExpand]->setFromNormalized(0.4000000059604645);
      value[ID::overtoneShift]->setFromNormalized(1.0);
      value[ID::attackMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::decayMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441401183605194);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(1.0);
      value[ID::phaserFrequency]->setFromNormalized(1.0);
      value[ID::phaserFeedback]->setFromNormalized(0.9799999594688416);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(1.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(1.0);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.7880001068115234);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetLongDecay: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(1.0);
      value[ID::attack0 + 1]->setFromNormalized(1.0);
      value[ID::attack0 + 2]->setFromNormalized(1.0);
      value[ID::attack0 + 3]->setFromNormalized(1.0);
      value[ID::attack0 + 4]->setFromNormalized(1.0);
      value[ID::attack0 + 5]->setFromNormalized(1.0);
      value[ID::attack0 + 6]->setFromNormalized(1.0);
      value[ID::attack0 + 7]->setFromNormalized(1.0);
      value[ID::attack0 + 8]->setFromNormalized(1.0);
      value[ID::attack0 + 9]->setFromNormalized(1.0);
      value[ID::attack0 + 10]->setFromNormalized(1.0);
      value[ID::attack0 + 11]->setFromNormalized(1.0);
      value[ID::attack0 + 12]->setFromNormalized(1.0);
      value[ID::attack0 + 13]->setFromNormalized(1.0);
      value[ID::attack0 + 14]->setFromNormalized(1.0);
      value[ID::attack0 + 15]->setFromNormalized(1.0);
      value[ID::attack0 + 16]->setFromNormalized(1.0);
      value[ID::attack0 + 17]->setFromNormalized(1.0);
      value[ID::attack0 + 18]->setFromNormalized(1.0);
      value[ID::attack0 + 19]->setFromNormalized(1.0);
      value[ID::attack0 + 20]->setFromNormalized(1.0);
      value[ID::attack0 + 21]->setFromNormalized(1.0);
      value[ID::attack0 + 22]->setFromNormalized(1.0);
      value[ID::attack0 + 23]->setFromNormalized(1.0);
      value[ID::attack0 + 24]->setFromNormalized(1.0);
      value[ID::attack0 + 25]->setFromNormalized(1.0);
      value[ID::attack0 + 26]->setFromNormalized(1.0);
      value[ID::attack0 + 27]->setFromNormalized(1.0);
      value[ID::attack0 + 28]->setFromNormalized(1.0);
      value[ID::attack0 + 29]->setFromNormalized(1.0);
      value[ID::attack0 + 30]->setFromNormalized(1.0);
      value[ID::attack0 + 31]->setFromNormalized(1.0);
      value[ID::attack0 + 32]->setFromNormalized(1.0);
      value[ID::attack0 + 33]->setFromNormalized(1.0);
      value[ID::attack0 + 34]->setFromNormalized(1.0);
      value[ID::attack0 + 35]->setFromNormalized(1.0);
      value[ID::attack0 + 36]->setFromNormalized(1.0);
      value[ID::attack0 + 37]->setFromNormalized(1.0);
      value[ID::attack0 + 38]->setFromNormalized(1.0);
      value[ID::attack0 + 39]->setFromNormalized(1.0);
      value[ID::attack0 + 40]->setFromNormalized(1.0);
      value[ID::attack0 + 41]->setFromNormalized(1.0);
      value[ID::attack0 + 42]->setFromNormalized(1.0);
      value[ID::attack0 + 43]->setFromNormalized(1.0);
      value[ID::attack0 + 44]->setFromNormalized(1.0);
      value[ID::attack0 + 45]->setFromNormalized(1.0);
      value[ID::attack0 + 46]->setFromNormalized(1.0);
      value[ID::attack0 + 47]->setFromNormalized(1.0);
      value[ID::attack0 + 48]->setFromNormalized(1.0);
      value[ID::attack0 + 49]->setFromNormalized(1.0);
      value[ID::attack0 + 50]->setFromNormalized(1.0);
      value[ID::attack0 + 51]->setFromNormalized(1.0);
      value[ID::attack0 + 52]->setFromNormalized(1.0);
      value[ID::attack0 + 53]->setFromNormalized(1.0);
      value[ID::attack0 + 54]->setFromNormalized(1.0);
      value[ID::attack0 + 55]->setFromNormalized(1.0);
      value[ID::attack0 + 56]->setFromNormalized(1.0);
      value[ID::attack0 + 57]->setFromNormalized(1.0);
      value[ID::attack0 + 58]->setFromNormalized(1.0);
      value[ID::attack0 + 59]->setFromNormalized(1.0);
      value[ID::attack0 + 60]->setFromNormalized(1.0);
      value[ID::attack0 + 61]->setFromNormalized(1.0);
      value[ID::attack0 + 62]->setFromNormalized(1.0);
      value[ID::attack0 + 63]->setFromNormalized(1.0);
      value[ID::decay0 + 0]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 1]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 2]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 3]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 4]->setFromNormalized(0.9935689580811468);
      value[ID::decay0 + 5]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 6]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 7]->setFromNormalized(0.0);
      value[ID::decay0 + 8]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 9]->setFromNormalized(0.9935689580811468);
      value[ID::decay0 + 10]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 11]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 12]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 13]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 14]->setFromNormalized(1.0);
      value[ID::decay0 + 15]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 16]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 17]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 18]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 19]->setFromNormalized(0.9935689580811468);
      value[ID::decay0 + 20]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 21]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 22]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 23]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 24]->setFromNormalized(0.9935689580811468);
      value[ID::decay0 + 25]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 26]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 27]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 28]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 29]->setFromNormalized(1.0);
      value[ID::decay0 + 30]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 31]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 32]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 33]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 34]->setFromNormalized(0.9935689580811468);
      value[ID::decay0 + 35]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 36]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 37]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 38]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 39]->setFromNormalized(0.9935689580811468);
      value[ID::decay0 + 40]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 41]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 42]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 43]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 44]->setFromNormalized(1.0);
      value[ID::decay0 + 45]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 46]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 47]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 48]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 49]->setFromNormalized(0.9935689580811468);
      value[ID::decay0 + 50]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 51]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 52]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 53]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 54]->setFromNormalized(0.9935689580811468);
      value[ID::decay0 + 55]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 56]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 57]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 58]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 59]->setFromNormalized(1.0);
      value[ID::decay0 + 60]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 61]->setFromNormalized(0.23083492789635834);
      value[ID::decay0 + 62]->setFromNormalized(0.967666821004543);
      value[ID::decay0 + 63]->setFromNormalized(0.23083492789635834);
      value[ID::overtone0 + 0]->setFromNormalized(0.3658484688091802);
      value[ID::overtone0 + 1]->setFromNormalized(0.47841722844277423);
      value[ID::overtone0 + 2]->setFromNormalized(1.0);
      value[ID::overtone0 + 3]->setFromNormalized(0.9179588414405895);
      value[ID::overtone0 + 4]->setFromNormalized(0.8543227750049676);
      value[ID::overtone0 + 5]->setFromNormalized(0.8023283228576634);
      value[ID::overtone0 + 6]->setFromNormalized(0.7583676399483428);
      value[ID::overtone0 + 7]->setFromNormalized(0.7202871642982533);
      value[ID::overtone0 + 8]->setFromNormalized(0.6866978042747376);
      value[ID::overtone0 + 9]->setFromNormalized(0.6566510978626312);
      value[ID::overtone0 + 10]->setFromNormalized(0.6294705457100003);
      value[ID::overtone0 + 11]->setFromNormalized(0.6046566457153272);
      value[ID::overtone0 + 12]->setFromNormalized(0.5818300704761983);
      value[ID::overtone0 + 13]->setFromNormalized(0.5606959628060065);
      value[ID::overtone0 + 14]->setFromNormalized(0.541020579279705);
      value[ID::overtone0 + 15]->setFromNormalized(0.5226154871559168);
      value[ID::overtone0 + 16]->setFromNormalized(0.5053265606383284);
      value[ID::overtone0 + 17]->setFromNormalized(0.4890261271324009);
      value[ID::overtone0 + 18]->setFromNormalized(0.47360723976379415);
      value[ID::overtone0 + 19]->setFromNormalized(0.45897942072029474);
      value[ID::overtone0 + 20]->setFromNormalized(0.44506544422308025);
      value[ID::overtone0 + 21]->setFromNormalized(0.4317988685676638);
      value[ID::overtone0 + 22]->setFromNormalized(0.4191221172142049);
      value[ID::overtone0 + 23]->setFromNormalized(0.4069849685729906);
      value[ID::overtone0 + 24]->setFromNormalized(0.3953433542846727);
      value[ID::overtone0 + 25]->setFromNormalized(0.3841583933338617);
      value[ID::overtone0 + 26]->setFromNormalized(0.37339560854947473);
      value[ID::overtone0 + 27]->setFromNormalized(0.36302428566366984);
      value[ID::overtone0 + 28]->setFromNormalized(0.353016944892799);
      value[ID::overtone0 + 29]->setFromNormalized(0.3433489021373686);
      value[ID::overtone0 + 30]->setFromNormalized(0.3339979021587136);
      value[ID::overtone0 + 31]->setFromNormalized(0.3249438100135804);
      value[ID::overtone0 + 32]->setFromNormalized(0.3161683499847376);
      value[ID::overtone0 + 33]->setFromNormalized(0.3076548834959918);
      value[ID::overtone0 + 34]->setFromNormalized(0.29938821922804787);
      value[ID::overtone0 + 35]->setFromNormalized(0.29135444999006443);
      value[ID::overtone0 + 36]->setFromNormalized(0.2835408119465992);
      value[ID::overtone0 + 37]->setFromNormalized(0.2759355626214579);
      value[ID::overtone0 + 38]->setFromNormalized(0.26852787475093554);
      value[ID::overtone0 + 39]->setFromNormalized(0.2613077435779586);
      value[ID::overtone0 + 40]->setFromNormalized(0.2542659055951195);
      value[ID::overtone0 + 41]->setFromNormalized(0.247393767080744);
      value[ID::overtone0 + 42]->setFromNormalized(0.2406833410449501);
      value[ID::overtone0 + 43]->setFromNormalized(0.23412719142532756);
      value[ID::overtone0 + 44]->setFromNormalized(0.22771838355444274);
      value[ID::overtone0 + 45]->setFromNormalized(0.22145044007186865);
      value[ID::overtone0 + 46]->setFromNormalized(0.21531730157801937);
      value[ID::overtone0 + 47]->setFromNormalized(0.2093132914306545);
      value[ID::overtone0 + 48]->setFromNormalized(0.20343308417142322);
      value[ID::overtone0 + 49]->setFromNormalized(0.1976716771423364);
      value[ID::overtone0 + 50]->setFromNormalized(0.19202436491306596);
      value[ID::overtone0 + 51]->setFromNormalized(0.18648671619152565);
      value[ID::overtone0 + 52]->setFromNormalized(0.18105455293386113);
      value[ID::overtone0 + 53]->setFromNormalized(0.1757239314071386);
      value[ID::overtone0 + 54]->setFromNormalized(0.1704911249897057);
      value[ID::overtone0 + 55]->setFromNormalized(0.16535260852133363);
      value[ID::overtone0 + 56]->setFromNormalized(0.1603050440385317);
      value[ID::overtone0 + 57]->setFromNormalized(0.15534526775046267);
      value[ID::overtone0 + 58]->setFromNormalized(0.15047027812819938);
      value[ID::overtone0 + 59]->setFromNormalized(0.14567722499503244);
      value[ID::overtone0 + 60]->setFromNormalized(0.1409633995185322);
      value[ID::overtone0 + 61]->setFromNormalized(0.13632622501637748);
      value[ID::overtone0 + 62]->setFromNormalized(0.131763248497818);
      value[ID::overtone0 + 63]->setFromNormalized(0.12727213287124428);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(1.0);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.42800021171569824);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.1680000424385071);
      value[ID::randomAttack]->setFromNormalized(1.0);
      value[ID::randomDecay]->setFromNormalized(0.263999879360199);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(1.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.7720000147819519);
      value[ID::decayMultiplier]->setFromNormalized(0.8880002498626709);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.23444217443466187);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.5800002217292786);
      value[ID::phaserFrequency]->setFromNormalized(0.0);
      value[ID::phaserFeedback]->setFromNormalized(0.9800004959106445);
      value[ID::phaserRange]->setFromNormalized(0.1560000330209732);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.3679994940757752);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.5640000104904175);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetMaxAttack: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(1.0);
      value[ID::attack0 + 1]->setFromNormalized(1.0);
      value[ID::attack0 + 2]->setFromNormalized(1.0);
      value[ID::attack0 + 3]->setFromNormalized(1.0);
      value[ID::attack0 + 4]->setFromNormalized(1.0);
      value[ID::attack0 + 5]->setFromNormalized(1.0);
      value[ID::attack0 + 6]->setFromNormalized(1.0);
      value[ID::attack0 + 7]->setFromNormalized(1.0);
      value[ID::attack0 + 8]->setFromNormalized(1.0);
      value[ID::attack0 + 9]->setFromNormalized(1.0);
      value[ID::attack0 + 10]->setFromNormalized(1.0);
      value[ID::attack0 + 11]->setFromNormalized(1.0);
      value[ID::attack0 + 12]->setFromNormalized(1.0);
      value[ID::attack0 + 13]->setFromNormalized(1.0);
      value[ID::attack0 + 14]->setFromNormalized(1.0);
      value[ID::attack0 + 15]->setFromNormalized(1.0);
      value[ID::attack0 + 16]->setFromNormalized(1.0);
      value[ID::attack0 + 17]->setFromNormalized(1.0);
      value[ID::attack0 + 18]->setFromNormalized(1.0);
      value[ID::attack0 + 19]->setFromNormalized(1.0);
      value[ID::attack0 + 20]->setFromNormalized(1.0);
      value[ID::attack0 + 21]->setFromNormalized(1.0);
      value[ID::attack0 + 22]->setFromNormalized(1.0);
      value[ID::attack0 + 23]->setFromNormalized(1.0);
      value[ID::attack0 + 24]->setFromNormalized(1.0);
      value[ID::attack0 + 25]->setFromNormalized(1.0);
      value[ID::attack0 + 26]->setFromNormalized(1.0);
      value[ID::attack0 + 27]->setFromNormalized(1.0);
      value[ID::attack0 + 28]->setFromNormalized(1.0);
      value[ID::attack0 + 29]->setFromNormalized(1.0);
      value[ID::attack0 + 30]->setFromNormalized(1.0);
      value[ID::attack0 + 31]->setFromNormalized(1.0);
      value[ID::attack0 + 32]->setFromNormalized(1.0);
      value[ID::attack0 + 33]->setFromNormalized(1.0);
      value[ID::attack0 + 34]->setFromNormalized(1.0);
      value[ID::attack0 + 35]->setFromNormalized(1.0);
      value[ID::attack0 + 36]->setFromNormalized(1.0);
      value[ID::attack0 + 37]->setFromNormalized(1.0);
      value[ID::attack0 + 38]->setFromNormalized(1.0);
      value[ID::attack0 + 39]->setFromNormalized(1.0);
      value[ID::attack0 + 40]->setFromNormalized(1.0);
      value[ID::attack0 + 41]->setFromNormalized(1.0);
      value[ID::attack0 + 42]->setFromNormalized(1.0);
      value[ID::attack0 + 43]->setFromNormalized(1.0);
      value[ID::attack0 + 44]->setFromNormalized(1.0);
      value[ID::attack0 + 45]->setFromNormalized(1.0);
      value[ID::attack0 + 46]->setFromNormalized(1.0);
      value[ID::attack0 + 47]->setFromNormalized(1.0);
      value[ID::attack0 + 48]->setFromNormalized(1.0);
      value[ID::attack0 + 49]->setFromNormalized(1.0);
      value[ID::attack0 + 50]->setFromNormalized(1.0);
      value[ID::attack0 + 51]->setFromNormalized(1.0);
      value[ID::attack0 + 52]->setFromNormalized(1.0);
      value[ID::attack0 + 53]->setFromNormalized(1.0);
      value[ID::attack0 + 54]->setFromNormalized(1.0);
      value[ID::attack0 + 55]->setFromNormalized(1.0);
      value[ID::attack0 + 56]->setFromNormalized(1.0);
      value[ID::attack0 + 57]->setFromNormalized(1.0);
      value[ID::attack0 + 58]->setFromNormalized(1.0);
      value[ID::attack0 + 59]->setFromNormalized(1.0);
      value[ID::attack0 + 60]->setFromNormalized(1.0);
      value[ID::attack0 + 61]->setFromNormalized(1.0);
      value[ID::attack0 + 62]->setFromNormalized(1.0);
      value[ID::attack0 + 63]->setFromNormalized(1.0);
      value[ID::decay0 + 0]->setFromNormalized(0.9214285714285715);
      value[ID::decay0 + 1]->setFromNormalized(0.9165322576250349);
      value[ID::decay0 + 2]->setFromNormalized(0.9067396300179618);
      value[ID::decay0 + 3]->setFromNormalized(0.8969470024108886);
      value[ID::decay0 + 4]->setFromNormalized(0.8871543748038155);
      value[ID::decay0 + 5]->setFromNormalized(0.8773617471967424);
      value[ID::decay0 + 6]->setFromNormalized(0.8675691195896693);
      value[ID::decay0 + 7]->setFromNormalized(0.8577764919825963);
      value[ID::decay0 + 8]->setFromNormalized(0.8479838643755232);
      value[ID::decay0 + 9]->setFromNormalized(0.8381912367684501);
      value[ID::decay0 + 10]->setFromNormalized(0.828398609161377);
      value[ID::decay0 + 11]->setFromNormalized(0.8186059815543039);
      value[ID::decay0 + 12]->setFromNormalized(0.8088133539472308);
      value[ID::decay0 + 13]->setFromNormalized(0.7990207263401576);
      value[ID::decay0 + 14]->setFromNormalized(0.7892280987330845);
      value[ID::decay0 + 15]->setFromNormalized(0.7794354711260114);
      value[ID::decay0 + 16]->setFromNormalized(0.7696428571428572);
      value[ID::decay0 + 17]->setFromNormalized(0.7598502295357841);
      value[ID::decay0 + 18]->setFromNormalized(0.750057601928711);
      value[ID::decay0 + 19]->setFromNormalized(0.7402649743216378);
      value[ID::decay0 + 20]->setFromNormalized(0.7304723467145647);
      value[ID::decay0 + 21]->setFromNormalized(0.7206797191074916);
      value[ID::decay0 + 22]->setFromNormalized(0.7108870915004185);
      value[ID::decay0 + 23]->setFromNormalized(0.7010944638933454);
      value[ID::decay0 + 24]->setFromNormalized(0.6913018362862724);
      value[ID::decay0 + 25]->setFromNormalized(0.6815092086791992);
      value[ID::decay0 + 26]->setFromNormalized(0.6717165810721262);
      value[ID::decay0 + 27]->setFromNormalized(0.661923953465053);
      value[ID::decay0 + 28]->setFromNormalized(0.65213132585798);
      value[ID::decay0 + 29]->setFromNormalized(0.6423386982509067);
      value[ID::decay0 + 30]->setFromNormalized(0.6325460706438337);
      value[ID::decay0 + 31]->setFromNormalized(0.6227534430367606);
      value[ID::decay0 + 32]->setFromNormalized(0.6129608154296875);
      value[ID::decay0 + 33]->setFromNormalized(0.6031681878226144);
      value[ID::decay0 + 34]->setFromNormalized(0.5933755602155413);
      value[ID::decay0 + 35]->setFromNormalized(0.5835829326084683);
      value[ID::decay0 + 36]->setFromNormalized(0.573790305001395);
      value[ID::decay0 + 37]->setFromNormalized(0.563997677394322);
      value[ID::decay0 + 38]->setFromNormalized(0.5542050497872488);
      value[ID::decay0 + 39]->setFromNormalized(0.5444124221801758);
      value[ID::decay0 + 40]->setFromNormalized(0.5346197945731026);
      value[ID::decay0 + 41]->setFromNormalized(0.5248271942138671);
      value[ID::decay0 + 42]->setFromNormalized(0.5150345938546317);
      value[ID::decay0 + 43]->setFromNormalized(0.5052419934953962);
      value[ID::decay0 + 44]->setFromNormalized(0.49544939313616077);
      value[ID::decay0 + 45]->setFromNormalized(0.4856567927769252);
      value[ID::decay0 + 46]->setFromNormalized(0.47586419241768974);
      value[ID::decay0 + 47]->setFromNormalized(0.4660715920584543);
      value[ID::decay0 + 48]->setFromNormalized(0.4562789916992187);
      value[ID::decay0 + 49]->setFromNormalized(0.44648639133998325);
      value[ID::decay0 + 50]->setFromNormalized(0.4366937909807478);
      value[ID::decay0 + 51]->setFromNormalized(0.4269011906215123);
      value[ID::decay0 + 52]->setFromNormalized(0.41710859026227676);
      value[ID::decay0 + 53]->setFromNormalized(0.4073159899030413);
      value[ID::decay0 + 54]->setFromNormalized(0.39752338954380584);
      value[ID::decay0 + 55]->setFromNormalized(0.38773078918457027);
      value[ID::decay0 + 56]->setFromNormalized(0.3779381888253348);
      value[ID::decay0 + 57]->setFromNormalized(0.36814558846609935);
      value[ID::decay0 + 58]->setFromNormalized(0.3583529881068639);
      value[ID::decay0 + 59]->setFromNormalized(0.3485603877476283);
      value[ID::decay0 + 60]->setFromNormalized(0.33876778738839286);
      value[ID::decay0 + 61]->setFromNormalized(0.3289751870291574);
      value[ID::decay0 + 62]->setFromNormalized(0.31918258666992183);
      value[ID::decay0 + 63]->setFromNormalized(0.3142857142857143);
      value[ID::overtone0 + 0]->setFromNormalized(0.31597052221186006);
      value[ID::overtone0 + 1]->setFromNormalized(0.6510174423513178);
      value[ID::overtone0 + 2]->setFromNormalized(0.7743806099549367);
      value[ID::overtone0 + 3]->setFromNormalized(0.6928571428571428);
      value[ID::overtone0 + 4]->setFromNormalized(0.4428571428571429);
      value[ID::overtone0 + 5]->setFromNormalized(0.8571428571428573);
      value[ID::overtone0 + 6]->setFromNormalized(0.7154021604224008);
      value[ID::overtone0 + 7]->setFromNormalized(0.747926305975688);
      value[ID::overtone0 + 8]->setFromNormalized(0.9391499550043483);
      value[ID::overtone0 + 9]->setFromNormalized(0.48571428571428577);
      value[ID::overtone0 + 10]->setFromNormalized(0.7141512528639938);
      value[ID::overtone0 + 11]->setFromNormalized(0.9195012272796068);
      value[ID::overtone0 + 12]->setFromNormalized(0.3999999999999999);
      value[ID::overtone0 + 13]->setFromNormalized(0.6846202285524976);
      value[ID::overtone0 + 14]->setFromNormalized(0.3836055460652206);
      value[ID::overtone0 + 15]->setFromNormalized(0.9040762768206931);
      value[ID::overtone0 + 16]->setFromNormalized(0.5502310137654256);
      value[ID::overtone0 + 17]->setFromNormalized(0.30714285714285705);
      value[ID::overtone0 + 18]->setFromNormalized(0.6784963330921306);
      value[ID::overtone0 + 19]->setFromNormalized(0.7991969521356863);
      value[ID::overtone0 + 20]->setFromNormalized(0.8395309686132941);
      value[ID::overtone0 + 21]->setFromNormalized(0.31428571428571417);
      value[ID::overtone0 + 22]->setFromNormalized(0.14351902118533175);
      value[ID::overtone0 + 23]->setFromNormalized(0.36344113734243966);
      value[ID::overtone0 + 24]->setFromNormalized(0.3445464058125607);
      value[ID::overtone0 + 25]->setFromNormalized(0.5710529982276299);
      value[ID::overtone0 + 26]->setFromNormalized(0.723931440836296);
      value[ID::overtone0 + 27]->setFromNormalized(0.7299928637018461);
      value[ID::overtone0 + 28]->setFromNormalized(0.13720286158834405);
      value[ID::overtone0 + 29]->setFromNormalized(0.9336303063866873);
      value[ID::overtone0 + 30]->setFromNormalized(0.6708205287736542);
      value[ID::overtone0 + 31]->setFromNormalized(0.9595563935439884);
      value[ID::overtone0 + 32]->setFromNormalized(0.03768234640605996);
      value[ID::overtone0 + 33]->setFromNormalized(0.2254745898183997);
      value[ID::overtone0 + 34]->setFromNormalized(0.972685593286873);
      value[ID::overtone0 + 35]->setFromNormalized(0.31501200409112906);
      value[ID::overtone0 + 36]->setFromNormalized(0.8661692647868572);
      value[ID::overtone0 + 37]->setFromNormalized(0.024804471645813918);
      value[ID::overtone0 + 38]->setFromNormalized(0.4323203535015582);
      value[ID::overtone0 + 39]->setFromNormalized(0.018862137149936585);
      value[ID::overtone0 + 40]->setFromNormalized(0.16322469073526785);
      value[ID::overtone0 + 41]->setFromNormalized(0.8935321712875071);
      value[ID::overtone0 + 42]->setFromNormalized(0.6260871900375178);
      value[ID::overtone0 + 43]->setFromNormalized(0.8676127195718928);
      value[ID::overtone0 + 44]->setFromNormalized(0.46568759828438716);
      value[ID::overtone0 + 45]->setFromNormalized(0.8376571923995595);
      value[ID::overtone0 + 46]->setFromNormalized(0.780001251574899);
      value[ID::overtone0 + 47]->setFromNormalized(0.8428010664356782);
      value[ID::overtone0 + 48]->setFromNormalized(0.859567549803225);
      value[ID::overtone0 + 49]->setFromNormalized(0.6329896297430389);
      value[ID::overtone0 + 50]->setFromNormalized(0.42857142857142866);
      value[ID::overtone0 + 51]->setFromNormalized(0.028571428571428647);
      value[ID::overtone0 + 52]->setFromNormalized(0.9714285714285713);
      value[ID::overtone0 + 53]->setFromNormalized(0.65);
      value[ID::overtone0 + 54]->setFromNormalized(0.6785714285714286);
      value[ID::overtone0 + 55]->setFromNormalized(0.7642857142857142);
      value[ID::overtone0 + 56]->setFromNormalized(0.8785714285714284);
      value[ID::overtone0 + 57]->setFromNormalized(0.9071428571428571);
      value[ID::overtone0 + 58]->setFromNormalized(0.8714285714285716);
      value[ID::overtone0 + 59]->setFromNormalized(0.8071428571428572);
      value[ID::overtone0 + 60]->setFromNormalized(0.8142857142857143);
      value[ID::overtone0 + 61]->setFromNormalized(0.7214285714285714);
      value[ID::overtone0 + 62]->setFromNormalized(0.06644647280185403);
      value[ID::overtone0 + 63]->setFromNormalized(0.7879144076643323);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.050000000000000044);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.7214285714285714);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.30714285714285716);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.6800000667572021);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.3079995810985565);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.1680000275373459);
      value[ID::randomPhase]->setFromNormalized(0.16000008583068848);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::decayMultiplier]->setFromNormalized(0.23600001633167267);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441401183605194);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.23199991881847384);
      value[ID::phaserFeedback]->setFromNormalized(0.8480000495910645);
      value[ID::phaserRange]->setFromNormalized(0.7520000338554382);
      value[ID::phaserMin]->setFromNormalized(1.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(0);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetMetallicContact: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.0);
      value[ID::attack0 + 6]->setFromNormalized(0.0);
      value[ID::attack0 + 7]->setFromNormalized(0.0);
      value[ID::attack0 + 8]->setFromNormalized(0.0);
      value[ID::attack0 + 9]->setFromNormalized(0.0);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.0);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.0);
      value[ID::attack0 + 14]->setFromNormalized(0.0);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.0);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.0);
      value[ID::attack0 + 22]->setFromNormalized(0.0);
      value[ID::attack0 + 23]->setFromNormalized(0.0);
      value[ID::attack0 + 24]->setFromNormalized(0.0);
      value[ID::attack0 + 25]->setFromNormalized(0.0);
      value[ID::attack0 + 26]->setFromNormalized(0.0);
      value[ID::attack0 + 27]->setFromNormalized(0.0);
      value[ID::attack0 + 28]->setFromNormalized(0.0);
      value[ID::attack0 + 29]->setFromNormalized(0.0);
      value[ID::attack0 + 30]->setFromNormalized(0.0);
      value[ID::attack0 + 31]->setFromNormalized(0.0);
      value[ID::attack0 + 32]->setFromNormalized(0.0);
      value[ID::attack0 + 33]->setFromNormalized(0.0);
      value[ID::attack0 + 34]->setFromNormalized(0.0);
      value[ID::attack0 + 35]->setFromNormalized(0.0);
      value[ID::attack0 + 36]->setFromNormalized(0.0);
      value[ID::attack0 + 37]->setFromNormalized(0.0);
      value[ID::attack0 + 38]->setFromNormalized(0.0);
      value[ID::attack0 + 39]->setFromNormalized(0.0);
      value[ID::attack0 + 40]->setFromNormalized(0.0);
      value[ID::attack0 + 41]->setFromNormalized(0.0);
      value[ID::attack0 + 42]->setFromNormalized(0.0);
      value[ID::attack0 + 43]->setFromNormalized(0.0);
      value[ID::attack0 + 44]->setFromNormalized(0.0);
      value[ID::attack0 + 45]->setFromNormalized(0.0);
      value[ID::attack0 + 46]->setFromNormalized(0.0);
      value[ID::attack0 + 47]->setFromNormalized(0.0);
      value[ID::attack0 + 48]->setFromNormalized(0.0);
      value[ID::attack0 + 49]->setFromNormalized(0.0);
      value[ID::attack0 + 50]->setFromNormalized(0.0);
      value[ID::attack0 + 51]->setFromNormalized(0.0);
      value[ID::attack0 + 52]->setFromNormalized(0.0);
      value[ID::attack0 + 53]->setFromNormalized(0.0);
      value[ID::attack0 + 54]->setFromNormalized(0.0);
      value[ID::attack0 + 55]->setFromNormalized(0.0);
      value[ID::attack0 + 56]->setFromNormalized(0.0);
      value[ID::attack0 + 57]->setFromNormalized(0.0);
      value[ID::attack0 + 58]->setFromNormalized(0.0);
      value[ID::attack0 + 59]->setFromNormalized(0.0);
      value[ID::attack0 + 60]->setFromNormalized(0.0);
      value[ID::attack0 + 61]->setFromNormalized(0.0);
      value[ID::attack0 + 62]->setFromNormalized(0.0);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 1]->setFromNormalized(0.20714285714285718);
      value[ID::decay0 + 2]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 3]->setFromNormalized(0.27142857142857146);
      value[ID::decay0 + 4]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 5]->setFromNormalized(0.3642857142857143);
      value[ID::decay0 + 6]->setFromNormalized(0.40714285714285714);
      value[ID::decay0 + 7]->setFromNormalized(0.4357142857142857);
      value[ID::decay0 + 8]->setFromNormalized(0.44999999999999996);
      value[ID::decay0 + 9]->setFromNormalized(0.5571428571428572);
      value[ID::decay0 + 10]->setFromNormalized(0.6428571428571428);
      value[ID::decay0 + 11]->setFromNormalized(0.9357142857142857);
      value[ID::decay0 + 12]->setFromNormalized(0.6);
      value[ID::decay0 + 13]->setFromNormalized(0.4214285714285714);
      value[ID::decay0 + 14]->setFromNormalized(0.3214285714285714);
      value[ID::decay0 + 15]->setFromNormalized(0.25);
      value[ID::decay0 + 16]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 17]->setFromNormalized(0.1785714285714286);
      value[ID::decay0 + 18]->setFromNormalized(0.17142857142857137);
      value[ID::decay0 + 19]->setFromNormalized(0.17142857142857137);
      value[ID::decay0 + 20]->setFromNormalized(0.18571428571428572);
      value[ID::decay0 + 21]->setFromNormalized(0.22142857142857142);
      value[ID::decay0 + 22]->setFromNormalized(0.2571428571428571);
      value[ID::decay0 + 23]->setFromNormalized(0.4642857142857143);
      value[ID::decay0 + 24]->setFromNormalized(0.8571428571428572);
      value[ID::decay0 + 25]->setFromNormalized(0.6785714285714286);
      value[ID::decay0 + 26]->setFromNormalized(0.5571428571428572);
      value[ID::decay0 + 27]->setFromNormalized(0.44999999999999996);
      value[ID::decay0 + 28]->setFromNormalized(0.26428571428571423);
      value[ID::decay0 + 29]->setFromNormalized(0.12857142857142856);
      value[ID::decay0 + 30]->setFromNormalized(0.035714285714285705);
      value[ID::decay0 + 31]->setFromNormalized(0.028571428571428584);
      value[ID::decay0 + 32]->setFromNormalized(0.21428571428571433);
      value[ID::decay0 + 33]->setFromNormalized(0.35);
      value[ID::decay0 + 34]->setFromNormalized(0.4928571428571429);
      value[ID::decay0 + 35]->setFromNormalized(0.6357142857142857);
      value[ID::decay0 + 36]->setFromNormalized(0.8071428571428572);
      value[ID::decay0 + 37]->setFromNormalized(0.8714285714285714);
      value[ID::decay0 + 38]->setFromNormalized(0.8285714285714285);
      value[ID::decay0 + 39]->setFromNormalized(0.7571428571428571);
      value[ID::decay0 + 40]->setFromNormalized(0.6071428571428572);
      value[ID::decay0 + 41]->setFromNormalized(0.5214285714285714);
      value[ID::decay0 + 42]->setFromNormalized(0.3642857142857143);
      value[ID::decay0 + 43]->setFromNormalized(0.2785714285714286);
      value[ID::decay0 + 44]->setFromNormalized(0.12857142857142856);
      value[ID::decay0 + 45]->setFromNormalized(0.12142857142857146);
      value[ID::decay0 + 46]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 47]->setFromNormalized(0.4714285714285714);
      value[ID::decay0 + 48]->setFromNormalized(0.6785714285714286);
      value[ID::decay0 + 49]->setFromNormalized(0.75);
      value[ID::decay0 + 50]->setFromNormalized(0.7357142857142858);
      value[ID::decay0 + 51]->setFromNormalized(0.65);
      value[ID::decay0 + 52]->setFromNormalized(0.5928571428571429);
      value[ID::decay0 + 53]->setFromNormalized(0.5357142857142857);
      value[ID::decay0 + 54]->setFromNormalized(0.5785714285714285);
      value[ID::decay0 + 55]->setFromNormalized(0.5428571428571429);
      value[ID::decay0 + 56]->setFromNormalized(0.4928571428571429);
      value[ID::decay0 + 57]->setFromNormalized(0.33571428571428574);
      value[ID::decay0 + 58]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 59]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 60]->setFromNormalized(0.21428571428571433);
      value[ID::decay0 + 61]->setFromNormalized(0.21428571428571433);
      value[ID::decay0 + 62]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 63]->setFromNormalized(0.17142857142857137);
      value[ID::overtone0 + 0]->setFromNormalized(0.34285714285714286);
      value[ID::overtone0 + 1]->setFromNormalized(0.3857142857142857);
      value[ID::overtone0 + 2]->setFromNormalized(0.4357142857142858);
      value[ID::overtone0 + 3]->setFromNormalized(0.4428571428571429);
      value[ID::overtone0 + 4]->setFromNormalized(0.55);
      value[ID::overtone0 + 5]->setFromNormalized(0.9071428571428571);
      value[ID::overtone0 + 6]->setFromNormalized(1.0);
      value[ID::overtone0 + 7]->setFromNormalized(0.9214285714285715);
      value[ID::overtone0 + 8]->setFromNormalized(0.7142857142857143);
      value[ID::overtone0 + 9]->setFromNormalized(0.5785714285714285);
      value[ID::overtone0 + 10]->setFromNormalized(0.5785714285714285);
      value[ID::overtone0 + 11]->setFromNormalized(0.5785714285714285);
      value[ID::overtone0 + 12]->setFromNormalized(0.5785714285714285);
      value[ID::overtone0 + 13]->setFromNormalized(0.6071428571428572);
      value[ID::overtone0 + 14]->setFromNormalized(0.7071428571428571);
      value[ID::overtone0 + 15]->setFromNormalized(0.8642857142857142);
      value[ID::overtone0 + 16]->setFromNormalized(0.38477553931086295);
      value[ID::overtone0 + 17]->setFromNormalized(0.06428571428571424);
      value[ID::overtone0 + 18]->setFromNormalized(0.14464285714285713);
      value[ID::overtone0 + 19]->setFromNormalized(0.3053571428571429);
      value[ID::overtone0 + 20]->setFromNormalized(0.4660714285714286);
      value[ID::overtone0 + 21]->setFromNormalized(0.6267857142857143);
      value[ID::overtone0 + 22]->setFromNormalized(0.7);
      value[ID::overtone0 + 23]->setFromNormalized(0.6476190567016602);
      value[ID::overtone0 + 24]->setFromNormalized(0.5428571701049805);
      value[ID::overtone0 + 25]->setFromNormalized(0.4380952562604632);
      value[ID::overtone0 + 26]->setFromNormalized(0.3857142857142857);
      value[ID::overtone0 + 27]->setFromNormalized(0.2764209843288903);
      value[ID::overtone0 + 28]->setFromNormalized(0.48571428571428577);
      value[ID::overtone0 + 29]->setFromNormalized(0.48571428571428577);
      value[ID::overtone0 + 30]->setFromNormalized(0.25431915308286346);
      value[ID::overtone0 + 31]->setFromNormalized(0.8142857142857143);
      value[ID::overtone0 + 32]->setFromNormalized(0.8714285714285716);
      value[ID::overtone0 + 33]->setFromNormalized(0.9142857142857143);
      value[ID::overtone0 + 34]->setFromNormalized(0.22796597782486216);
      value[ID::overtone0 + 35]->setFromNormalized(0.41428571428571426);
      value[ID::overtone0 + 36]->setFromNormalized(0.27857142857142847);
      value[ID::overtone0 + 37]->setFromNormalized(0.2);
      value[ID::overtone0 + 38]->setFromNormalized(0.03571428571428577);
      value[ID::overtone0 + 39]->setFromNormalized(0.02142857142857153);
      value[ID::overtone0 + 40]->setFromNormalized(0.02142857142857153);
      value[ID::overtone0 + 41]->setFromNormalized(0.18837535480104978);
      value[ID::overtone0 + 42]->setFromNormalized(0.02142857142857153);
      value[ID::overtone0 + 43]->setFromNormalized(0.042857142857142885);
      value[ID::overtone0 + 44]->setFromNormalized(0.1733937431123282);
      value[ID::overtone0 + 45]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 46]->setFromNormalized(0.21428571428571433);
      value[ID::overtone0 + 47]->setFromNormalized(0.29999999999999993);
      value[ID::overtone0 + 48]->setFromNormalized(0.4571428571428572);
      value[ID::overtone0 + 49]->setFromNormalized(0.5);
      value[ID::overtone0 + 50]->setFromNormalized(0.3999999999999999);
      value[ID::overtone0 + 51]->setFromNormalized(0.35);
      value[ID::overtone0 + 52]->setFromNormalized(0.35);
      value[ID::overtone0 + 53]->setFromNormalized(0.35);
      value[ID::overtone0 + 54]->setFromNormalized(0.3214285714285713);
      value[ID::overtone0 + 55]->setFromNormalized(0.16428571428571423);
      value[ID::overtone0 + 56]->setFromNormalized(0.12857142857142848);
      value[ID::overtone0 + 57]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 58]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 59]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 60]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 61]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 62]->setFromNormalized(0.10032972527320912);
      value[ID::overtone0 + 63]->setFromNormalized(0.07857142857142865);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(8120178);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.6360000967979431);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.5640000104904175);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.4000000059604645);
      value[ID::overtoneShift]->setFromNormalized(0.09600000828504562);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.1680000126361847);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetModuloKey: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.8785714285714286);
      value[ID::attack0 + 1]->setFromNormalized(0.8532019751412527);
      value[ID::attack0 + 2]->setFromNormalized(0.8024630546569824);
      value[ID::attack0 + 3]->setFromNormalized(0.7517241341727121);
      value[ID::attack0 + 4]->setFromNormalized(0.7009852273123605);
      value[ID::attack0 + 5]->setFromNormalized(0.6502463204520089);
      value[ID::attack0 + 6]->setFromNormalized(0.5995074135916574);
      value[ID::attack0 + 7]->setFromNormalized(0.5487685067313057);
      value[ID::attack0 + 8]->setFromNormalized(0.498029545375279);
      value[ID::attack0 + 9]->setFromNormalized(0.44729063851492745);
      value[ID::attack0 + 10]->setFromNormalized(0.3965517316545759);
      value[ID::attack0 + 11]->setFromNormalized(0.34581282479422437);
      value[ID::attack0 + 12]->setFromNormalized(0.2950739179338727);
      value[ID::attack0 + 13]->setFromNormalized(0.24433501107352112);
      value[ID::attack0 + 14]->setFromNormalized(0.19359610421316958);
      value[ID::attack0 + 15]->setFromNormalized(0.14285719735281804);
      value[ID::attack0 + 16]->setFromNormalized(0.09211829049246653);
      value[ID::attack0 + 17]->setFromNormalized(0.0413793291364397);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.0);
      value[ID::attack0 + 22]->setFromNormalized(0.0);
      value[ID::attack0 + 23]->setFromNormalized(0.0);
      value[ID::attack0 + 24]->setFromNormalized(0.0);
      value[ID::attack0 + 25]->setFromNormalized(0.7642857142857142);
      value[ID::attack0 + 26]->setFromNormalized(0.6853174482073103);
      value[ID::attack0 + 27]->setFromNormalized(0.5273809705461774);
      value[ID::attack0 + 28]->setFromNormalized(0.36944443838936947);
      value[ID::attack0 + 29]->setFromNormalized(0.21150796072823658);
      value[ID::attack0 + 30]->setFromNormalized(0.05357142857142859);
      value[ID::attack0 + 31]->setFromNormalized(0.0);
      value[ID::attack0 + 32]->setFromNormalized(0.0);
      value[ID::attack0 + 33]->setFromNormalized(0.0);
      value[ID::attack0 + 34]->setFromNormalized(0.0);
      value[ID::attack0 + 35]->setFromNormalized(0.0);
      value[ID::attack0 + 36]->setFromNormalized(0.0);
      value[ID::attack0 + 37]->setFromNormalized(0.0);
      value[ID::attack0 + 38]->setFromNormalized(0.0);
      value[ID::attack0 + 39]->setFromNormalized(0.0);
      value[ID::attack0 + 40]->setFromNormalized(0.0);
      value[ID::attack0 + 41]->setFromNormalized(0.0);
      value[ID::attack0 + 42]->setFromNormalized(0.0);
      value[ID::attack0 + 43]->setFromNormalized(0.0);
      value[ID::attack0 + 44]->setFromNormalized(0.0);
      value[ID::attack0 + 45]->setFromNormalized(0.0);
      value[ID::attack0 + 46]->setFromNormalized(0.18571428571428567);
      value[ID::attack0 + 47]->setFromNormalized(0.2061688559395926);
      value[ID::attack0 + 48]->setFromNormalized(0.2470779418945312);
      value[ID::attack0 + 49]->setFromNormalized(0.28798702784946983);
      value[ID::attack0 + 50]->setFromNormalized(0.32889611380440853);
      value[ID::attack0 + 51]->setFromNormalized(0.3698051997593471);
      value[ID::attack0 + 52]->setFromNormalized(0.4107142857142857);
      value[ID::attack0 + 53]->setFromNormalized(0.4516233716692243);
      value[ID::attack0 + 54]->setFromNormalized(0.492532457624163);
      value[ID::attack0 + 55]->setFromNormalized(0.5334415435791016);
      value[ID::attack0 + 56]->setFromNormalized(0.5743506022862026);
      value[ID::attack0 + 57]->setFromNormalized(0.6152596882411412);
      value[ID::attack0 + 58]->setFromNormalized(0.6357142857142857);
      value[ID::attack0 + 59]->setFromNormalized(0.0);
      value[ID::attack0 + 60]->setFromNormalized(0.0);
      value[ID::attack0 + 61]->setFromNormalized(0.0);
      value[ID::attack0 + 62]->setFromNormalized(0.0);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.0);
      value[ID::decay0 + 1]->setFromNormalized(0.0);
      value[ID::decay0 + 2]->setFromNormalized(0.0);
      value[ID::decay0 + 3]->setFromNormalized(0.0);
      value[ID::decay0 + 4]->setFromNormalized(0.029047720772879433);
      value[ID::decay0 + 5]->setFromNormalized(0.07000013078962056);
      value[ID::decay0 + 6]->setFromNormalized(0.11095248631068647);
      value[ID::decay0 + 7]->setFromNormalized(0.15190484183175224);
      value[ID::decay0 + 8]->setFromNormalized(0.19285719735281803);
      value[ID::decay0 + 9]->setFromNormalized(0.23380955287388394);
      value[ID::decay0 + 10]->setFromNormalized(0.27476190839494974);
      value[ID::decay0 + 11]->setFromNormalized(0.31571426391601565);
      value[ID::decay0 + 12]->setFromNormalized(0.35666661943708144);
      value[ID::decay0 + 13]->setFromNormalized(0.39761897495814735);
      value[ID::decay0 + 14]->setFromNormalized(0.43857133047921315);
      value[ID::decay0 + 15]->setFromNormalized(0.47952368600027906);
      value[ID::decay0 + 16]->setFromNormalized(0.0);
      value[ID::decay0 + 17]->setFromNormalized(0.0);
      value[ID::decay0 + 18]->setFromNormalized(0.0);
      value[ID::decay0 + 19]->setFromNormalized(0.0);
      value[ID::decay0 + 20]->setFromNormalized(0.0);
      value[ID::decay0 + 21]->setFromNormalized(0.0);
      value[ID::decay0 + 22]->setFromNormalized(0.0);
      value[ID::decay0 + 23]->setFromNormalized(0.0);
      value[ID::decay0 + 24]->setFromNormalized(0.0);
      value[ID::decay0 + 25]->setFromNormalized(0.0);
      value[ID::decay0 + 26]->setFromNormalized(0.07214290073939733);
      value[ID::decay0 + 27]->setFromNormalized(0.17071440560477125);
      value[ID::decay0 + 28]->setFromNormalized(0.26928585597446986);
      value[ID::decay0 + 29]->setFromNormalized(0.3678573063441686);
      value[ID::decay0 + 30]->setFromNormalized(0.4664287567138672);
      value[ID::decay0 + 31]->setFromNormalized(0.5650002070835658);
      value[ID::decay0 + 32]->setFromNormalized(0.0);
      value[ID::decay0 + 33]->setFromNormalized(0.0);
      value[ID::decay0 + 34]->setFromNormalized(0.0);
      value[ID::decay0 + 35]->setFromNormalized(0.0);
      value[ID::decay0 + 36]->setFromNormalized(0.0);
      value[ID::decay0 + 37]->setFromNormalized(0.0);
      value[ID::decay0 + 38]->setFromNormalized(0.0);
      value[ID::decay0 + 39]->setFromNormalized(0.0);
      value[ID::decay0 + 40]->setFromNormalized(0.0);
      value[ID::decay0 + 41]->setFromNormalized(0.0);
      value[ID::decay0 + 42]->setFromNormalized(0.0);
      value[ID::decay0 + 43]->setFromNormalized(0.0);
      value[ID::decay0 + 44]->setFromNormalized(0.0);
      value[ID::decay0 + 45]->setFromNormalized(0.0);
      value[ID::decay0 + 46]->setFromNormalized(0.0);
      value[ID::decay0 + 47]->setFromNormalized(0.08169642857142856);
      value[ID::decay0 + 48]->setFromNormalized(0.17544642857142856);
      value[ID::decay0 + 49]->setFromNormalized(0.26919642857142856);
      value[ID::decay0 + 50]->setFromNormalized(0.36294642857142856);
      value[ID::decay0 + 51]->setFromNormalized(0.45669642857142856);
      value[ID::decay0 + 52]->setFromNormalized(0.5504464285714286);
      value[ID::decay0 + 53]->setFromNormalized(0.6441964285714286);
      value[ID::decay0 + 54]->setFromNormalized(0.7379464285714286);
      value[ID::decay0 + 55]->setFromNormalized(0.8316964285714286);
      value[ID::decay0 + 56]->setFromNormalized(0.8785714285714286);
      value[ID::decay0 + 57]->setFromNormalized(0.05456894283106585);
      value[ID::decay0 + 58]->setFromNormalized(0.05453046944166419);
      value[ID::decay0 + 59]->setFromNormalized(0.03992774524131448);
      value[ID::decay0 + 60]->setFromNormalized(0.03930000918682948);
      value[ID::decay0 + 61]->setFromNormalized(0.038866632119093816);
      value[ID::decay0 + 62]->setFromNormalized(0.01726351213351824);
      value[ID::decay0 + 63]->setFromNormalized(0.011014551274340093);
      value[ID::overtone0 + 0]->setFromNormalized(0.0);
      value[ID::overtone0 + 1]->setFromNormalized(0.0);
      value[ID::overtone0 + 2]->setFromNormalized(0.0);
      value[ID::overtone0 + 3]->setFromNormalized(0.0);
      value[ID::overtone0 + 4]->setFromNormalized(0.0);
      value[ID::overtone0 + 5]->setFromNormalized(0.0);
      value[ID::overtone0 + 6]->setFromNormalized(0.0);
      value[ID::overtone0 + 7]->setFromNormalized(0.0);
      value[ID::overtone0 + 8]->setFromNormalized(0.06785736083984376);
      value[ID::overtone0 + 9]->setFromNormalized(0.19807717459542412);
      value[ID::overtone0 + 10]->setFromNormalized(0.3282969883510045);
      value[ID::overtone0 + 11]->setFromNormalized(0.4585168021065849);
      value[ID::overtone0 + 12]->setFromNormalized(0.5887366158621652);
      value[ID::overtone0 + 13]->setFromNormalized(0.7189563751220703);
      value[ID::overtone0 + 14]->setFromNormalized(0.8491761752537318);
      value[ID::overtone0 + 15]->setFromNormalized(0.0);
      value[ID::overtone0 + 16]->setFromNormalized(0.0);
      value[ID::overtone0 + 17]->setFromNormalized(0.0);
      value[ID::overtone0 + 18]->setFromNormalized(0.0);
      value[ID::overtone0 + 19]->setFromNormalized(0.0);
      value[ID::overtone0 + 20]->setFromNormalized(0.0);
      value[ID::overtone0 + 21]->setFromNormalized(0.0);
      value[ID::overtone0 + 22]->setFromNormalized(0.018067060198102603);
      value[ID::overtone0 + 23]->setFromNormalized(0.09117627825055799);
      value[ID::overtone0 + 24]->setFromNormalized(0.16428549630301337);
      value[ID::overtone0 + 25]->setFromNormalized(0.23739471435546866);
      value[ID::overtone0 + 26]->setFromNormalized(0.31050393240792395);
      value[ID::overtone0 + 27]->setFromNormalized(0.3836131504603795);
      value[ID::overtone0 + 28]->setFromNormalized(0.4567223685128349);
      value[ID::overtone0 + 29]->setFromNormalized(0.5298315865652902);
      value[ID::overtone0 + 30]->setFromNormalized(0.6029408591134207);
      value[ID::overtone0 + 31]->setFromNormalized(0.6760500771658762);
      value[ID::overtone0 + 32]->setFromNormalized(0.7491593497140068);
      value[ID::overtone0 + 33]->setFromNormalized(0.0);
      value[ID::overtone0 + 34]->setFromNormalized(0.0);
      value[ID::overtone0 + 35]->setFromNormalized(0.0);
      value[ID::overtone0 + 36]->setFromNormalized(0.0);
      value[ID::overtone0 + 37]->setFromNormalized(0.0);
      value[ID::overtone0 + 38]->setFromNormalized(0.001714324951171875);
      value[ID::overtone0 + 39]->setFromNormalized(0.035428619384765624);
      value[ID::overtone0 + 40]->setFromNormalized(0.06914291381835938);
      value[ID::overtone0 + 41]->setFromNormalized(0.10285720825195313);
      value[ID::overtone0 + 42]->setFromNormalized(0.13657150268554688);
      value[ID::overtone0 + 43]->setFromNormalized(0.17028579711914063);
      value[ID::overtone0 + 44]->setFromNormalized(0.20400009155273438);
      value[ID::overtone0 + 45]->setFromNormalized(0.23771438598632813);
      value[ID::overtone0 + 46]->setFromNormalized(0.27142868041992185);
      value[ID::overtone0 + 47]->setFromNormalized(0.3051429748535156);
      value[ID::overtone0 + 48]->setFromNormalized(0.33885726928710935);
      value[ID::overtone0 + 49]->setFromNormalized(0.3725715637207031);
      value[ID::overtone0 + 50]->setFromNormalized(0.40628585815429685);
      value[ID::overtone0 + 51]->setFromNormalized(0.4400001525878906);
      value[ID::overtone0 + 52]->setFromNormalized(0.47371444702148435);
      value[ID::overtone0 + 53]->setFromNormalized(0.5074287414550781);
      value[ID::overtone0 + 54]->setFromNormalized(0.5411430358886719);
      value[ID::overtone0 + 55]->setFromNormalized(0.5748573303222656);
      value[ID::overtone0 + 56]->setFromNormalized(0.6085716247558594);
      value[ID::overtone0 + 57]->setFromNormalized(0.6422859191894531);
      value[ID::overtone0 + 58]->setFromNormalized(0.6760002136230469);
      value[ID::overtone0 + 59]->setFromNormalized(0.6928571428571428);
      value[ID::overtone0 + 60]->setFromNormalized(0.03475794306121767);
      value[ID::overtone0 + 61]->setFromNormalized(0.022763502295125092);
      value[ID::overtone0 + 62]->setFromNormalized(0.0036972072912913488);
      value[ID::overtone0 + 63]->setFromNormalized(0.0034052791160620543);
      value[ID::saturation0 + 0]->setFromNormalized(0.8857142857142857);
      value[ID::saturation0 + 1]->setFromNormalized(0.8489130428859166);
      value[ID::saturation0 + 2]->setFromNormalized(0.7753105572291783);
      value[ID::saturation0 + 3]->setFromNormalized(0.7017080579485212);
      value[ID::saturation0 + 4]->setFromNormalized(0.6281055995396205);
      value[ID::saturation0 + 5]->setFromNormalized(0.5545030866350446);
      value[ID::saturation0 + 6]->setFromNormalized(0.4809005737304688);
      value[ID::saturation0 + 7]->setFromNormalized(0.40729806082589276);
      value[ID::saturation0 + 8]->setFromNormalized(0.3336955479213169);
      value[ID::saturation0 + 9]->setFromNormalized(0.26009303501674097);
      value[ID::saturation0 + 10]->setFromNormalized(0.1864905221121652);
      value[ID::saturation0 + 11]->setFromNormalized(0.11288800920758923);
      value[ID::saturation0 + 12]->setFromNormalized(0.03928549630301339);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.9);
      value[ID::saturation0 + 18]->setFromNormalized(0.8692176818847657);
      value[ID::saturation0 + 19]->setFromNormalized(0.8076530729021345);
      value[ID::saturation0 + 20]->setFromNormalized(0.7460884366716658);
      value[ID::saturation0 + 21]->setFromNormalized(0.6845238276890346);
      value[ID::saturation0 + 22]->setFromNormalized(0.6229591914585659);
      value[ID::saturation0 + 23]->setFromNormalized(0.5613945552280971);
      value[ID::saturation0 + 24]->setFromNormalized(0.4998299189976283);
      value[ID::saturation0 + 25]->setFromNormalized(0.4382652827671595);
      value[ID::saturation0 + 26]->setFromNormalized(0.3767006465366909);
      value[ID::saturation0 + 27]->setFromNormalized(0.315136010306222);
      value[ID::saturation0 + 28]->setFromNormalized(0.25357137407575336);
      value[ID::saturation0 + 29]->setFromNormalized(0.19200673784528455);
      value[ID::saturation0 + 30]->setFromNormalized(0.1304421016148158);
      value[ID::saturation0 + 31]->setFromNormalized(0.06887751988002228);
      value[ID::saturation0 + 32]->setFromNormalized(0.007312883649553703);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.7571428571428571);
      value[ID::saturation0 + 36]->setFromNormalized(0.7351851872035435);
      value[ID::saturation0 + 37]->setFromNormalized(0.6912698473249164);
      value[ID::saturation0 + 38]->setFromNormalized(0.6473545074462891);
      value[ID::saturation0 + 39]->setFromNormalized(0.6034391675676618);
      value[ID::saturation0 + 40]->setFromNormalized(0.5595238276890345);
      value[ID::saturation0 + 41]->setFromNormalized(0.5156084878104074);
      value[ID::saturation0 + 42]->setFromNormalized(0.4716931479317802);
      value[ID::saturation0 + 43]->setFromNormalized(0.4277778080531528);
      value[ID::saturation0 + 44]->setFromNormalized(0.38386246817452563);
      value[ID::saturation0 + 45]->setFromNormalized(0.3399471282958984);
      value[ID::saturation0 + 46]->setFromNormalized(0.2960317884172712);
      value[ID::saturation0 + 47]->setFromNormalized(0.25211644853864396);
      value[ID::saturation0 + 48]->setFromNormalized(0.20820110866001673);
      value[ID::saturation0 + 49]->setFromNormalized(0.16428576878138956);
      value[ID::saturation0 + 50]->setFromNormalized(0.12037042890276228);
      value[ID::saturation0 + 51]->setFromNormalized(0.0764550345284598);
      value[ID::saturation0 + 52]->setFromNormalized(0.032539694649832605);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.8960006237030029);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.6919990181922913);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.04000000283122063);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.49599993228912354);
      value[ID::phaserFrequency]->setFromNormalized(0.45999994874000555);
      value[ID::phaserFeedback]->setFromNormalized(0.3479999601840973);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(7);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetNotHappening: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.06428571428571427);
      value[ID::attack0 + 1]->setFromNormalized(0.10714285714285708);
      value[ID::attack0 + 2]->setFromNormalized(0.13571428571428565);
      value[ID::attack0 + 3]->setFromNormalized(0.1928571428571428);
      value[ID::attack0 + 4]->setFromNormalized(0.2285714285714285);
      value[ID::attack0 + 5]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 6]->setFromNormalized(0.3214285714285714);
      value[ID::attack0 + 7]->setFromNormalized(0.33571428571428574);
      value[ID::attack0 + 8]->setFromNormalized(0.3928571428571429);
      value[ID::attack0 + 9]->setFromNormalized(0.4285714285714286);
      value[ID::attack0 + 10]->setFromNormalized(0.44999999999999996);
      value[ID::attack0 + 11]->setFromNormalized(0.48571428571428577);
      value[ID::attack0 + 12]->setFromNormalized(0.4928571428571429);
      value[ID::attack0 + 13]->setFromNormalized(0.55);
      value[ID::attack0 + 14]->setFromNormalized(0.5642857142857143);
      value[ID::attack0 + 15]->setFromNormalized(0.6142857142857143);
      value[ID::attack0 + 16]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 17]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 18]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 19]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 20]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 21]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 22]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 23]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 24]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 25]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 26]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 27]->setFromNormalized(0.5857142857142856);
      value[ID::attack0 + 28]->setFromNormalized(0.5642857142857143);
      value[ID::attack0 + 29]->setFromNormalized(0.5357142857142857);
      value[ID::attack0 + 30]->setFromNormalized(0.5571428571428572);
      value[ID::attack0 + 31]->setFromNormalized(0.5214285714285714);
      value[ID::attack0 + 32]->setFromNormalized(0.4928571428571429);
      value[ID::attack0 + 33]->setFromNormalized(0.4714285714285714);
      value[ID::attack0 + 34]->setFromNormalized(0.44285714285714284);
      value[ID::attack0 + 35]->setFromNormalized(0.41428571428571426);
      value[ID::attack0 + 36]->setFromNormalized(0.40714285714285714);
      value[ID::attack0 + 37]->setFromNormalized(0.3571428571428571);
      value[ID::attack0 + 38]->setFromNormalized(0.33571428571428574);
      value[ID::attack0 + 39]->setFromNormalized(0.33571428571428574);
      value[ID::attack0 + 40]->setFromNormalized(0.2928571428571428);
      value[ID::attack0 + 41]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 42]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 43]->setFromNormalized(0.26428571428571423);
      value[ID::attack0 + 44]->setFromNormalized(0.24285714285714285);
      value[ID::attack0 + 45]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 46]->setFromNormalized(0.20714285714285716);
      value[ID::attack0 + 47]->setFromNormalized(0.1857142857142857);
      value[ID::attack0 + 48]->setFromNormalized(0.16428571428571423);
      value[ID::attack0 + 49]->setFromNormalized(0.16428571428571423);
      value[ID::attack0 + 50]->setFromNormalized(0.1571428571428571);
      value[ID::attack0 + 51]->setFromNormalized(0.12142857142857143);
      value[ID::attack0 + 52]->setFromNormalized(0.10714285714285708);
      value[ID::attack0 + 53]->setFromNormalized(0.10714285714285708);
      value[ID::attack0 + 54]->setFromNormalized(0.07142857142857138);
      value[ID::attack0 + 55]->setFromNormalized(0.06428571428571427);
      value[ID::attack0 + 56]->setFromNormalized(0.05000000000000004);
      value[ID::attack0 + 57]->setFromNormalized(0.03571428571428569);
      value[ID::attack0 + 58]->setFromNormalized(0.03571428571428569);
      value[ID::attack0 + 59]->setFromNormalized(0.02142857142857146);
      value[ID::attack0 + 60]->setFromNormalized(0.02142857142857146);
      value[ID::attack0 + 61]->setFromNormalized(0.02142857142857146);
      value[ID::attack0 + 62]->setFromNormalized(0.014285714285714231);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.09285714285714287);
      value[ID::decay0 + 1]->setFromNormalized(0.0642857142857143);
      value[ID::decay0 + 2]->setFromNormalized(0.05000000000000005);
      value[ID::decay0 + 3]->setFromNormalized(0.05000000000000005);
      value[ID::decay0 + 4]->setFromNormalized(0.05000000000000005);
      value[ID::decay0 + 5]->setFromNormalized(0.05000000000000005);
      value[ID::decay0 + 6]->setFromNormalized(0.07857142857142864);
      value[ID::decay0 + 7]->setFromNormalized(0.08571428571428576);
      value[ID::decay0 + 8]->setFromNormalized(0.09999999999999999);
      value[ID::decay0 + 9]->setFromNormalized(0.12142857142857146);
      value[ID::decay0 + 10]->setFromNormalized(0.12857142857142856);
      value[ID::decay0 + 11]->setFromNormalized(0.15000000000000002);
      value[ID::decay0 + 12]->setFromNormalized(0.18571428571428572);
      value[ID::decay0 + 13]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 14]->setFromNormalized(0.21428571428571433);
      value[ID::decay0 + 15]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 16]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 17]->setFromNormalized(0.25);
      value[ID::decay0 + 18]->setFromNormalized(0.26428571428571423);
      value[ID::decay0 + 19]->setFromNormalized(0.27142857142857146);
      value[ID::decay0 + 20]->setFromNormalized(0.2928571428571428);
      value[ID::decay0 + 21]->setFromNormalized(0.30714285714285716);
      value[ID::decay0 + 22]->setFromNormalized(0.35);
      value[ID::decay0 + 23]->setFromNormalized(0.37142857142857144);
      value[ID::decay0 + 24]->setFromNormalized(0.4);
      value[ID::decay0 + 25]->setFromNormalized(0.4357142857142857);
      value[ID::decay0 + 26]->setFromNormalized(0.5071428571428571);
      value[ID::decay0 + 27]->setFromNormalized(0.5142857142857142);
      value[ID::decay0 + 28]->setFromNormalized(0.5571428571428572);
      value[ID::decay0 + 29]->setFromNormalized(0.5785714285714285);
      value[ID::decay0 + 30]->setFromNormalized(0.6214285714285714);
      value[ID::decay0 + 31]->setFromNormalized(0.6428571428571428);
      value[ID::decay0 + 32]->setFromNormalized(0.6785714285714286);
      value[ID::decay0 + 33]->setFromNormalized(0.7071428571428571);
      value[ID::decay0 + 34]->setFromNormalized(0.7428571428571429);
      value[ID::decay0 + 35]->setFromNormalized(0.7714285714285715);
      value[ID::decay0 + 36]->setFromNormalized(0.8214285714285714);
      value[ID::decay0 + 37]->setFromNormalized(0.85);
      value[ID::decay0 + 38]->setFromNormalized(0.8928571428571429);
      value[ID::decay0 + 39]->setFromNormalized(0.9214285714285715);
      value[ID::decay0 + 40]->setFromNormalized(0.9357142857142857);
      value[ID::decay0 + 41]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 42]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 43]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 44]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 45]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 46]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 47]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 48]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 49]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 50]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 51]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 52]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 53]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 54]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 55]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 56]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 57]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 58]->setFromNormalized(0.9571428571428572);
      value[ID::decay0 + 59]->setFromNormalized(0.9);
      value[ID::decay0 + 60]->setFromNormalized(0.9142857142857143);
      value[ID::decay0 + 61]->setFromNormalized(0.8928571428571429);
      value[ID::decay0 + 62]->setFromNormalized(0.5);
      value[ID::decay0 + 63]->setFromNormalized(0.5);
      value[ID::overtone0 + 0]->setFromNormalized(0.3642857142857143);
      value[ID::overtone0 + 1]->setFromNormalized(0.4642857142857143);
      value[ID::overtone0 + 2]->setFromNormalized(0.5142857142857142);
      value[ID::overtone0 + 3]->setFromNormalized(0.55);
      value[ID::overtone0 + 4]->setFromNormalized(0.5785714285714285);
      value[ID::overtone0 + 5]->setFromNormalized(0.6);
      value[ID::overtone0 + 6]->setFromNormalized(0.6214285714285714);
      value[ID::overtone0 + 7]->setFromNormalized(0.65);
      value[ID::overtone0 + 8]->setFromNormalized(0.6714285714285715);
      value[ID::overtone0 + 9]->setFromNormalized(0.7142857142857143);
      value[ID::overtone0 + 10]->setFromNormalized(0.7285714285714286);
      value[ID::overtone0 + 11]->setFromNormalized(0.75);
      value[ID::overtone0 + 12]->setFromNormalized(0.7857142857142857);
      value[ID::overtone0 + 13]->setFromNormalized(0.8285714285714285);
      value[ID::overtone0 + 14]->setFromNormalized(0.8785714285714284);
      value[ID::overtone0 + 15]->setFromNormalized(0.9642857142857142);
      value[ID::overtone0 + 16]->setFromNormalized(1.0);
      value[ID::overtone0 + 17]->setFromNormalized(1.0);
      value[ID::overtone0 + 18]->setFromNormalized(1.0);
      value[ID::overtone0 + 19]->setFromNormalized(1.0);
      value[ID::overtone0 + 20]->setFromNormalized(1.0);
      value[ID::overtone0 + 21]->setFromNormalized(1.0);
      value[ID::overtone0 + 22]->setFromNormalized(1.0);
      value[ID::overtone0 + 23]->setFromNormalized(1.0);
      value[ID::overtone0 + 24]->setFromNormalized(0.9928571428571429);
      value[ID::overtone0 + 25]->setFromNormalized(0.9214285714285715);
      value[ID::overtone0 + 26]->setFromNormalized(0.8285714285714285);
      value[ID::overtone0 + 27]->setFromNormalized(0.8285714285714285);
      value[ID::overtone0 + 28]->setFromNormalized(0.8142857142857143);
      value[ID::overtone0 + 29]->setFromNormalized(0.8);
      value[ID::overtone0 + 30]->setFromNormalized(0.7714285714285715);
      value[ID::overtone0 + 31]->setFromNormalized(0.75);
      value[ID::overtone0 + 32]->setFromNormalized(0.7142857142857143);
      value[ID::overtone0 + 33]->setFromNormalized(0.7);
      value[ID::overtone0 + 34]->setFromNormalized(0.6642857142857144);
      value[ID::overtone0 + 35]->setFromNormalized(0.6214285714285714);
      value[ID::overtone0 + 36]->setFromNormalized(0.5857142857142856);
      value[ID::overtone0 + 37]->setFromNormalized(0.5428571428571429);
      value[ID::overtone0 + 38]->setFromNormalized(0.5142857142857142);
      value[ID::overtone0 + 39]->setFromNormalized(0.4928571428571429);
      value[ID::overtone0 + 40]->setFromNormalized(0.47857142857142854);
      value[ID::overtone0 + 41]->setFromNormalized(0.4357142857142858);
      value[ID::overtone0 + 42]->setFromNormalized(0.40714285714285714);
      value[ID::overtone0 + 43]->setFromNormalized(0.3857142857142857);
      value[ID::overtone0 + 44]->setFromNormalized(0.3642857142857143);
      value[ID::overtone0 + 45]->setFromNormalized(0.34285714285714286);
      value[ID::overtone0 + 46]->setFromNormalized(0.3285714285714286);
      value[ID::overtone0 + 47]->setFromNormalized(0.30714285714285705);
      value[ID::overtone0 + 48]->setFromNormalized(0.2857142857142856);
      value[ID::overtone0 + 49]->setFromNormalized(0.26428571428571423);
      value[ID::overtone0 + 50]->setFromNormalized(0.24285714285714288);
      value[ID::overtone0 + 51]->setFromNormalized(0.22857142857142856);
      value[ID::overtone0 + 52]->setFromNormalized(0.22857142857142856);
      value[ID::overtone0 + 53]->setFromNormalized(0.2);
      value[ID::overtone0 + 54]->setFromNormalized(0.18571428571428578);
      value[ID::overtone0 + 55]->setFromNormalized(0.18571428571428578);
      value[ID::overtone0 + 56]->setFromNormalized(0.17142857142857118);
      value[ID::overtone0 + 57]->setFromNormalized(0.16428571428571423);
      value[ID::overtone0 + 58]->setFromNormalized(0.1428571428571427);
      value[ID::overtone0 + 59]->setFromNormalized(0.12857142857142848);
      value[ID::overtone0 + 60]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 61]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 62]->setFromNormalized(0.12142857142857152);
      value[ID::overtone0 + 63]->setFromNormalized(0.12142857142857152);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.5843762507903832);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.952989487392368);
      value[ID::saturation0 + 9]->setFromNormalized(0.28529195576478705);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.3214285714285714);
      value[ID::saturation0 + 13]->setFromNormalized(0.7395319302991868);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.7145327671233985);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.19999999999999998);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.2624663247185161);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.6855575566012251);
      value[ID::saturation0 + 27]->setFromNormalized(0.2056633157831999);
      value[ID::saturation0 + 28]->setFromNormalized(0.9070603913039283);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.5104786222053562);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.20600888257743527);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.2522172863956759);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.3438305316111002);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.16439518721367585);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.014909568799360244);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.250237965108395);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.4972726737690813);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.16399997472763062);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.39799949526786804);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(0.220000222325325);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetNotSoMuch: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.0);
      value[ID::attack0 + 6]->setFromNormalized(0.0);
      value[ID::attack0 + 7]->setFromNormalized(0.0);
      value[ID::attack0 + 8]->setFromNormalized(0.0);
      value[ID::attack0 + 9]->setFromNormalized(0.0);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.0);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.0);
      value[ID::attack0 + 14]->setFromNormalized(0.0);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.0);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.0);
      value[ID::attack0 + 22]->setFromNormalized(0.0);
      value[ID::attack0 + 23]->setFromNormalized(0.0);
      value[ID::attack0 + 24]->setFromNormalized(0.0);
      value[ID::attack0 + 25]->setFromNormalized(0.0);
      value[ID::attack0 + 26]->setFromNormalized(0.0);
      value[ID::attack0 + 27]->setFromNormalized(0.0);
      value[ID::attack0 + 28]->setFromNormalized(0.0);
      value[ID::attack0 + 29]->setFromNormalized(0.0);
      value[ID::attack0 + 30]->setFromNormalized(0.0);
      value[ID::attack0 + 31]->setFromNormalized(0.0);
      value[ID::attack0 + 32]->setFromNormalized(0.0);
      value[ID::attack0 + 33]->setFromNormalized(0.0);
      value[ID::attack0 + 34]->setFromNormalized(0.0);
      value[ID::attack0 + 35]->setFromNormalized(0.0);
      value[ID::attack0 + 36]->setFromNormalized(0.0);
      value[ID::attack0 + 37]->setFromNormalized(0.0);
      value[ID::attack0 + 38]->setFromNormalized(0.0);
      value[ID::attack0 + 39]->setFromNormalized(0.0);
      value[ID::attack0 + 40]->setFromNormalized(0.0);
      value[ID::attack0 + 41]->setFromNormalized(0.0);
      value[ID::attack0 + 42]->setFromNormalized(0.0);
      value[ID::attack0 + 43]->setFromNormalized(0.0);
      value[ID::attack0 + 44]->setFromNormalized(0.0);
      value[ID::attack0 + 45]->setFromNormalized(0.0);
      value[ID::attack0 + 46]->setFromNormalized(0.0);
      value[ID::attack0 + 47]->setFromNormalized(0.0);
      value[ID::attack0 + 48]->setFromNormalized(0.0);
      value[ID::attack0 + 49]->setFromNormalized(0.0);
      value[ID::attack0 + 50]->setFromNormalized(0.0);
      value[ID::attack0 + 51]->setFromNormalized(0.0);
      value[ID::attack0 + 52]->setFromNormalized(0.0);
      value[ID::attack0 + 53]->setFromNormalized(0.0);
      value[ID::attack0 + 54]->setFromNormalized(0.0);
      value[ID::attack0 + 55]->setFromNormalized(0.0);
      value[ID::attack0 + 56]->setFromNormalized(0.0);
      value[ID::attack0 + 57]->setFromNormalized(0.0);
      value[ID::attack0 + 58]->setFromNormalized(0.0);
      value[ID::attack0 + 59]->setFromNormalized(0.0);
      value[ID::attack0 + 60]->setFromNormalized(0.0);
      value[ID::attack0 + 61]->setFromNormalized(0.0);
      value[ID::attack0 + 62]->setFromNormalized(0.0);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.536816348068379);
      value[ID::decay0 + 1]->setFromNormalized(0.07898165957184546);
      value[ID::decay0 + 2]->setFromNormalized(0.9043526866649673);
      value[ID::decay0 + 3]->setFromNormalized(0.6862669561968405);
      value[ID::decay0 + 4]->setFromNormalized(0.3105038164401128);
      value[ID::decay0 + 5]->setFromNormalized(0.7871457636176099);
      value[ID::decay0 + 6]->setFromNormalized(0.03050691187185584);
      value[ID::decay0 + 7]->setFromNormalized(0.8203423538352274);
      value[ID::decay0 + 8]->setFromNormalized(0.1675973676241247);
      value[ID::decay0 + 9]->setFromNormalized(0.11550842699812792);
      value[ID::decay0 + 10]->setFromNormalized(0.04735455352604102);
      value[ID::decay0 + 11]->setFromNormalized(0.48651722540308057);
      value[ID::decay0 + 12]->setFromNormalized(0.1294226551381325);
      value[ID::decay0 + 13]->setFromNormalized(0.915629451266848);
      value[ID::decay0 + 14]->setFromNormalized(0.08564566382022094);
      value[ID::decay0 + 15]->setFromNormalized(0.4044555944383388);
      value[ID::decay0 + 16]->setFromNormalized(0.5669253233121971);
      value[ID::decay0 + 17]->setFromNormalized(0.6218004737416395);
      value[ID::decay0 + 18]->setFromNormalized(0.8663505063089534);
      value[ID::decay0 + 19]->setFromNormalized(0.49285564670144416);
      value[ID::decay0 + 20]->setFromNormalized(0.9119374675193881);
      value[ID::decay0 + 21]->setFromNormalized(0.06878277554701401);
      value[ID::decay0 + 22]->setFromNormalized(0.670813073622344);
      value[ID::decay0 + 23]->setFromNormalized(0.06397313703117365);
      value[ID::decay0 + 24]->setFromNormalized(0.8686478526347806);
      value[ID::decay0 + 25]->setFromNormalized(0.4677573898695115);
      value[ID::decay0 + 26]->setFromNormalized(0.38655660897476607);
      value[ID::decay0 + 27]->setFromNormalized(0.9048958461996544);
      value[ID::decay0 + 28]->setFromNormalized(0.48364584453819504);
      value[ID::decay0 + 29]->setFromNormalized(0.2164267612017501);
      value[ID::decay0 + 30]->setFromNormalized(0.20135012577336867);
      value[ID::decay0 + 31]->setFromNormalized(0.9379254843693834);
      value[ID::decay0 + 32]->setFromNormalized(0.1958391032800437);
      value[ID::decay0 + 33]->setFromNormalized(0.4741547492158684);
      value[ID::decay0 + 34]->setFromNormalized(0.5756377571865814);
      value[ID::decay0 + 35]->setFromNormalized(0.9434184914281022);
      value[ID::decay0 + 36]->setFromNormalized(0.27692165893108894);
      value[ID::decay0 + 37]->setFromNormalized(0.9673505884939252);
      value[ID::decay0 + 38]->setFromNormalized(0.8028746740189537);
      value[ID::decay0 + 39]->setFromNormalized(0.187535910864138);
      value[ID::decay0 + 40]->setFromNormalized(0.8838016455271097);
      value[ID::decay0 + 41]->setFromNormalized(0.07201931230786784);
      value[ID::decay0 + 42]->setFromNormalized(0.26771854913832077);
      value[ID::decay0 + 43]->setFromNormalized(0.5662810980860291);
      value[ID::decay0 + 44]->setFromNormalized(0.594810775489203);
      value[ID::decay0 + 45]->setFromNormalized(0.2573848758535779);
      value[ID::decay0 + 46]->setFromNormalized(0.6613060605136728);
      value[ID::decay0 + 47]->setFromNormalized(0.8027033507242931);
      value[ID::decay0 + 48]->setFromNormalized(0.5786722650351718);
      value[ID::decay0 + 49]->setFromNormalized(0.6907431781757591);
      value[ID::decay0 + 50]->setFromNormalized(0.17222397035766918);
      value[ID::decay0 + 51]->setFromNormalized(0.4564191303995301);
      value[ID::decay0 + 52]->setFromNormalized(0.9470045173523517);
      value[ID::decay0 + 53]->setFromNormalized(0.01518085127316249);
      value[ID::decay0 + 54]->setFromNormalized(0.7698545596447113);
      value[ID::decay0 + 55]->setFromNormalized(0.9878338006943731);
      value[ID::decay0 + 56]->setFromNormalized(0.6981228819688855);
      value[ID::decay0 + 57]->setFromNormalized(0.034538377628913486);
      value[ID::decay0 + 58]->setFromNormalized(0.3461778854952435);
      value[ID::decay0 + 59]->setFromNormalized(0.2044443577048183);
      value[ID::decay0 + 60]->setFromNormalized(0.8776929273756905);
      value[ID::decay0 + 61]->setFromNormalized(0.4334204095657425);
      value[ID::decay0 + 62]->setFromNormalized(0.30276999752006334);
      value[ID::decay0 + 63]->setFromNormalized(0.17896079901591255);
      value[ID::overtone0 + 0]->setFromNormalized(1.0);
      value[ID::overtone0 + 1]->setFromNormalized(0.8494850021680094);
      value[ID::overtone0 + 2]->setFromNormalized(0.7614393726401688);
      value[ID::overtone0 + 3]->setFromNormalized(0.6989700043360187);
      value[ID::overtone0 + 4]->setFromNormalized(0.6505149978319906);
      value[ID::overtone0 + 5]->setFromNormalized(0.6109243748081781);
      value[ID::overtone0 + 6]->setFromNormalized(0.5774509799928716);
      value[ID::overtone0 + 7]->setFromNormalized(0.5484550065040282);
      value[ID::overtone0 + 8]->setFromNormalized(0.5228787452803376);
      value[ID::overtone0 + 9]->setFromNormalized(0.5);
      value[ID::overtone0 + 10]->setFromNormalized(0.47930365742088743);
      value[ID::overtone0 + 11]->setFromNormalized(0.46040937697618756);
      value[ID::overtone0 + 12]->setFromNormalized(0.44302832384658164);
      value[ID::overtone0 + 13]->setFromNormalized(0.426935982160881);
      value[ID::overtone0 + 14]->setFromNormalized(0.4119543704721593);
      value[ID::overtone0 + 15]->setFromNormalized(0.3979400086720375);
      value[ID::overtone0 + 16]->setFromNormalized(0.38477553931086295);
      value[ID::overtone0 + 17]->setFromNormalized(0.37236374744834677);
      value[ID::overtone0 + 18]->setFromNormalized(0.36062319952358546);
      value[ID::overtone0 + 19]->setFromNormalized(0.3494850021680094);
      value[ID::overtone0 + 20]->setFromNormalized(0.33889035263304024);
      value[ID::overtone0 + 21]->setFromNormalized(0.3287886595888967);
      value[ID::overtone0 + 22]->setFromNormalized(0.31913608199120347);
      value[ID::overtone0 + 23]->setFromNormalized(0.3098943791441968);
      value[ID::overtone0 + 24]->setFromNormalized(0.30102999566398125);
      value[ID::overtone0 + 25]->setFromNormalized(0.2925133260145909);
      value[ID::overtone0 + 26]->setFromNormalized(0.2843181179205061);
      value[ID::overtone0 + 27]->setFromNormalized(0.2764209843288903);
      value[ID::overtone0 + 28]->setFromNormalized(0.268801001050522);
      value[ID::overtone0 + 29]->setFromNormalized(0.2614393726401687);
      value[ID::overtone0 + 30]->setFromNormalized(0.25431915308286346);
      value[ID::overtone0 + 31]->setFromNormalized(0.24742501084004687);
      value[ID::overtone0 + 32]->setFromNormalized(0.24074303006105602);
      value[ID::overtone0 + 33]->setFromNormalized(0.23426054147887232);
      value[ID::overtone0 + 34]->setFromNormalized(0.22796597782486216);
      value[ID::overtone0 + 35]->setFromNormalized(0.22184874961635614);
      value[ID::overtone0 + 36]->setFromNormalized(0.2158991379665025);
      value[ID::overtone0 + 37]->setFromNormalized(0.21010820169159494);
      value[ID::overtone0 + 38]->setFromNormalized(0.20446769648675023);
      value[ID::overtone0 + 39]->setFromNormalized(0.1989700043360189);
      value[ID::overtone0 + 40]->setFromNormalized(0.19360807164013227);
      value[ID::overtone0 + 41]->setFromNormalized(0.18837535480104978);
      value[ID::overtone0 + 42]->setFromNormalized(0.18326577221020662);
      value[ID::overtone0 + 43]->setFromNormalized(0.17827366175690623);
      value[ID::overtone0 + 44]->setFromNormalized(0.1733937431123282);
      value[ID::overtone0 + 45]->setFromNormalized(0.168621084159213);
      value[ID::overtone0 + 46]->setFromNormalized(0.16395107103214118);
      value[ID::overtone0 + 47]->setFromNormalized(0.15937938131220636);
      value[ID::overtone0 + 48]->setFromNormalized(0.15490195998574324);
      value[ID::overtone0 + 49]->setFromNormalized(0.15051499783199063);
      value[ID::overtone0 + 50]->setFromNormalized(0.1462149119510318);
      value[ID::overtone0 + 51]->setFromNormalized(0.14199832818260044);
      value[ID::overtone0 + 52]->setFromNormalized(0.1378620651996055);
      value[ID::overtone0 + 53]->setFromNormalized(0.13380312008851564);
      value[ID::overtone0 + 54]->setFromNormalized(0.1298186552528781);
      value[ID::overtone0 + 55]->setFromNormalized(0.12590598649689982);
      value[ID::overtone0 + 56]->setFromNormalized(0.12206257216375427);
      value[ID::overtone0 + 57]->setFromNormalized(0.11828600321853137);
      value[ID::overtone0 + 58]->setFromNormalized(0.11457399417892784);
      value[ID::overtone0 + 59]->setFromNormalized(0.11092437480817825);
      value[ID::overtone0 + 60]->setFromNormalized(0.10733508249461661);
      value[ID::overtone0 + 61]->setFromNormalized(0.10380415525087301);
      value[ID::overtone0 + 62]->setFromNormalized(0.10032972527320912);
      value[ID::overtone0 + 63]->setFromNormalized(0.09691001300805642);
      value[ID::saturation0 + 0]->setFromNormalized(0.77024882980269);
      value[ID::saturation0 + 1]->setFromNormalized(0.5131179909948692);
      value[ID::saturation0 + 2]->setFromNormalized(0.6068709533873102);
      value[ID::saturation0 + 3]->setFromNormalized(0.5310978973526466);
      value[ID::saturation0 + 4]->setFromNormalized(0.5165674907465219);
      value[ID::saturation0 + 5]->setFromNormalized(0.4979480346817276);
      value[ID::saturation0 + 6]->setFromNormalized(0.4596291799387625);
      value[ID::saturation0 + 7]->setFromNormalized(0.24479877824436572);
      value[ID::saturation0 + 8]->setFromNormalized(0.5741486760279381);
      value[ID::saturation0 + 9]->setFromNormalized(0.530277661426502);
      value[ID::saturation0 + 10]->setFromNormalized(0.6063777104289285);
      value[ID::saturation0 + 11]->setFromNormalized(0.5381177873980755);
      value[ID::saturation0 + 12]->setFromNormalized(0.3160867685592752);
      value[ID::saturation0 + 13]->setFromNormalized(0.7132609021279267);
      value[ID::saturation0 + 14]->setFromNormalized(0.43826640577144027);
      value[ID::saturation0 + 15]->setFromNormalized(0.5034036462154583);
      value[ID::saturation0 + 16]->setFromNormalized(0.34851919154072797);
      value[ID::saturation0 + 17]->setFromNormalized(0.33347391093045725);
      value[ID::saturation0 + 18]->setFromNormalized(0.47745180960505096);
      value[ID::saturation0 + 19]->setFromNormalized(0.38122191411895784);
      value[ID::saturation0 + 20]->setFromNormalized(0.27098956570195093);
      value[ID::saturation0 + 21]->setFromNormalized(0.516471829151602);
      value[ID::saturation0 + 22]->setFromNormalized(0.4359417912214383);
      value[ID::saturation0 + 23]->setFromNormalized(0.6693142734216883);
      value[ID::saturation0 + 24]->setFromNormalized(0.23171534797474494);
      value[ID::saturation0 + 25]->setFromNormalized(0.2856146704958577);
      value[ID::saturation0 + 26]->setFromNormalized(0.2163420490728855);
      value[ID::saturation0 + 27]->setFromNormalized(0.6394335585452668);
      value[ID::saturation0 + 28]->setFromNormalized(0.6647344785902851);
      value[ID::saturation0 + 29]->setFromNormalized(0.7685847635306577);
      value[ID::saturation0 + 30]->setFromNormalized(0.47195368096476764);
      value[ID::saturation0 + 31]->setFromNormalized(0.28893885330961105);
      value[ID::saturation0 + 32]->setFromNormalized(0.26441497090647537);
      value[ID::saturation0 + 33]->setFromNormalized(0.4917457683130137);
      value[ID::saturation0 + 34]->setFromNormalized(0.39729372411625313);
      value[ID::saturation0 + 35]->setFromNormalized(0.7423630702549636);
      value[ID::saturation0 + 36]->setFromNormalized(0.7536697866505228);
      value[ID::saturation0 + 37]->setFromNormalized(0.6199376487647844);
      value[ID::saturation0 + 38]->setFromNormalized(0.3529171119515431);
      value[ID::saturation0 + 39]->setFromNormalized(0.6636598088779625);
      value[ID::saturation0 + 40]->setFromNormalized(0.5126334722194115);
      value[ID::saturation0 + 41]->setFromNormalized(0.5421745572444601);
      value[ID::saturation0 + 42]->setFromNormalized(0.7221633093053687);
      value[ID::saturation0 + 43]->setFromNormalized(0.2718864566380288);
      value[ID::saturation0 + 44]->setFromNormalized(0.46040827941995627);
      value[ID::saturation0 + 45]->setFromNormalized(0.23926691073879214);
      value[ID::saturation0 + 46]->setFromNormalized(0.5521406369689885);
      value[ID::saturation0 + 47]->setFromNormalized(0.45479148863086233);
      value[ID::saturation0 + 48]->setFromNormalized(0.1992192644572109);
      value[ID::saturation0 + 49]->setFromNormalized(0.5727215458873888);
      value[ID::saturation0 + 50]->setFromNormalized(0.4069274510216354);
      value[ID::saturation0 + 51]->setFromNormalized(0.7349945274892213);
      value[ID::saturation0 + 52]->setFromNormalized(0.34819377553292075);
      value[ID::saturation0 + 53]->setFromNormalized(0.5313847852619127);
      value[ID::saturation0 + 54]->setFromNormalized(0.21522036187614815);
      value[ID::saturation0 + 55]->setFromNormalized(0.6552150531233346);
      value[ID::saturation0 + 56]->setFromNormalized(0.6848932994392695);
      value[ID::saturation0 + 57]->setFromNormalized(0.6564664037557443);
      value[ID::saturation0 + 58]->setFromNormalized(0.3271915348510054);
      value[ID::saturation0 + 59]->setFromNormalized(0.46622363358696817);
      value[ID::saturation0 + 60]->setFromNormalized(0.2693696268948998);
      value[ID::saturation0 + 61]->setFromNormalized(0.7975443061663502);
      value[ID::saturation0 + 62]->setFromNormalized(0.47052710201422915);
      value[ID::saturation0 + 63]->setFromNormalized(0.46558636314337204);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.12000006437301637);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.6160000562667847);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(1.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.02200000174343586);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.778441846370697);
      value[ID::saturationMix]->setFromNormalized(0.07200004160404205);
      value[ID::phaserMix]->setFromNormalized(0.47999998927116394);
      value[ID::phaserFrequency]->setFromNormalized(0.0);
      value[ID::phaserFeedback]->setFromNormalized(0.9760003685951233);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.5519992709159851);
      value[ID::phaserOffset]->setFromNormalized(0.0);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetOutOfTune: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.12789587038472397);
      value[ID::attack0 + 1]->setFromNormalized(0.30598879759097947);
      value[ID::attack0 + 2]->setFromNormalized(0.8436002398759749);
      value[ID::attack0 + 3]->setFromNormalized(0.7297886176264642);
      value[ID::attack0 + 4]->setFromNormalized(0.1690602763500345);
      value[ID::attack0 + 5]->setFromNormalized(0.8784374874958408);
      value[ID::attack0 + 6]->setFromNormalized(0.454090324814276);
      value[ID::attack0 + 7]->setFromNormalized(0.9429311852215707);
      value[ID::attack0 + 8]->setFromNormalized(0.18748005216665084);
      value[ID::attack0 + 9]->setFromNormalized(0.09577625869702062);
      value[ID::attack0 + 10]->setFromNormalized(0.38556980014275055);
      value[ID::attack0 + 11]->setFromNormalized(0.7350957225442143);
      value[ID::attack0 + 12]->setFromNormalized(0.0007695341853777136);
      value[ID::attack0 + 13]->setFromNormalized(0.354050689665162);
      value[ID::attack0 + 14]->setFromNormalized(0.5897036698551669);
      value[ID::attack0 + 15]->setFromNormalized(0.017845460282469385);
      value[ID::attack0 + 16]->setFromNormalized(0.542597528124802);
      value[ID::attack0 + 17]->setFromNormalized(0.5720094615562155);
      value[ID::attack0 + 18]->setFromNormalized(0.23710516667410145);
      value[ID::attack0 + 19]->setFromNormalized(0.12181310254117518);
      value[ID::attack0 + 20]->setFromNormalized(0.18029106211216475);
      value[ID::attack0 + 21]->setFromNormalized(0.09603385104406702);
      value[ID::attack0 + 22]->setFromNormalized(0.11044684107903145);
      value[ID::attack0 + 23]->setFromNormalized(0.6958648497795492);
      value[ID::attack0 + 24]->setFromNormalized(0.005941924215405623);
      value[ID::attack0 + 25]->setFromNormalized(0.200334109935221);
      value[ID::attack0 + 26]->setFromNormalized(0.7609196139237381);
      value[ID::attack0 + 27]->setFromNormalized(0.431922375430868);
      value[ID::attack0 + 28]->setFromNormalized(0.765875237066674);
      value[ID::attack0 + 29]->setFromNormalized(0.29721618158600416);
      value[ID::attack0 + 30]->setFromNormalized(0.17196322107551418);
      value[ID::attack0 + 31]->setFromNormalized(0.8513310230067135);
      value[ID::attack0 + 32]->setFromNormalized(0.45775918611625555);
      value[ID::attack0 + 33]->setFromNormalized(0.0819444386104957);
      value[ID::attack0 + 34]->setFromNormalized(0.3690035542574424);
      value[ID::attack0 + 35]->setFromNormalized(0.6276960482216067);
      value[ID::attack0 + 36]->setFromNormalized(0.5256666345041391);
      value[ID::attack0 + 37]->setFromNormalized(0.8641485068737513);
      value[ID::attack0 + 38]->setFromNormalized(0.41228304672589694);
      value[ID::attack0 + 39]->setFromNormalized(0.6332096330191935);
      value[ID::attack0 + 40]->setFromNormalized(0.15088541385245033);
      value[ID::attack0 + 41]->setFromNormalized(0.5621008463970639);
      value[ID::attack0 + 42]->setFromNormalized(0.3508480651333917);
      value[ID::attack0 + 43]->setFromNormalized(0.04457094431397967);
      value[ID::attack0 + 44]->setFromNormalized(0.8612428072718775);
      value[ID::attack0 + 45]->setFromNormalized(0.6268526828053046);
      value[ID::attack0 + 46]->setFromNormalized(0.6694752028831287);
      value[ID::attack0 + 47]->setFromNormalized(0.37417874731156525);
      value[ID::attack0 + 48]->setFromNormalized(0.07470317186837626);
      value[ID::attack0 + 49]->setFromNormalized(0.4042741652114803);
      value[ID::attack0 + 50]->setFromNormalized(0.6043568974832636);
      value[ID::attack0 + 51]->setFromNormalized(0.30105420371034064);
      value[ID::attack0 + 52]->setFromNormalized(0.5119787744252612);
      value[ID::attack0 + 53]->setFromNormalized(0.6787878140512142);
      value[ID::attack0 + 54]->setFromNormalized(0.8515144618950151);
      value[ID::attack0 + 55]->setFromNormalized(0.1841659527895729);
      value[ID::attack0 + 56]->setFromNormalized(0.14817346546781282);
      value[ID::attack0 + 57]->setFromNormalized(0.3159822170164578);
      value[ID::attack0 + 58]->setFromNormalized(0.8318763763816281);
      value[ID::attack0 + 59]->setFromNormalized(0.9343186934495518);
      value[ID::attack0 + 60]->setFromNormalized(0.6305224411393526);
      value[ID::attack0 + 61]->setFromNormalized(0.4043175401191924);
      value[ID::attack0 + 62]->setFromNormalized(0.10441203180609303);
      value[ID::attack0 + 63]->setFromNormalized(0.07289507209847289);
      value[ID::decay0 + 0]->setFromNormalized(0.04181279698414642);
      value[ID::decay0 + 1]->setFromNormalized(0.3756856863194665);
      value[ID::decay0 + 2]->setFromNormalized(0.42659229902994056);
      value[ID::decay0 + 3]->setFromNormalized(0.33936903267903973);
      value[ID::decay0 + 4]->setFromNormalized(0.6426248867109956);
      value[ID::decay0 + 5]->setFromNormalized(0.47241542637146766);
      value[ID::decay0 + 6]->setFromNormalized(0.6900709164437636);
      value[ID::decay0 + 7]->setFromNormalized(0.8561627437030843);
      value[ID::decay0 + 8]->setFromNormalized(0.9593244478061176);
      value[ID::decay0 + 9]->setFromNormalized(0.5992560725232433);
      value[ID::decay0 + 10]->setFromNormalized(0.38094404219088934);
      value[ID::decay0 + 11]->setFromNormalized(0.39464498191928576);
      value[ID::decay0 + 12]->setFromNormalized(0.09176601850328327);
      value[ID::decay0 + 13]->setFromNormalized(0.9685240140438017);
      value[ID::decay0 + 14]->setFromNormalized(0.04377599976745151);
      value[ID::decay0 + 15]->setFromNormalized(0.7797518085066362);
      value[ID::decay0 + 16]->setFromNormalized(0.8774046525610453);
      value[ID::decay0 + 17]->setFromNormalized(0.19935633022052054);
      value[ID::decay0 + 18]->setFromNormalized(0.5643610820664429);
      value[ID::decay0 + 19]->setFromNormalized(0.6395471317619185);
      value[ID::decay0 + 20]->setFromNormalized(0.35696709837781415);
      value[ID::decay0 + 21]->setFromNormalized(0.11934532458444738);
      value[ID::decay0 + 22]->setFromNormalized(0.9899141475020508);
      value[ID::decay0 + 23]->setFromNormalized(0.4540131519037721);
      value[ID::decay0 + 24]->setFromNormalized(0.054039380034063535);
      value[ID::decay0 + 25]->setFromNormalized(0.9916470300375472);
      value[ID::decay0 + 26]->setFromNormalized(0.6318369497900655);
      value[ID::decay0 + 27]->setFromNormalized(0.8925790684991036);
      value[ID::decay0 + 28]->setFromNormalized(0.4057946015535075);
      value[ID::decay0 + 29]->setFromNormalized(0.3477419549428459);
      value[ID::decay0 + 30]->setFromNormalized(0.7703869334717768);
      value[ID::decay0 + 31]->setFromNormalized(0.25388621263870936);
      value[ID::decay0 + 32]->setFromNormalized(0.28676261257192626);
      value[ID::decay0 + 33]->setFromNormalized(0.923587443721149);
      value[ID::decay0 + 34]->setFromNormalized(0.604606334404954);
      value[ID::decay0 + 35]->setFromNormalized(0.8694260402871155);
      value[ID::decay0 + 36]->setFromNormalized(0.3287528067891603);
      value[ID::decay0 + 37]->setFromNormalized(0.8257481011271316);
      value[ID::decay0 + 38]->setFromNormalized(0.48684563086558763);
      value[ID::decay0 + 39]->setFromNormalized(0.5200231678089824);
      value[ID::decay0 + 40]->setFromNormalized(0.7656234250265619);
      value[ID::decay0 + 41]->setFromNormalized(0.7655335963960301);
      value[ID::decay0 + 42]->setFromNormalized(0.9638911237248421);
      value[ID::decay0 + 43]->setFromNormalized(0.7097852061306119);
      value[ID::decay0 + 44]->setFromNormalized(0.790902892552001);
      value[ID::decay0 + 45]->setFromNormalized(0.9287147032981933);
      value[ID::decay0 + 46]->setFromNormalized(0.7221511702815273);
      value[ID::decay0 + 47]->setFromNormalized(0.45833438715606295);
      value[ID::decay0 + 48]->setFromNormalized(0.09673360835202427);
      value[ID::decay0 + 49]->setFromNormalized(0.2014475424331142);
      value[ID::decay0 + 50]->setFromNormalized(0.8073410298429124);
      value[ID::decay0 + 51]->setFromNormalized(0.10331251241110095);
      value[ID::decay0 + 52]->setFromNormalized(0.1298215407289223);
      value[ID::decay0 + 53]->setFromNormalized(0.21696441959842833);
      value[ID::decay0 + 54]->setFromNormalized(0.5344883919208621);
      value[ID::decay0 + 55]->setFromNormalized(0.8325129698855469);
      value[ID::decay0 + 56]->setFromNormalized(0.1814082091270393);
      value[ID::decay0 + 57]->setFromNormalized(0.4490993701836546);
      value[ID::decay0 + 58]->setFromNormalized(0.9532845341744263);
      value[ID::decay0 + 59]->setFromNormalized(0.2926280208626388);
      value[ID::decay0 + 60]->setFromNormalized(0.8853769590354373);
      value[ID::decay0 + 61]->setFromNormalized(0.9840937036780653);
      value[ID::decay0 + 62]->setFromNormalized(0.3482260731600269);
      value[ID::decay0 + 63]->setFromNormalized(0.8484536875457851);
      value[ID::overtone0 + 0]->setFromNormalized(0.6);
      value[ID::overtone0 + 1]->setFromNormalized(0.24285714285714288);
      value[ID::overtone0 + 2]->setFromNormalized(0.5087266361539905);
      value[ID::overtone0 + 3]->setFromNormalized(0.6889507519999514);
      value[ID::overtone0 + 4]->setFromNormalized(0.11547705752477348);
      value[ID::overtone0 + 5]->setFromNormalized(0.9932978341621588);
      value[ID::overtone0 + 6]->setFromNormalized(0.2022304095990574);
      value[ID::overtone0 + 7]->setFromNormalized(0.018499827348669663);
      value[ID::overtone0 + 8]->setFromNormalized(0.7185394646719816);
      value[ID::overtone0 + 9]->setFromNormalized(0.2214365628410631);
      value[ID::overtone0 + 10]->setFromNormalized(0.5689107643835466);
      value[ID::overtone0 + 11]->setFromNormalized(0.4844167773141324);
      value[ID::overtone0 + 12]->setFromNormalized(0.16311590770650283);
      value[ID::overtone0 + 13]->setFromNormalized(0.8003069986738554);
      value[ID::overtone0 + 14]->setFromNormalized(0.3401478415635798);
      value[ID::overtone0 + 15]->setFromNormalized(0.18839416306174234);
      value[ID::overtone0 + 16]->setFromNormalized(0.42996368816714836);
      value[ID::overtone0 + 17]->setFromNormalized(0.9754471004066916);
      value[ID::overtone0 + 18]->setFromNormalized(0.8141660801047887);
      value[ID::overtone0 + 19]->setFromNormalized(0.7114620065486115);
      value[ID::overtone0 + 20]->setFromNormalized(0.6604342496481386);
      value[ID::overtone0 + 21]->setFromNormalized(0.45221139113455167);
      value[ID::overtone0 + 22]->setFromNormalized(0.9663208575495581);
      value[ID::overtone0 + 23]->setFromNormalized(0.049528663521142845);
      value[ID::overtone0 + 24]->setFromNormalized(0.5018331052078773);
      value[ID::overtone0 + 25]->setFromNormalized(0.3212921046886602);
      value[ID::overtone0 + 26]->setFromNormalized(0.3128642223385157);
      value[ID::overtone0 + 27]->setFromNormalized(0.11514758969016584);
      value[ID::overtone0 + 28]->setFromNormalized(0.1494938272302873);
      value[ID::overtone0 + 29]->setFromNormalized(0.21900819258059245);
      value[ID::overtone0 + 30]->setFromNormalized(0.2640647414014207);
      value[ID::overtone0 + 31]->setFromNormalized(0.551729493490085);
      value[ID::overtone0 + 32]->setFromNormalized(0.005147895925976443);
      value[ID::overtone0 + 33]->setFromNormalized(0.35848260840228274);
      value[ID::overtone0 + 34]->setFromNormalized(0.7638958788467297);
      value[ID::overtone0 + 35]->setFromNormalized(0.5173869141038457);
      value[ID::overtone0 + 36]->setFromNormalized(0.677232979359635);
      value[ID::overtone0 + 37]->setFromNormalized(0.40857592644160234);
      value[ID::overtone0 + 38]->setFromNormalized(0.7766864327438379);
      value[ID::overtone0 + 39]->setFromNormalized(0.3457906601313874);
      value[ID::overtone0 + 40]->setFromNormalized(0.28307622505617847);
      value[ID::overtone0 + 41]->setFromNormalized(0.8277102110579009);
      value[ID::overtone0 + 42]->setFromNormalized(0.7680788517654248);
      value[ID::overtone0 + 43]->setFromNormalized(0.03125426305391095);
      value[ID::overtone0 + 44]->setFromNormalized(0.031463720855589905);
      value[ID::overtone0 + 45]->setFromNormalized(0.8896463640988831);
      value[ID::overtone0 + 46]->setFromNormalized(0.28722177661101184);
      value[ID::overtone0 + 47]->setFromNormalized(0.8215400577012663);
      value[ID::overtone0 + 48]->setFromNormalized(0.44404304340774037);
      value[ID::overtone0 + 49]->setFromNormalized(0.301015624810484);
      value[ID::overtone0 + 50]->setFromNormalized(0.9704068724828486);
      value[ID::overtone0 + 51]->setFromNormalized(0.6967008646933879);
      value[ID::overtone0 + 52]->setFromNormalized(0.886791199053768);
      value[ID::overtone0 + 53]->setFromNormalized(0.6523060627603257);
      value[ID::overtone0 + 54]->setFromNormalized(0.22146014835469535);
      value[ID::overtone0 + 55]->setFromNormalized(0.3004134134192742);
      value[ID::overtone0 + 56]->setFromNormalized(0.7136117002781758);
      value[ID::overtone0 + 57]->setFromNormalized(0.7185287931520905);
      value[ID::overtone0 + 58]->setFromNormalized(0.2356468627933488);
      value[ID::overtone0 + 59]->setFromNormalized(0.5519464325121144);
      value[ID::overtone0 + 60]->setFromNormalized(0.4572924690277774);
      value[ID::overtone0 + 61]->setFromNormalized(0.922956608464025);
      value[ID::overtone0 + 62]->setFromNormalized(0.7054445454213788);
      value[ID::overtone0 + 63]->setFromNormalized(0.46113896725013603);
      value[ID::saturation0 + 0]->setFromNormalized(0.36454098155992243);
      value[ID::saturation0 + 1]->setFromNormalized(0.9895231530821833);
      value[ID::saturation0 + 2]->setFromNormalized(0.15932376386120461);
      value[ID::saturation0 + 3]->setFromNormalized(0.9911083379499335);
      value[ID::saturation0 + 4]->setFromNormalized(0.009616730272250632);
      value[ID::saturation0 + 5]->setFromNormalized(0.6154568311958063);
      value[ID::saturation0 + 6]->setFromNormalized(0.7876068351615277);
      value[ID::saturation0 + 7]->setFromNormalized(0.2556596866836342);
      value[ID::saturation0 + 8]->setFromNormalized(0.6918689248467114);
      value[ID::saturation0 + 9]->setFromNormalized(0.6414006319587202);
      value[ID::saturation0 + 10]->setFromNormalized(0.45977056237821357);
      value[ID::saturation0 + 11]->setFromNormalized(0.8374942868105402);
      value[ID::saturation0 + 12]->setFromNormalized(0.1373796569729222);
      value[ID::saturation0 + 13]->setFromNormalized(0.5460490523355094);
      value[ID::saturation0 + 14]->setFromNormalized(0.5091191364601508);
      value[ID::saturation0 + 15]->setFromNormalized(0.7777119167311826);
      value[ID::saturation0 + 16]->setFromNormalized(0.4468631950278151);
      value[ID::saturation0 + 17]->setFromNormalized(0.6041904841329284);
      value[ID::saturation0 + 18]->setFromNormalized(0.31657004033650493);
      value[ID::saturation0 + 19]->setFromNormalized(0.501417260073765);
      value[ID::saturation0 + 20]->setFromNormalized(0.29597032642074045);
      value[ID::saturation0 + 21]->setFromNormalized(0.2887066439364316);
      value[ID::saturation0 + 22]->setFromNormalized(0.37536500237897946);
      value[ID::saturation0 + 23]->setFromNormalized(0.7708263197931735);
      value[ID::saturation0 + 24]->setFromNormalized(0.5216719805584408);
      value[ID::saturation0 + 25]->setFromNormalized(0.6930601914361895);
      value[ID::saturation0 + 26]->setFromNormalized(0.7025383494258527);
      value[ID::saturation0 + 27]->setFromNormalized(0.3311254364683186);
      value[ID::saturation0 + 28]->setFromNormalized(0.09535013698128703);
      value[ID::saturation0 + 29]->setFromNormalized(0.34218038117342753);
      value[ID::saturation0 + 30]->setFromNormalized(0.9260827513240164);
      value[ID::saturation0 + 31]->setFromNormalized(0.8582843283331212);
      value[ID::saturation0 + 32]->setFromNormalized(0.300602769189819);
      value[ID::saturation0 + 33]->setFromNormalized(0.3791818228347676);
      value[ID::saturation0 + 34]->setFromNormalized(0.7915479381004927);
      value[ID::saturation0 + 35]->setFromNormalized(0.4855529837828751);
      value[ID::saturation0 + 36]->setFromNormalized(0.24842732469698386);
      value[ID::saturation0 + 37]->setFromNormalized(0.16496829237841654);
      value[ID::saturation0 + 38]->setFromNormalized(0.6969592560124988);
      value[ID::saturation0 + 39]->setFromNormalized(0.6344708159760307);
      value[ID::saturation0 + 40]->setFromNormalized(0.6100819567266701);
      value[ID::saturation0 + 41]->setFromNormalized(0.7150348184450166);
      value[ID::saturation0 + 42]->setFromNormalized(0.521785990419548);
      value[ID::saturation0 + 43]->setFromNormalized(0.026542261905662213);
      value[ID::saturation0 + 44]->setFromNormalized(0.691578749924522);
      value[ID::saturation0 + 45]->setFromNormalized(0.614754268855635);
      value[ID::saturation0 + 46]->setFromNormalized(0.3656093322771933);
      value[ID::saturation0 + 47]->setFromNormalized(0.59101768242623);
      value[ID::saturation0 + 48]->setFromNormalized(0.036546631723458865);
      value[ID::saturation0 + 49]->setFromNormalized(0.8465312237024235);
      value[ID::saturation0 + 50]->setFromNormalized(0.6816571154456896);
      value[ID::saturation0 + 51]->setFromNormalized(0.2702167427463954);
      value[ID::saturation0 + 52]->setFromNormalized(0.9966860413363354);
      value[ID::saturation0 + 53]->setFromNormalized(0.9738578965335333);
      value[ID::saturation0 + 54]->setFromNormalized(0.9482440997427768);
      value[ID::saturation0 + 55]->setFromNormalized(0.8923875675399692);
      value[ID::saturation0 + 56]->setFromNormalized(0.11562400120486462);
      value[ID::saturation0 + 57]->setFromNormalized(0.7452823601968653);
      value[ID::saturation0 + 58]->setFromNormalized(0.5670392431770046);
      value[ID::saturation0 + 59]->setFromNormalized(0.33019376753247187);
      value[ID::saturation0 + 60]->setFromNormalized(0.955352909954299);
      value[ID::saturation0 + 61]->setFromNormalized(0.2333693260162028);
      value[ID::saturation0 + 62]->setFromNormalized(0.5705065770744963);
      value[ID::saturation0 + 63]->setFromNormalized(0.6259260254246035);
      value[ID::gain]->setFromNormalized(0.3679995536804199);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.975999653339386);
      value[ID::pitchMultiply]->setFromNormalized(0.9280001521110535);
      value[ID::pitchModulo]->setFromNormalized(0.12199980020523071);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.6719999313354492);
      value[ID::randomFrequency]->setFromNormalized(0.060000032186508186);
      value[ID::randomAttack]->setFromNormalized(0.5320000648498535);
      value[ID::randomDecay]->setFromNormalized(0.3840000033378601);
      value[ID::randomSaturation]->setFromNormalized(0.4880000352859497);
      value[ID::randomPhase]->setFromNormalized(0.6520000696182251);
      value[ID::overtoneExpand]->setFromNormalized(0.09399977326393129);
      value[ID::overtoneShift]->setFromNormalized(0.9600001573562622);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.8040000796318054);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.9000000357627869);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(2);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetPercussive: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.6736375474083542);
      value[ID::attack0 + 1]->setFromNormalized(0.685533257396305);
      value[ID::attack0 + 2]->setFromNormalized(0.3541115022185138);
      value[ID::attack0 + 3]->setFromNormalized(0.8416615698707396);
      value[ID::attack0 + 4]->setFromNormalized(0.13397195952845428);
      value[ID::attack0 + 5]->setFromNormalized(0.3055524080483639);
      value[ID::attack0 + 6]->setFromNormalized(0.5428571428571429);
      value[ID::attack0 + 7]->setFromNormalized(0.7348745930703231);
      value[ID::attack0 + 8]->setFromNormalized(0.7440630860914611);
      value[ID::attack0 + 9]->setFromNormalized(0.9661004302513779);
      value[ID::attack0 + 10]->setFromNormalized(0.8734131111032717);
      value[ID::attack0 + 11]->setFromNormalized(0.19541109204265072);
      value[ID::attack0 + 12]->setFromNormalized(0.3652536980442928);
      value[ID::attack0 + 13]->setFromNormalized(0.48777092115155785);
      value[ID::attack0 + 14]->setFromNormalized(0.8019080650757489);
      value[ID::attack0 + 15]->setFromNormalized(0.2624055140216303);
      value[ID::attack0 + 16]->setFromNormalized(0.1278588506444756);
      value[ID::attack0 + 17]->setFromNormalized(0.6087805575397839);
      value[ID::attack0 + 18]->setFromNormalized(0.39057124052899145);
      value[ID::attack0 + 19]->setFromNormalized(0.5617080333499073);
      value[ID::attack0 + 20]->setFromNormalized(0.7110780234167132);
      value[ID::attack0 + 21]->setFromNormalized(0.5898050775330107);
      value[ID::attack0 + 22]->setFromNormalized(0.8835621623400313);
      value[ID::attack0 + 23]->setFromNormalized(0.659020825676216);
      value[ID::attack0 + 24]->setFromNormalized(0.2832783698386385);
      value[ID::attack0 + 25]->setFromNormalized(0.3376503061970597);
      value[ID::attack0 + 26]->setFromNormalized(0.7092305066309279);
      value[ID::attack0 + 27]->setFromNormalized(0.1650131729416406);
      value[ID::attack0 + 28]->setFromNormalized(0.9082844238053491);
      value[ID::attack0 + 29]->setFromNormalized(0.18097384118448562);
      value[ID::attack0 + 30]->setFromNormalized(0.42088303435618385);
      value[ID::attack0 + 31]->setFromNormalized(0.47922238640887094);
      value[ID::attack0 + 32]->setFromNormalized(0.8992709121744291);
      value[ID::attack0 + 33]->setFromNormalized(0.5699488549231049);
      value[ID::attack0 + 34]->setFromNormalized(0.6030776736578894);
      value[ID::attack0 + 35]->setFromNormalized(0.12445557298112118);
      value[ID::attack0 + 36]->setFromNormalized(0.0356207010926488);
      value[ID::attack0 + 37]->setFromNormalized(0.5637076201705421);
      value[ID::attack0 + 38]->setFromNormalized(0.7471799652095031);
      value[ID::attack0 + 39]->setFromNormalized(0.8484718056056385);
      value[ID::attack0 + 40]->setFromNormalized(0.373910445125178);
      value[ID::attack0 + 41]->setFromNormalized(0.5269997221762425);
      value[ID::attack0 + 42]->setFromNormalized(0.27468956529239347);
      value[ID::attack0 + 43]->setFromNormalized(0.4963192147179623);
      value[ID::attack0 + 44]->setFromNormalized(0.7248985666126214);
      value[ID::attack0 + 45]->setFromNormalized(0.43269470546724753);
      value[ID::attack0 + 46]->setFromNormalized(0.07308412739563931);
      value[ID::attack0 + 47]->setFromNormalized(0.957321181469045);
      value[ID::attack0 + 48]->setFromNormalized(0.7394259957018973);
      value[ID::attack0 + 49]->setFromNormalized(0.6206204029690779);
      value[ID::attack0 + 50]->setFromNormalized(0.8005778246210666);
      value[ID::attack0 + 51]->setFromNormalized(0.782347123084988);
      value[ID::attack0 + 52]->setFromNormalized(0.7415868908546803);
      value[ID::attack0 + 53]->setFromNormalized(0.7663515968382637);
      value[ID::attack0 + 54]->setFromNormalized(0.7540987641656111);
      value[ID::attack0 + 55]->setFromNormalized(0.7818901031454774);
      value[ID::attack0 + 56]->setFromNormalized(0.6185202862929937);
      value[ID::attack0 + 57]->setFromNormalized(0.6771132380494252);
      value[ID::attack0 + 58]->setFromNormalized(0.8285813637371815);
      value[ID::attack0 + 59]->setFromNormalized(0.4817594708128357);
      value[ID::attack0 + 60]->setFromNormalized(0.3329716106993237);
      value[ID::attack0 + 61]->setFromNormalized(0.6804859944816073);
      value[ID::attack0 + 62]->setFromNormalized(0.8777959395771712);
      value[ID::attack0 + 63]->setFromNormalized(0.9816141002951809);
      value[ID::decay0 + 0]->setFromNormalized(0.03865951367724991);
      value[ID::decay0 + 1]->setFromNormalized(0.7736204869930706);
      value[ID::decay0 + 2]->setFromNormalized(0.08772554497713204);
      value[ID::decay0 + 3]->setFromNormalized(0.13538723526916774);
      value[ID::decay0 + 4]->setFromNormalized(0.38374724906136637);
      value[ID::decay0 + 5]->setFromNormalized(0.44285714285714284);
      value[ID::decay0 + 6]->setFromNormalized(0.9642857142857143);
      value[ID::decay0 + 7]->setFromNormalized(0.8214285714285714);
      value[ID::decay0 + 8]->setFromNormalized(0.7071428571428571);
      value[ID::decay0 + 9]->setFromNormalized(0.12142857142857146);
      value[ID::decay0 + 10]->setFromNormalized(0.8642857142857143);
      value[ID::decay0 + 11]->setFromNormalized(0.85);
      value[ID::decay0 + 12]->setFromNormalized(0.30000000000000004);
      value[ID::decay0 + 13]->setFromNormalized(0.22142857142857142);
      value[ID::decay0 + 14]->setFromNormalized(0.13571428571428568);
      value[ID::decay0 + 15]->setFromNormalized(0.7461288013052344);
      value[ID::decay0 + 16]->setFromNormalized(0.39281351207618975);
      value[ID::decay0 + 17]->setFromNormalized(0.9117172314106414);
      value[ID::decay0 + 18]->setFromNormalized(0.4103354984023498);
      value[ID::decay0 + 19]->setFromNormalized(0.17142857142857137);
      value[ID::decay0 + 20]->setFromNormalized(0.5145813187952835);
      value[ID::decay0 + 21]->setFromNormalized(0.4390100122731308);
      value[ID::decay0 + 22]->setFromNormalized(0.06501708835051134);
      value[ID::decay0 + 23]->setFromNormalized(0.06257628033956854);
      value[ID::decay0 + 24]->setFromNormalized(0.1894439678240979);
      value[ID::decay0 + 25]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 26]->setFromNormalized(0.2571428571428571);
      value[ID::decay0 + 27]->setFromNormalized(0.30000000000000004);
      value[ID::decay0 + 28]->setFromNormalized(0.33571428571428574);
      value[ID::decay0 + 29]->setFromNormalized(0.5785714285714285);
      value[ID::decay0 + 30]->setFromNormalized(0.5642857142857143);
      value[ID::decay0 + 31]->setFromNormalized(0.47857142857142854);
      value[ID::decay0 + 32]->setFromNormalized(0.3571428571428571);
      value[ID::decay0 + 33]->setFromNormalized(0.30000000000000004);
      value[ID::decay0 + 34]->setFromNormalized(0.8071428571428572);
      value[ID::decay0 + 35]->setFromNormalized(0.7928571428571428);
      value[ID::decay0 + 36]->setFromNormalized(0.7785714285714286);
      value[ID::decay0 + 37]->setFromNormalized(0.7142857142857143);
      value[ID::decay0 + 38]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 39]->setFromNormalized(0.6714285714285715);
      value[ID::decay0 + 40]->setFromNormalized(0.6071428571428572);
      value[ID::decay0 + 41]->setFromNormalized(0.6071428571428572);
      value[ID::decay0 + 42]->setFromNormalized(0.6071428571428572);
      value[ID::decay0 + 43]->setFromNormalized(0.44285714285714284);
      value[ID::decay0 + 44]->setFromNormalized(0.41428571428571426);
      value[ID::decay0 + 45]->setFromNormalized(0.3642857142857143);
      value[ID::decay0 + 46]->setFromNormalized(0.3571428571428571);
      value[ID::decay0 + 47]->setFromNormalized(0.3571428571428571);
      value[ID::decay0 + 48]->setFromNormalized(0.4214285714285714);
      value[ID::decay0 + 49]->setFromNormalized(0.2630694289501826);
      value[ID::decay0 + 50]->setFromNormalized(0.4294473515825942);
      value[ID::decay0 + 51]->setFromNormalized(0.3969301206229211);
      value[ID::decay0 + 52]->setFromNormalized(0.2289715797278782);
      value[ID::decay0 + 53]->setFromNormalized(0.10714285714285711);
      value[ID::decay0 + 54]->setFromNormalized(0.04637357433514147);
      value[ID::decay0 + 55]->setFromNormalized(0.18538295987321757);
      value[ID::decay0 + 56]->setFromNormalized(0.7214285714285714);
      value[ID::decay0 + 57]->setFromNormalized(0.8357142857142857);
      value[ID::decay0 + 58]->setFromNormalized(0.85);
      value[ID::decay0 + 59]->setFromNormalized(0.7928571428571428);
      value[ID::decay0 + 60]->setFromNormalized(0.6642857142857144);
      value[ID::decay0 + 61]->setFromNormalized(0.6285714285714286);
      value[ID::decay0 + 62]->setFromNormalized(0.31646687233275195);
      value[ID::decay0 + 63]->setFromNormalized(0.5145469471761315);
      value[ID::overtone0 + 0]->setFromNormalized(0.18891727279243115);
      value[ID::overtone0 + 1]->setFromNormalized(0.43971716135116523);
      value[ID::overtone0 + 2]->setFromNormalized(1.0);
      value[ID::overtone0 + 3]->setFromNormalized(0.37525450013046324);
      value[ID::overtone0 + 4]->setFromNormalized(0.8727979089579092);
      value[ID::overtone0 + 5]->setFromNormalized(0.6453829390428889);
      value[ID::overtone0 + 6]->setFromNormalized(0.38524795828404956);
      value[ID::overtone0 + 7]->setFromNormalized(0.9401990059911325);
      value[ID::overtone0 + 8]->setFromNormalized(0.6220662918736781);
      value[ID::overtone0 + 9]->setFromNormalized(0.7805962240270825);
      value[ID::overtone0 + 10]->setFromNormalized(0.4392330267722868);
      value[ID::overtone0 + 11]->setFromNormalized(0.00993354484297484);
      value[ID::overtone0 + 12]->setFromNormalized(0.8497860341189198);
      value[ID::overtone0 + 13]->setFromNormalized(0.8510694278302606);
      value[ID::overtone0 + 14]->setFromNormalized(0.7837926688086663);
      value[ID::overtone0 + 15]->setFromNormalized(0.14239997802464757);
      value[ID::overtone0 + 16]->setFromNormalized(0.16185402973995106);
      value[ID::overtone0 + 17]->setFromNormalized(0.42556006361915666);
      value[ID::overtone0 + 18]->setFromNormalized(0.7375527491605876);
      value[ID::overtone0 + 19]->setFromNormalized(0.7819948715878351);
      value[ID::overtone0 + 20]->setFromNormalized(0.5963108831799935);
      value[ID::overtone0 + 21]->setFromNormalized(0.3621489156230946);
      value[ID::overtone0 + 22]->setFromNormalized(0.13936832215741574);
      value[ID::overtone0 + 23]->setFromNormalized(0.505528983179444);
      value[ID::overtone0 + 24]->setFromNormalized(0.2324651550044412);
      value[ID::overtone0 + 25]->setFromNormalized(0.18054350575174177);
      value[ID::overtone0 + 26]->setFromNormalized(0.04939740456353388);
      value[ID::overtone0 + 27]->setFromNormalized(0.4163179861477772);
      value[ID::overtone0 + 28]->setFromNormalized(0.5271320487660396);
      value[ID::overtone0 + 29]->setFromNormalized(0.44481398411264605);
      value[ID::overtone0 + 30]->setFromNormalized(0.04626873365168969);
      value[ID::overtone0 + 31]->setFromNormalized(0.7810732594893012);
      value[ID::overtone0 + 32]->setFromNormalized(0.2774848852510994);
      value[ID::overtone0 + 33]->setFromNormalized(0.16525083579345629);
      value[ID::overtone0 + 34]->setFromNormalized(0.7238220688957867);
      value[ID::overtone0 + 35]->setFromNormalized(0.09213361456880467);
      value[ID::overtone0 + 36]->setFromNormalized(0.04589347188906103);
      value[ID::overtone0 + 37]->setFromNormalized(0.09501135632085429);
      value[ID::overtone0 + 38]->setFromNormalized(0.4808777053108999);
      value[ID::overtone0 + 39]->setFromNormalized(0.26419621186844766);
      value[ID::overtone0 + 40]->setFromNormalized(0.3991963732273165);
      value[ID::overtone0 + 41]->setFromNormalized(0.032426956265408965);
      value[ID::overtone0 + 42]->setFromNormalized(0.6863994749337323);
      value[ID::overtone0 + 43]->setFromNormalized(0.4621241039059566);
      value[ID::overtone0 + 44]->setFromNormalized(0.07695009807248106);
      value[ID::overtone0 + 45]->setFromNormalized(0.7408849515650937);
      value[ID::overtone0 + 46]->setFromNormalized(0.36427823787930513);
      value[ID::overtone0 + 47]->setFromNormalized(0.6658112422503706);
      value[ID::overtone0 + 48]->setFromNormalized(0.5606243589880557);
      value[ID::overtone0 + 49]->setFromNormalized(0.09093758615764606);
      value[ID::overtone0 + 50]->setFromNormalized(0.10358992372686267);
      value[ID::overtone0 + 51]->setFromNormalized(0.33454123886874954);
      value[ID::overtone0 + 52]->setFromNormalized(0.38658098713722167);
      value[ID::overtone0 + 53]->setFromNormalized(0.43118648565305506);
      value[ID::overtone0 + 54]->setFromNormalized(0.689765554480259);
      value[ID::overtone0 + 55]->setFromNormalized(0.3940152368898606);
      value[ID::overtone0 + 56]->setFromNormalized(0.34823419563991165);
      value[ID::overtone0 + 57]->setFromNormalized(0.4237522359004161);
      value[ID::overtone0 + 58]->setFromNormalized(0.25921832822900015);
      value[ID::overtone0 + 59]->setFromNormalized(0.8456137137356758);
      value[ID::overtone0 + 60]->setFromNormalized(0.11314480073785323);
      value[ID::overtone0 + 61]->setFromNormalized(0.2289539910565493);
      value[ID::overtone0 + 62]->setFromNormalized(0.5959060211486711);
      value[ID::overtone0 + 63]->setFromNormalized(0.19270532897990264);
      value[ID::saturation0 + 0]->setFromNormalized(0.9597259012961838);
      value[ID::saturation0 + 1]->setFromNormalized(0.34561951392432877);
      value[ID::saturation0 + 2]->setFromNormalized(0.6646815941002131);
      value[ID::saturation0 + 3]->setFromNormalized(0.14837032962929306);
      value[ID::saturation0 + 4]->setFromNormalized(0.41012110346770086);
      value[ID::saturation0 + 5]->setFromNormalized(0.7803356987079951);
      value[ID::saturation0 + 6]->setFromNormalized(0.3684317265942598);
      value[ID::saturation0 + 7]->setFromNormalized(0.549825667462626);
      value[ID::saturation0 + 8]->setFromNormalized(0.7052892074303007);
      value[ID::saturation0 + 9]->setFromNormalized(0.4750983897241158);
      value[ID::saturation0 + 10]->setFromNormalized(0.4001544218606906);
      value[ID::saturation0 + 11]->setFromNormalized(0.01705964353368702);
      value[ID::saturation0 + 12]->setFromNormalized(0.4714285714285714);
      value[ID::saturation0 + 13]->setFromNormalized(0.45952382768903455);
      value[ID::saturation0 + 14]->setFromNormalized(0.4357142857142857);
      value[ID::saturation0 + 15]->setFromNormalized(0.4119047437395368);
      value[ID::saturation0 + 16]->setFromNormalized(0.38809520176478796);
      value[ID::saturation0 + 17]->setFromNormalized(0.36428565979003896);
      value[ID::saturation0 + 18]->setFromNormalized(0.34047611781529014);
      value[ID::saturation0 + 19]->setFromNormalized(0.31666657584054125);
      value[ID::saturation0 + 20]->setFromNormalized(0.2928570338657924);
      value[ID::saturation0 + 21]->setFromNormalized(0.2690474918910435);
      value[ID::saturation0 + 22]->setFromNormalized(0.24523794991629466);
      value[ID::saturation0 + 23]->setFromNormalized(0.2214284079415457);
      value[ID::saturation0 + 24]->setFromNormalized(0.19761886596679687);
      value[ID::saturation0 + 25]->setFromNormalized(0.17380932399204796);
      value[ID::saturation0 + 26]->setFromNormalized(0.1499997820172991);
      value[ID::saturation0 + 27]->setFromNormalized(0.12619024004255022);
      value[ID::saturation0 + 28]->setFromNormalized(0.10238069806780133);
      value[ID::saturation0 + 29]->setFromNormalized(0.0785711015973772);
      value[ID::saturation0 + 30]->setFromNormalized(0.05476161411830362);
      value[ID::saturation0 + 31]->setFromNormalized(0.030952126639229895);
      value[ID::saturation0 + 32]->setFromNormalized(0.007142639160156279);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.7280000448226929);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.41000035405158997);
      value[ID::pitchMultiply]->setFromNormalized(0.2498124539852142);
      value[ID::pitchModulo]->setFromNormalized(0.2120000571012497);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.7759999632835388);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.6320001482963562);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(1.0);
      value[ID::overtoneExpand]->setFromNormalized(0.8080000877380371);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.08800017833709717);
      value[ID::decayMultiplier]->setFromNormalized(0.10800009220838545);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441401183605194);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetPermuteSaturation: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.17857142857142858);
      value[ID::attack0 + 1]->setFromNormalized(0.20535714285714288);
      value[ID::attack0 + 2]->setFromNormalized(0.2589285714285714);
      value[ID::attack0 + 3]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 4]->setFromNormalized(0.3142857142857143);
      value[ID::attack0 + 5]->setFromNormalized(0.3255639212472098);
      value[ID::attack0 + 6]->setFromNormalized(0.3481203351702009);
      value[ID::attack0 + 7]->setFromNormalized(0.3706767490931919);
      value[ID::attack0 + 8]->setFromNormalized(0.9714285714285714);
      value[ID::attack0 + 9]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 10]->setFromNormalized(0.2961734771728516);
      value[ID::attack0 + 11]->setFromNormalized(0.3313775743756976);
      value[ID::attack0 + 12]->setFromNormalized(0.8357142857142857);
      value[ID::attack0 + 13]->setFromNormalized(0.4017857687813895);
      value[ID::attack0 + 14]->setFromNormalized(0.4369898659842355);
      value[ID::attack0 + 15]->setFromNormalized(0.4721939631870815);
      value[ID::attack0 + 16]->setFromNormalized(0.8785714285714286);
      value[ID::attack0 + 17]->setFromNormalized(0.5426021575927734);
      value[ID::attack0 + 18]->setFromNormalized(0.5778062547956194);
      value[ID::attack0 + 19]->setFromNormalized(0.6130103519984653);
      value[ID::attack0 + 20]->setFromNormalized(0.9857142857142858);
      value[ID::attack0 + 21]->setFromNormalized(0.4);
      value[ID::attack0 + 22]->setFromNormalized(0.3968641008649554);
      value[ID::attack0 + 23]->setFromNormalized(0.3905923025948661);
      value[ID::attack0 + 24]->setFromNormalized(0.3928571428571429);
      value[ID::attack0 + 25]->setFromNormalized(0.41948051452636714);
      value[ID::attack0 + 26]->setFromNormalized(0.47272725786481584);
      value[ID::attack0 + 27]->setFromNormalized(0.5259740012032645);
      value[ID::attack0 + 28]->setFromNormalized(0.5792207445417132);
      value[ID::attack0 + 29]->setFromNormalized(0.6324674878801618);
      value[ID::attack0 + 30]->setFromNormalized(0.6857142312186104);
      value[ID::attack0 + 31]->setFromNormalized(0.7389609745570591);
      value[ID::attack0 + 32]->setFromNormalized(0.7922077178955078);
      value[ID::attack0 + 33]->setFromNormalized(0.8454544748578753);
      value[ID::attack0 + 34]->setFromNormalized(0.8987012386322022);
      value[ID::attack0 + 35]->setFromNormalized(0.9519479955945697);
      value[ID::attack0 + 36]->setFromNormalized(0.9785714285714285);
      value[ID::attack0 + 37]->setFromNormalized(0.9714285714285714);
      value[ID::attack0 + 38]->setFromNormalized(0.9568681308201381);
      value[ID::attack0 + 39]->setFromNormalized(0.9277472496032715);
      value[ID::attack0 + 40]->setFromNormalized(0.8986263683864049);
      value[ID::attack0 + 41]->setFromNormalized(0.8695054871695382);
      value[ID::attack0 + 42]->setFromNormalized(0.8403846059526716);
      value[ID::attack0 + 43]->setFromNormalized(0.811263724735805);
      value[ID::attack0 + 44]->setFromNormalized(0.7821428435189384);
      value[ID::attack0 + 45]->setFromNormalized(0.7530219486781529);
      value[ID::attack0 + 46]->setFromNormalized(0.7239010947091239);
      value[ID::attack0 + 47]->setFromNormalized(0.6947801862444196);
      value[ID::attack0 + 48]->setFromNormalized(0.6656593322753906);
      value[ID::attack0 + 49]->setFromNormalized(0.6365384238106864);
      value[ID::attack0 + 50]->setFromNormalized(0.6074175698416573);
      value[ID::attack0 + 51]->setFromNormalized(0.6071428571428572);
      value[ID::attack0 + 52]->setFromNormalized(0.6240259715488978);
      value[ID::attack0 + 53]->setFromNormalized(0.6577922003609793);
      value[ID::attack0 + 54]->setFromNormalized(0.6915584291730608);
      value[ID::attack0 + 55]->setFromNormalized(0.7253246579851422);
      value[ID::attack0 + 56]->setFromNormalized(0.7590908867972238);
      value[ID::attack0 + 57]->setFromNormalized(0.7928571156093053);
      value[ID::attack0 + 58]->setFromNormalized(0.8266233444213867);
      value[ID::attack0 + 59]->setFromNormalized(0.8603895732334682);
      value[ID::attack0 + 60]->setFromNormalized(0.8941558020455497);
      value[ID::attack0 + 61]->setFromNormalized(0.9279220308576311);
      value[ID::attack0 + 62]->setFromNormalized(0.961688266481672);
      value[ID::attack0 + 63]->setFromNormalized(0.9785714285714285);
      value[ID::decay0 + 0]->setFromNormalized(0.8);
      value[ID::decay0 + 1]->setFromNormalized(0.6142857142857143);
      value[ID::decay0 + 2]->setFromNormalized(0.4214285714285714);
      value[ID::decay0 + 3]->setFromNormalized(0.15000000000000002);
      value[ID::decay0 + 4]->setFromNormalized(0.9);
      value[ID::decay0 + 5]->setFromNormalized(0.7928571428571428);
      value[ID::decay0 + 6]->setFromNormalized(0.5);
      value[ID::decay0 + 7]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 8]->setFromNormalized(0.9428571428571428);
      value[ID::decay0 + 9]->setFromNormalized(0.8);
      value[ID::decay0 + 10]->setFromNormalized(0.5285714285714286);
      value[ID::decay0 + 11]->setFromNormalized(0.3642857142857143);
      value[ID::decay0 + 12]->setFromNormalized(0.9357142857142857);
      value[ID::decay0 + 13]->setFromNormalized(0.7428571428571429);
      value[ID::decay0 + 14]->setFromNormalized(0.4714285714285714);
      value[ID::decay0 + 15]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 16]->setFromNormalized(0.8071428571428572);
      value[ID::decay0 + 17]->setFromNormalized(0.6714285714285715);
      value[ID::decay0 + 18]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 19]->setFromNormalized(0.1785714285714286);
      value[ID::decay0 + 20]->setFromNormalized(0.6928571428571428);
      value[ID::decay0 + 21]->setFromNormalized(0.5142857142857142);
      value[ID::decay0 + 22]->setFromNormalized(0.26428571428571423);
      value[ID::decay0 + 23]->setFromNormalized(0.18571428571428572);
      value[ID::decay0 + 24]->setFromNormalized(0.9071428571428571);
      value[ID::decay0 + 25]->setFromNormalized(0.7285714285714286);
      value[ID::decay0 + 26]->setFromNormalized(0.5214285714285714);
      value[ID::decay0 + 27]->setFromNormalized(0.30000000000000004);
      value[ID::decay0 + 28]->setFromNormalized(0.9071428571428571);
      value[ID::decay0 + 29]->setFromNormalized(0.791666671207973);
      value[ID::decay0 + 30]->setFromNormalized(0.5607142857142857);
      value[ID::decay0 + 31]->setFromNormalized(0.3297619410923549);
      value[ID::decay0 + 32]->setFromNormalized(0.8642857142857143);
      value[ID::decay0 + 33]->setFromNormalized(0.775);
      value[ID::decay0 + 34]->setFromNormalized(0.5964285714285714);
      value[ID::decay0 + 35]->setFromNormalized(0.4178571428571428);
      value[ID::decay0 + 36]->setFromNormalized(0.9357142857142857);
      value[ID::decay0 + 37]->setFromNormalized(0.7988095147269113);
      value[ID::decay0 + 38]->setFromNormalized(0.525);
      value[ID::decay0 + 39]->setFromNormalized(0.2511904035295759);
      value[ID::decay0 + 40]->setFromNormalized(0.8714285714285714);
      value[ID::decay0 + 41]->setFromNormalized(0.7428571428571429);
      value[ID::decay0 + 42]->setFromNormalized(0.48571428571428577);
      value[ID::decay0 + 43]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 44]->setFromNormalized(0.8214285714285714);
      value[ID::decay0 + 45]->setFromNormalized(0.7023809705461774);
      value[ID::decay0 + 46]->setFromNormalized(0.4642857142857143);
      value[ID::decay0 + 47]->setFromNormalized(0.2261905125209264);
      value[ID::decay0 + 48]->setFromNormalized(0.9785714285714285);
      value[ID::decay0 + 49]->setFromNormalized(0.7571428571428571);
      value[ID::decay0 + 50]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 51]->setFromNormalized(0.09285714285714287);
      value[ID::decay0 + 52]->setFromNormalized(0.9142857142857143);
      value[ID::decay0 + 53]->setFromNormalized(0.7773809432983398);
      value[ID::decay0 + 54]->setFromNormalized(0.5035714285714286);
      value[ID::decay0 + 55]->setFromNormalized(0.22976183210100445);
      value[ID::decay0 + 56]->setFromNormalized(0.8571428571428572);
      value[ID::decay0 + 57]->setFromNormalized(0.7345238276890347);
      value[ID::decay0 + 58]->setFromNormalized(0.4892857142857143);
      value[ID::decay0 + 59]->setFromNormalized(0.2440476553780692);
      value[ID::decay0 + 60]->setFromNormalized(0.9071428571428571);
      value[ID::decay0 + 61]->setFromNormalized(0.725);
      value[ID::decay0 + 62]->setFromNormalized(0.36071428571428577);
      value[ID::decay0 + 63]->setFromNormalized(0.1785714285714286);
      value[ID::overtone0 + 0]->setFromNormalized(1.0);
      value[ID::overtone0 + 1]->setFromNormalized(1.0);
      value[ID::overtone0 + 2]->setFromNormalized(1.0);
      value[ID::overtone0 + 3]->setFromNormalized(1.0);
      value[ID::overtone0 + 4]->setFromNormalized(1.0);
      value[ID::overtone0 + 5]->setFromNormalized(0.8794642857142858);
      value[ID::overtone0 + 6]->setFromNormalized(0.7526785714285714);
      value[ID::overtone0 + 7]->setFromNormalized(0.6258928571428571);
      value[ID::overtone0 + 8]->setFromNormalized(0.49910714285714286);
      value[ID::overtone0 + 9]->setFromNormalized(0.4357142857142858);
      value[ID::overtone0 + 10]->setFromNormalized(0.2071428571428572);
      value[ID::overtone0 + 11]->setFromNormalized(0.270408194405692);
      value[ID::overtone0 + 12]->setFromNormalized(0.39693875994001104);
      value[ID::overtone0 + 13]->setFromNormalized(0.5234694344656807);
      value[ID::overtone0 + 14]->setFromNormalized(0.6500000272478377);
      value[ID::overtone0 + 15]->setFromNormalized(0.776530647277832);
      value[ID::overtone0 + 16]->setFromNormalized(0.9030612673078264);
      value[ID::overtone0 + 17]->setFromNormalized(1.0);
      value[ID::overtone0 + 18]->setFromNormalized(1.0);
      value[ID::overtone0 + 19]->setFromNormalized(0.7122021811349051);
      value[ID::overtone0 + 20]->setFromNormalized(0.2928571428571427);
      value[ID::overtone0 + 21]->setFromNormalized(0.3666666848318916);
      value[ID::overtone0 + 22]->setFromNormalized(0.5142857687813895);
      value[ID::overtone0 + 23]->setFromNormalized(0.661904798235212);
      value[ID::overtone0 + 24]->setFromNormalized(0.8095238685607911);
      value[ID::overtone0 + 25]->setFromNormalized(0.9571429252624511);
      value[ID::overtone0 + 26]->setFromNormalized(1.0);
      value[ID::overtone0 + 27]->setFromNormalized(0.1928571428571429);
      value[ID::overtone0 + 28]->setFromNormalized(0.23061223711286258);
      value[ID::overtone0 + 29]->setFromNormalized(0.30612242562430236);
      value[ID::overtone0 + 30]->setFromNormalized(0.3816326141357421);
      value[ID::overtone0 + 31]->setFromNormalized(0.4571428026471819);
      value[ID::overtone0 + 32]->setFromNormalized(0.5326529911586216);
      value[ID::overtone0 + 33]->setFromNormalized(0.6081631796700613);
      value[ID::overtone0 + 34]->setFromNormalized(0.683673368181501);
      value[ID::overtone0 + 35]->setFromNormalized(0.5357142857142857);
      value[ID::overtone0 + 36]->setFromNormalized(0.5339947291782925);
      value[ID::overtone0 + 37]->setFromNormalized(0.5305555616106306);
      value[ID::overtone0 + 38]->setFromNormalized(0.5271163940429687);
      value[ID::overtone0 + 39]->setFromNormalized(0.5236772264753069);
      value[ID::overtone0 + 40]->setFromNormalized(0.5202380589076451);
      value[ID::overtone0 + 41]->setFromNormalized(0.5167988913399832);
      value[ID::overtone0 + 42]->setFromNormalized(0.5133597237723214);
      value[ID::overtone0 + 43]->setFromNormalized(0.5099205562046596);
      value[ID::overtone0 + 44]->setFromNormalized(0.5064813886369978);
      value[ID::overtone0 + 45]->setFromNormalized(0.5030422210693359);
      value[ID::overtone0 + 46]->setFromNormalized(0.4996030535016741);
      value[ID::overtone0 + 47]->setFromNormalized(0.49616388593401234);
      value[ID::overtone0 + 48]->setFromNormalized(0.49272471836635046);
      value[ID::overtone0 + 49]->setFromNormalized(0.48928555079868863);
      value[ID::overtone0 + 50]->setFromNormalized(0.4858463832310268);
      value[ID::overtone0 + 51]->setFromNormalized(0.48240721566336486);
      value[ID::overtone0 + 52]->setFromNormalized(0.47896804809570315);
      value[ID::overtone0 + 53]->setFromNormalized(0.4755288805280413);
      value[ID::overtone0 + 54]->setFromNormalized(0.4720897129603795);
      value[ID::overtone0 + 55]->setFromNormalized(0.4686505453927177);
      value[ID::overtone0 + 56]->setFromNormalized(0.46521137782505584);
      value[ID::overtone0 + 57]->setFromNormalized(0.461772210257394);
      value[ID::overtone0 + 58]->setFromNormalized(0.4583330426897322);
      value[ID::overtone0 + 59]->setFromNormalized(0.45489387512207025);
      value[ID::overtone0 + 60]->setFromNormalized(0.45145470755440853);
      value[ID::overtone0 + 61]->setFromNormalized(0.4480155399867467);
      value[ID::overtone0 + 62]->setFromNormalized(0.4445763724190849);
      value[ID::overtone0 + 63]->setFromNormalized(0.4428571428571429);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.7916306717044153);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.5586239647064085);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.06476034496875979);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.7903642549431238);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.3948536234657938);
      value[ID::saturation0 + 13]->setFromNormalized(0.050000000000000044);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.371021388314126);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.5394287826482722);
      value[ID::saturation0 + 22]->setFromNormalized(0.5440119640966367);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.5142857142857142);
      value[ID::saturation0 + 25]->setFromNormalized(0.4833765082731092);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.4097155962681928);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.5571428571428572);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.9971710384389321);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.6302890532998189);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.7214285714285714);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.8788160036868481);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.5914207426927869);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.2563033637172364);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.6800000667572021);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.013999540358781815);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.3240000009536743);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.1680000275373459);
      value[ID::randomPhase]->setFromNormalized(0.16000008583068848);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.22600001096725464);
      value[ID::attackMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::decayMultiplier]->setFromNormalized(0.36800000071525574);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441401183605194);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.23199991881847384);
      value[ID::phaserFeedback]->setFromNormalized(0.8480000495910645);
      value[ID::phaserRange]->setFromNormalized(0.7520000338554382);
      value[ID::phaserMin]->setFromNormalized(1.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(0);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetPhasedBass: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.03571428571428569);
      value[ID::attack0 + 6]->setFromNormalized(0.09285714285714285);
      value[ID::attack0 + 7]->setFromNormalized(0.12142857142857143);
      value[ID::attack0 + 8]->setFromNormalized(0.07142857142857138);
      value[ID::attack0 + 9]->setFromNormalized(0.04285714285714281);
      value[ID::attack0 + 10]->setFromNormalized(0.04285714285714281);
      value[ID::attack0 + 11]->setFromNormalized(0.04285714285714281);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.04285714285714281);
      value[ID::attack0 + 14]->setFromNormalized(0.057142857142857155);
      value[ID::attack0 + 15]->setFromNormalized(0.08571428571428573);
      value[ID::attack0 + 16]->setFromNormalized(0.17142857142857135);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.2928571428571428);
      value[ID::attack0 + 19]->setFromNormalized(0.35);
      value[ID::attack0 + 20]->setFromNormalized(0.4);
      value[ID::attack0 + 21]->setFromNormalized(0.4571428571428572);
      value[ID::attack0 + 22]->setFromNormalized(0.5785714285714285);
      value[ID::attack0 + 23]->setFromNormalized(0.5857142857142856);
      value[ID::attack0 + 24]->setFromNormalized(0.4928571428571429);
      value[ID::attack0 + 25]->setFromNormalized(0.41428571428571426);
      value[ID::attack0 + 26]->setFromNormalized(0.3571428571428571);
      value[ID::attack0 + 27]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 28]->setFromNormalized(0.1857142857142857);
      value[ID::attack0 + 29]->setFromNormalized(0.13571428571428565);
      value[ID::attack0 + 30]->setFromNormalized(0.09999999999999996);
      value[ID::attack0 + 31]->setFromNormalized(0.09285714285714285);
      value[ID::attack0 + 32]->setFromNormalized(0.11428571428571431);
      value[ID::attack0 + 33]->setFromNormalized(0.1571428571428571);
      value[ID::attack0 + 34]->setFromNormalized(0.24285714285714285);
      value[ID::attack0 + 35]->setFromNormalized(0.3928571428571429);
      value[ID::attack0 + 36]->setFromNormalized(0.5357142857142857);
      value[ID::attack0 + 37]->setFromNormalized(0.6285714285714286);
      value[ID::attack0 + 38]->setFromNormalized(0.6285714285714286);
      value[ID::attack0 + 39]->setFromNormalized(0.6);
      value[ID::attack0 + 40]->setFromNormalized(0.55);
      value[ID::attack0 + 41]->setFromNormalized(0.4714285714285714);
      value[ID::attack0 + 42]->setFromNormalized(0.4);
      value[ID::attack0 + 43]->setFromNormalized(0.3285714285714286);
      value[ID::attack0 + 44]->setFromNormalized(0.20714285714285716);
      value[ID::attack0 + 45]->setFromNormalized(0.0);
      value[ID::attack0 + 46]->setFromNormalized(0.09285714285714285);
      value[ID::attack0 + 47]->setFromNormalized(0.02142857142857146);
      value[ID::attack0 + 48]->setFromNormalized(0.0);
      value[ID::attack0 + 49]->setFromNormalized(0.0);
      value[ID::attack0 + 50]->setFromNormalized(0.0);
      value[ID::attack0 + 51]->setFromNormalized(0.10714285714285708);
      value[ID::attack0 + 52]->setFromNormalized(0.30000000000000004);
      value[ID::attack0 + 53]->setFromNormalized(0.3642857142857143);
      value[ID::attack0 + 54]->setFromNormalized(0.5142857142857142);
      value[ID::attack0 + 55]->setFromNormalized(0.5214285714285714);
      value[ID::attack0 + 56]->setFromNormalized(0.47857142857142854);
      value[ID::attack0 + 57]->setFromNormalized(0.3571428571428571);
      value[ID::attack0 + 58]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 59]->setFromNormalized(0.2285714285714285);
      value[ID::attack0 + 60]->setFromNormalized(0.0);
      value[ID::attack0 + 61]->setFromNormalized(0.12142857142857143);
      value[ID::attack0 + 62]->setFromNormalized(0.05000000000000004);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.5);
      value[ID::decay0 + 1]->setFromNormalized(0.5);
      value[ID::decay0 + 2]->setFromNormalized(0.5);
      value[ID::decay0 + 3]->setFromNormalized(0.5);
      value[ID::decay0 + 4]->setFromNormalized(0.5);
      value[ID::decay0 + 5]->setFromNormalized(0.5);
      value[ID::decay0 + 6]->setFromNormalized(0.4714285714285714);
      value[ID::decay0 + 7]->setFromNormalized(0.6142857142857143);
      value[ID::decay0 + 8]->setFromNormalized(0.75);
      value[ID::decay0 + 9]->setFromNormalized(0.9);
      value[ID::decay0 + 10]->setFromNormalized(0.9857142857142858);
      value[ID::decay0 + 11]->setFromNormalized(1.0);
      value[ID::decay0 + 12]->setFromNormalized(0.9);
      value[ID::decay0 + 13]->setFromNormalized(0.7714285714285715);
      value[ID::decay0 + 14]->setFromNormalized(0.6214285714285714);
      value[ID::decay0 + 15]->setFromNormalized(0.5);
      value[ID::decay0 + 16]->setFromNormalized(0.47857142857142854);
      value[ID::decay0 + 17]->setFromNormalized(0.3928571428571429);
      value[ID::decay0 + 18]->setFromNormalized(0.25);
      value[ID::decay0 + 19]->setFromNormalized(0.5);
      value[ID::decay0 + 20]->setFromNormalized(0.1428571428571429);
      value[ID::decay0 + 21]->setFromNormalized(0.07857142857142864);
      value[ID::decay0 + 22]->setFromNormalized(0.05714285714285717);
      value[ID::decay0 + 23]->setFromNormalized(0.05714285714285717);
      value[ID::decay0 + 24]->setFromNormalized(0.05714285714285717);
      value[ID::decay0 + 25]->setFromNormalized(0.09285714285714287);
      value[ID::decay0 + 26]->setFromNormalized(0.13571428571428568);
      value[ID::decay0 + 27]->setFromNormalized(0.22142857142857142);
      value[ID::decay0 + 28]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 29]->setFromNormalized(0.41428571428571426);
      value[ID::decay0 + 30]->setFromNormalized(0.5428571428571429);
      value[ID::decay0 + 31]->setFromNormalized(0.5);
      value[ID::decay0 + 32]->setFromNormalized(0.7142857142857143);
      value[ID::decay0 + 33]->setFromNormalized(0.6928571428571428);
      value[ID::decay0 + 34]->setFromNormalized(0.6357142857142857);
      value[ID::decay0 + 35]->setFromNormalized(0.5214285714285714);
      value[ID::decay0 + 36]->setFromNormalized(0.4357142857142857);
      value[ID::decay0 + 37]->setFromNormalized(0.37857142857142856);
      value[ID::decay0 + 38]->setFromNormalized(0.30714285714285716);
      value[ID::decay0 + 39]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 40]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 41]->setFromNormalized(0.26428571428571423);
      value[ID::decay0 + 42]->setFromNormalized(0.3214285714285714);
      value[ID::decay0 + 43]->setFromNormalized(0.3928571428571429);
      value[ID::decay0 + 44]->setFromNormalized(0.44999999999999996);
      value[ID::decay0 + 45]->setFromNormalized(0.5);
      value[ID::decay0 + 46]->setFromNormalized(0.5285714285714286);
      value[ID::decay0 + 47]->setFromNormalized(0.5);
      value[ID::decay0 + 48]->setFromNormalized(0.4642857142857143);
      value[ID::decay0 + 49]->setFromNormalized(0.4285714285714286);
      value[ID::decay0 + 50]->setFromNormalized(0.33571428571428574);
      value[ID::decay0 + 51]->setFromNormalized(0.2785714285714286);
      value[ID::decay0 + 52]->setFromNormalized(0.22142857142857142);
      value[ID::decay0 + 53]->setFromNormalized(0.25);
      value[ID::decay0 + 54]->setFromNormalized(0.5);
      value[ID::decay0 + 55]->setFromNormalized(0.30714285714285716);
      value[ID::decay0 + 56]->setFromNormalized(0.3857142857142857);
      value[ID::decay0 + 57]->setFromNormalized(0.44285714285714284);
      value[ID::decay0 + 58]->setFromNormalized(0.4642857142857143);
      value[ID::decay0 + 59]->setFromNormalized(0.4571428571428572);
      value[ID::decay0 + 60]->setFromNormalized(0.3571428571428571);
      value[ID::decay0 + 61]->setFromNormalized(0.30000000000000004);
      value[ID::decay0 + 62]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 63]->setFromNormalized(0.20714285714285718);
      value[ID::overtone0 + 0]->setFromNormalized(1.0);
      value[ID::overtone0 + 1]->setFromNormalized(1.0);
      value[ID::overtone0 + 2]->setFromNormalized(0.47857142857142854);
      value[ID::overtone0 + 3]->setFromNormalized(0.8714285714285716);
      value[ID::overtone0 + 4]->setFromNormalized(0.8);
      value[ID::overtone0 + 5]->setFromNormalized(0.5642857142857143);
      value[ID::overtone0 + 6]->setFromNormalized(0.5857142857142856);
      value[ID::overtone0 + 7]->setFromNormalized(0.6285714285714286);
      value[ID::overtone0 + 8]->setFromNormalized(0.6785714285714286);
      value[ID::overtone0 + 9]->setFromNormalized(0.7357142857142858);
      value[ID::overtone0 + 10]->setFromNormalized(0.47930365742088743);
      value[ID::overtone0 + 11]->setFromNormalized(0.85);
      value[ID::overtone0 + 12]->setFromNormalized(0.44302832384658164);
      value[ID::overtone0 + 13]->setFromNormalized(0.9214285714285715);
      value[ID::overtone0 + 14]->setFromNormalized(1.0);
      value[ID::overtone0 + 15]->setFromNormalized(0.9357142857142857);
      value[ID::overtone0 + 16]->setFromNormalized(0.7714285714285715);
      value[ID::overtone0 + 17]->setFromNormalized(0.5642857142857143);
      value[ID::overtone0 + 18]->setFromNormalized(0.5);
      value[ID::overtone0 + 19]->setFromNormalized(0.37857142857142856);
      value[ID::overtone0 + 20]->setFromNormalized(0.3285714285714286);
      value[ID::overtone0 + 21]->setFromNormalized(0.3287886595888967);
      value[ID::overtone0 + 22]->setFromNormalized(0.31428571428571417);
      value[ID::overtone0 + 23]->setFromNormalized(0.3098943791441968);
      value[ID::overtone0 + 24]->setFromNormalized(0.31428571428571417);
      value[ID::overtone0 + 25]->setFromNormalized(0.3214285714285713);
      value[ID::overtone0 + 26]->setFromNormalized(0.3642857142857143);
      value[ID::overtone0 + 27]->setFromNormalized(0.2764209843288903);
      value[ID::overtone0 + 28]->setFromNormalized(0.42857142857142866);
      value[ID::overtone0 + 29]->setFromNormalized(0.4928571428571429);
      value[ID::overtone0 + 30]->setFromNormalized(0.25431915308286346);
      value[ID::overtone0 + 31]->setFromNormalized(0.5142857142857142);
      value[ID::overtone0 + 32]->setFromNormalized(0.5571428571428572);
      value[ID::overtone0 + 33]->setFromNormalized(0.5571428571428572);
      value[ID::overtone0 + 34]->setFromNormalized(0.45);
      value[ID::overtone0 + 35]->setFromNormalized(0.37857142857142856);
      value[ID::overtone0 + 36]->setFromNormalized(0.33571428571428574);
      value[ID::overtone0 + 37]->setFromNormalized(0.33571428571428574);
      value[ID::overtone0 + 38]->setFromNormalized(0.33571428571428574);
      value[ID::overtone0 + 39]->setFromNormalized(0.33571428571428574);
      value[ID::overtone0 + 40]->setFromNormalized(0.33571428571428574);
      value[ID::overtone0 + 41]->setFromNormalized(0.3285714285714286);
      value[ID::overtone0 + 42]->setFromNormalized(0.26428571428571423);
      value[ID::overtone0 + 43]->setFromNormalized(0.12857142857142848);
      value[ID::overtone0 + 44]->setFromNormalized(0.05);
      value[ID::overtone0 + 45]->setFromNormalized(0.05);
      value[ID::overtone0 + 46]->setFromNormalized(0.05);
      value[ID::overtone0 + 47]->setFromNormalized(0.07142857142857136);
      value[ID::overtone0 + 48]->setFromNormalized(0.08571428571428577);
      value[ID::overtone0 + 49]->setFromNormalized(0.15051499783199063);
      value[ID::overtone0 + 50]->setFromNormalized(0.08571428571428577);
      value[ID::overtone0 + 51]->setFromNormalized(0.08571428571428577);
      value[ID::overtone0 + 52]->setFromNormalized(0.08571428571428577);
      value[ID::overtone0 + 53]->setFromNormalized(0.07142857142857136);
      value[ID::overtone0 + 54]->setFromNormalized(0.06428571428571424);
      value[ID::overtone0 + 55]->setFromNormalized(0.06428571428571424);
      value[ID::overtone0 + 56]->setFromNormalized(0.05);
      value[ID::overtone0 + 57]->setFromNormalized(0.05);
      value[ID::overtone0 + 58]->setFromNormalized(0.05);
      value[ID::overtone0 + 59]->setFromNormalized(0.05);
      value[ID::overtone0 + 60]->setFromNormalized(0.05);
      value[ID::overtone0 + 61]->setFromNormalized(0.05);
      value[ID::overtone0 + 62]->setFromNormalized(0.05);
      value[ID::overtone0 + 63]->setFromNormalized(0.05);
      value[ID::saturation0 + 0]->setFromNormalized(0.014285714285714284);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.13571428571428565);
      value[ID::saturation0 + 9]->setFromNormalized(0.18877552577427456);
      value[ID::saturation0 + 10]->setFromNormalized(0.2948980058942522);
      value[ID::saturation0 + 11]->setFromNormalized(0.4010204860142299);
      value[ID::saturation0 + 12]->setFromNormalized(0.5071429661342075);
      value[ID::saturation0 + 13]->setFromNormalized(0.61326539175851);
      value[ID::saturation0 + 14]->setFromNormalized(0.7193878718784877);
      value[ID::saturation0 + 15]->setFromNormalized(0.825510311126709);
      value[ID::saturation0 + 16]->setFromNormalized(0.8785714285714286);
      value[ID::saturation0 + 17]->setFromNormalized(0.07857142857142858);
      value[ID::saturation0 + 18]->setFromNormalized(0.07912695748465404);
      value[ID::saturation0 + 19]->setFromNormalized(0.08023801531110485);
      value[ID::saturation0 + 20]->setFromNormalized(0.08134907313755582);
      value[ID::saturation0 + 21]->setFromNormalized(0.08246013096400669);
      value[ID::saturation0 + 22]->setFromNormalized(0.08357118879045751);
      value[ID::saturation0 + 23]->setFromNormalized(0.08468224661690849);
      value[ID::saturation0 + 24]->setFromNormalized(0.08579330444335939);
      value[ID::saturation0 + 25]->setFromNormalized(0.08690441676548545);
      value[ID::saturation0 + 26]->setFromNormalized(0.08801552908761157);
      value[ID::saturation0 + 27]->setFromNormalized(0.08912664140973767);
      value[ID::saturation0 + 28]->setFromNormalized(0.09023775373186384);
      value[ID::saturation0 + 29]->setFromNormalized(0.09134886605398998);
      value[ID::saturation0 + 30]->setFromNormalized(0.09245997837611608);
      value[ID::saturation0 + 31]->setFromNormalized(0.0935710906982422);
      value[ID::saturation0 + 32]->setFromNormalized(0.09468220302036831);
      value[ID::saturation0 + 33]->setFromNormalized(0.09579331534249447);
      value[ID::saturation0 + 34]->setFromNormalized(0.09690442766462044);
      value[ID::saturation0 + 35]->setFromNormalized(0.09801553998674661);
      value[ID::saturation0 + 36]->setFromNormalized(0.09912665230887271);
      value[ID::saturation0 + 37]->setFromNormalized(0.10023776463099884);
      value[ID::saturation0 + 38]->setFromNormalized(0.10134887695312496);
      value[ID::saturation0 + 39]->setFromNormalized(0.10245998927525113);
      value[ID::saturation0 + 40]->setFromNormalized(0.10357110159737722);
      value[ID::saturation0 + 41]->setFromNormalized(0.10468221391950334);
      value[ID::saturation0 + 42]->setFromNormalized(0.10579332624162949);
      value[ID::saturation0 + 43]->setFromNormalized(0.10690443856375553);
      value[ID::saturation0 + 44]->setFromNormalized(0.10801555088588166);
      value[ID::saturation0 + 45]->setFromNormalized(0.10912666320800779);
      value[ID::saturation0 + 46]->setFromNormalized(0.1102377755301339);
      value[ID::saturation0 + 47]->setFromNormalized(0.11134888785226);
      value[ID::saturation0 + 48]->setFromNormalized(0.11246000017438613);
      value[ID::saturation0 + 49]->setFromNormalized(0.1135711124965123);
      value[ID::saturation0 + 50]->setFromNormalized(0.11468222481863843);
      value[ID::saturation0 + 51]->setFromNormalized(0.11579333714076451);
      value[ID::saturation0 + 52]->setFromNormalized(0.11690444946289061);
      value[ID::saturation0 + 53]->setFromNormalized(0.11801556178501671);
      value[ID::saturation0 + 54]->setFromNormalized(0.11912667410714284);
      value[ID::saturation0 + 55]->setFromNormalized(0.12023778642926893);
      value[ID::saturation0 + 56]->setFromNormalized(0.12134889875139507);
      value[ID::saturation0 + 57]->setFromNormalized(0.12246001107352125);
      value[ID::saturation0 + 58]->setFromNormalized(0.12357112339564733);
      value[ID::saturation0 + 59]->setFromNormalized(0.12468223571777347);
      value[ID::saturation0 + 60]->setFromNormalized(0.12579334803989947);
      value[ID::saturation0 + 61]->setFromNormalized(0.12690446036202563);
      value[ID::saturation0 + 62]->setFromNormalized(0.12801557268415176);
      value[ID::saturation0 + 63]->setFromNormalized(0.12857142857142853);
      value[ID::gain]->setFromNormalized(0.9119998812675476);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.07999972999095917);
      value[ID::pitchMultiply]->setFromNormalized(0.0298125259578228);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.7479999661445618);
      value[ID::randomDecay]->setFromNormalized(0.47999998927116394);
      value[ID::randomSaturation]->setFromNormalized(0.5720000267028809);
      value[ID::randomPhase]->setFromNormalized(1.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.33799999952316284);
      value[ID::attackMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::decayMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.4240001142024994);
      value[ID::phaserFrequency]->setFromNormalized(0.16800010204315186);
      value[ID::phaserFeedback]->setFromNormalized(0.16800007224082947);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.7160000205039978);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(10);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetPhaserFeedback: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.0);
      value[ID::attack0 + 6]->setFromNormalized(0.0);
      value[ID::attack0 + 7]->setFromNormalized(0.0);
      value[ID::attack0 + 8]->setFromNormalized(0.0);
      value[ID::attack0 + 9]->setFromNormalized(0.0);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.0);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.0);
      value[ID::attack0 + 14]->setFromNormalized(0.0);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.0);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.0);
      value[ID::attack0 + 22]->setFromNormalized(0.0);
      value[ID::attack0 + 23]->setFromNormalized(0.0);
      value[ID::attack0 + 24]->setFromNormalized(0.0);
      value[ID::attack0 + 25]->setFromNormalized(0.0);
      value[ID::attack0 + 26]->setFromNormalized(0.0);
      value[ID::attack0 + 27]->setFromNormalized(0.0);
      value[ID::attack0 + 28]->setFromNormalized(0.0);
      value[ID::attack0 + 29]->setFromNormalized(0.0);
      value[ID::attack0 + 30]->setFromNormalized(0.0);
      value[ID::attack0 + 31]->setFromNormalized(0.0);
      value[ID::attack0 + 32]->setFromNormalized(0.0);
      value[ID::attack0 + 33]->setFromNormalized(0.0);
      value[ID::attack0 + 34]->setFromNormalized(0.0);
      value[ID::attack0 + 35]->setFromNormalized(0.0);
      value[ID::attack0 + 36]->setFromNormalized(0.0);
      value[ID::attack0 + 37]->setFromNormalized(0.0);
      value[ID::attack0 + 38]->setFromNormalized(0.0);
      value[ID::attack0 + 39]->setFromNormalized(0.0);
      value[ID::attack0 + 40]->setFromNormalized(0.0);
      value[ID::attack0 + 41]->setFromNormalized(0.0);
      value[ID::attack0 + 42]->setFromNormalized(0.0);
      value[ID::attack0 + 43]->setFromNormalized(0.0);
      value[ID::attack0 + 44]->setFromNormalized(0.0);
      value[ID::attack0 + 45]->setFromNormalized(0.0);
      value[ID::attack0 + 46]->setFromNormalized(0.0);
      value[ID::attack0 + 47]->setFromNormalized(0.0);
      value[ID::attack0 + 48]->setFromNormalized(0.0);
      value[ID::attack0 + 49]->setFromNormalized(0.0);
      value[ID::attack0 + 50]->setFromNormalized(0.0);
      value[ID::attack0 + 51]->setFromNormalized(0.0);
      value[ID::attack0 + 52]->setFromNormalized(0.0);
      value[ID::attack0 + 53]->setFromNormalized(0.0);
      value[ID::attack0 + 54]->setFromNormalized(0.0);
      value[ID::attack0 + 55]->setFromNormalized(0.0);
      value[ID::attack0 + 56]->setFromNormalized(0.0);
      value[ID::attack0 + 57]->setFromNormalized(0.0);
      value[ID::attack0 + 58]->setFromNormalized(0.0);
      value[ID::attack0 + 59]->setFromNormalized(0.0);
      value[ID::attack0 + 60]->setFromNormalized(0.0);
      value[ID::attack0 + 61]->setFromNormalized(0.0);
      value[ID::attack0 + 62]->setFromNormalized(0.0);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.9916123593060557);
      value[ID::decay0 + 1]->setFromNormalized(0.9643522411415668);
      value[ID::decay0 + 2]->setFromNormalized(0.9543036589870907);
      value[ID::decay0 + 3]->setFromNormalized(0.9135239658452347);
      value[ID::decay0 + 4]->setFromNormalized(0.8908038265156902);
      value[ID::decay0 + 5]->setFromNormalized(0.8337551258898712);
      value[ID::decay0 + 6]->setFromNormalized(0.8313382199057293);
      value[ID::decay0 + 7]->setFromNormalized(0.8177419680057639);
      value[ID::decay0 + 8]->setFromNormalized(0.7976466905928065);
      value[ID::decay0 + 9]->setFromNormalized(0.7966531593307279);
      value[ID::decay0 + 10]->setFromNormalized(0.778296337455586);
      value[ID::decay0 + 11]->setFromNormalized(0.7696236423363911);
      value[ID::decay0 + 12]->setFromNormalized(0.7370646672159558);
      value[ID::decay0 + 13]->setFromNormalized(0.6873762473545787);
      value[ID::decay0 + 14]->setFromNormalized(0.6744862904840353);
      value[ID::decay0 + 15]->setFromNormalized(0.6735038792529483);
      value[ID::decay0 + 16]->setFromNormalized(0.6374856873644775);
      value[ID::decay0 + 17]->setFromNormalized(0.6324352635993544);
      value[ID::decay0 + 18]->setFromNormalized(0.6184159003721564);
      value[ID::decay0 + 19]->setFromNormalized(0.614807868499453);
      value[ID::decay0 + 20]->setFromNormalized(0.5865916106450938);
      value[ID::decay0 + 21]->setFromNormalized(0.5825230115154347);
      value[ID::decay0 + 22]->setFromNormalized(0.5767209521281037);
      value[ID::decay0 + 23]->setFromNormalized(0.5327852516473848);
      value[ID::decay0 + 24]->setFromNormalized(0.5317989310312979);
      value[ID::decay0 + 25]->setFromNormalized(0.5180509452633211);
      value[ID::decay0 + 26]->setFromNormalized(0.5117291012850104);
      value[ID::decay0 + 27]->setFromNormalized(0.5090918296957443);
      value[ID::decay0 + 28]->setFromNormalized(0.49861831847720955);
      value[ID::decay0 + 29]->setFromNormalized(0.4968469013749717);
      value[ID::decay0 + 30]->setFromNormalized(0.49155686603833165);
      value[ID::decay0 + 31]->setFromNormalized(0.4914566239214817);
      value[ID::decay0 + 32]->setFromNormalized(0.4697958783581732);
      value[ID::decay0 + 33]->setFromNormalized(0.4290952576282851);
      value[ID::decay0 + 34]->setFromNormalized(0.42710074017248373);
      value[ID::decay0 + 35]->setFromNormalized(0.4103381411220154);
      value[ID::decay0 + 36]->setFromNormalized(0.38896478854835187);
      value[ID::decay0 + 37]->setFromNormalized(0.3661398995822826);
      value[ID::decay0 + 38]->setFromNormalized(0.3532839696355461);
      value[ID::decay0 + 39]->setFromNormalized(0.3441292580501446);
      value[ID::decay0 + 40]->setFromNormalized(0.33886598893562647);
      value[ID::decay0 + 41]->setFromNormalized(0.33628754521371024);
      value[ID::decay0 + 42]->setFromNormalized(0.3330424044746312);
      value[ID::decay0 + 43]->setFromNormalized(0.3285443953189521);
      value[ID::decay0 + 44]->setFromNormalized(0.3262026950705329);
      value[ID::decay0 + 45]->setFromNormalized(0.30995686154484225);
      value[ID::decay0 + 46]->setFromNormalized(0.26655241111478384);
      value[ID::decay0 + 47]->setFromNormalized(0.2428511168835067);
      value[ID::decay0 + 48]->setFromNormalized(0.23956346481389723);
      value[ID::decay0 + 49]->setFromNormalized(0.20471488401249138);
      value[ID::decay0 + 50]->setFromNormalized(0.17984161263326592);
      value[ID::decay0 + 51]->setFromNormalized(0.1676588660503443);
      value[ID::decay0 + 52]->setFromNormalized(0.15541649990500317);
      value[ID::decay0 + 53]->setFromNormalized(0.14077871375937923);
      value[ID::decay0 + 54]->setFromNormalized(0.10814855532318497);
      value[ID::decay0 + 55]->setFromNormalized(0.06513539142707227);
      value[ID::decay0 + 56]->setFromNormalized(0.06492628339205564);
      value[ID::decay0 + 57]->setFromNormalized(0.05456894283106584);
      value[ID::decay0 + 58]->setFromNormalized(0.05453046944166418);
      value[ID::decay0 + 59]->setFromNormalized(0.03992774524131448);
      value[ID::decay0 + 60]->setFromNormalized(0.03930000918682947);
      value[ID::decay0 + 61]->setFromNormalized(0.03886663211909381);
      value[ID::decay0 + 62]->setFromNormalized(0.017263512133518236);
      value[ID::decay0 + 63]->setFromNormalized(0.011014551274340091);
      value[ID::overtone0 + 0]->setFromNormalized(0.998232633598378);
      value[ID::overtone0 + 1]->setFromNormalized(0.985272855275279);
      value[ID::overtone0 + 2]->setFromNormalized(0.9837673463053767);
      value[ID::overtone0 + 3]->setFromNormalized(0.9826322393335862);
      value[ID::overtone0 + 4]->setFromNormalized(0.9807126464750018);
      value[ID::overtone0 + 5]->setFromNormalized(0.9270665693432324);
      value[ID::overtone0 + 6]->setFromNormalized(0.8784810536164356);
      value[ID::overtone0 + 7]->setFromNormalized(0.8546445093030088);
      value[ID::overtone0 + 8]->setFromNormalized(0.8372189154179314);
      value[ID::overtone0 + 9]->setFromNormalized(0.835169168635314);
      value[ID::overtone0 + 10]->setFromNormalized(0.8301608831251542);
      value[ID::overtone0 + 11]->setFromNormalized(0.8239372321942933);
      value[ID::overtone0 + 12]->setFromNormalized(0.8238485905626574);
      value[ID::overtone0 + 13]->setFromNormalized(0.816587598534596);
      value[ID::overtone0 + 14]->setFromNormalized(0.7695062021203548);
      value[ID::overtone0 + 15]->setFromNormalized(0.7525101268426684);
      value[ID::overtone0 + 16]->setFromNormalized(0.7520445245706409);
      value[ID::overtone0 + 17]->setFromNormalized(0.7428541554266509);
      value[ID::overtone0 + 18]->setFromNormalized(0.7368137656075303);
      value[ID::overtone0 + 19]->setFromNormalized(0.734517746565019);
      value[ID::overtone0 + 20]->setFromNormalized(0.7195317252531008);
      value[ID::overtone0 + 21]->setFromNormalized(0.7156641348584154);
      value[ID::overtone0 + 22]->setFromNormalized(0.6748088991072597);
      value[ID::overtone0 + 23]->setFromNormalized(0.6669503948520917);
      value[ID::overtone0 + 24]->setFromNormalized(0.6527243307811625);
      value[ID::overtone0 + 25]->setFromNormalized(0.652587377705399);
      value[ID::overtone0 + 26]->setFromNormalized(0.6397398142346638);
      value[ID::overtone0 + 27]->setFromNormalized(0.6387629854322983);
      value[ID::overtone0 + 28]->setFromNormalized(0.6217920445334504);
      value[ID::overtone0 + 29]->setFromNormalized(0.6142879971518133);
      value[ID::overtone0 + 30]->setFromNormalized(0.5841988164061835);
      value[ID::overtone0 + 31]->setFromNormalized(0.5824029037511926);
      value[ID::overtone0 + 32]->setFromNormalized(0.572552890809045);
      value[ID::overtone0 + 33]->setFromNormalized(0.5332946100003039);
      value[ID::overtone0 + 34]->setFromNormalized(0.4988303555399778);
      value[ID::overtone0 + 35]->setFromNormalized(0.49228258913982803);
      value[ID::overtone0 + 36]->setFromNormalized(0.4794678196469711);
      value[ID::overtone0 + 37]->setFromNormalized(0.46043467933408094);
      value[ID::overtone0 + 38]->setFromNormalized(0.4521039371982055);
      value[ID::overtone0 + 39]->setFromNormalized(0.45097365507497955);
      value[ID::overtone0 + 40]->setFromNormalized(0.4366853391052764);
      value[ID::overtone0 + 41]->setFromNormalized(0.41105689042485294);
      value[ID::overtone0 + 42]->setFromNormalized(0.3940304625815063);
      value[ID::overtone0 + 43]->setFromNormalized(0.3901644741221693);
      value[ID::overtone0 + 44]->setFromNormalized(0.37583446689374833);
      value[ID::overtone0 + 45]->setFromNormalized(0.36582033576965456);
      value[ID::overtone0 + 46]->setFromNormalized(0.3651336203799868);
      value[ID::overtone0 + 47]->setFromNormalized(0.34690965960134534);
      value[ID::overtone0 + 48]->setFromNormalized(0.2566706358706671);
      value[ID::overtone0 + 49]->setFromNormalized(0.2347552898222851);
      value[ID::overtone0 + 50]->setFromNormalized(0.22883704527234983);
      value[ID::overtone0 + 51]->setFromNormalized(0.21608385107022965);
      value[ID::overtone0 + 52]->setFromNormalized(0.19970518347121935);
      value[ID::overtone0 + 53]->setFromNormalized(0.1892036790675249);
      value[ID::overtone0 + 54]->setFromNormalized(0.17398413176902122);
      value[ID::overtone0 + 55]->setFromNormalized(0.1557659068118685);
      value[ID::overtone0 + 56]->setFromNormalized(0.13899433969057035);
      value[ID::overtone0 + 57]->setFromNormalized(0.1121979474505526);
      value[ID::overtone0 + 58]->setFromNormalized(0.07903738364756503);
      value[ID::overtone0 + 59]->setFromNormalized(0.07750425973044912);
      value[ID::overtone0 + 60]->setFromNormalized(0.03475794306121767);
      value[ID::overtone0 + 61]->setFromNormalized(0.022763502295125092);
      value[ID::overtone0 + 62]->setFromNormalized(0.0036972072912913488);
      value[ID::overtone0 + 63]->setFromNormalized(0.0034052791160620543);
      value[ID::saturation0 + 0]->setFromNormalized(0.9489051368170157);
      value[ID::saturation0 + 1]->setFromNormalized(0.9342045016917735);
      value[ID::saturation0 + 2]->setFromNormalized(0.9307676428416922);
      value[ID::saturation0 + 3]->setFromNormalized(0.9086523599500853);
      value[ID::saturation0 + 4]->setFromNormalized(0.9073530859028128);
      value[ID::saturation0 + 5]->setFromNormalized(0.8768175038630138);
      value[ID::saturation0 + 6]->setFromNormalized(0.867818863457825);
      value[ID::saturation0 + 7]->setFromNormalized(0.8633916964030289);
      value[ID::saturation0 + 8]->setFromNormalized(0.8603800592984557);
      value[ID::saturation0 + 9]->setFromNormalized(0.8270824702175604);
      value[ID::saturation0 + 10]->setFromNormalized(0.8270360920503945);
      value[ID::saturation0 + 11]->setFromNormalized(0.8215069413871223);
      value[ID::saturation0 + 12]->setFromNormalized(0.8112917928390381);
      value[ID::saturation0 + 13]->setFromNormalized(0.8071353822702325);
      value[ID::saturation0 + 14]->setFromNormalized(0.7661879354084566);
      value[ID::saturation0 + 15]->setFromNormalized(0.7646695429156668);
      value[ID::saturation0 + 16]->setFromNormalized(0.7556488126673014);
      value[ID::saturation0 + 17]->setFromNormalized(0.7547912215268264);
      value[ID::saturation0 + 18]->setFromNormalized(0.7293283855247719);
      value[ID::saturation0 + 19]->setFromNormalized(0.7217413781097263);
      value[ID::saturation0 + 20]->setFromNormalized(0.7120967493763077);
      value[ID::saturation0 + 21]->setFromNormalized(0.7111342830824088);
      value[ID::saturation0 + 22]->setFromNormalized(0.6799360990946519);
      value[ID::saturation0 + 23]->setFromNormalized(0.6635981472327813);
      value[ID::saturation0 + 24]->setFromNormalized(0.6552131013455857);
      value[ID::saturation0 + 25]->setFromNormalized(0.6158783382365572);
      value[ID::saturation0 + 26]->setFromNormalized(0.5939095680145895);
      value[ID::saturation0 + 27]->setFromNormalized(0.5840263013886947);
      value[ID::saturation0 + 28]->setFromNormalized(0.5535858762578205);
      value[ID::saturation0 + 29]->setFromNormalized(0.5296405880963404);
      value[ID::saturation0 + 30]->setFromNormalized(0.5269040054051519);
      value[ID::saturation0 + 31]->setFromNormalized(0.5119403380265609);
      value[ID::saturation0 + 32]->setFromNormalized(0.4698803614213569);
      value[ID::saturation0 + 33]->setFromNormalized(0.46987095314789035);
      value[ID::saturation0 + 34]->setFromNormalized(0.4568898052790785);
      value[ID::saturation0 + 35]->setFromNormalized(0.439463693093639);
      value[ID::saturation0 + 36]->setFromNormalized(0.4113334619924451);
      value[ID::saturation0 + 37]->setFromNormalized(0.40180086697255185);
      value[ID::saturation0 + 38]->setFromNormalized(0.38374853778809304);
      value[ID::saturation0 + 39]->setFromNormalized(0.37513575615868444);
      value[ID::saturation0 + 40]->setFromNormalized(0.36565781791370294);
      value[ID::saturation0 + 41]->setFromNormalized(0.34832142863993565);
      value[ID::saturation0 + 42]->setFromNormalized(0.3042979943869044);
      value[ID::saturation0 + 43]->setFromNormalized(0.29604588000390214);
      value[ID::saturation0 + 44]->setFromNormalized(0.2910195984401235);
      value[ID::saturation0 + 45]->setFromNormalized(0.26230100949283947);
      value[ID::saturation0 + 46]->setFromNormalized(0.2594382949962299);
      value[ID::saturation0 + 47]->setFromNormalized(0.25482496584802744);
      value[ID::saturation0 + 48]->setFromNormalized(0.2543245904037509);
      value[ID::saturation0 + 49]->setFromNormalized(0.23851115625926914);
      value[ID::saturation0 + 50]->setFromNormalized(0.23649887462714703);
      value[ID::saturation0 + 51]->setFromNormalized(0.22596982162399548);
      value[ID::saturation0 + 52]->setFromNormalized(0.20789328209113236);
      value[ID::saturation0 + 53]->setFromNormalized(0.1786732546372822);
      value[ID::saturation0 + 54]->setFromNormalized(0.1592256307306444);
      value[ID::saturation0 + 55]->setFromNormalized(0.15119019876809003);
      value[ID::saturation0 + 56]->setFromNormalized(0.13643011362209706);
      value[ID::saturation0 + 57]->setFromNormalized(0.12438206568981722);
      value[ID::saturation0 + 58]->setFromNormalized(0.12223344024105097);
      value[ID::saturation0 + 59]->setFromNormalized(0.09939746695878988);
      value[ID::saturation0 + 60]->setFromNormalized(0.09631516257774071);
      value[ID::saturation0 + 61]->setFromNormalized(0.09378680529926717);
      value[ID::saturation0 + 62]->setFromNormalized(0.06139818177839182);
      value[ID::saturation0 + 63]->setFromNormalized(0.03078290886609603);
      value[ID::gain]->setFromNormalized(0.2720000743865967);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.49599993228912354);
      value[ID::phaserFrequency]->setFromNormalized(0.27199995517730713);
      value[ID::phaserFeedback]->setFromNormalized(0.01600000075995922);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetPluck: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.0);
      value[ID::attack0 + 6]->setFromNormalized(0.0);
      value[ID::attack0 + 7]->setFromNormalized(0.0);
      value[ID::attack0 + 8]->setFromNormalized(0.0);
      value[ID::attack0 + 9]->setFromNormalized(0.0);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.0);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.007629939488002278);
      value[ID::attack0 + 14]->setFromNormalized(0.043668910435267876);
      value[ID::attack0 + 15]->setFromNormalized(0.07970788138253347);
      value[ID::attack0 + 16]->setFromNormalized(0.11574690682547427);
      value[ID::attack0 + 17]->setFromNormalized(0.15178587777273997);
      value[ID::attack0 + 18]->setFromNormalized(0.18782484872000557);
      value[ID::attack0 + 19]->setFromNormalized(0.22386381966727117);
      value[ID::attack0 + 20]->setFromNormalized(0.2599027906145368);
      value[ID::attack0 + 21]->setFromNormalized(0.2959417615618024);
      value[ID::attack0 + 22]->setFromNormalized(0.3319807325090681);
      value[ID::attack0 + 23]->setFromNormalized(0.3642857142857143);
      value[ID::attack0 + 24]->setFromNormalized(0.3731685093470982);
      value[ID::attack0 + 25]->setFromNormalized(0.3909340994698661);
      value[ID::attack0 + 26]->setFromNormalized(0.4086996895926339);
      value[ID::attack0 + 27]->setFromNormalized(0.4264652797154018);
      value[ID::attack0 + 28]->setFromNormalized(0.4442308698381696);
      value[ID::attack0 + 29]->setFromNormalized(0.4619964599609375);
      value[ID::attack0 + 30]->setFromNormalized(0.4797620500837053);
      value[ID::attack0 + 31]->setFromNormalized(0.4975276402064732);
      value[ID::attack0 + 32]->setFromNormalized(0.515293230329241);
      value[ID::attack0 + 33]->setFromNormalized(0.5330588204520089);
      value[ID::attack0 + 34]->setFromNormalized(0.5508244105747768);
      value[ID::attack0 + 35]->setFromNormalized(0.5685899734497071);
      value[ID::attack0 + 36]->setFromNormalized(0.5863555363246373);
      value[ID::attack0 + 37]->setFromNormalized(0.6041210991995676);
      value[ID::attack0 + 38]->setFromNormalized(0.6218866620744978);
      value[ID::attack0 + 39]->setFromNormalized(0.6396522249494281);
      value[ID::attack0 + 40]->setFromNormalized(0.6574177878243583);
      value[ID::attack0 + 41]->setFromNormalized(0.6751833506992886);
      value[ID::attack0 + 42]->setFromNormalized(0.6929489135742187);
      value[ID::attack0 + 43]->setFromNormalized(0.710714476449149);
      value[ID::attack0 + 44]->setFromNormalized(0.7284800393240792);
      value[ID::attack0 + 45]->setFromNormalized(0.7462456021990095);
      value[ID::attack0 + 46]->setFromNormalized(0.7640111650739397);
      value[ID::attack0 + 47]->setFromNormalized(0.7817767143249512);
      value[ID::attack0 + 48]->setFromNormalized(0.7995422771998815);
      value[ID::attack0 + 49]->setFromNormalized(0.8173078400748117);
      value[ID::attack0 + 50]->setFromNormalized(0.835073402949742);
      value[ID::attack0 + 51]->setFromNormalized(0.8528389658246721);
      value[ID::attack0 + 52]->setFromNormalized(0.8706045286996024);
      value[ID::attack0 + 53]->setFromNormalized(0.8883700915745326);
      value[ID::attack0 + 54]->setFromNormalized(0.9061356612614223);
      value[ID::attack0 + 55]->setFromNormalized(0.9239012309483119);
      value[ID::attack0 + 56]->setFromNormalized(0.9416668006352016);
      value[ID::attack0 + 57]->setFromNormalized(0.959432373728071);
      value[ID::attack0 + 58]->setFromNormalized(0.9771979434149606);
      value[ID::attack0 + 59]->setFromNormalized(0.9949635105473654);
      value[ID::attack0 + 60]->setFromNormalized(1.0);
      value[ID::attack0 + 61]->setFromNormalized(1.0);
      value[ID::attack0 + 62]->setFromNormalized(1.0);
      value[ID::attack0 + 63]->setFromNormalized(1.0);
      value[ID::decay0 + 0]->setFromNormalized(1.0);
      value[ID::decay0 + 1]->setFromNormalized(0.9285714285714285);
      value[ID::decay0 + 2]->setFromNormalized(0.8928571428571428);
      value[ID::decay0 + 3]->setFromNormalized(0.807142857142857);
      value[ID::decay0 + 4]->setFromNormalized(0.7571428571428571);
      value[ID::decay0 + 5]->setFromNormalized(0.6714285714285714);
      value[ID::decay0 + 6]->setFromNormalized(0.657142857142857);
      value[ID::decay0 + 7]->setFromNormalized(0.5785714285714285);
      value[ID::decay0 + 8]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 9]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 10]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 11]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 12]->setFromNormalized(0.37142857142857144);
      value[ID::decay0 + 13]->setFromNormalized(0.33571428571428563);
      value[ID::decay0 + 14]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 15]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 16]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 17]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 18]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 19]->setFromNormalized(0.2928571428571428);
      value[ID::decay0 + 20]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 21]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 22]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 23]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 24]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 25]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 26]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 27]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 28]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 29]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 30]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 31]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 32]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 33]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 34]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 35]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 36]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 37]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 38]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 39]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 40]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 41]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 42]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 43]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 44]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 45]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 46]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 47]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 48]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 49]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 50]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 51]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 52]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 53]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 54]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 55]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 56]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 57]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 58]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 59]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 60]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 61]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 62]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 63]->setFromNormalized(0.19999999999999996);
      value[ID::overtone0 + 0]->setFromNormalized(0.284462174030539);
      value[ID::overtone0 + 1]->setFromNormalized(0.2926684985697037);
      value[ID::overtone0 + 2]->setFromNormalized(0.30119762445929377);
      value[ID::overtone0 + 3]->setFromNormalized(0.3100760285315647);
      value[ID::overtone0 + 4]->setFromNormalized(0.3193335900372216);
      value[ID::overtone0 + 5]->setFromNormalized(0.3290042007530527);
      value[ID::overtone0 + 6]->setFromNormalized(0.3391265185180341);
      value[ID::overtone0 + 7]->setFromNormalized(0.349744906736543);
      value[ID::overtone0 + 8]->setFromNormalized(0.36091061790282497);
      value[ID::overtone0 + 9]->setFromNormalized(0.3726833015540114);
      value[ID::overtone0 + 10]->setFromNormalized(0.3851329498456373);
      value[ID::overtone0 + 11]->setFromNormalized(0.39435765283922475);
      value[ID::overtone0 + 12]->setFromNormalized(0.4021040077704613);
      value[ID::overtone0 + 13]->setFromNormalized(0.41366478680116725);
      value[ID::overtone0 + 14]->setFromNormalized(0.4336700486460786);
      value[ID::overtone0 + 15]->setFromNormalized(0.45779436101438453);
      value[ID::overtone0 + 16]->setFromNormalized(0.4790326728117574);
      value[ID::overtone0 + 17]->setFromNormalized(0.5006371393640316);
      value[ID::overtone0 + 18]->setFromNormalized(0.5239902970494659);
      value[ID::overtone0 + 19]->setFromNormalized(0.5499654278487884);
      value[ID::overtone0 + 20]->setFromNormalized(0.5794469275499461);
      value[ID::overtone0 + 21]->setFromNormalized(0.6136287667300382);
      value[ID::overtone0 + 22]->setFromNormalized(0.6543712562993491);
      value[ID::overtone0 + 23]->setFromNormalized(0.7049268777585121);
      value[ID::overtone0 + 24]->setFromNormalized(0.7719504175222301);
      value[ID::overtone0 + 25]->setFromNormalized(0.8738118065634131);
      value[ID::overtone0 + 26]->setFromNormalized(0.6246039355211377);
      value[ID::overtone0 + 27]->setFromNormalized(0.06574657942708857);
      value[ID::overtone0 + 28]->setFromNormalized(0.08996015331705678);
      value[ID::overtone0 + 29]->setFromNormalized(0.10036646368751541);
      value[ID::overtone0 + 30]->setFromNormalized(0.10620864033010342);
      value[ID::overtone0 + 31]->setFromNormalized(0.11056900310573639);
      value[ID::overtone0 + 32]->setFromNormalized(0.11447633350106515);
      value[ID::overtone0 + 33]->setFromNormalized(0.11827496962778365);
      value[ID::overtone0 + 34]->setFromNormalized(0.12208117609614569);
      value[ID::overtone0 + 35]->setFromNormalized(0.12593527261530787);
      value[ID::overtone0 + 36]->setFromNormalized(0.12985234931890055);
      value[ID::overtone0 + 37]->setFromNormalized(0.1338391782023404);
      value[ID::overtone0 + 38]->setFromNormalized(0.1378998571948488);
      value[ID::overtone0 + 39]->setFromNormalized(0.14203769910949368);
      value[ID::overtone0 + 40]->setFromNormalized(0.14625586963083864);
      value[ID::overtone0 + 41]->setFromNormalized(0.15055760914952412);
      value[ID::overtone0 + 42]->setFromNormalized(0.1549463168158244);
      value[ID::overtone0 + 43]->setFromNormalized(0.15942558972005738);
      value[ID::overtone0 + 44]->setFromNormalized(0.1639992483038039);
      value[ID::overtone0 + 45]->setFromNormalized(0.168671358525115);
      value[ID::overtone0 + 46]->setFromNormalized(0.17344625446478315);
      value[ID::overtone0 + 47]->setFromNormalized(0.178328562810632);
      value[ID::overtone0 + 48]->setFromNormalized(0.1833232299406294);
      value[ID::overtone0 + 49]->setFromNormalized(0.18843555212727042);
      value[ID::overtone0 + 50]->setFromNormalized(0.19367120936780716);
      value[ID::overtone0 + 51]->setFromNormalized(0.19903630339685882);
      value[ID::overtone0 + 52]->setFromNormalized(0.20453740052506797);
      value[ID::overtone0 + 53]->setFromNormalized(0.21018158006105514);
      value[ID::overtone0 + 54]->setFromNormalized(0.2159764892146379);
      value[ID::overtone0 + 55]->setFromNormalized(0.22193040555195198);
      value[ID::overtone0 + 56]->setFromNormalized(0.22805230828522882);
      value[ID::overtone0 + 57]->setFromNormalized(0.23435195994171903);
      value[ID::overtone0 + 58]->setFromNormalized(0.24084000028094055);
      value[ID::overtone0 + 59]->setFromNormalized(0.2475280547346169);
      value[ID::overtone0 + 60]->setFromNormalized(0.2544288601525496);
      value[ID::overtone0 + 61]->setFromNormalized(0.26155641128108);
      value[ID::overtone0 + 62]->setFromNormalized(0.26892613222016415);
      value[ID::overtone0 + 63]->setFromNormalized(0.27655507815652003);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.75199955701828);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.3400000035762787);
      value[ID::randomFrequency]->setFromNormalized(0.14799997210502627);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetPong: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.7571428571428571);
      value[ID::attack0 + 1]->setFromNormalized(0.65);
      value[ID::attack0 + 2]->setFromNormalized(0.5285714285714286);
      value[ID::attack0 + 3]->setFromNormalized(0.5);
      value[ID::attack0 + 4]->setFromNormalized(0.3642857142857143);
      value[ID::attack0 + 5]->setFromNormalized(0.2928571428571428);
      value[ID::attack0 + 6]->setFromNormalized(0.24999999999999997);
      value[ID::attack0 + 7]->setFromNormalized(0.20714285714285716);
      value[ID::attack0 + 8]->setFromNormalized(0.19999999999999993);
      value[ID::attack0 + 9]->setFromNormalized(0.17142857142857135);
      value[ID::attack0 + 10]->setFromNormalized(0.15);
      value[ID::attack0 + 11]->setFromNormalized(0.12857142857142856);
      value[ID::attack0 + 12]->setFromNormalized(0.11428571428571431);
      value[ID::attack0 + 13]->setFromNormalized(0.11428571428571431);
      value[ID::attack0 + 14]->setFromNormalized(0.11428571428571431);
      value[ID::attack0 + 15]->setFromNormalized(0.11428571428571431);
      value[ID::attack0 + 16]->setFromNormalized(0.37142857142857144);
      value[ID::attack0 + 17]->setFromNormalized(0.37142857142857144);
      value[ID::attack0 + 18]->setFromNormalized(0.37142857142857144);
      value[ID::attack0 + 19]->setFromNormalized(0.37142857142857144);
      value[ID::attack0 + 20]->setFromNormalized(0.37142857142857144);
      value[ID::attack0 + 21]->setFromNormalized(0.33571428571428574);
      value[ID::attack0 + 22]->setFromNormalized(0.34285714285714286);
      value[ID::attack0 + 23]->setFromNormalized(0.34285714285714286);
      value[ID::attack0 + 24]->setFromNormalized(0.3571428571428571);
      value[ID::attack0 + 25]->setFromNormalized(0.37857142857142856);
      value[ID::attack0 + 26]->setFromNormalized(0.4);
      value[ID::attack0 + 27]->setFromNormalized(0.37142857142857144);
      value[ID::attack0 + 28]->setFromNormalized(0.44285714285714284);
      value[ID::attack0 + 29]->setFromNormalized(0.4642857142857143);
      value[ID::attack0 + 30]->setFromNormalized(0.5071428571428571);
      value[ID::attack0 + 31]->setFromNormalized(0.5357142857142857);
      value[ID::attack0 + 32]->setFromNormalized(0.5357142857142857);
      value[ID::attack0 + 33]->setFromNormalized(0.55);
      value[ID::attack0 + 34]->setFromNormalized(0.55);
      value[ID::attack0 + 35]->setFromNormalized(0.5642857142857143);
      value[ID::attack0 + 36]->setFromNormalized(0.5642857142857143);
      value[ID::attack0 + 37]->setFromNormalized(0.5142857142857142);
      value[ID::attack0 + 38]->setFromNormalized(0.4642857142857143);
      value[ID::attack0 + 39]->setFromNormalized(0.3285714285714286);
      value[ID::attack0 + 40]->setFromNormalized(0.17857142857142858);
      value[ID::attack0 + 41]->setFromNormalized(0.26428571428571423);
      value[ID::attack0 + 42]->setFromNormalized(0.21428571428571427);
      value[ID::attack0 + 43]->setFromNormalized(0.21428571428571427);
      value[ID::attack0 + 44]->setFromNormalized(0.19999999999999993);
      value[ID::attack0 + 45]->setFromNormalized(0.19999999999999993);
      value[ID::attack0 + 46]->setFromNormalized(0.19999999999999993);
      value[ID::attack0 + 47]->setFromNormalized(0.19999999999999993);
      value[ID::attack0 + 48]->setFromNormalized(0.19999999999999993);
      value[ID::attack0 + 49]->setFromNormalized(0.20714285714285716);
      value[ID::attack0 + 50]->setFromNormalized(0.2571428571428571);
      value[ID::attack0 + 51]->setFromNormalized(0.30714285714285716);
      value[ID::attack0 + 52]->setFromNormalized(0.35);
      value[ID::attack0 + 53]->setFromNormalized(0.4);
      value[ID::attack0 + 54]->setFromNormalized(0.40714285714285714);
      value[ID::attack0 + 55]->setFromNormalized(0.40714285714285714);
      value[ID::attack0 + 56]->setFromNormalized(0.40714285714285714);
      value[ID::attack0 + 57]->setFromNormalized(0.40714285714285714);
      value[ID::attack0 + 58]->setFromNormalized(0.40714285714285714);
      value[ID::attack0 + 59]->setFromNormalized(0.40714285714285714);
      value[ID::attack0 + 60]->setFromNormalized(0.40714285714285714);
      value[ID::attack0 + 61]->setFromNormalized(0.3857142857142857);
      value[ID::attack0 + 62]->setFromNormalized(0.37142857142857144);
      value[ID::attack0 + 63]->setFromNormalized(0.30000000000000004);
      value[ID::decay0 + 0]->setFromNormalized(0.38129910313970466);
      value[ID::decay0 + 1]->setFromNormalized(0.32335598787780406);
      value[ID::decay0 + 2]->setFromNormalized(0.44428227229095146);
      value[ID::decay0 + 3]->setFromNormalized(0.6017358757279558);
      value[ID::decay0 + 4]->setFromNormalized(0.5318088736302412);
      value[ID::decay0 + 5]->setFromNormalized(0.4888847329163341);
      value[ID::decay0 + 6]->setFromNormalized(0.5696052217845035);
      value[ID::decay0 + 7]->setFromNormalized(0.45445586096264673);
      value[ID::decay0 + 8]->setFromNormalized(0.30714285714285716);
      value[ID::decay0 + 9]->setFromNormalized(0.2785714285714286);
      value[ID::decay0 + 10]->setFromNormalized(0.5071428571428571);
      value[ID::decay0 + 11]->setFromNormalized(0.8752705338367025);
      value[ID::decay0 + 12]->setFromNormalized(0.636438893054913);
      value[ID::decay0 + 13]->setFromNormalized(0.4355492537379987);
      value[ID::decay0 + 14]->setFromNormalized(0.6838137314399076);
      value[ID::decay0 + 15]->setFromNormalized(0.7526615023654075);
      value[ID::decay0 + 16]->setFromNormalized(0.5173538036488342);
      value[ID::decay0 + 17]->setFromNormalized(0.39074614760826826);
      value[ID::decay0 + 18]->setFromNormalized(0.45773150015649905);
      value[ID::decay0 + 19]->setFromNormalized(0.5243440823471719);
      value[ID::decay0 + 20]->setFromNormalized(0.6887569945993519);
      value[ID::decay0 + 21]->setFromNormalized(0.5961483913193674);
      value[ID::decay0 + 22]->setFromNormalized(0.43911567712759386);
      value[ID::decay0 + 23]->setFromNormalized(0.6371191782063789);
      value[ID::decay0 + 24]->setFromNormalized(0.8121704093795392);
      value[ID::decay0 + 25]->setFromNormalized(0.7452598469315883);
      value[ID::decay0 + 26]->setFromNormalized(0.5848104989680328);
      value[ID::decay0 + 27]->setFromNormalized(0.5110468850868305);
      value[ID::decay0 + 28]->setFromNormalized(0.4344737229295774);
      value[ID::decay0 + 29]->setFromNormalized(0.5343639306126721);
      value[ID::decay0 + 30]->setFromNormalized(0.7118538792935929);
      value[ID::decay0 + 31]->setFromNormalized(0.6067643115249853);
      value[ID::decay0 + 32]->setFromNormalized(0.40114615574584644);
      value[ID::decay0 + 33]->setFromNormalized(0.5764520880802352);
      value[ID::decay0 + 34]->setFromNormalized(0.5613136631970397);
      value[ID::decay0 + 35]->setFromNormalized(0.1990783466473844);
      value[ID::decay0 + 36]->setFromNormalized(0.0);
      value[ID::decay0 + 37]->setFromNormalized(0.23391817536337897);
      value[ID::decay0 + 38]->setFromNormalized(0.4314793199489956);
      value[ID::decay0 + 39]->setFromNormalized(0.47777740517277595);
      value[ID::decay0 + 40]->setFromNormalized(0.6776791363309277);
      value[ID::decay0 + 41]->setFromNormalized(0.8963635043074295);
      value[ID::decay0 + 42]->setFromNormalized(0.9999999999999999);
      value[ID::decay0 + 43]->setFromNormalized(0.7053253096537995);
      value[ID::decay0 + 44]->setFromNormalized(0.5765415685022169);
      value[ID::decay0 + 45]->setFromNormalized(0.4903346318677517);
      value[ID::decay0 + 46]->setFromNormalized(0.18959605934581525);
      value[ID::decay0 + 47]->setFromNormalized(0.11320079552157122);
      value[ID::decay0 + 48]->setFromNormalized(0.2890237595385452);
      value[ID::decay0 + 49]->setFromNormalized(0.43388139139664345);
      value[ID::decay0 + 50]->setFromNormalized(0.626526971532585);
      value[ID::decay0 + 51]->setFromNormalized(0.7908313491968335);
      value[ID::decay0 + 52]->setFromNormalized(0.5774223033699691);
      value[ID::decay0 + 53]->setFromNormalized(0.3275287958670097);
      value[ID::decay0 + 54]->setFromNormalized(0.3167100393954493);
      value[ID::decay0 + 55]->setFromNormalized(0.6117904059206577);
      value[ID::decay0 + 56]->setFromNormalized(0.573297905923464);
      value[ID::decay0 + 57]->setFromNormalized(0.4716275148037816);
      value[ID::decay0 + 58]->setFromNormalized(0.5065102049787836);
      value[ID::decay0 + 59]->setFromNormalized(0.4867652179063916);
      value[ID::decay0 + 60]->setFromNormalized(0.5150831458342613);
      value[ID::decay0 + 61]->setFromNormalized(0.6885933875496657);
      value[ID::decay0 + 62]->setFromNormalized(0.9387659130545137);
      value[ID::decay0 + 63]->setFromNormalized(0.5807422734296797);
      value[ID::overtone0 + 0]->setFromNormalized(0.33571428571428574);
      value[ID::overtone0 + 1]->setFromNormalized(0.37142857142857144);
      value[ID::overtone0 + 2]->setFromNormalized(0.4428571428571429);
      value[ID::overtone0 + 3]->setFromNormalized(0.5642857142857143);
      value[ID::overtone0 + 4]->setFromNormalized(0.7571428571428571);
      value[ID::overtone0 + 5]->setFromNormalized(0.8785714285714284);
      value[ID::overtone0 + 6]->setFromNormalized(0.9357142857142857);
      value[ID::overtone0 + 7]->setFromNormalized(0.8448727497195556);
      value[ID::overtone0 + 8]->setFromNormalized(0.6861808642393175);
      value[ID::overtone0 + 9]->setFromNormalized(0.5561124230821538);
      value[ID::overtone0 + 10]->setFromNormalized(0.4804911542466316);
      value[ID::overtone0 + 11]->setFromNormalized(0.35991492515696877);
      value[ID::overtone0 + 12]->setFromNormalized(0.28285162306607015);
      value[ID::overtone0 + 13]->setFromNormalized(0.3083864663029249);
      value[ID::overtone0 + 14]->setFromNormalized(0.3305439265273312);
      value[ID::overtone0 + 15]->setFromNormalized(0.17857142857142866);
      value[ID::overtone0 + 16]->setFromNormalized(0.17803949628557483);
      value[ID::overtone0 + 17]->setFromNormalized(0.17697568620954235);
      value[ID::overtone0 + 18]->setFromNormalized(0.17591187613351006);
      value[ID::overtone0 + 19]->setFromNormalized(0.17484806605747777);
      value[ID::overtone0 + 20]->setFromNormalized(0.1737842559814453);
      value[ID::overtone0 + 21]->setFromNormalized(0.17272044590541286);
      value[ID::overtone0 + 22]->setFromNormalized(0.17165663582938057);
      value[ID::overtone0 + 23]->setFromNormalized(0.17059282575334828);
      value[ID::overtone0 + 24]->setFromNormalized(0.1695290156773158);
      value[ID::overtone0 + 25]->setFromNormalized(0.16846520560128334);
      value[ID::overtone0 + 26]->setFromNormalized(0.1674013955252512);
      value[ID::overtone0 + 27]->setFromNormalized(0.16633758544921876);
      value[ID::overtone0 + 28]->setFromNormalized(0.16527377537318647);
      value[ID::overtone0 + 29]->setFromNormalized(0.16420996529715398);
      value[ID::overtone0 + 30]->setFromNormalized(0.1631461552211217);
      value[ID::overtone0 + 31]->setFromNormalized(0.16208234514508923);
      value[ID::overtone0 + 32]->setFromNormalized(0.16101853506905695);
      value[ID::overtone0 + 33]->setFromNormalized(0.1599547249930245);
      value[ID::overtone0 + 34]->setFromNormalized(0.1588909149169922);
      value[ID::overtone0 + 35]->setFromNormalized(0.1578271048409599);
      value[ID::overtone0 + 36]->setFromNormalized(0.15676329476492726);
      value[ID::overtone0 + 37]->setFromNormalized(0.15569948468889513);
      value[ID::overtone0 + 38]->setFromNormalized(0.15463567461286268);
      value[ID::overtone0 + 39]->setFromNormalized(0.1535718645368304);
      value[ID::overtone0 + 40]->setFromNormalized(0.1525080544607979);
      value[ID::overtone0 + 41]->setFromNormalized(0.15144424438476561);
      value[ID::overtone0 + 42]->setFromNormalized(0.15038043430873332);
      value[ID::overtone0 + 43]->setFromNormalized(0.14931662423270087);
      value[ID::overtone0 + 44]->setFromNormalized(0.14825281415666858);
      value[ID::overtone0 + 45]->setFromNormalized(0.14718900408063612);
      value[ID::overtone0 + 46]->setFromNormalized(0.14612519400460383);
      value[ID::overtone0 + 47]->setFromNormalized(0.14506138392857118);
      value[ID::overtone0 + 48]->setFromNormalized(0.14399757385253906);
      value[ID::overtone0 + 49]->setFromNormalized(0.1429337637765066);
      value[ID::overtone0 + 50]->setFromNormalized(0.1418699537004743);
      value[ID::overtone0 + 51]->setFromNormalized(0.14080614362444202);
      value[ID::overtone0 + 52]->setFromNormalized(0.13974233354840954);
      value[ID::overtone0 + 53]->setFromNormalized(0.13867852347237725);
      value[ID::overtone0 + 54]->setFromNormalized(0.13761471339634496);
      value[ID::overtone0 + 55]->setFromNormalized(0.1365509033203125);
      value[ID::overtone0 + 56]->setFromNormalized(0.13548709324428004);
      value[ID::overtone0 + 57]->setFromNormalized(0.13442328316824775);
      value[ID::overtone0 + 58]->setFromNormalized(0.13335947309221546);
      value[ID::overtone0 + 59]->setFromNormalized(0.13229566301618298);
      value[ID::overtone0 + 60]->setFromNormalized(0.13123185294015052);
      value[ID::overtone0 + 61]->setFromNormalized(0.1301680428641184);
      value[ID::overtone0 + 62]->setFromNormalized(0.12910423278808594);
      value[ID::overtone0 + 63]->setFromNormalized(0.12857142857142848);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.2928571428571428);
      value[ID::saturation0 + 16]->setFromNormalized(0.2998480115618024);
      value[ID::saturation0 + 17]->setFromNormalized(0.3138297489711217);
      value[ID::saturation0 + 18]->setFromNormalized(0.32781148638044083);
      value[ID::saturation0 + 19]->setFromNormalized(0.34179322378976);
      value[ID::saturation0 + 20]->setFromNormalized(0.35577496119907925);
      value[ID::saturation0 + 21]->setFromNormalized(0.36975669860839844);
      value[ID::saturation0 + 22]->setFromNormalized(0.38373843601771757);
      value[ID::saturation0 + 23]->setFromNormalized(0.39772017342703675);
      value[ID::saturation0 + 24]->setFromNormalized(0.41170191083635593);
      value[ID::saturation0 + 25]->setFromNormalized(0.4256836482456752);
      value[ID::saturation0 + 26]->setFromNormalized(0.43966538565499447);
      value[ID::saturation0 + 27]->setFromNormalized(0.45364712306431365);
      value[ID::saturation0 + 28]->setFromNormalized(0.46762886047363283);
      value[ID::saturation0 + 29]->setFromNormalized(0.48161059788295196);
      value[ID::saturation0 + 30]->setFromNormalized(0.49559233529227115);
      value[ID::saturation0 + 31]->setFromNormalized(0.5095740727015904);
      value[ID::saturation0 + 32]->setFromNormalized(0.5235558101109097);
      value[ID::saturation0 + 33]->setFromNormalized(0.5375375475202289);
      value[ID::saturation0 + 34]->setFromNormalized(0.5515193121773856);
      value[ID::saturation0 + 35]->setFromNormalized(0.5655010768345424);
      value[ID::saturation0 + 36]->setFromNormalized(0.5794828414916993);
      value[ID::saturation0 + 37]->setFromNormalized(0.593464606148856);
      value[ID::saturation0 + 38]->setFromNormalized(0.6074463708060128);
      value[ID::saturation0 + 39]->setFromNormalized(0.6214281354631697);
      value[ID::saturation0 + 40]->setFromNormalized(0.6354099001203263);
      value[ID::saturation0 + 41]->setFromNormalized(0.6493916647774833);
      value[ID::saturation0 + 42]->setFromNormalized(0.6633734294346401);
      value[ID::saturation0 + 43]->setFromNormalized(0.6773551940917969);
      value[ID::saturation0 + 44]->setFromNormalized(0.6913369587489537);
      value[ID::saturation0 + 45]->setFromNormalized(0.7053187234061105);
      value[ID::saturation0 + 46]->setFromNormalized(0.7193004880632673);
      value[ID::saturation0 + 47]->setFromNormalized(0.7332822527204241);
      value[ID::saturation0 + 48]->setFromNormalized(0.7472640173775809);
      value[ID::saturation0 + 49]->setFromNormalized(0.7612457820347377);
      value[ID::saturation0 + 50]->setFromNormalized(0.7752275603158133);
      value[ID::saturation0 + 51]->setFromNormalized(0.7892093249729701);
      value[ID::saturation0 + 52]->setFromNormalized(0.803191089630127);
      value[ID::saturation0 + 53]->setFromNormalized(0.8171728542872838);
      value[ID::saturation0 + 54]->setFromNormalized(0.8311546189444405);
      value[ID::saturation0 + 55]->setFromNormalized(0.8451363836015974);
      value[ID::saturation0 + 56]->setFromNormalized(0.8591181482587542);
      value[ID::saturation0 + 57]->setFromNormalized(0.8730999129159109);
      value[ID::saturation0 + 58]->setFromNormalized(0.8870816775730677);
      value[ID::saturation0 + 59]->setFromNormalized(0.9010634422302246);
      value[ID::saturation0 + 60]->setFromNormalized(0.9150452068873814);
      value[ID::saturation0 + 61]->setFromNormalized(0.9290269715445382);
      value[ID::saturation0 + 62]->setFromNormalized(0.9430087362016949);
      value[ID::saturation0 + 63]->setFromNormalized(0.95);
      value[ID::gain]->setFromNormalized(0.8000001907348633);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.0);
      value[ID::pitchMultiply]->setFromNormalized(0.20381253957748413);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(8120178);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.20799989998340607);
      value[ID::randomFrequency]->setFromNormalized(0.6200003027915955);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.5839999914169312);
      value[ID::randomSaturation]->setFromNormalized(0.9120000600814819);
      value[ID::randomPhase]->setFromNormalized(0.8160001039505005);
      value[ID::overtoneExpand]->setFromNormalized(0.4000000059604645);
      value[ID::overtoneShift]->setFromNormalized(0.28000009059906006);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.2239999622106552);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.10244134068489075);
      value[ID::saturationMix]->setFromNormalized(0.2680000066757202);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetRandom: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.43932233001344645);
      value[ID::attack0 + 1]->setFromNormalized(0.11113113498139836);
      value[ID::attack0 + 2]->setFromNormalized(0.16435566543081512);
      value[ID::attack0 + 3]->setFromNormalized(0.3310890238235371);
      value[ID::attack0 + 4]->setFromNormalized(0.6362617581184767);
      value[ID::attack0 + 5]->setFromNormalized(0.7332577130595566);
      value[ID::attack0 + 6]->setFromNormalized(0.3933198968925333);
      value[ID::attack0 + 7]->setFromNormalized(0.41193017296073564);
      value[ID::attack0 + 8]->setFromNormalized(0.39798046964146705);
      value[ID::attack0 + 9]->setFromNormalized(0.280790659989984);
      value[ID::attack0 + 10]->setFromNormalized(0.44050098617493405);
      value[ID::attack0 + 11]->setFromNormalized(0.6974157243660386);
      value[ID::attack0 + 12]->setFromNormalized(0.9389821478593285);
      value[ID::attack0 + 13]->setFromNormalized(0.7225787349484276);
      value[ID::attack0 + 14]->setFromNormalized(0.6877833727083178);
      value[ID::attack0 + 15]->setFromNormalized(0.6663410581200133);
      value[ID::attack0 + 16]->setFromNormalized(0.5588187958416564);
      value[ID::attack0 + 17]->setFromNormalized(0.3355526286220477);
      value[ID::attack0 + 18]->setFromNormalized(0.06607704614016362);
      value[ID::attack0 + 19]->setFromNormalized(0.28914092381745626);
      value[ID::attack0 + 20]->setFromNormalized(0.6195361800126077);
      value[ID::attack0 + 21]->setFromNormalized(0.7918431500303846);
      value[ID::attack0 + 22]->setFromNormalized(0.883858379654223);
      value[ID::attack0 + 23]->setFromNormalized(1.0);
      value[ID::attack0 + 24]->setFromNormalized(0.6822416929064926);
      value[ID::attack0 + 25]->setFromNormalized(0.3180943481204481);
      value[ID::attack0 + 26]->setFromNormalized(0.5847451789824009);
      value[ID::attack0 + 27]->setFromNormalized(0.73370331883524);
      value[ID::attack0 + 28]->setFromNormalized(0.5861029294577231);
      value[ID::attack0 + 29]->setFromNormalized(0.36060002485046705);
      value[ID::attack0 + 30]->setFromNormalized(0.19472083072356436);
      value[ID::attack0 + 31]->setFromNormalized(0.38433999926805773);
      value[ID::attack0 + 32]->setFromNormalized(0.7343436529016694);
      value[ID::attack0 + 33]->setFromNormalized(0.6754230953946971);
      value[ID::attack0 + 34]->setFromNormalized(0.2504125443019275);
      value[ID::attack0 + 35]->setFromNormalized(0.0);
      value[ID::attack0 + 36]->setFromNormalized(0.1828087941873324);
      value[ID::attack0 + 37]->setFromNormalized(0.2238256018362422);
      value[ID::attack0 + 38]->setFromNormalized(0.06547090974630897);
      value[ID::attack0 + 39]->setFromNormalized(0.2804524069716009);
      value[ID::attack0 + 40]->setFromNormalized(0.34808289422359917);
      value[ID::attack0 + 41]->setFromNormalized(0.572470590155167);
      value[ID::attack0 + 42]->setFromNormalized(0.5439728011901138);
      value[ID::attack0 + 43]->setFromNormalized(0.22491576522931087);
      value[ID::attack0 + 44]->setFromNormalized(0.37055334698350484);
      value[ID::attack0 + 45]->setFromNormalized(0.5932291848631452);
      value[ID::attack0 + 46]->setFromNormalized(0.37495133284789317);
      value[ID::attack0 + 47]->setFromNormalized(0.07106604531610082);
      value[ID::attack0 + 48]->setFromNormalized(0.33711959425429106);
      value[ID::attack0 + 49]->setFromNormalized(0.6327135949936291);
      value[ID::attack0 + 50]->setFromNormalized(0.3636232852935297);
      value[ID::attack0 + 51]->setFromNormalized(0.08703786167726489);
      value[ID::attack0 + 52]->setFromNormalized(0.35105704838521323);
      value[ID::attack0 + 53]->setFromNormalized(0.723811543446464);
      value[ID::attack0 + 54]->setFromNormalized(0.778170830572703);
      value[ID::attack0 + 55]->setFromNormalized(0.8223358315717899);
      value[ID::attack0 + 56]->setFromNormalized(0.9718055410001364);
      value[ID::attack0 + 57]->setFromNormalized(0.788320749083098);
      value[ID::attack0 + 58]->setFromNormalized(0.37672177974089927);
      value[ID::attack0 + 59]->setFromNormalized(0.10827765617233452);
      value[ID::attack0 + 60]->setFromNormalized(0.2741684815598612);
      value[ID::attack0 + 61]->setFromNormalized(0.5577104795375443);
      value[ID::attack0 + 62]->setFromNormalized(0.5683312855387499);
      value[ID::attack0 + 63]->setFromNormalized(0.7892857921374812);
      value[ID::decay0 + 0]->setFromNormalized(0.5035714285714286);
      value[ID::decay0 + 1]->setFromNormalized(0.9142857142857143);
      value[ID::decay0 + 2]->setFromNormalized(0.41428571428571426);
      value[ID::decay0 + 3]->setFromNormalized(0.775);
      value[ID::decay0 + 4]->setFromNormalized(0.8214285714285714);
      value[ID::decay0 + 5]->setFromNormalized(0.3297619410923549);
      value[ID::decay0 + 6]->setFromNormalized(0.7285714285714286);
      value[ID::decay0 + 7]->setFromNormalized(0.36071428571428577);
      value[ID::decay0 + 8]->setFromNormalized(0.5964285714285714);
      value[ID::decay0 + 9]->setFromNormalized(0.9785714285714285);
      value[ID::decay0 + 10]->setFromNormalized(0.30000000000000004);
      value[ID::decay0 + 11]->setFromNormalized(0.8571428571428572);
      value[ID::decay0 + 12]->setFromNormalized(0.1785714285714286);
      value[ID::decay0 + 13]->setFromNormalized(0.8642857142857143);
      value[ID::decay0 + 14]->setFromNormalized(0.4178571428571428);
      value[ID::decay0 + 15]->setFromNormalized(0.2511904035295759);
      value[ID::decay0 + 16]->setFromNormalized(0.7988095147269113);
      value[ID::decay0 + 17]->setFromNormalized(0.9357142857142857);
      value[ID::decay0 + 18]->setFromNormalized(0.09285714285714287);
      value[ID::decay0 + 19]->setFromNormalized(0.6928571428571428);
      value[ID::decay0 + 20]->setFromNormalized(0.7345238276890347);
      value[ID::decay0 + 21]->setFromNormalized(0.7023809705461774);
      value[ID::decay0 + 22]->setFromNormalized(0.4642857142857143);
      value[ID::decay0 + 23]->setFromNormalized(0.1785714285714286);
      value[ID::decay0 + 24]->setFromNormalized(0.22976183210100445);
      value[ID::decay0 + 25]->setFromNormalized(0.5142857142857142);
      value[ID::decay0 + 26]->setFromNormalized(0.7428571428571429);
      value[ID::decay0 + 27]->setFromNormalized(0.6714285714285715);
      value[ID::decay0 + 28]->setFromNormalized(0.5607142857142857);
      value[ID::decay0 + 29]->setFromNormalized(0.525);
      value[ID::decay0 + 30]->setFromNormalized(0.2261905125209264);
      value[ID::decay0 + 31]->setFromNormalized(0.5214285714285714);
      value[ID::decay0 + 32]->setFromNormalized(0.26428571428571423);
      value[ID::decay0 + 33]->setFromNormalized(0.18571428571428572);
      value[ID::decay0 + 34]->setFromNormalized(0.6142857142857143);
      value[ID::decay0 + 35]->setFromNormalized(0.2440476553780692);
      value[ID::decay0 + 36]->setFromNormalized(0.9071428571428571);
      value[ID::decay0 + 37]->setFromNormalized(0.9071428571428571);
      value[ID::decay0 + 38]->setFromNormalized(0.7428571428571429);
      value[ID::decay0 + 39]->setFromNormalized(0.7773809432983398);
      value[ID::decay0 + 40]->setFromNormalized(0.15000000000000002);
      value[ID::decay0 + 41]->setFromNormalized(0.725);
      value[ID::decay0 + 42]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 43]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 44]->setFromNormalized(0.8714285714285714);
      value[ID::decay0 + 45]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 46]->setFromNormalized(0.4214285714285714);
      value[ID::decay0 + 47]->setFromNormalized(0.9);
      value[ID::decay0 + 48]->setFromNormalized(0.9428571428571428);
      value[ID::decay0 + 49]->setFromNormalized(0.7571428571428571);
      value[ID::decay0 + 50]->setFromNormalized(0.8071428571428572);
      value[ID::decay0 + 51]->setFromNormalized(0.5285714285714286);
      value[ID::decay0 + 52]->setFromNormalized(0.5);
      value[ID::decay0 + 53]->setFromNormalized(0.9071428571428571);
      value[ID::decay0 + 54]->setFromNormalized(0.48571428571428577);
      value[ID::decay0 + 55]->setFromNormalized(0.9357142857142857);
      value[ID::decay0 + 56]->setFromNormalized(0.4892857142857143);
      value[ID::decay0 + 57]->setFromNormalized(0.4714285714285714);
      value[ID::decay0 + 58]->setFromNormalized(0.791666671207973);
      value[ID::decay0 + 59]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 60]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 61]->setFromNormalized(0.8);
      value[ID::decay0 + 62]->setFromNormalized(0.3642857142857143);
      value[ID::decay0 + 63]->setFromNormalized(0.7928571428571428);
      value[ID::overtone0 + 0]->setFromNormalized(1.0);
      value[ID::overtone0 + 1]->setFromNormalized(1.0);
      value[ID::overtone0 + 2]->setFromNormalized(1.0);
      value[ID::overtone0 + 3]->setFromNormalized(1.0);
      value[ID::overtone0 + 4]->setFromNormalized(1.0);
      value[ID::overtone0 + 5]->setFromNormalized(1.0);
      value[ID::overtone0 + 6]->setFromNormalized(1.0);
      value[ID::overtone0 + 7]->setFromNormalized(1.0);
      value[ID::overtone0 + 8]->setFromNormalized(1.0);
      value[ID::overtone0 + 9]->setFromNormalized(1.0);
      value[ID::overtone0 + 10]->setFromNormalized(1.0);
      value[ID::overtone0 + 11]->setFromNormalized(1.0);
      value[ID::overtone0 + 12]->setFromNormalized(1.0);
      value[ID::overtone0 + 13]->setFromNormalized(1.0);
      value[ID::overtone0 + 14]->setFromNormalized(1.0);
      value[ID::overtone0 + 15]->setFromNormalized(1.0);
      value[ID::overtone0 + 16]->setFromNormalized(1.0);
      value[ID::overtone0 + 17]->setFromNormalized(1.0);
      value[ID::overtone0 + 18]->setFromNormalized(1.0);
      value[ID::overtone0 + 19]->setFromNormalized(1.0);
      value[ID::overtone0 + 20]->setFromNormalized(1.0);
      value[ID::overtone0 + 21]->setFromNormalized(1.0);
      value[ID::overtone0 + 22]->setFromNormalized(1.0);
      value[ID::overtone0 + 23]->setFromNormalized(1.0);
      value[ID::overtone0 + 24]->setFromNormalized(1.0);
      value[ID::overtone0 + 25]->setFromNormalized(1.0);
      value[ID::overtone0 + 26]->setFromNormalized(1.0);
      value[ID::overtone0 + 27]->setFromNormalized(1.0);
      value[ID::overtone0 + 28]->setFromNormalized(1.0);
      value[ID::overtone0 + 29]->setFromNormalized(1.0);
      value[ID::overtone0 + 30]->setFromNormalized(1.0);
      value[ID::overtone0 + 31]->setFromNormalized(1.0);
      value[ID::overtone0 + 32]->setFromNormalized(1.0);
      value[ID::overtone0 + 33]->setFromNormalized(1.0);
      value[ID::overtone0 + 34]->setFromNormalized(1.0);
      value[ID::overtone0 + 35]->setFromNormalized(1.0);
      value[ID::overtone0 + 36]->setFromNormalized(1.0);
      value[ID::overtone0 + 37]->setFromNormalized(1.0);
      value[ID::overtone0 + 38]->setFromNormalized(1.0);
      value[ID::overtone0 + 39]->setFromNormalized(1.0);
      value[ID::overtone0 + 40]->setFromNormalized(1.0);
      value[ID::overtone0 + 41]->setFromNormalized(1.0);
      value[ID::overtone0 + 42]->setFromNormalized(1.0);
      value[ID::overtone0 + 43]->setFromNormalized(1.0);
      value[ID::overtone0 + 44]->setFromNormalized(1.0);
      value[ID::overtone0 + 45]->setFromNormalized(1.0);
      value[ID::overtone0 + 46]->setFromNormalized(1.0);
      value[ID::overtone0 + 47]->setFromNormalized(1.0);
      value[ID::overtone0 + 48]->setFromNormalized(1.0);
      value[ID::overtone0 + 49]->setFromNormalized(1.0);
      value[ID::overtone0 + 50]->setFromNormalized(1.0);
      value[ID::overtone0 + 51]->setFromNormalized(1.0);
      value[ID::overtone0 + 52]->setFromNormalized(1.0);
      value[ID::overtone0 + 53]->setFromNormalized(1.0);
      value[ID::overtone0 + 54]->setFromNormalized(1.0);
      value[ID::overtone0 + 55]->setFromNormalized(1.0);
      value[ID::overtone0 + 56]->setFromNormalized(1.0);
      value[ID::overtone0 + 57]->setFromNormalized(1.0);
      value[ID::overtone0 + 58]->setFromNormalized(1.0);
      value[ID::overtone0 + 59]->setFromNormalized(1.0);
      value[ID::overtone0 + 60]->setFromNormalized(1.0);
      value[ID::overtone0 + 61]->setFromNormalized(1.0);
      value[ID::overtone0 + 62]->setFromNormalized(1.0);
      value[ID::overtone0 + 63]->setFromNormalized(1.0);
      value[ID::saturation0 + 0]->setFromNormalized(1.0);
      value[ID::saturation0 + 1]->setFromNormalized(1.0);
      value[ID::saturation0 + 2]->setFromNormalized(1.0);
      value[ID::saturation0 + 3]->setFromNormalized(1.0);
      value[ID::saturation0 + 4]->setFromNormalized(1.0);
      value[ID::saturation0 + 5]->setFromNormalized(1.0);
      value[ID::saturation0 + 6]->setFromNormalized(1.0);
      value[ID::saturation0 + 7]->setFromNormalized(1.0);
      value[ID::saturation0 + 8]->setFromNormalized(1.0);
      value[ID::saturation0 + 9]->setFromNormalized(1.0);
      value[ID::saturation0 + 10]->setFromNormalized(1.0);
      value[ID::saturation0 + 11]->setFromNormalized(1.0);
      value[ID::saturation0 + 12]->setFromNormalized(1.0);
      value[ID::saturation0 + 13]->setFromNormalized(1.0);
      value[ID::saturation0 + 14]->setFromNormalized(1.0);
      value[ID::saturation0 + 15]->setFromNormalized(1.0);
      value[ID::saturation0 + 16]->setFromNormalized(1.0);
      value[ID::saturation0 + 17]->setFromNormalized(1.0);
      value[ID::saturation0 + 18]->setFromNormalized(1.0);
      value[ID::saturation0 + 19]->setFromNormalized(1.0);
      value[ID::saturation0 + 20]->setFromNormalized(1.0);
      value[ID::saturation0 + 21]->setFromNormalized(1.0);
      value[ID::saturation0 + 22]->setFromNormalized(1.0);
      value[ID::saturation0 + 23]->setFromNormalized(1.0);
      value[ID::saturation0 + 24]->setFromNormalized(1.0);
      value[ID::saturation0 + 25]->setFromNormalized(1.0);
      value[ID::saturation0 + 26]->setFromNormalized(1.0);
      value[ID::saturation0 + 27]->setFromNormalized(1.0);
      value[ID::saturation0 + 28]->setFromNormalized(1.0);
      value[ID::saturation0 + 29]->setFromNormalized(1.0);
      value[ID::saturation0 + 30]->setFromNormalized(1.0);
      value[ID::saturation0 + 31]->setFromNormalized(1.0);
      value[ID::saturation0 + 32]->setFromNormalized(1.0);
      value[ID::saturation0 + 33]->setFromNormalized(1.0);
      value[ID::saturation0 + 34]->setFromNormalized(1.0);
      value[ID::saturation0 + 35]->setFromNormalized(1.0);
      value[ID::saturation0 + 36]->setFromNormalized(1.0);
      value[ID::saturation0 + 37]->setFromNormalized(1.0);
      value[ID::saturation0 + 38]->setFromNormalized(1.0);
      value[ID::saturation0 + 39]->setFromNormalized(1.0);
      value[ID::saturation0 + 40]->setFromNormalized(1.0);
      value[ID::saturation0 + 41]->setFromNormalized(1.0);
      value[ID::saturation0 + 42]->setFromNormalized(1.0);
      value[ID::saturation0 + 43]->setFromNormalized(1.0);
      value[ID::saturation0 + 44]->setFromNormalized(1.0);
      value[ID::saturation0 + 45]->setFromNormalized(1.0);
      value[ID::saturation0 + 46]->setFromNormalized(1.0);
      value[ID::saturation0 + 47]->setFromNormalized(1.0);
      value[ID::saturation0 + 48]->setFromNormalized(1.0);
      value[ID::saturation0 + 49]->setFromNormalized(1.0);
      value[ID::saturation0 + 50]->setFromNormalized(1.0);
      value[ID::saturation0 + 51]->setFromNormalized(1.0);
      value[ID::saturation0 + 52]->setFromNormalized(1.0);
      value[ID::saturation0 + 53]->setFromNormalized(1.0);
      value[ID::saturation0 + 54]->setFromNormalized(1.0);
      value[ID::saturation0 + 55]->setFromNormalized(1.0);
      value[ID::saturation0 + 56]->setFromNormalized(1.0);
      value[ID::saturation0 + 57]->setFromNormalized(1.0);
      value[ID::saturation0 + 58]->setFromNormalized(1.0);
      value[ID::saturation0 + 59]->setFromNormalized(1.0);
      value[ID::saturation0 + 60]->setFromNormalized(1.0);
      value[ID::saturation0 + 61]->setFromNormalized(1.0);
      value[ID::saturation0 + 62]->setFromNormalized(1.0);
      value[ID::saturation0 + 63]->setFromNormalized(1.0);
      value[ID::gain]->setFromNormalized(0.29200005531311035);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(1);
      value[ID::masterOctave]->setFromNormalized(1.0);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(704643);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(1.0);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.1680000275373459);
      value[ID::randomPhase]->setFromNormalized(0.16000008583068848);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::decayMultiplier]->setFromNormalized(0.08800017833709717);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441401183605194);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.23199991881847384);
      value[ID::phaserFeedback]->setFromNormalized(0.8480000495910645);
      value[ID::phaserRange]->setFromNormalized(0.7520000338554382);
      value[ID::phaserMin]->setFromNormalized(1.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(0);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetRandomDecay: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.0);
      value[ID::attack0 + 6]->setFromNormalized(0.0);
      value[ID::attack0 + 7]->setFromNormalized(0.0);
      value[ID::attack0 + 8]->setFromNormalized(0.0);
      value[ID::attack0 + 9]->setFromNormalized(0.0);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.0);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.0);
      value[ID::attack0 + 14]->setFromNormalized(0.0);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.0);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.0);
      value[ID::attack0 + 22]->setFromNormalized(0.0);
      value[ID::attack0 + 23]->setFromNormalized(0.0);
      value[ID::attack0 + 24]->setFromNormalized(0.0);
      value[ID::attack0 + 25]->setFromNormalized(0.0);
      value[ID::attack0 + 26]->setFromNormalized(0.0);
      value[ID::attack0 + 27]->setFromNormalized(0.0);
      value[ID::attack0 + 28]->setFromNormalized(0.0);
      value[ID::attack0 + 29]->setFromNormalized(0.0);
      value[ID::attack0 + 30]->setFromNormalized(0.0);
      value[ID::attack0 + 31]->setFromNormalized(0.0);
      value[ID::attack0 + 32]->setFromNormalized(0.0);
      value[ID::attack0 + 33]->setFromNormalized(0.0);
      value[ID::attack0 + 34]->setFromNormalized(0.0);
      value[ID::attack0 + 35]->setFromNormalized(0.0);
      value[ID::attack0 + 36]->setFromNormalized(0.0);
      value[ID::attack0 + 37]->setFromNormalized(0.0);
      value[ID::attack0 + 38]->setFromNormalized(0.0);
      value[ID::attack0 + 39]->setFromNormalized(0.0);
      value[ID::attack0 + 40]->setFromNormalized(0.0);
      value[ID::attack0 + 41]->setFromNormalized(0.0);
      value[ID::attack0 + 42]->setFromNormalized(0.0);
      value[ID::attack0 + 43]->setFromNormalized(0.0);
      value[ID::attack0 + 44]->setFromNormalized(0.0);
      value[ID::attack0 + 45]->setFromNormalized(0.0);
      value[ID::attack0 + 46]->setFromNormalized(0.0);
      value[ID::attack0 + 47]->setFromNormalized(0.0);
      value[ID::attack0 + 48]->setFromNormalized(0.0);
      value[ID::attack0 + 49]->setFromNormalized(0.0);
      value[ID::attack0 + 50]->setFromNormalized(0.0);
      value[ID::attack0 + 51]->setFromNormalized(0.0);
      value[ID::attack0 + 52]->setFromNormalized(0.0);
      value[ID::attack0 + 53]->setFromNormalized(0.0);
      value[ID::attack0 + 54]->setFromNormalized(0.0);
      value[ID::attack0 + 55]->setFromNormalized(0.0);
      value[ID::attack0 + 56]->setFromNormalized(0.0);
      value[ID::attack0 + 57]->setFromNormalized(0.0);
      value[ID::attack0 + 58]->setFromNormalized(0.0);
      value[ID::attack0 + 59]->setFromNormalized(0.0);
      value[ID::attack0 + 60]->setFromNormalized(0.0);
      value[ID::attack0 + 61]->setFromNormalized(0.0);
      value[ID::attack0 + 62]->setFromNormalized(0.0);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.6299828954545842);
      value[ID::decay0 + 1]->setFromNormalized(0.6588937538791063);
      value[ID::decay0 + 2]->setFromNormalized(0.00914243625389294);
      value[ID::decay0 + 3]->setFromNormalized(0.6570389726837209);
      value[ID::decay0 + 4]->setFromNormalized(0.5075958728460587);
      value[ID::decay0 + 5]->setFromNormalized(0.9461102866134821);
      value[ID::decay0 + 6]->setFromNormalized(0.6279282395054181);
      value[ID::decay0 + 7]->setFromNormalized(0.40745880659834915);
      value[ID::decay0 + 8]->setFromNormalized(0.9538824244030294);
      value[ID::decay0 + 9]->setFromNormalized(0.17160503021634);
      value[ID::decay0 + 10]->setFromNormalized(0.5063488871048336);
      value[ID::decay0 + 11]->setFromNormalized(0.7700865183615214);
      value[ID::decay0 + 12]->setFromNormalized(0.9737367395240489);
      value[ID::decay0 + 13]->setFromNormalized(0.08075452942608487);
      value[ID::decay0 + 14]->setFromNormalized(0.7307259120145191);
      value[ID::decay0 + 15]->setFromNormalized(0.4562314933612098);
      value[ID::decay0 + 16]->setFromNormalized(0.6581812849464993);
      value[ID::decay0 + 17]->setFromNormalized(0.1570181005799967);
      value[ID::decay0 + 18]->setFromNormalized(0.24265194563841613);
      value[ID::decay0 + 19]->setFromNormalized(0.503275690878653);
      value[ID::decay0 + 20]->setFromNormalized(0.5034485434975053);
      value[ID::decay0 + 21]->setFromNormalized(0.8993237232344738);
      value[ID::decay0 + 22]->setFromNormalized(0.27981637066471415);
      value[ID::decay0 + 23]->setFromNormalized(0.040820356379676244);
      value[ID::decay0 + 24]->setFromNormalized(0.7120459764084679);
      value[ID::decay0 + 25]->setFromNormalized(0.6096741297095878);
      value[ID::decay0 + 26]->setFromNormalized(0.18830835791992917);
      value[ID::decay0 + 27]->setFromNormalized(0.843861862970316);
      value[ID::decay0 + 28]->setFromNormalized(0.6816728959595285);
      value[ID::decay0 + 29]->setFromNormalized(0.8849841041406149);
      value[ID::decay0 + 30]->setFromNormalized(0.13421272761419067);
      value[ID::decay0 + 31]->setFromNormalized(0.6186997986192626);
      value[ID::decay0 + 32]->setFromNormalized(0.12191984181237943);
      value[ID::decay0 + 33]->setFromNormalized(0.9545889878334729);
      value[ID::decay0 + 34]->setFromNormalized(0.9856628097158269);
      value[ID::decay0 + 35]->setFromNormalized(0.23825252075265413);
      value[ID::decay0 + 36]->setFromNormalized(0.28416372969529136);
      value[ID::decay0 + 37]->setFromNormalized(0.8717173454430407);
      value[ID::decay0 + 38]->setFromNormalized(0.4169506119305393);
      value[ID::decay0 + 39]->setFromNormalized(0.358002522201965);
      value[ID::decay0 + 40]->setFromNormalized(0.4673690015981747);
      value[ID::decay0 + 41]->setFromNormalized(0.0028930579140363237);
      value[ID::decay0 + 42]->setFromNormalized(0.055970034397794306);
      value[ID::decay0 + 43]->setFromNormalized(0.3991570558305585);
      value[ID::decay0 + 44]->setFromNormalized(0.7651372506523995);
      value[ID::decay0 + 45]->setFromNormalized(0.8626349628581343);
      value[ID::decay0 + 46]->setFromNormalized(0.7952718639120542);
      value[ID::decay0 + 47]->setFromNormalized(0.08448187596754536);
      value[ID::decay0 + 48]->setFromNormalized(0.8421497871750346);
      value[ID::decay0 + 49]->setFromNormalized(0.042679721086098805);
      value[ID::decay0 + 50]->setFromNormalized(0.6241627993238875);
      value[ID::decay0 + 51]->setFromNormalized(0.6698455791713053);
      value[ID::decay0 + 52]->setFromNormalized(0.7584595649811473);
      value[ID::decay0 + 53]->setFromNormalized(0.9784408788288229);
      value[ID::decay0 + 54]->setFromNormalized(0.401272902977306);
      value[ID::decay0 + 55]->setFromNormalized(0.8392341049952143);
      value[ID::decay0 + 56]->setFromNormalized(0.13866909549796014);
      value[ID::decay0 + 57]->setFromNormalized(0.4801610619502388);
      value[ID::decay0 + 58]->setFromNormalized(0.8866087213907371);
      value[ID::decay0 + 59]->setFromNormalized(0.04891027853216862);
      value[ID::decay0 + 60]->setFromNormalized(0.04729332599841702);
      value[ID::decay0 + 61]->setFromNormalized(0.6450840518740327);
      value[ID::decay0 + 62]->setFromNormalized(0.34853672970079985);
      value[ID::decay0 + 63]->setFromNormalized(0.6199058108938663);
      value[ID::overtone0 + 0]->setFromNormalized(0.9487688408131472);
      value[ID::overtone0 + 1]->setFromNormalized(0.9479850588941161);
      value[ID::overtone0 + 2]->setFromNormalized(0.9465394835042641);
      value[ID::overtone0 + 3]->setFromNormalized(0.9444736105586685);
      value[ID::overtone0 + 4]->setFromNormalized(0.9352988244173106);
      value[ID::overtone0 + 5]->setFromNormalized(0.9337737276895883);
      value[ID::overtone0 + 6]->setFromNormalized(0.9254584178827461);
      value[ID::overtone0 + 7]->setFromNormalized(0.8814251156008854);
      value[ID::overtone0 + 8]->setFromNormalized(0.8379001886887144);
      value[ID::overtone0 + 9]->setFromNormalized(0.8296554837439849);
      value[ID::overtone0 + 10]->setFromNormalized(0.818728208724145);
      value[ID::overtone0 + 11]->setFromNormalized(0.7815095821897918);
      value[ID::overtone0 + 12]->setFromNormalized(0.7809941679490203);
      value[ID::overtone0 + 13]->setFromNormalized(0.7768313936644584);
      value[ID::overtone0 + 14]->setFromNormalized(0.7766618949648432);
      value[ID::overtone0 + 15]->setFromNormalized(0.7636152775076245);
      value[ID::overtone0 + 16]->setFromNormalized(0.7609371525315638);
      value[ID::overtone0 + 17]->setFromNormalized(0.7399304873197284);
      value[ID::overtone0 + 18]->setFromNormalized(0.7203700170868454);
      value[ID::overtone0 + 19]->setFromNormalized(0.7125793914567847);
      value[ID::overtone0 + 20]->setFromNormalized(0.6971633581787405);
      value[ID::overtone0 + 21]->setFromNormalized(0.6888604268739278);
      value[ID::overtone0 + 22]->setFromNormalized(0.6785443744112483);
      value[ID::overtone0 + 23]->setFromNormalized(0.6557411898517764);
      value[ID::overtone0 + 24]->setFromNormalized(0.6507904899011918);
      value[ID::overtone0 + 25]->setFromNormalized(0.6127832153099642);
      value[ID::overtone0 + 26]->setFromNormalized(0.5832528836143527);
      value[ID::overtone0 + 27]->setFromNormalized(0.5105967103760682);
      value[ID::overtone0 + 28]->setFromNormalized(0.48433537697760987);
      value[ID::overtone0 + 29]->setFromNormalized(0.4715956628181449);
      value[ID::overtone0 + 30]->setFromNormalized(0.4666336215549133);
      value[ID::overtone0 + 31]->setFromNormalized(0.4621425281162934);
      value[ID::overtone0 + 32]->setFromNormalized(0.4621318267907104);
      value[ID::overtone0 + 33]->setFromNormalized(0.41133050345771904);
      value[ID::overtone0 + 34]->setFromNormalized(0.4076360595239562);
      value[ID::overtone0 + 35]->setFromNormalized(0.40673891030905357);
      value[ID::overtone0 + 36]->setFromNormalized(0.3851187017046227);
      value[ID::overtone0 + 37]->setFromNormalized(0.3690702768135954);
      value[ID::overtone0 + 38]->setFromNormalized(0.36894349312604957);
      value[ID::overtone0 + 39]->setFromNormalized(0.3678888347990985);
      value[ID::overtone0 + 40]->setFromNormalized(0.36179526797093187);
      value[ID::overtone0 + 41]->setFromNormalized(0.33327848165319685);
      value[ID::overtone0 + 42]->setFromNormalized(0.31920870654523714);
      value[ID::overtone0 + 43]->setFromNormalized(0.3076887673707729);
      value[ID::overtone0 + 44]->setFromNormalized(0.3023190551944376);
      value[ID::overtone0 + 45]->setFromNormalized(0.29710945869069194);
      value[ID::overtone0 + 46]->setFromNormalized(0.25982373281975607);
      value[ID::overtone0 + 47]->setFromNormalized(0.237288083833338);
      value[ID::overtone0 + 48]->setFromNormalized(0.22305174850193765);
      value[ID::overtone0 + 49]->setFromNormalized(0.21508036554528634);
      value[ID::overtone0 + 50]->setFromNormalized(0.20940188152660566);
      value[ID::overtone0 + 51]->setFromNormalized(0.20343662961567333);
      value[ID::overtone0 + 52]->setFromNormalized(0.19446489236767447);
      value[ID::overtone0 + 53]->setFromNormalized(0.16723088311393292);
      value[ID::overtone0 + 54]->setFromNormalized(0.1503882780943684);
      value[ID::overtone0 + 55]->setFromNormalized(0.14691538446024985);
      value[ID::overtone0 + 56]->setFromNormalized(0.11115873695152274);
      value[ID::overtone0 + 57]->setFromNormalized(0.11089332470963206);
      value[ID::overtone0 + 58]->setFromNormalized(0.09084130938521132);
      value[ID::overtone0 + 59]->setFromNormalized(0.08277838342393817);
      value[ID::overtone0 + 60]->setFromNormalized(0.07933250727315447);
      value[ID::overtone0 + 61]->setFromNormalized(0.07912277056481169);
      value[ID::overtone0 + 62]->setFromNormalized(0.024216298419324288);
      value[ID::overtone0 + 63]->setFromNormalized(0.005331587721202347);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.28800007700920105);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetRubberBand: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.30714285714285716);
      value[ID::attack0 + 1]->setFromNormalized(0.7857142857142857);
      value[ID::attack0 + 2]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 3]->setFromNormalized(0.7642857142857142);
      value[ID::attack0 + 4]->setFromNormalized(0.8571428571428572);
      value[ID::attack0 + 5]->setFromNormalized(0.95);
      value[ID::attack0 + 6]->setFromNormalized(0.9642857142857143);
      value[ID::attack0 + 7]->setFromNormalized(0.9785714285714285);
      value[ID::attack0 + 8]->setFromNormalized(0.9785714285714285);
      value[ID::attack0 + 9]->setFromNormalized(0.9785714285714285);
      value[ID::attack0 + 10]->setFromNormalized(0.9714285714285714);
      value[ID::attack0 + 11]->setFromNormalized(0.9214285714285715);
      value[ID::attack0 + 12]->setFromNormalized(0.7285714285714286);
      value[ID::attack0 + 13]->setFromNormalized(0.0);
      value[ID::attack0 + 14]->setFromNormalized(0.0);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.0);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.0);
      value[ID::attack0 + 22]->setFromNormalized(0.0);
      value[ID::attack0 + 23]->setFromNormalized(0.0);
      value[ID::attack0 + 24]->setFromNormalized(0.0);
      value[ID::attack0 + 25]->setFromNormalized(0.0);
      value[ID::attack0 + 26]->setFromNormalized(0.0);
      value[ID::attack0 + 27]->setFromNormalized(0.0);
      value[ID::attack0 + 28]->setFromNormalized(0.0);
      value[ID::attack0 + 29]->setFromNormalized(0.0);
      value[ID::attack0 + 30]->setFromNormalized(0.0);
      value[ID::attack0 + 31]->setFromNormalized(0.0);
      value[ID::attack0 + 32]->setFromNormalized(0.0);
      value[ID::attack0 + 33]->setFromNormalized(0.0);
      value[ID::attack0 + 34]->setFromNormalized(0.0);
      value[ID::attack0 + 35]->setFromNormalized(0.0);
      value[ID::attack0 + 36]->setFromNormalized(0.0);
      value[ID::attack0 + 37]->setFromNormalized(0.0);
      value[ID::attack0 + 38]->setFromNormalized(0.0);
      value[ID::attack0 + 39]->setFromNormalized(0.0);
      value[ID::attack0 + 40]->setFromNormalized(0.0);
      value[ID::attack0 + 41]->setFromNormalized(0.0);
      value[ID::attack0 + 42]->setFromNormalized(0.0);
      value[ID::attack0 + 43]->setFromNormalized(0.0);
      value[ID::attack0 + 44]->setFromNormalized(0.0);
      value[ID::attack0 + 45]->setFromNormalized(0.0);
      value[ID::attack0 + 46]->setFromNormalized(0.0);
      value[ID::attack0 + 47]->setFromNormalized(0.0);
      value[ID::attack0 + 48]->setFromNormalized(0.0);
      value[ID::attack0 + 49]->setFromNormalized(0.0);
      value[ID::attack0 + 50]->setFromNormalized(0.0);
      value[ID::attack0 + 51]->setFromNormalized(0.0);
      value[ID::attack0 + 52]->setFromNormalized(0.0);
      value[ID::attack0 + 53]->setFromNormalized(0.0);
      value[ID::attack0 + 54]->setFromNormalized(0.0);
      value[ID::attack0 + 55]->setFromNormalized(0.0);
      value[ID::attack0 + 56]->setFromNormalized(0.0);
      value[ID::attack0 + 57]->setFromNormalized(0.0);
      value[ID::attack0 + 58]->setFromNormalized(0.0);
      value[ID::attack0 + 59]->setFromNormalized(0.0);
      value[ID::attack0 + 60]->setFromNormalized(0.0);
      value[ID::attack0 + 61]->setFromNormalized(0.0);
      value[ID::attack0 + 62]->setFromNormalized(0.0);
      value[ID::attack0 + 63]->setFromNormalized(0.0);
      value[ID::decay0 + 0]->setFromNormalized(0.7714285714285715);
      value[ID::decay0 + 1]->setFromNormalized(0.3142857142857143);
      value[ID::decay0 + 2]->setFromNormalized(0.2785714285714286);
      value[ID::decay0 + 3]->setFromNormalized(0.27142857142857146);
      value[ID::decay0 + 4]->setFromNormalized(0.25);
      value[ID::decay0 + 5]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 6]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 7]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 8]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 9]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 10]->setFromNormalized(0.2428571428571429);
      value[ID::decay0 + 11]->setFromNormalized(0.19285714285714284);
      value[ID::decay0 + 12]->setFromNormalized(0.09999999999999999);
      value[ID::decay0 + 13]->setFromNormalized(0.0714285714285714);
      value[ID::decay0 + 14]->setFromNormalized(0.021428571428571467);
      value[ID::decay0 + 15]->setFromNormalized(0.0);
      value[ID::decay0 + 16]->setFromNormalized(0.0);
      value[ID::decay0 + 17]->setFromNormalized(0.0);
      value[ID::decay0 + 18]->setFromNormalized(0.0);
      value[ID::decay0 + 19]->setFromNormalized(0.0);
      value[ID::decay0 + 20]->setFromNormalized(0.0);
      value[ID::decay0 + 21]->setFromNormalized(0.0);
      value[ID::decay0 + 22]->setFromNormalized(0.0);
      value[ID::decay0 + 23]->setFromNormalized(0.0);
      value[ID::decay0 + 24]->setFromNormalized(0.0);
      value[ID::decay0 + 25]->setFromNormalized(0.0);
      value[ID::decay0 + 26]->setFromNormalized(0.0);
      value[ID::decay0 + 27]->setFromNormalized(0.0);
      value[ID::decay0 + 28]->setFromNormalized(0.0);
      value[ID::decay0 + 29]->setFromNormalized(0.0);
      value[ID::decay0 + 30]->setFromNormalized(0.0);
      value[ID::decay0 + 31]->setFromNormalized(0.0);
      value[ID::decay0 + 32]->setFromNormalized(0.0);
      value[ID::decay0 + 33]->setFromNormalized(0.0);
      value[ID::decay0 + 34]->setFromNormalized(0.0);
      value[ID::decay0 + 35]->setFromNormalized(0.0);
      value[ID::decay0 + 36]->setFromNormalized(0.0);
      value[ID::decay0 + 37]->setFromNormalized(0.0);
      value[ID::decay0 + 38]->setFromNormalized(0.0);
      value[ID::decay0 + 39]->setFromNormalized(0.0);
      value[ID::decay0 + 40]->setFromNormalized(0.0);
      value[ID::decay0 + 41]->setFromNormalized(0.0);
      value[ID::decay0 + 42]->setFromNormalized(0.0);
      value[ID::decay0 + 43]->setFromNormalized(0.0);
      value[ID::decay0 + 44]->setFromNormalized(0.0);
      value[ID::decay0 + 45]->setFromNormalized(0.0);
      value[ID::decay0 + 46]->setFromNormalized(0.0);
      value[ID::decay0 + 47]->setFromNormalized(0.0);
      value[ID::decay0 + 48]->setFromNormalized(0.0);
      value[ID::decay0 + 49]->setFromNormalized(0.0);
      value[ID::decay0 + 50]->setFromNormalized(0.0);
      value[ID::decay0 + 51]->setFromNormalized(0.0);
      value[ID::decay0 + 52]->setFromNormalized(0.0);
      value[ID::decay0 + 53]->setFromNormalized(0.0);
      value[ID::decay0 + 54]->setFromNormalized(0.0);
      value[ID::decay0 + 55]->setFromNormalized(0.0);
      value[ID::decay0 + 56]->setFromNormalized(0.0);
      value[ID::decay0 + 57]->setFromNormalized(0.0);
      value[ID::decay0 + 58]->setFromNormalized(0.0);
      value[ID::decay0 + 59]->setFromNormalized(0.0);
      value[ID::decay0 + 60]->setFromNormalized(0.0);
      value[ID::decay0 + 61]->setFromNormalized(0.0);
      value[ID::decay0 + 62]->setFromNormalized(0.0);
      value[ID::decay0 + 63]->setFromNormalized(0.0);
      value[ID::overtone0 + 0]->setFromNormalized(0.4642857142857143);
      value[ID::overtone0 + 1]->setFromNormalized(0.6928571428571428);
      value[ID::overtone0 + 2]->setFromNormalized(1.0);
      value[ID::overtone0 + 3]->setFromNormalized(1.0);
      value[ID::overtone0 + 4]->setFromNormalized(0.8857142857142858);
      value[ID::overtone0 + 5]->setFromNormalized(0.7071428571428571);
      value[ID::overtone0 + 6]->setFromNormalized(0.4214285714285714);
      value[ID::overtone0 + 7]->setFromNormalized(0.3857142857142857);
      value[ID::overtone0 + 8]->setFromNormalized(0.3285714285714286);
      value[ID::overtone0 + 9]->setFromNormalized(0.27142857142857135);
      value[ID::overtone0 + 10]->setFromNormalized(0.22857142857142856);
      value[ID::overtone0 + 11]->setFromNormalized(0.17142857142857118);
      value[ID::overtone0 + 12]->setFromNormalized(0.028571428571428647);
      value[ID::overtone0 + 13]->setFromNormalized(0.0);
      value[ID::overtone0 + 14]->setFromNormalized(0.0);
      value[ID::overtone0 + 15]->setFromNormalized(0.0);
      value[ID::overtone0 + 16]->setFromNormalized(0.0);
      value[ID::overtone0 + 17]->setFromNormalized(0.0);
      value[ID::overtone0 + 18]->setFromNormalized(0.0);
      value[ID::overtone0 + 19]->setFromNormalized(0.0);
      value[ID::overtone0 + 20]->setFromNormalized(0.0);
      value[ID::overtone0 + 21]->setFromNormalized(0.0);
      value[ID::overtone0 + 22]->setFromNormalized(0.0);
      value[ID::overtone0 + 23]->setFromNormalized(0.0);
      value[ID::overtone0 + 24]->setFromNormalized(0.0);
      value[ID::overtone0 + 25]->setFromNormalized(0.0);
      value[ID::overtone0 + 26]->setFromNormalized(0.0);
      value[ID::overtone0 + 27]->setFromNormalized(0.0);
      value[ID::overtone0 + 28]->setFromNormalized(0.0);
      value[ID::overtone0 + 29]->setFromNormalized(0.0);
      value[ID::overtone0 + 30]->setFromNormalized(0.0);
      value[ID::overtone0 + 31]->setFromNormalized(0.0);
      value[ID::overtone0 + 32]->setFromNormalized(0.0);
      value[ID::overtone0 + 33]->setFromNormalized(0.0);
      value[ID::overtone0 + 34]->setFromNormalized(0.0);
      value[ID::overtone0 + 35]->setFromNormalized(0.0);
      value[ID::overtone0 + 36]->setFromNormalized(0.0);
      value[ID::overtone0 + 37]->setFromNormalized(0.0);
      value[ID::overtone0 + 38]->setFromNormalized(0.0);
      value[ID::overtone0 + 39]->setFromNormalized(0.0223818538420673);
      value[ID::overtone0 + 40]->setFromNormalized(0.0);
      value[ID::overtone0 + 41]->setFromNormalized(0.0);
      value[ID::overtone0 + 42]->setFromNormalized(0.0);
      value[ID::overtone0 + 43]->setFromNormalized(0.0);
      value[ID::overtone0 + 44]->setFromNormalized(0.0);
      value[ID::overtone0 + 45]->setFromNormalized(0.0);
      value[ID::overtone0 + 46]->setFromNormalized(0.0);
      value[ID::overtone0 + 47]->setFromNormalized(0.0);
      value[ID::overtone0 + 48]->setFromNormalized(0.0);
      value[ID::overtone0 + 49]->setFromNormalized(0.0);
      value[ID::overtone0 + 50]->setFromNormalized(0.0);
      value[ID::overtone0 + 51]->setFromNormalized(0.0);
      value[ID::overtone0 + 52]->setFromNormalized(0.0);
      value[ID::overtone0 + 53]->setFromNormalized(0.0);
      value[ID::overtone0 + 54]->setFromNormalized(0.0);
      value[ID::overtone0 + 55]->setFromNormalized(0.0);
      value[ID::overtone0 + 56]->setFromNormalized(0.0);
      value[ID::overtone0 + 57]->setFromNormalized(0.0);
      value[ID::overtone0 + 58]->setFromNormalized(0.0);
      value[ID::overtone0 + 59]->setFromNormalized(0.0);
      value[ID::overtone0 + 60]->setFromNormalized(0.0);
      value[ID::overtone0 + 61]->setFromNormalized(0.0);
      value[ID::overtone0 + 62]->setFromNormalized(0.0);
      value[ID::overtone0 + 63]->setFromNormalized(0.0);
      value[ID::saturation0 + 0]->setFromNormalized(0.05714285714285713);
      value[ID::saturation0 + 1]->setFromNormalized(0.10714285714285707);
      value[ID::saturation0 + 2]->setFromNormalized(0.10714285714285707);
      value[ID::saturation0 + 3]->setFromNormalized(0.06428571428571424);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.5480000376701355);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.2819998562335968);
      value[ID::pitchMultiply]->setFromNormalized(0.2472124844789505);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.2319999784231186);
      value[ID::randomFrequency]->setFromNormalized(0.1680000424385071);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.18800009787082672);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(1.0);
      value[ID::overtoneExpand]->setFromNormalized(0.1599997580051422);
      value[ID::overtoneShift]->setFromNormalized(0.0006000000284984708);
      value[ID::attackMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::decayMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetSaturation1: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.0);
      value[ID::attack0 + 4]->setFromNormalized(0.0);
      value[ID::attack0 + 5]->setFromNormalized(0.0);
      value[ID::attack0 + 6]->setFromNormalized(0.0);
      value[ID::attack0 + 7]->setFromNormalized(0.0);
      value[ID::attack0 + 8]->setFromNormalized(0.0);
      value[ID::attack0 + 9]->setFromNormalized(0.0);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.0);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.0);
      value[ID::attack0 + 14]->setFromNormalized(0.0);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.05000000000000004);
      value[ID::attack0 + 17]->setFromNormalized(0.05695484706333708);
      value[ID::attack0 + 18]->setFromNormalized(0.07086465018136155);
      value[ID::attack0 + 19]->setFromNormalized(0.08477445329938614);
      value[ID::attack0 + 20]->setFromNormalized(0.09868425641741073);
      value[ID::attack0 + 21]->setFromNormalized(0.11259400503976001);
      value[ID::attack0 + 22]->setFromNormalized(0.1265037536621094);
      value[ID::attack0 + 23]->setFromNormalized(0.14041350228445867);
      value[ID::attack0 + 24]->setFromNormalized(0.15432325090680796);
      value[ID::attack0 + 25]->setFromNormalized(0.16823299952915735);
      value[ID::attack0 + 26]->setFromNormalized(0.18214274815150663);
      value[ID::attack0 + 27]->setFromNormalized(0.19605249677385603);
      value[ID::attack0 + 28]->setFromNormalized(0.2099622453962053);
      value[ID::attack0 + 29]->setFromNormalized(0.2238719940185547);
      value[ID::attack0 + 30]->setFromNormalized(0.237781742640904);
      value[ID::attack0 + 31]->setFromNormalized(0.2516914912632533);
      value[ID::attack0 + 32]->setFromNormalized(0.2656012398856027);
      value[ID::attack0 + 33]->setFromNormalized(0.279510988507952);
      value[ID::attack0 + 34]->setFromNormalized(0.29342073713030137);
      value[ID::attack0 + 35]->setFromNormalized(0.30733048575265065);
      value[ID::attack0 + 36]->setFromNormalized(0.3142857142857143);
      value[ID::attack0 + 37]->setFromNormalized(0.30892857142857144);
      value[ID::attack0 + 38]->setFromNormalized(0.29821428571428577);
      value[ID::attack0 + 39]->setFromNormalized(0.2875);
      value[ID::attack0 + 40]->setFromNormalized(0.2767857142857143);
      value[ID::attack0 + 41]->setFromNormalized(0.2660714285714286);
      value[ID::attack0 + 42]->setFromNormalized(0.25535714285714284);
      value[ID::attack0 + 43]->setFromNormalized(0.24464285714285713);
      value[ID::attack0 + 44]->setFromNormalized(0.23392857142857135);
      value[ID::attack0 + 45]->setFromNormalized(0.22321428571428567);
      value[ID::attack0 + 46]->setFromNormalized(0.2125);
      value[ID::attack0 + 47]->setFromNormalized(0.2017857142857142);
      value[ID::attack0 + 48]->setFromNormalized(0.19107142857142853);
      value[ID::attack0 + 49]->setFromNormalized(0.18035714285714285);
      value[ID::attack0 + 50]->setFromNormalized(0.16964285714285707);
      value[ID::attack0 + 51]->setFromNormalized(0.1589285714285714);
      value[ID::attack0 + 52]->setFromNormalized(0.14821428571428572);
      value[ID::attack0 + 53]->setFromNormalized(0.13749999999999993);
      value[ID::attack0 + 54]->setFromNormalized(0.12678571428571425);
      value[ID::attack0 + 55]->setFromNormalized(0.11607142857142859);
      value[ID::attack0 + 56]->setFromNormalized(0.1053571428571428);
      value[ID::attack0 + 57]->setFromNormalized(0.09464285714285713);
      value[ID::attack0 + 58]->setFromNormalized(0.08392857142857145);
      value[ID::attack0 + 59]->setFromNormalized(0.07321428571428566);
      value[ID::attack0 + 60]->setFromNormalized(0.06249999999999999);
      value[ID::attack0 + 61]->setFromNormalized(0.05178571428571432);
      value[ID::attack0 + 62]->setFromNormalized(0.04107142857142853);
      value[ID::attack0 + 63]->setFromNormalized(0.03571428571428569);
      value[ID::decay0 + 0]->setFromNormalized(0.9857142857142858);
      value[ID::decay0 + 1]->setFromNormalized(0.2571428571428571);
      value[ID::decay0 + 2]->setFromNormalized(0.25562062944684705);
      value[ID::decay0 + 3]->setFromNormalized(0.2525761195591518);
      value[ID::decay0 + 4]->setFromNormalized(0.2495316096714565);
      value[ID::decay0 + 5]->setFromNormalized(0.24648709978376115);
      value[ID::decay0 + 6]->setFromNormalized(0.24344258989606582);
      value[ID::decay0 + 7]->setFromNormalized(0.24039808000837048);
      value[ID::decay0 + 8]->setFromNormalized(0.23735357012067526);
      value[ID::decay0 + 9]->setFromNormalized(0.23430906023297995);
      value[ID::decay0 + 10]->setFromNormalized(0.2312645503452846);
      value[ID::decay0 + 11]->setFromNormalized(0.22822004045758926);
      value[ID::decay0 + 12]->setFromNormalized(0.22517553056989395);
      value[ID::decay0 + 13]->setFromNormalized(0.22213102068219873);
      value[ID::decay0 + 14]->setFromNormalized(0.21908651079450336);
      value[ID::decay0 + 15]->setFromNormalized(0.21604200090680803);
      value[ID::decay0 + 16]->setFromNormalized(0.2129974910191127);
      value[ID::decay0 + 17]->setFromNormalized(0.20995298113141736);
      value[ID::decay0 + 18]->setFromNormalized(0.20690847124372214);
      value[ID::decay0 + 19]->setFromNormalized(0.20386396135602683);
      value[ID::decay0 + 20]->setFromNormalized(0.2008194514683315);
      value[ID::decay0 + 21]->setFromNormalized(0.19777494158063613);
      value[ID::decay0 + 22]->setFromNormalized(0.19473043169294083);
      value[ID::decay0 + 23]->setFromNormalized(0.19168592180524557);
      value[ID::decay0 + 24]->setFromNormalized(0.18864141191755024);
      value[ID::decay0 + 25]->setFromNormalized(0.1855969020298549);
      value[ID::decay0 + 26]->setFromNormalized(0.18255239214215957);
      value[ID::decay0 + 27]->setFromNormalized(0.17950788225446423);
      value[ID::decay0 + 28]->setFromNormalized(0.176463372366769);
      value[ID::decay0 + 29]->setFromNormalized(0.1734188624790737);
      value[ID::decay0 + 30]->setFromNormalized(0.17037435259137837);
      value[ID::decay0 + 31]->setFromNormalized(0.167329842703683);
      value[ID::decay0 + 32]->setFromNormalized(0.16428533281598767);
      value[ID::decay0 + 33]->setFromNormalized(0.16124082292829245);
      value[ID::decay0 + 34]->setFromNormalized(0.15819631304059711);
      value[ID::decay0 + 35]->setFromNormalized(0.15515180315290178);
      value[ID::decay0 + 36]->setFromNormalized(0.15210729326520644);
      value[ID::decay0 + 37]->setFromNormalized(0.1490627833775111);
      value[ID::decay0 + 38]->setFromNormalized(0.1460182734898159);
      value[ID::decay0 + 39]->setFromNormalized(0.14297376360212055);
      value[ID::decay0 + 40]->setFromNormalized(0.13992925371442522);
      value[ID::decay0 + 41]->setFromNormalized(0.13688474382672988);
      value[ID::decay0 + 42]->setFromNormalized(0.13384023393903455);
      value[ID::decay0 + 43]->setFromNormalized(0.13079572405133932);
      value[ID::decay0 + 44]->setFromNormalized(0.127751214163644);
      value[ID::decay0 + 45]->setFromNormalized(0.12470670427594867);
      value[ID::decay0 + 46]->setFromNormalized(0.12166219438825333);
      value[ID::decay0 + 47]->setFromNormalized(0.118617684500558);
      value[ID::decay0 + 48]->setFromNormalized(0.11557317461286278);
      value[ID::decay0 + 49]->setFromNormalized(0.11252866472516743);
      value[ID::decay0 + 50]->setFromNormalized(0.1094841548374721);
      value[ID::decay0 + 51]->setFromNormalized(0.10643964494977676);
      value[ID::decay0 + 52]->setFromNormalized(0.10339513506208144);
      value[ID::decay0 + 53]->setFromNormalized(0.1003506251743862);
      value[ID::decay0 + 54]->setFromNormalized(0.09730611528669088);
      value[ID::decay0 + 55]->setFromNormalized(0.09426160539899553);
      value[ID::decay0 + 56]->setFromNormalized(0.09121709551130021);
      value[ID::decay0 + 57]->setFromNormalized(0.08817258562360487);
      value[ID::decay0 + 58]->setFromNormalized(0.08512802124023434);
      value[ID::decay0 + 59]->setFromNormalized(0.0820835658482143);
      value[ID::decay0 + 60]->setFromNormalized(0.07903911045619418);
      value[ID::decay0 + 61]->setFromNormalized(0.07599465506417415);
      value[ID::decay0 + 62]->setFromNormalized(0.072950199672154);
      value[ID::decay0 + 63]->setFromNormalized(0.0714285714285714);
      value[ID::overtone0 + 0]->setFromNormalized(1.0);
      value[ID::overtone0 + 1]->setFromNormalized(0.1);
      value[ID::overtone0 + 2]->setFromNormalized(0.09918033054896772);
      value[ID::overtone0 + 3]->setFromNormalized(0.09754099164690296);
      value[ID::overtone0 + 4]->setFromNormalized(0.0959016527448382);
      value[ID::overtone0 + 5]->setFromNormalized(0.09426231384277343);
      value[ID::overtone0 + 6]->setFromNormalized(0.09262297494070851);
      value[ID::overtone0 + 7]->setFromNormalized(0.09098363603864393);
      value[ID::overtone0 + 8]->setFromNormalized(0.08934429713657917);
      value[ID::overtone0 + 9]->setFromNormalized(0.08770495823451459);
      value[ID::overtone0 + 10]->setFromNormalized(0.08606561933244983);
      value[ID::overtone0 + 11]->setFromNormalized(0.0844262259347099);
      value[ID::overtone0 + 12]->setFromNormalized(0.08278688703264514);
      value[ID::overtone0 + 13]->setFromNormalized(0.08114754813058038);
      value[ID::overtone0 + 14]->setFromNormalized(0.07950820922851562);
      value[ID::overtone0 + 15]->setFromNormalized(0.07786887032645087);
      value[ID::overtone0 + 16]->setFromNormalized(0.1);
      value[ID::overtone0 + 17]->setFromNormalized(0.10625);
      value[ID::overtone0 + 18]->setFromNormalized(0.11875);
      value[ID::overtone0 + 19]->setFromNormalized(0.13125);
      value[ID::overtone0 + 20]->setFromNormalized(0.14375);
      value[ID::overtone0 + 21]->setFromNormalized(0.15625);
      value[ID::overtone0 + 22]->setFromNormalized(0.16875);
      value[ID::overtone0 + 23]->setFromNormalized(0.18125);
      value[ID::overtone0 + 24]->setFromNormalized(0.19375);
      value[ID::overtone0 + 25]->setFromNormalized(0.2062499999999999);
      value[ID::overtone0 + 26]->setFromNormalized(0.21875);
      value[ID::overtone0 + 27]->setFromNormalized(0.23125);
      value[ID::overtone0 + 28]->setFromNormalized(0.2437499999999999);
      value[ID::overtone0 + 29]->setFromNormalized(0.25625);
      value[ID::overtone0 + 30]->setFromNormalized(0.26874999999999993);
      value[ID::overtone0 + 31]->setFromNormalized(0.28125);
      value[ID::overtone0 + 32]->setFromNormalized(0.29375);
      value[ID::overtone0 + 33]->setFromNormalized(0.29999999999999993);
      value[ID::overtone0 + 34]->setFromNormalized(0.29261905125209253);
      value[ID::overtone0 + 35]->setFromNormalized(0.27785715375627795);
      value[ID::overtone0 + 36]->setFromNormalized(0.2630952562604632);
      value[ID::overtone0 + 37]->setFromNormalized(0.24833335876464835);
      value[ID::overtone0 + 38]->setFromNormalized(0.23357146126883369);
      value[ID::overtone0 + 39]->setFromNormalized(0.21880956377301883);
      value[ID::overtone0 + 40]->setFromNormalized(0.20404766627720416);
      value[ID::overtone0 + 41]->setFromNormalized(0.18928576878138942);
      value[ID::overtone0 + 42]->setFromNormalized(0.17452387128557484);
      value[ID::overtone0 + 43]->setFromNormalized(0.1597619737897599);
      value[ID::overtone0 + 44]->setFromNormalized(0.14500007629394532);
      value[ID::overtone0 + 45]->setFromNormalized(0.13023817879813054);
      value[ID::overtone0 + 46]->setFromNormalized(0.1154762813023158);
      value[ID::overtone0 + 47]->setFromNormalized(0.10071438380650104);
      value[ID::overtone0 + 48]->setFromNormalized(0.08595248631068646);
      value[ID::overtone0 + 49]->setFromNormalized(0.07857142857142865);
      value[ID::overtone0 + 50]->setFromNormalized(0.02049200875418524);
      value[ID::overtone0 + 51]->setFromNormalized(0.018852669852120484);
      value[ID::overtone0 + 52]->setFromNormalized(0.017213330950055904);
      value[ID::overtone0 + 53]->setFromNormalized(0.01557399204799097);
      value[ID::overtone0 + 54]->setFromNormalized(0.01393465314592639);
      value[ID::overtone0 + 55]->setFromNormalized(0.012295314243861455);
      value[ID::overtone0 + 56]->setFromNormalized(0.010655975341796875);
      value[ID::overtone0 + 57]->setFromNormalized(0.009016636439732117);
      value[ID::overtone0 + 58]->setFromNormalized(0.00737729753766736);
      value[ID::overtone0 + 59]->setFromNormalized(0.005737958635602602);
      value[ID::overtone0 + 60]->setFromNormalized(0.004098619733538022);
      value[ID::overtone0 + 61]->setFromNormalized(0.002459280831473265);
      value[ID::overtone0 + 62]->setFromNormalized(0.0008199419294085075);
      value[ID::overtone0 + 63]->setFromNormalized(0.0);
      value[ID::saturation0 + 0]->setFromNormalized(1.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.5);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.09200000762939455);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.4880000054836273);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.3744414150714874);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetSparse: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.0);
      value[ID::attack0 + 1]->setFromNormalized(0.0);
      value[ID::attack0 + 2]->setFromNormalized(0.0);
      value[ID::attack0 + 3]->setFromNormalized(0.04285714285714281);
      value[ID::attack0 + 4]->setFromNormalized(0.9);
      value[ID::attack0 + 5]->setFromNormalized(0.9357142857142857);
      value[ID::attack0 + 6]->setFromNormalized(0.9785714285714285);
      value[ID::attack0 + 7]->setFromNormalized(1.0);
      value[ID::attack0 + 8]->setFromNormalized(1.0);
      value[ID::attack0 + 9]->setFromNormalized(1.0);
      value[ID::attack0 + 10]->setFromNormalized(1.0);
      value[ID::attack0 + 11]->setFromNormalized(0.8928571428571429);
      value[ID::attack0 + 12]->setFromNormalized(0.8);
      value[ID::attack0 + 13]->setFromNormalized(0.6142857142857143);
      value[ID::attack0 + 14]->setFromNormalized(0.5928571428571429);
      value[ID::attack0 + 15]->setFromNormalized(0.5071428571428571);
      value[ID::attack0 + 16]->setFromNormalized(0.41428571428571426);
      value[ID::attack0 + 17]->setFromNormalized(0.26428571428571423);
      value[ID::attack0 + 18]->setFromNormalized(0.1857142857142857);
      value[ID::attack0 + 19]->setFromNormalized(0.2571428571428571);
      value[ID::attack0 + 20]->setFromNormalized(0.19999999999999993);
      value[ID::attack0 + 21]->setFromNormalized(0.2214285714285714);
      value[ID::attack0 + 22]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 23]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 24]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 25]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 26]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 27]->setFromNormalized(0.30714285714285716);
      value[ID::attack0 + 28]->setFromNormalized(0.35);
      value[ID::attack0 + 29]->setFromNormalized(0.37857142857142856);
      value[ID::attack0 + 30]->setFromNormalized(0.44285714285714284);
      value[ID::attack0 + 31]->setFromNormalized(0.48571428571428577);
      value[ID::attack0 + 32]->setFromNormalized(0.5142857142857142);
      value[ID::attack0 + 33]->setFromNormalized(0.5642857142857143);
      value[ID::attack0 + 34]->setFromNormalized(0.6071428571428572);
      value[ID::attack0 + 35]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 36]->setFromNormalized(0.6642857142857144);
      value[ID::attack0 + 37]->setFromNormalized(0.6857142857142857);
      value[ID::attack0 + 38]->setFromNormalized(0.7071428571428571);
      value[ID::attack0 + 39]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 40]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 41]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 42]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 43]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 44]->setFromNormalized(0.7);
      value[ID::attack0 + 45]->setFromNormalized(0.6785714285714286);
      value[ID::attack0 + 46]->setFromNormalized(0.6428571428571428);
      value[ID::attack0 + 47]->setFromNormalized(0.6285714285714286);
      value[ID::attack0 + 48]->setFromNormalized(0.5857142857142856);
      value[ID::attack0 + 49]->setFromNormalized(0.5714285714285714);
      value[ID::attack0 + 50]->setFromNormalized(0.5428571428571429);
      value[ID::attack0 + 51]->setFromNormalized(0.5357142857142857);
      value[ID::attack0 + 52]->setFromNormalized(0.4928571428571429);
      value[ID::attack0 + 53]->setFromNormalized(0.4714285714285714);
      value[ID::attack0 + 54]->setFromNormalized(0.4357142857142857);
      value[ID::attack0 + 55]->setFromNormalized(0.41428571428571426);
      value[ID::attack0 + 56]->setFromNormalized(0.3928571428571429);
      value[ID::attack0 + 57]->setFromNormalized(0.37142857142857144);
      value[ID::attack0 + 58]->setFromNormalized(0.3642857142857143);
      value[ID::attack0 + 59]->setFromNormalized(0.33571428571428574);
      value[ID::attack0 + 60]->setFromNormalized(0.3142857142857143);
      value[ID::attack0 + 61]->setFromNormalized(0.2928571428571428);
      value[ID::attack0 + 62]->setFromNormalized(0.27142857142857146);
      value[ID::attack0 + 63]->setFromNormalized(0.26428571428571423);
      value[ID::decay0 + 0]->setFromNormalized(0.6928571428571428);
      value[ID::decay0 + 1]->setFromNormalized(0.7071428571428571);
      value[ID::decay0 + 2]->setFromNormalized(0.7357142857142858);
      value[ID::decay0 + 3]->setFromNormalized(0.7857142857142857);
      value[ID::decay0 + 4]->setFromNormalized(0.8285714285714285);
      value[ID::decay0 + 5]->setFromNormalized(0.9071428571428571);
      value[ID::decay0 + 6]->setFromNormalized(0.9642857142857143);
      value[ID::decay0 + 7]->setFromNormalized(1.0);
      value[ID::decay0 + 8]->setFromNormalized(1.0);
      value[ID::decay0 + 9]->setFromNormalized(1.0);
      value[ID::decay0 + 10]->setFromNormalized(0.8571428571428572);
      value[ID::decay0 + 11]->setFromNormalized(0.8214285714285714);
      value[ID::decay0 + 12]->setFromNormalized(0.7214285714285714);
      value[ID::decay0 + 13]->setFromNormalized(0.6857142857142857);
      value[ID::decay0 + 14]->setFromNormalized(0.5642857142857143);
      value[ID::decay0 + 15]->setFromNormalized(0.5);
      value[ID::decay0 + 16]->setFromNormalized(0.3642857142857143);
      value[ID::decay0 + 17]->setFromNormalized(0.2928571428571428);
      value[ID::decay0 + 18]->setFromNormalized(0.25);
      value[ID::decay0 + 19]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 20]->setFromNormalized(0.20714285714285718);
      value[ID::decay0 + 21]->setFromNormalized(0.20714285714285718);
      value[ID::decay0 + 22]->setFromNormalized(0.20714285714285718);
      value[ID::decay0 + 23]->setFromNormalized(0.20714285714285718);
      value[ID::decay0 + 24]->setFromNormalized(0.22142857142857142);
      value[ID::decay0 + 25]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 26]->setFromNormalized(0.26428571428571423);
      value[ID::decay0 + 27]->setFromNormalized(0.2857142857142857);
      value[ID::decay0 + 28]->setFromNormalized(0.30714285714285716);
      value[ID::decay0 + 29]->setFromNormalized(0.5);
      value[ID::decay0 + 30]->setFromNormalized(0.3285714285714286);
      value[ID::decay0 + 31]->setFromNormalized(0.3285714285714286);
      value[ID::decay0 + 32]->setFromNormalized(0.3285714285714286);
      value[ID::decay0 + 33]->setFromNormalized(0.3285714285714286);
      value[ID::decay0 + 34]->setFromNormalized(0.3285714285714286);
      value[ID::decay0 + 35]->setFromNormalized(0.3285714285714286);
      value[ID::decay0 + 36]->setFromNormalized(0.30714285714285716);
      value[ID::decay0 + 37]->setFromNormalized(0.2928571428571428);
      value[ID::decay0 + 38]->setFromNormalized(0.2857142857142857);
      value[ID::decay0 + 39]->setFromNormalized(0.27142857142857146);
      value[ID::decay0 + 40]->setFromNormalized(0.25);
      value[ID::decay0 + 41]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 42]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 43]->setFromNormalized(0.20714285714285718);
      value[ID::decay0 + 44]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 45]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 46]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 47]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 48]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 49]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 50]->setFromNormalized(0.19999999999999996);
      value[ID::decay0 + 51]->setFromNormalized(0.21428571428571433);
      value[ID::decay0 + 52]->setFromNormalized(0.22142857142857142);
      value[ID::decay0 + 53]->setFromNormalized(0.22142857142857142);
      value[ID::decay0 + 54]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 55]->setFromNormalized(0.17142857142857137);
      value[ID::decay0 + 56]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 57]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 58]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 59]->setFromNormalized(0.2357142857142858);
      value[ID::decay0 + 60]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 61]->setFromNormalized(0.18571428571428572);
      value[ID::decay0 + 62]->setFromNormalized(0.16428571428571428);
      value[ID::decay0 + 63]->setFromNormalized(0.12142857142857146);
      value[ID::overtone0 + 0]->setFromNormalized(0.0);
      value[ID::overtone0 + 1]->setFromNormalized(0.8217656306414616);
      value[ID::overtone0 + 2]->setFromNormalized(0.0);
      value[ID::overtone0 + 3]->setFromNormalized(0.0);
      value[ID::overtone0 + 4]->setFromNormalized(0.0);
      value[ID::overtone0 + 5]->setFromNormalized(0.809404696775277);
      value[ID::overtone0 + 6]->setFromNormalized(0.0);
      value[ID::overtone0 + 7]->setFromNormalized(0.0);
      value[ID::overtone0 + 8]->setFromNormalized(0.0);
      value[ID::overtone0 + 9]->setFromNormalized(0.7410900506330376);
      value[ID::overtone0 + 10]->setFromNormalized(0.709692749975724);
      value[ID::overtone0 + 11]->setFromNormalized(0.0);
      value[ID::overtone0 + 12]->setFromNormalized(0.0);
      value[ID::overtone0 + 13]->setFromNormalized(0.0);
      value[ID::overtone0 + 14]->setFromNormalized(0.0);
      value[ID::overtone0 + 15]->setFromNormalized(0.0);
      value[ID::overtone0 + 16]->setFromNormalized(0.0);
      value[ID::overtone0 + 17]->setFromNormalized(0.0);
      value[ID::overtone0 + 18]->setFromNormalized(0.8459440534838627);
      value[ID::overtone0 + 19]->setFromNormalized(0.7304814186005617);
      value[ID::overtone0 + 20]->setFromNormalized(0.0);
      value[ID::overtone0 + 21]->setFromNormalized(0.0);
      value[ID::overtone0 + 22]->setFromNormalized(0.6275685882851331);
      value[ID::overtone0 + 23]->setFromNormalized(0.0);
      value[ID::overtone0 + 24]->setFromNormalized(0.5355024998124595);
      value[ID::overtone0 + 25]->setFromNormalized(0.8706476921642281);
      value[ID::overtone0 + 26]->setFromNormalized(0.0);
      value[ID::overtone0 + 27]->setFromNormalized(0.0);
      value[ID::overtone0 + 28]->setFromNormalized(0.0);
      value[ID::overtone0 + 29]->setFromNormalized(0.0);
      value[ID::overtone0 + 30]->setFromNormalized(0.0);
      value[ID::overtone0 + 31]->setFromNormalized(0.0);
      value[ID::overtone0 + 32]->setFromNormalized(0.0);
      value[ID::overtone0 + 33]->setFromNormalized(0.0);
      value[ID::overtone0 + 34]->setFromNormalized(0.0);
      value[ID::overtone0 + 35]->setFromNormalized(0.0);
      value[ID::overtone0 + 36]->setFromNormalized(0.0);
      value[ID::overtone0 + 37]->setFromNormalized(0.0);
      value[ID::overtone0 + 38]->setFromNormalized(0.0);
      value[ID::overtone0 + 39]->setFromNormalized(0.0);
      value[ID::overtone0 + 40]->setFromNormalized(0.0);
      value[ID::overtone0 + 41]->setFromNormalized(0.6526561886075208);
      value[ID::overtone0 + 42]->setFromNormalized(0.0);
      value[ID::overtone0 + 43]->setFromNormalized(0.0);
      value[ID::overtone0 + 44]->setFromNormalized(0.5053465775039276);
      value[ID::overtone0 + 45]->setFromNormalized(0.0);
      value[ID::overtone0 + 46]->setFromNormalized(0.08617373073189043);
      value[ID::overtone0 + 47]->setFromNormalized(0.0);
      value[ID::overtone0 + 48]->setFromNormalized(0.0);
      value[ID::overtone0 + 49]->setFromNormalized(0.0);
      value[ID::overtone0 + 50]->setFromNormalized(0.29866883557118645);
      value[ID::overtone0 + 51]->setFromNormalized(0.0);
      value[ID::overtone0 + 52]->setFromNormalized(0.02277834942684347);
      value[ID::overtone0 + 53]->setFromNormalized(0.0);
      value[ID::overtone0 + 54]->setFromNormalized(0.0);
      value[ID::overtone0 + 55]->setFromNormalized(0.8788442481896259);
      value[ID::overtone0 + 56]->setFromNormalized(0.0);
      value[ID::overtone0 + 57]->setFromNormalized(0.8243948019167353);
      value[ID::overtone0 + 58]->setFromNormalized(0.0);
      value[ID::overtone0 + 59]->setFromNormalized(0.0);
      value[ID::overtone0 + 60]->setFromNormalized(0.0);
      value[ID::overtone0 + 61]->setFromNormalized(0.0);
      value[ID::overtone0 + 62]->setFromNormalized(0.0);
      value[ID::overtone0 + 63]->setFromNormalized(0.0);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(1.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.0);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.0);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(0.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(0.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.0);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.0);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.3357142857142857);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.0);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.0);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.0);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.0);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.0);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.0);
      value[ID::saturation0 + 55]->setFromNormalized(0.8357142857142857);
      value[ID::saturation0 + 56]->setFromNormalized(0.0);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.0);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.8760000467300415);
      value[ID::gainBoost]->setFromNormalized(0.0679999366402626);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.3980008065700531);
      value[ID::pitchMultiply]->setFromNormalized(0.20781244337558746);
      value[ID::pitchModulo]->setFromNormalized(0.11800000816583633);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.2640000283718109);
      value[ID::randomFrequency]->setFromNormalized(0.04800000414252282);
      value[ID::randomAttack]->setFromNormalized(0.43999990820884705);
      value[ID::randomDecay]->setFromNormalized(0.3400000035762787);
      value[ID::randomSaturation]->setFromNormalized(0.42399975657463074);
      value[ID::randomPhase]->setFromNormalized(0.984000027179718);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.056000005453825);
      value[ID::attackMultiplier]->setFromNormalized(1.0);
      value[ID::decayMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.3864414393901825);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.6840002536773682);
      value[ID::phaserFrequency]->setFromNormalized(0.2359999865293503);
      value[ID::phaserFeedback]->setFromNormalized(0.7679998278617859);
      value[ID::phaserRange]->setFromNormalized(0.49999991059303284);
      value[ID::phaserMin]->setFromNormalized(0.6480003595352173);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.1520000696182251);
      value[ID::phaserStage]->setFromInt(2);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetStrangeBass: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.9214285714285715);
      value[ID::attack0 + 1]->setFromNormalized(0.8352678571428571);
      value[ID::attack0 + 2]->setFromNormalized(0.6629464285714286);
      value[ID::attack0 + 3]->setFromNormalized(0.490625);
      value[ID::attack0 + 4]->setFromNormalized(0.31830357142857146);
      value[ID::attack0 + 5]->setFromNormalized(0.1459821428571428);
      value[ID::attack0 + 6]->setFromNormalized(0.0);
      value[ID::attack0 + 7]->setFromNormalized(0.0);
      value[ID::attack0 + 8]->setFromNormalized(0.0);
      value[ID::attack0 + 9]->setFromNormalized(0.0);
      value[ID::attack0 + 10]->setFromNormalized(0.0);
      value[ID::attack0 + 11]->setFromNormalized(0.0);
      value[ID::attack0 + 12]->setFromNormalized(0.0);
      value[ID::attack0 + 13]->setFromNormalized(0.0);
      value[ID::attack0 + 14]->setFromNormalized(0.0);
      value[ID::attack0 + 15]->setFromNormalized(0.0);
      value[ID::attack0 + 16]->setFromNormalized(0.0);
      value[ID::attack0 + 17]->setFromNormalized(0.0);
      value[ID::attack0 + 18]->setFromNormalized(0.0);
      value[ID::attack0 + 19]->setFromNormalized(0.0);
      value[ID::attack0 + 20]->setFromNormalized(0.0);
      value[ID::attack0 + 21]->setFromNormalized(0.0);
      value[ID::attack0 + 22]->setFromNormalized(0.0);
      value[ID::attack0 + 23]->setFromNormalized(0.0);
      value[ID::attack0 + 24]->setFromNormalized(0.0);
      value[ID::attack0 + 25]->setFromNormalized(0.0);
      value[ID::attack0 + 26]->setFromNormalized(0.0);
      value[ID::attack0 + 27]->setFromNormalized(0.0);
      value[ID::attack0 + 28]->setFromNormalized(0.0);
      value[ID::attack0 + 29]->setFromNormalized(0.0);
      value[ID::attack0 + 30]->setFromNormalized(0.0);
      value[ID::attack0 + 31]->setFromNormalized(0.0);
      value[ID::attack0 + 32]->setFromNormalized(0.0);
      value[ID::attack0 + 33]->setFromNormalized(0.0);
      value[ID::attack0 + 34]->setFromNormalized(0.0);
      value[ID::attack0 + 35]->setFromNormalized(0.08571428571428573);
      value[ID::attack0 + 36]->setFromNormalized(0.1484693799700055);
      value[ID::attack0 + 37]->setFromNormalized(0.27397956848144533);
      value[ID::attack0 + 38]->setFromNormalized(0.399489756992885);
      value[ID::attack0 + 39]->setFromNormalized(0.5249999455043248);
      value[ID::attack0 + 40]->setFromNormalized(0.6505101340157645);
      value[ID::attack0 + 41]->setFromNormalized(0.7760203225272042);
      value[ID::attack0 + 42]->setFromNormalized(0.9015305314745222);
      value[ID::attack0 + 43]->setFromNormalized(1.0);
      value[ID::attack0 + 44]->setFromNormalized(1.0);
      value[ID::attack0 + 45]->setFromNormalized(1.0);
      value[ID::attack0 + 46]->setFromNormalized(1.0);
      value[ID::attack0 + 47]->setFromNormalized(1.0);
      value[ID::attack0 + 48]->setFromNormalized(1.0);
      value[ID::attack0 + 49]->setFromNormalized(1.0);
      value[ID::attack0 + 50]->setFromNormalized(1.0);
      value[ID::attack0 + 51]->setFromNormalized(1.0);
      value[ID::attack0 + 52]->setFromNormalized(1.0);
      value[ID::attack0 + 53]->setFromNormalized(1.0);
      value[ID::attack0 + 54]->setFromNormalized(1.0);
      value[ID::attack0 + 55]->setFromNormalized(1.0);
      value[ID::attack0 + 56]->setFromNormalized(1.0);
      value[ID::attack0 + 57]->setFromNormalized(1.0);
      value[ID::attack0 + 58]->setFromNormalized(1.0);
      value[ID::attack0 + 59]->setFromNormalized(1.0);
      value[ID::attack0 + 60]->setFromNormalized(1.0);
      value[ID::attack0 + 61]->setFromNormalized(1.0);
      value[ID::attack0 + 62]->setFromNormalized(1.0);
      value[ID::attack0 + 63]->setFromNormalized(1.0);
      value[ID::decay0 + 0]->setFromNormalized(0.5);
      value[ID::decay0 + 1]->setFromNormalized(0.5);
      value[ID::decay0 + 2]->setFromNormalized(0.5);
      value[ID::decay0 + 3]->setFromNormalized(0.5571428571428572);
      value[ID::decay0 + 4]->setFromNormalized(0.6285714285714286);
      value[ID::decay0 + 5]->setFromNormalized(0.7714285714285715);
      value[ID::decay0 + 6]->setFromNormalized(0.9142857142857143);
      value[ID::decay0 + 7]->setFromNormalized(0.9857142857142858);
      value[ID::decay0 + 8]->setFromNormalized(0.9357142857142857);
      value[ID::decay0 + 9]->setFromNormalized(0.7535714285714286);
      value[ID::decay0 + 10]->setFromNormalized(0.5714285714285714);
      value[ID::decay0 + 11]->setFromNormalized(0.5);
      value[ID::decay0 + 12]->setFromNormalized(0.5);
      value[ID::decay0 + 13]->setFromNormalized(0.5);
      value[ID::decay0 + 14]->setFromNormalized(0.5);
      value[ID::decay0 + 15]->setFromNormalized(0.5);
      value[ID::decay0 + 16]->setFromNormalized(0.5);
      value[ID::decay0 + 17]->setFromNormalized(0.5);
      value[ID::decay0 + 18]->setFromNormalized(0.5);
      value[ID::decay0 + 19]->setFromNormalized(0.5);
      value[ID::decay0 + 20]->setFromNormalized(0.5);
      value[ID::decay0 + 21]->setFromNormalized(0.5);
      value[ID::decay0 + 22]->setFromNormalized(0.5);
      value[ID::decay0 + 23]->setFromNormalized(0.5);
      value[ID::decay0 + 24]->setFromNormalized(0.5);
      value[ID::decay0 + 25]->setFromNormalized(0.5);
      value[ID::decay0 + 26]->setFromNormalized(0.5);
      value[ID::decay0 + 27]->setFromNormalized(0.5);
      value[ID::decay0 + 28]->setFromNormalized(0.5);
      value[ID::decay0 + 29]->setFromNormalized(0.5);
      value[ID::decay0 + 30]->setFromNormalized(0.5);
      value[ID::decay0 + 31]->setFromNormalized(0.5);
      value[ID::decay0 + 32]->setFromNormalized(0.5);
      value[ID::decay0 + 33]->setFromNormalized(0.5);
      value[ID::decay0 + 34]->setFromNormalized(0.5);
      value[ID::decay0 + 35]->setFromNormalized(0.5);
      value[ID::decay0 + 36]->setFromNormalized(0.5428571428571429);
      value[ID::decay0 + 37]->setFromNormalized(0.5342032841273716);
      value[ID::decay0 + 38]->setFromNormalized(0.5168955666678292);
      value[ID::decay0 + 39]->setFromNormalized(0.4995878492082868);
      value[ID::decay0 + 40]->setFromNormalized(0.4822801317487444);
      value[ID::decay0 + 41]->setFromNormalized(0.464972414289202);
      value[ID::decay0 + 42]->setFromNormalized(0.4476646968296596);
      value[ID::decay0 + 43]->setFromNormalized(0.4303569793701172);
      value[ID::decay0 + 44]->setFromNormalized(0.4130492619105748);
      value[ID::decay0 + 45]->setFromNormalized(0.3957415444510324);
      value[ID::decay0 + 46]->setFromNormalized(0.37843382699149);
      value[ID::decay0 + 47]->setFromNormalized(0.36112610953194757);
      value[ID::decay0 + 48]->setFromNormalized(0.34381839207240517);
      value[ID::decay0 + 49]->setFromNormalized(0.32651067461286276);
      value[ID::decay0 + 50]->setFromNormalized(0.30920295715332036);
      value[ID::decay0 + 51]->setFromNormalized(0.29189523969377795);
      value[ID::decay0 + 52]->setFromNormalized(0.27458752223423544);
      value[ID::decay0 + 53]->setFromNormalized(0.25727980477469303);
      value[ID::decay0 + 54]->setFromNormalized(0.23997208731515066);
      value[ID::decay0 + 55]->setFromNormalized(0.22266436985560822);
      value[ID::decay0 + 56]->setFromNormalized(0.20535665239606582);
      value[ID::decay0 + 57]->setFromNormalized(0.18804893493652342);
      value[ID::decay0 + 58]->setFromNormalized(0.170741217476981);
      value[ID::decay0 + 59]->setFromNormalized(0.1534335000174386);
      value[ID::decay0 + 60]->setFromNormalized(0.1361257825578962);
      value[ID::decay0 + 61]->setFromNormalized(0.11881806509835381);
      value[ID::decay0 + 62]->setFromNormalized(0.1015103476388114);
      value[ID::decay0 + 63]->setFromNormalized(0.09285714285714287);
      value[ID::overtone0 + 0]->setFromNormalized(0.21428571428571433);
      value[ID::overtone0 + 1]->setFromNormalized(0.17142857142857118);
      value[ID::overtone0 + 2]->setFromNormalized(0.17142857142857118);
      value[ID::overtone0 + 3]->setFromNormalized(0.17857142857142866);
      value[ID::overtone0 + 4]->setFromNormalized(0.27142857142857135);
      value[ID::overtone0 + 5]->setFromNormalized(0.3285714285714286);
      value[ID::overtone0 + 6]->setFromNormalized(0.9928571428571429);
      value[ID::overtone0 + 7]->setFromNormalized(0.4357142857142858);
      value[ID::overtone0 + 8]->setFromNormalized(0.5428571428571429);
      value[ID::overtone0 + 9]->setFromNormalized(0.6357142857142857);
      value[ID::overtone0 + 10]->setFromNormalized(0.7428571428571429);
      value[ID::overtone0 + 11]->setFromNormalized(0.8071428571428572);
      value[ID::overtone0 + 12]->setFromNormalized(0.9);
      value[ID::overtone0 + 13]->setFromNormalized(0.9785714285714284);
      value[ID::overtone0 + 14]->setFromNormalized(0.8571428571428573);
      value[ID::overtone0 + 15]->setFromNormalized(0.3979400086720375);
      value[ID::overtone0 + 16]->setFromNormalized(0.8071428571428572);
      value[ID::overtone0 + 17]->setFromNormalized(0.75);
      value[ID::overtone0 + 18]->setFromNormalized(0.7071428571428571);
      value[ID::overtone0 + 19]->setFromNormalized(0.7071428571428571);
      value[ID::overtone0 + 20]->setFromNormalized(0.33889035263304024);
      value[ID::overtone0 + 21]->setFromNormalized(0.3287886595888967);
      value[ID::overtone0 + 22]->setFromNormalized(0.31913608199120347);
      value[ID::overtone0 + 23]->setFromNormalized(0.3098943791441968);
      value[ID::overtone0 + 24]->setFromNormalized(0.30102999566398125);
      value[ID::overtone0 + 25]->setFromNormalized(0.2925133260145909);
      value[ID::overtone0 + 26]->setFromNormalized(0.2843181179205061);
      value[ID::overtone0 + 27]->setFromNormalized(0.2764209843288903);
      value[ID::overtone0 + 28]->setFromNormalized(0.268801001050522);
      value[ID::overtone0 + 29]->setFromNormalized(0.2614393726401687);
      value[ID::overtone0 + 30]->setFromNormalized(0.25431915308286346);
      value[ID::overtone0 + 31]->setFromNormalized(0.24742501084004687);
      value[ID::overtone0 + 32]->setFromNormalized(0.24074303006105602);
      value[ID::overtone0 + 33]->setFromNormalized(0.23426054147887232);
      value[ID::overtone0 + 34]->setFromNormalized(0.22796597782486216);
      value[ID::overtone0 + 35]->setFromNormalized(0.22184874961635614);
      value[ID::overtone0 + 36]->setFromNormalized(0.2158991379665025);
      value[ID::overtone0 + 37]->setFromNormalized(0.21010820169159494);
      value[ID::overtone0 + 38]->setFromNormalized(0.20446769648675023);
      value[ID::overtone0 + 39]->setFromNormalized(0.1989700043360189);
      value[ID::overtone0 + 40]->setFromNormalized(0.19360807164013227);
      value[ID::overtone0 + 41]->setFromNormalized(0.18837535480104978);
      value[ID::overtone0 + 42]->setFromNormalized(0.18326577221020662);
      value[ID::overtone0 + 43]->setFromNormalized(0.17827366175690623);
      value[ID::overtone0 + 44]->setFromNormalized(0.1733937431123282);
      value[ID::overtone0 + 45]->setFromNormalized(0.168621084159213);
      value[ID::overtone0 + 46]->setFromNormalized(0.16395107103214118);
      value[ID::overtone0 + 47]->setFromNormalized(0.15937938131220636);
      value[ID::overtone0 + 48]->setFromNormalized(0.15490195998574324);
      value[ID::overtone0 + 49]->setFromNormalized(0.15051499783199063);
      value[ID::overtone0 + 50]->setFromNormalized(0.1462149119510318);
      value[ID::overtone0 + 51]->setFromNormalized(0.14199832818260044);
      value[ID::overtone0 + 52]->setFromNormalized(0.1378620651996055);
      value[ID::overtone0 + 53]->setFromNormalized(0.13380312008851564);
      value[ID::overtone0 + 54]->setFromNormalized(0.1298186552528781);
      value[ID::overtone0 + 55]->setFromNormalized(0.12590598649689982);
      value[ID::overtone0 + 56]->setFromNormalized(0.12206257216375427);
      value[ID::overtone0 + 57]->setFromNormalized(0.11828600321853137);
      value[ID::overtone0 + 58]->setFromNormalized(0.11457399417892784);
      value[ID::overtone0 + 59]->setFromNormalized(0.11092437480817825);
      value[ID::overtone0 + 60]->setFromNormalized(0.10733508249461661);
      value[ID::overtone0 + 61]->setFromNormalized(0.10380415525087301);
      value[ID::overtone0 + 62]->setFromNormalized(0.10032972527320912);
      value[ID::overtone0 + 63]->setFromNormalized(0.09691001300805642);
      value[ID::saturation0 + 0]->setFromNormalized(0.08571428571428573);
      value[ID::saturation0 + 1]->setFromNormalized(0.12857142857142853);
      value[ID::saturation0 + 2]->setFromNormalized(0.1434210641043526);
      value[ID::saturation0 + 3]->setFromNormalized(0.17312033517020084);
      value[ID::saturation0 + 4]->setFromNormalized(0.20281960623604908);
      value[ID::saturation0 + 5]->setFromNormalized(0.23251887730189735);
      value[ID::saturation0 + 6]->setFromNormalized(0.2571428571428571);
      value[ID::saturation0 + 7]->setFromNormalized(0.3244047437395368);
      value[ID::saturation0 + 8]->setFromNormalized(0.45892857142857146);
      value[ID::saturation0 + 9]->setFromNormalized(0.5934524263654437);
      value[ID::saturation0 + 10]->setFromNormalized(0.7279762540544783);
      value[ID::saturation0 + 11]->setFromNormalized(0.8625000544956752);
      value[ID::saturation0 + 12]->setFromNormalized(0.9970238753727504);
      value[ID::saturation0 + 13]->setFromNormalized(0.9642857142857142);
      value[ID::saturation0 + 14]->setFromNormalized(0.9595238106591361);
      value[ID::saturation0 + 15]->setFromNormalized(0.9500000034059796);
      value[ID::saturation0 + 16]->setFromNormalized(0.9404761927468436);
      value[ID::saturation0 + 17]->setFromNormalized(0.9309523854936873);
      value[ID::saturation0 + 18]->setFromNormalized(0.9214285782405308);
      value[ID::saturation0 + 19]->setFromNormalized(0.9119047709873745);
      value[ID::saturation0 + 20]->setFromNormalized(0.9023809637342181);
      value[ID::saturation0 + 21]->setFromNormalized(0.8928571564810617);
      value[ID::saturation0 + 22]->setFromNormalized(0.8833333560398645);
      value[ID::saturation0 + 23]->setFromNormalized(0.8785714285714286);
      value[ID::saturation0 + 24]->setFromNormalized(0.4928571428571429);
      value[ID::saturation0 + 25]->setFromNormalized(1.0);
      value[ID::saturation0 + 26]->setFromNormalized(1.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.8928571428571429);
      value[ID::saturation0 + 28]->setFromNormalized(0.75);
      value[ID::saturation0 + 29]->setFromNormalized(0.6857142857142857);
      value[ID::saturation0 + 30]->setFromNormalized(0.6428571428571428);
      value[ID::saturation0 + 31]->setFromNormalized(0.6071428571428572);
      value[ID::saturation0 + 32]->setFromNormalized(0.6);
      value[ID::saturation0 + 33]->setFromNormalized(0.5857142857142856);
      value[ID::saturation0 + 34]->setFromNormalized(0.5571428571428572);
      value[ID::saturation0 + 35]->setFromNormalized(0.5571428571428572);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.5571428571428572);
      value[ID::saturation0 + 38]->setFromNormalized(0.5571428571428572);
      value[ID::saturation0 + 39]->setFromNormalized(0.5571428571428572);
      value[ID::saturation0 + 40]->setFromNormalized(0.0);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.5785714285714285);
      value[ID::saturation0 + 43]->setFromNormalized(0.6428571428571428);
      value[ID::saturation0 + 44]->setFromNormalized(0.6928571428571428);
      value[ID::saturation0 + 45]->setFromNormalized(0.8357142857142857);
      value[ID::saturation0 + 46]->setFromNormalized(0.9857142857142858);
      value[ID::saturation0 + 47]->setFromNormalized(1.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.9);
      value[ID::saturation0 + 49]->setFromNormalized(0.7785714285714286);
      value[ID::saturation0 + 50]->setFromNormalized(0.6571428571428571);
      value[ID::saturation0 + 51]->setFromNormalized(0.5357142857142857);
      value[ID::saturation0 + 52]->setFromNormalized(0.37857142857142856);
      value[ID::saturation0 + 53]->setFromNormalized(0.31428571428571433);
      value[ID::saturation0 + 54]->setFromNormalized(0.19285714285714278);
      value[ID::saturation0 + 55]->setFromNormalized(0.1428571428571429);
      value[ID::saturation0 + 56]->setFromNormalized(0.1857142857142857);
      value[ID::saturation0 + 57]->setFromNormalized(0.24285714285714285);
      value[ID::saturation0 + 58]->setFromNormalized(0.26428571428571423);
      value[ID::saturation0 + 59]->setFromNormalized(0.31428571428571433);
      value[ID::saturation0 + 60]->setFromNormalized(0.3357142857142857);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.3357142857142857);
      value[ID::saturation0 + 63]->setFromNormalized(0.2785714285714285);
      value[ID::gain]->setFromNormalized(1.0);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.09199997037649155);
      value[ID::pitchMultiply]->setFromNormalized(0.24981245311327832);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.06400014460086823);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(1.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.0);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetSubCluster: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 1]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 2]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 3]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 4]->setFromNormalized(0.23571428571428574);
      value[ID::attack0 + 5]->setFromNormalized(0.24285714285714285);
      value[ID::attack0 + 6]->setFromNormalized(0.26428571428571423);
      value[ID::attack0 + 7]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 8]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 9]->setFromNormalized(0.30000000000000004);
      value[ID::attack0 + 10]->setFromNormalized(0.34285714285714286);
      value[ID::attack0 + 11]->setFromNormalized(0.34285714285714286);
      value[ID::attack0 + 12]->setFromNormalized(0.3928571428571429);
      value[ID::attack0 + 13]->setFromNormalized(0.4928571428571429);
      value[ID::attack0 + 14]->setFromNormalized(0.5285714285714286);
      value[ID::attack0 + 15]->setFromNormalized(0.5785714285714285);
      value[ID::attack0 + 16]->setFromNormalized(0.6857142857142857);
      value[ID::attack0 + 17]->setFromNormalized(0.7857142857142857);
      value[ID::attack0 + 18]->setFromNormalized(0.8928571428571429);
      value[ID::attack0 + 19]->setFromNormalized(0.9214285714285715);
      value[ID::attack0 + 20]->setFromNormalized(0.9428571428571428);
      value[ID::attack0 + 21]->setFromNormalized(0.9642857142857143);
      value[ID::attack0 + 22]->setFromNormalized(0.95);
      value[ID::attack0 + 23]->setFromNormalized(0.9357142857142857);
      value[ID::attack0 + 24]->setFromNormalized(0.9285714285714286);
      value[ID::attack0 + 25]->setFromNormalized(0.8928571428571429);
      value[ID::attack0 + 26]->setFromNormalized(0.8357142857142857);
      value[ID::attack0 + 27]->setFromNormalized(0.7714285714285715);
      value[ID::attack0 + 28]->setFromNormalized(0.7357142857142858);
      value[ID::attack0 + 29]->setFromNormalized(0.6857142857142857);
      value[ID::attack0 + 30]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 31]->setFromNormalized(0.5428571428571429);
      value[ID::attack0 + 32]->setFromNormalized(0.5);
      value[ID::attack0 + 33]->setFromNormalized(0.44285714285714284);
      value[ID::attack0 + 34]->setFromNormalized(0.4);
      value[ID::attack0 + 35]->setFromNormalized(0.3642857142857143);
      value[ID::attack0 + 36]->setFromNormalized(0.3142857142857143);
      value[ID::attack0 + 37]->setFromNormalized(0.2785714285714286);
      value[ID::attack0 + 38]->setFromNormalized(0.34285714285714286);
      value[ID::attack0 + 39]->setFromNormalized(0.34285714285714286);
      value[ID::attack0 + 40]->setFromNormalized(0.33571428571428574);
      value[ID::attack0 + 41]->setFromNormalized(0.3142857142857143);
      value[ID::attack0 + 42]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 43]->setFromNormalized(0.27142857142857146);
      value[ID::attack0 + 44]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 45]->setFromNormalized(0.27142857142857146);
      value[ID::attack0 + 46]->setFromNormalized(0.24285714285714285);
      value[ID::attack0 + 47]->setFromNormalized(0.2571428571428571);
      value[ID::attack0 + 48]->setFromNormalized(0.2285714285714285);
      value[ID::attack0 + 49]->setFromNormalized(0.2214285714285714);
      value[ID::attack0 + 50]->setFromNormalized(0.20714285714285716);
      value[ID::attack0 + 51]->setFromNormalized(0.19999999999999993);
      value[ID::attack0 + 52]->setFromNormalized(0.17142857142857135);
      value[ID::attack0 + 53]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 54]->setFromNormalized(0.2928571428571428);
      value[ID::attack0 + 55]->setFromNormalized(0.34285714285714286);
      value[ID::attack0 + 56]->setFromNormalized(0.3642857142857143);
      value[ID::attack0 + 57]->setFromNormalized(0.41428571428571426);
      value[ID::attack0 + 58]->setFromNormalized(0.44999999999999996);
      value[ID::attack0 + 59]->setFromNormalized(0.44999999999999996);
      value[ID::attack0 + 60]->setFromNormalized(0.48571428571428577);
      value[ID::attack0 + 61]->setFromNormalized(0.48571428571428577);
      value[ID::attack0 + 62]->setFromNormalized(0.5);
      value[ID::attack0 + 63]->setFromNormalized(0.5);
      value[ID::decay0 + 0]->setFromNormalized(0.16155357003369797);
      value[ID::decay0 + 1]->setFromNormalized(0.3608911209870203);
      value[ID::decay0 + 2]->setFromNormalized(0.08442201076431617);
      value[ID::decay0 + 3]->setFromNormalized(0.8061878042618403);
      value[ID::decay0 + 4]->setFromNormalized(0.1482446153196476);
      value[ID::decay0 + 5]->setFromNormalized(0.9496347195010898);
      value[ID::decay0 + 6]->setFromNormalized(0.22527492101662455);
      value[ID::decay0 + 7]->setFromNormalized(0.18044918195800194);
      value[ID::decay0 + 8]->setFromNormalized(0.7982446663967354);
      value[ID::decay0 + 9]->setFromNormalized(0.7395511183097614);
      value[ID::decay0 + 10]->setFromNormalized(0.4889014748280121);
      value[ID::decay0 + 11]->setFromNormalized(0.7103190274908276);
      value[ID::decay0 + 12]->setFromNormalized(0.17049764910364132);
      value[ID::decay0 + 13]->setFromNormalized(0.3049587688409161);
      value[ID::decay0 + 14]->setFromNormalized(0.8813230630842697);
      value[ID::decay0 + 15]->setFromNormalized(0.8527364530637694);
      value[ID::decay0 + 16]->setFromNormalized(0.3176310319167239);
      value[ID::decay0 + 17]->setFromNormalized(0.8081140023040622);
      value[ID::decay0 + 18]->setFromNormalized(0.5978224412606193);
      value[ID::decay0 + 19]->setFromNormalized(0.21177078677306277);
      value[ID::decay0 + 20]->setFromNormalized(0.14621381056768726);
      value[ID::decay0 + 21]->setFromNormalized(0.35056127206593);
      value[ID::decay0 + 22]->setFromNormalized(0.8752759464702906);
      value[ID::decay0 + 23]->setFromNormalized(0.261843076801854);
      value[ID::decay0 + 24]->setFromNormalized(0.48657449795600355);
      value[ID::decay0 + 25]->setFromNormalized(0.6140862240869591);
      value[ID::decay0 + 26]->setFromNormalized(0.8227710853224888);
      value[ID::decay0 + 27]->setFromNormalized(0.36380943481584876);
      value[ID::decay0 + 28]->setFromNormalized(0.2671332905317729);
      value[ID::decay0 + 29]->setFromNormalized(0.5059477902637803);
      value[ID::decay0 + 30]->setFromNormalized(0.6807348358642646);
      value[ID::decay0 + 31]->setFromNormalized(0.17859107396770968);
      value[ID::decay0 + 32]->setFromNormalized(0.9999999999999999);
      value[ID::decay0 + 33]->setFromNormalized(0.5220664771991376);
      value[ID::decay0 + 34]->setFromNormalized(0.6615724095248334);
      value[ID::decay0 + 35]->setFromNormalized(0.8546428712757581);
      value[ID::decay0 + 36]->setFromNormalized(0.6518953731270182);
      value[ID::decay0 + 37]->setFromNormalized(0.4993548577870886);
      value[ID::decay0 + 38]->setFromNormalized(0.42677773721448836);
      value[ID::decay0 + 39]->setFromNormalized(0.7181842725836025);
      value[ID::decay0 + 40]->setFromNormalized(0.15455931781944396);
      value[ID::decay0 + 41]->setFromNormalized(0.3386895547388792);
      value[ID::decay0 + 42]->setFromNormalized(0.30438236817115955);
      value[ID::decay0 + 43]->setFromNormalized(0.8716404359659528);
      value[ID::decay0 + 44]->setFromNormalized(0.6047776509709343);
      value[ID::decay0 + 45]->setFromNormalized(0.8063067886368472);
      value[ID::decay0 + 46]->setFromNormalized(0.7705162026777178);
      value[ID::decay0 + 47]->setFromNormalized(0.55046319090006);
      value[ID::decay0 + 48]->setFromNormalized(0.08454822170744776);
      value[ID::decay0 + 49]->setFromNormalized(0.823682453763304);
      value[ID::decay0 + 50]->setFromNormalized(0.5631251208227052);
      value[ID::decay0 + 51]->setFromNormalized(0.6064419593007778);
      value[ID::decay0 + 52]->setFromNormalized(0.49612597011243675);
      value[ID::decay0 + 53]->setFromNormalized(0.1836510439667282);
      value[ID::decay0 + 54]->setFromNormalized(0.8017683092660474);
      value[ID::decay0 + 55]->setFromNormalized(0.5910549066041482);
      value[ID::decay0 + 56]->setFromNormalized(0.530771008855984);
      value[ID::decay0 + 57]->setFromNormalized(0.3247773742320283);
      value[ID::decay0 + 58]->setFromNormalized(0.4804534329841258);
      value[ID::decay0 + 59]->setFromNormalized(0.8779437700824531);
      value[ID::decay0 + 60]->setFromNormalized(0.8743556891531487);
      value[ID::decay0 + 61]->setFromNormalized(0.5842759679247714);
      value[ID::decay0 + 62]->setFromNormalized(0.449322898633235);
      value[ID::decay0 + 63]->setFromNormalized(0.7853112208685405);
      value[ID::overtone0 + 0]->setFromNormalized(0.20325203252032517);
      value[ID::overtone0 + 1]->setFromNormalized(0.20325203252032517);
      value[ID::overtone0 + 2]->setFromNormalized(0.20325203252032517);
      value[ID::overtone0 + 3]->setFromNormalized(0.20325203252032517);
      value[ID::overtone0 + 4]->setFromNormalized(0.20325203252032517);
      value[ID::overtone0 + 5]->setFromNormalized(0.21951219512195125);
      value[ID::overtone0 + 6]->setFromNormalized(0.26829268292682934);
      value[ID::overtone0 + 7]->setFromNormalized(0.2764227642276422);
      value[ID::overtone0 + 8]->setFromNormalized(0.30081300813008127);
      value[ID::overtone0 + 9]->setFromNormalized(0.34959349593495936);
      value[ID::overtone0 + 10]->setFromNormalized(0.4065040650406503);
      value[ID::overtone0 + 11]->setFromNormalized(0.46341463414634143);
      value[ID::overtone0 + 12]->setFromNormalized(0.5121951219512194);
      value[ID::overtone0 + 13]->setFromNormalized(0.5691056910569106);
      value[ID::overtone0 + 14]->setFromNormalized(0.6260162601626016);
      value[ID::overtone0 + 15]->setFromNormalized(0.6829268292682926);
      value[ID::overtone0 + 16]->setFromNormalized(0.7317073170731705);
      value[ID::overtone0 + 17]->setFromNormalized(0.8211382113821137);
      value[ID::overtone0 + 18]->setFromNormalized(0.8943089430894309);
      value[ID::overtone0 + 19]->setFromNormalized(0.9268292682926829);
      value[ID::overtone0 + 20]->setFromNormalized(1.0);
      value[ID::overtone0 + 21]->setFromNormalized(1.0);
      value[ID::overtone0 + 22]->setFromNormalized(1.0);
      value[ID::overtone0 + 23]->setFromNormalized(1.0);
      value[ID::overtone0 + 24]->setFromNormalized(0.959349593495935);
      value[ID::overtone0 + 25]->setFromNormalized(0.9512195121951219);
      value[ID::overtone0 + 26]->setFromNormalized(0.9105691056910569);
      value[ID::overtone0 + 27]->setFromNormalized(0.8943089430894309);
      value[ID::overtone0 + 28]->setFromNormalized(0.853658536585366);
      value[ID::overtone0 + 29]->setFromNormalized(0.8130081300813007);
      value[ID::overtone0 + 30]->setFromNormalized(0.8048780487804879);
      value[ID::overtone0 + 31]->setFromNormalized(0.7642276422764228);
      value[ID::overtone0 + 32]->setFromNormalized(0.7154471544715447);
      value[ID::overtone0 + 33]->setFromNormalized(0.6910569105691058);
      value[ID::overtone0 + 34]->setFromNormalized(0.6585365853658536);
      value[ID::overtone0 + 35]->setFromNormalized(0.6422764227642276);
      value[ID::overtone0 + 36]->setFromNormalized(0.6097560975609756);
      value[ID::overtone0 + 37]->setFromNormalized(0.5853658536585366);
      value[ID::overtone0 + 38]->setFromNormalized(0.5447154471544715);
      value[ID::overtone0 + 39]->setFromNormalized(0.5040650406504065);
      value[ID::overtone0 + 40]->setFromNormalized(0.4796747967479674);
      value[ID::overtone0 + 41]->setFromNormalized(0.2520325203252032);
      value[ID::overtone0 + 42]->setFromNormalized(0.4227642276422764);
      value[ID::overtone0 + 43]->setFromNormalized(0.4065040650406503);
      value[ID::overtone0 + 44]->setFromNormalized(0.3739837398373984);
      value[ID::overtone0 + 45]->setFromNormalized(0.3739837398373984);
      value[ID::overtone0 + 46]->setFromNormalized(0.3414634146341463);
      value[ID::overtone0 + 47]->setFromNormalized(0.3252032520325203);
      value[ID::overtone0 + 48]->setFromNormalized(0.21951219512195125);
      value[ID::overtone0 + 49]->setFromNormalized(0.1951219512195122);
      value[ID::overtone0 + 50]->setFromNormalized(0.26016260162601623);
      value[ID::overtone0 + 51]->setFromNormalized(0.26016260162601623);
      value[ID::overtone0 + 52]->setFromNormalized(0.2439024390243903);
      value[ID::overtone0 + 53]->setFromNormalized(0.23577235772357721);
      value[ID::overtone0 + 54]->setFromNormalized(0.21951219512195125);
      value[ID::overtone0 + 55]->setFromNormalized(0.1788617886178862);
      value[ID::overtone0 + 56]->setFromNormalized(0.17073170731707316);
      value[ID::overtone0 + 57]->setFromNormalized(0.17073170731707316);
      value[ID::overtone0 + 58]->setFromNormalized(0.17073170731707316);
      value[ID::overtone0 + 59]->setFromNormalized(0.17073170731707316);
      value[ID::overtone0 + 60]->setFromNormalized(0.17073170731707316);
      value[ID::overtone0 + 61]->setFromNormalized(0.17073170731707316);
      value[ID::overtone0 + 62]->setFromNormalized(0.04878048780487809);
      value[ID::overtone0 + 63]->setFromNormalized(0.15447154471544716);
      value[ID::saturation0 + 0]->setFromNormalized(0.040052909728872585);
      value[ID::saturation0 + 1]->setFromNormalized(0.04313928008711942);
      value[ID::saturation0 + 2]->setFromNormalized(0.0413612627228351);
      value[ID::saturation0 + 3]->setFromNormalized(0.03516041436151022);
      value[ID::saturation0 + 4]->setFromNormalized(0.04622303547893379);
      value[ID::saturation0 + 5]->setFromNormalized(0.039415865628106214);
      value[ID::saturation0 + 6]->setFromNormalized(0.04352948181218481);
      value[ID::saturation0 + 7]->setFromNormalized(0.041195944354234446);
      value[ID::saturation0 + 8]->setFromNormalized(0.052170123273858546);
      value[ID::saturation0 + 9]->setFromNormalized(0.045135070830270685);
      value[ID::saturation0 + 10]->setFromNormalized(0.04962795736967755);
      value[ID::saturation0 + 11]->setFromNormalized(0.05094794438549371);
      value[ID::saturation0 + 12]->setFromNormalized(0.05365230955120828);
      value[ID::saturation0 + 13]->setFromNormalized(0.05173213261433374);
      value[ID::saturation0 + 14]->setFromNormalized(0.11480232594215524);
      value[ID::saturation0 + 15]->setFromNormalized(0.09510857759180308);
      value[ID::saturation0 + 16]->setFromNormalized(0.10880360847141694);
      value[ID::saturation0 + 17]->setFromNormalized(0.09519371520510533);
      value[ID::saturation0 + 18]->setFromNormalized(0.09557626397607383);
      value[ID::saturation0 + 19]->setFromNormalized(0.09336706518839032);
      value[ID::saturation0 + 20]->setFromNormalized(0.0744662065481557);
      value[ID::saturation0 + 21]->setFromNormalized(0.0744650397616103);
      value[ID::saturation0 + 22]->setFromNormalized(0.08984176169098293);
      value[ID::saturation0 + 23]->setFromNormalized(0.0740713597835634);
      value[ID::saturation0 + 24]->setFromNormalized(0.07419814987130163);
      value[ID::saturation0 + 25]->setFromNormalized(0.07824256786751968);
      value[ID::saturation0 + 26]->setFromNormalized(0.0671243763285866);
      value[ID::saturation0 + 27]->setFromNormalized(0.06824907143907283);
      value[ID::saturation0 + 28]->setFromNormalized(0.07028553363043549);
      value[ID::saturation0 + 29]->setFromNormalized(0.10173203866250977);
      value[ID::saturation0 + 30]->setFromNormalized(0.0723880301483498);
      value[ID::saturation0 + 31]->setFromNormalized(0.08573268929160897);
      value[ID::saturation0 + 32]->setFromNormalized(0.10904849400773511);
      value[ID::saturation0 + 33]->setFromNormalized(0.09304799772072124);
      value[ID::saturation0 + 34]->setFromNormalized(0.07328924467983393);
      value[ID::saturation0 + 35]->setFromNormalized(0.07560186050117837);
      value[ID::saturation0 + 36]->setFromNormalized(0.08719451262917796);
      value[ID::saturation0 + 37]->setFromNormalized(0.09066475956349428);
      value[ID::saturation0 + 38]->setFromNormalized(0.1004997866844219);
      value[ID::saturation0 + 39]->setFromNormalized(0.12640485863677411);
      value[ID::saturation0 + 40]->setFromNormalized(0.11450079418911621);
      value[ID::saturation0 + 41]->setFromNormalized(0.10367234239280768);
      value[ID::saturation0 + 42]->setFromNormalized(0.09853135933809026);
      value[ID::saturation0 + 43]->setFromNormalized(0.1100123832969838);
      value[ID::saturation0 + 44]->setFromNormalized(0.10004477605237637);
      value[ID::saturation0 + 45]->setFromNormalized(0.0898639842730815);
      value[ID::saturation0 + 46]->setFromNormalized(0.1406550823271983);
      value[ID::saturation0 + 47]->setFromNormalized(0.13702644792381372);
      value[ID::saturation0 + 48]->setFromNormalized(0.12394061546686666);
      value[ID::saturation0 + 49]->setFromNormalized(0.1344664682637368);
      value[ID::saturation0 + 50]->setFromNormalized(0.12096583299221707);
      value[ID::saturation0 + 51]->setFromNormalized(0.11229853831254599);
      value[ID::saturation0 + 52]->setFromNormalized(0.15176613751509233);
      value[ID::saturation0 + 53]->setFromNormalized(0.15964074440360107);
      value[ID::saturation0 + 54]->setFromNormalized(0.14981277543844615);
      value[ID::saturation0 + 55]->setFromNormalized(0.175720163482121);
      value[ID::saturation0 + 56]->setFromNormalized(0.13450849251156333);
      value[ID::saturation0 + 57]->setFromNormalized(0.16401442459224655);
      value[ID::saturation0 + 58]->setFromNormalized(0.16273008104686737);
      value[ID::saturation0 + 59]->setFromNormalized(0.17528848589296292);
      value[ID::saturation0 + 60]->setFromNormalized(0.14648488725329048);
      value[ID::saturation0 + 61]->setFromNormalized(0.18765098070283637);
      value[ID::saturation0 + 62]->setFromNormalized(0.181332318943208);
      value[ID::saturation0 + 63]->setFromNormalized(0.16350707037361953);
      value[ID::gain]->setFromNormalized(0.6799999475479126);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.1959996372461319);
      value[ID::pitchMultiply]->setFromNormalized(0.047812581062316895);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(8120178);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.0);
      value[ID::randomFrequency]->setFromNormalized(0.0);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(1.0);
      value[ID::overtoneExpand]->setFromNormalized(0.4000000059604645);
      value[ID::overtoneShift]->setFromNormalized(1.280568540096283e-07);
      value[ID::attackMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::decayMultiplier]->setFromNormalized(0.8120000958442688);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441401183605194);
      value[ID::saturationMix]->setFromNormalized(0.3079998791217804);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetWhenItIsReady: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.3797807109611024);
      value[ID::attack0 + 1]->setFromNormalized(0.7493445975041917);
      value[ID::attack0 + 2]->setFromNormalized(0.17348074680330672);
      value[ID::attack0 + 3]->setFromNormalized(0.2996218420689939);
      value[ID::attack0 + 4]->setFromNormalized(0.08345816738453304);
      value[ID::attack0 + 5]->setFromNormalized(0.1475848555931844);
      value[ID::attack0 + 6]->setFromNormalized(0.21653853324291947);
      value[ID::attack0 + 7]->setFromNormalized(0.6928452280324221);
      value[ID::attack0 + 8]->setFromNormalized(0.1771644696301772);
      value[ID::attack0 + 9]->setFromNormalized(0.3523238005371697);
      value[ID::attack0 + 10]->setFromNormalized(0.31103117978451245);
      value[ID::attack0 + 11]->setFromNormalized(0.2844788466790215);
      value[ID::attack0 + 12]->setFromNormalized(0.3286883667910281);
      value[ID::attack0 + 13]->setFromNormalized(0.566886701625695);
      value[ID::attack0 + 14]->setFromNormalized(0.11944969693283004);
      value[ID::attack0 + 15]->setFromNormalized(0.5869938351792742);
      value[ID::attack0 + 16]->setFromNormalized(0.4003120070600432);
      value[ID::attack0 + 17]->setFromNormalized(0.35890512934255175);
      value[ID::attack0 + 18]->setFromNormalized(0.3788618486306754);
      value[ID::attack0 + 19]->setFromNormalized(0.2845240172990362);
      value[ID::attack0 + 20]->setFromNormalized(0.2056654913438375);
      value[ID::attack0 + 21]->setFromNormalized(0.4320915580171122);
      value[ID::attack0 + 22]->setFromNormalized(0.20003912137798513);
      value[ID::attack0 + 23]->setFromNormalized(0.17636564501933089);
      value[ID::attack0 + 24]->setFromNormalized(0.07853898674833165);
      value[ID::attack0 + 25]->setFromNormalized(0.3955355831527372);
      value[ID::attack0 + 26]->setFromNormalized(0.19303517565068115);
      value[ID::attack0 + 27]->setFromNormalized(0.4986916902526468);
      value[ID::attack0 + 28]->setFromNormalized(0.3247718242439287);
      value[ID::attack0 + 29]->setFromNormalized(0.18583148034306507);
      value[ID::attack0 + 30]->setFromNormalized(0.3905574539809727);
      value[ID::attack0 + 31]->setFromNormalized(0.8046514645035678);
      value[ID::attack0 + 32]->setFromNormalized(0.33165223389480275);
      value[ID::attack0 + 33]->setFromNormalized(0.9697242252070539);
      value[ID::attack0 + 34]->setFromNormalized(0.17204727785088036);
      value[ID::attack0 + 35]->setFromNormalized(0.18369990435539835);
      value[ID::attack0 + 36]->setFromNormalized(0.31523193741046307);
      value[ID::attack0 + 37]->setFromNormalized(1.0);
      value[ID::attack0 + 38]->setFromNormalized(0.36496367538652214);
      value[ID::attack0 + 39]->setFromNormalized(0.3127935336186477);
      value[ID::attack0 + 40]->setFromNormalized(0.3175470416991161);
      value[ID::attack0 + 41]->setFromNormalized(0.31512753047529735);
      value[ID::attack0 + 42]->setFromNormalized(0.435395631053399);
      value[ID::attack0 + 43]->setFromNormalized(0.9176122137385067);
      value[ID::attack0 + 44]->setFromNormalized(0.15274579327858406);
      value[ID::attack0 + 45]->setFromNormalized(0.993478282490525);
      value[ID::attack0 + 46]->setFromNormalized(0.4420716761820486);
      value[ID::attack0 + 47]->setFromNormalized(0.470570304998703);
      value[ID::attack0 + 48]->setFromNormalized(0.3174709669787697);
      value[ID::attack0 + 49]->setFromNormalized(0.20355178971977486);
      value[ID::attack0 + 50]->setFromNormalized(0.11907415776841486);
      value[ID::attack0 + 51]->setFromNormalized(0.4401151870926475);
      value[ID::attack0 + 52]->setFromNormalized(0.36946095932992135);
      value[ID::attack0 + 53]->setFromNormalized(0.2214455324948739);
      value[ID::attack0 + 54]->setFromNormalized(0.12209610870840783);
      value[ID::attack0 + 55]->setFromNormalized(0.5455491130961554);
      value[ID::attack0 + 56]->setFromNormalized(0.3454137325567876);
      value[ID::attack0 + 57]->setFromNormalized(0.9073199571551441);
      value[ID::attack0 + 58]->setFromNormalized(0.24110584071324856);
      value[ID::attack0 + 59]->setFromNormalized(0.12243315718949938);
      value[ID::attack0 + 60]->setFromNormalized(0.44462351163048214);
      value[ID::attack0 + 61]->setFromNormalized(0.7744301348698632);
      value[ID::attack0 + 62]->setFromNormalized(0.12696173247245887);
      value[ID::attack0 + 63]->setFromNormalized(0.27183065695219116);
      value[ID::decay0 + 0]->setFromNormalized(0.4739399828409185);
      value[ID::decay0 + 1]->setFromNormalized(0.7288068672658167);
      value[ID::decay0 + 2]->setFromNormalized(0.21473814978630118);
      value[ID::decay0 + 3]->setFromNormalized(0.2664627473167306);
      value[ID::decay0 + 4]->setFromNormalized(0.1849604780798984);
      value[ID::decay0 + 5]->setFromNormalized(0.030595970319919556);
      value[ID::decay0 + 6]->setFromNormalized(0.42362580461809396);
      value[ID::decay0 + 7]->setFromNormalized(0.19096417190922518);
      value[ID::decay0 + 8]->setFromNormalized(0.17840240221874598);
      value[ID::decay0 + 9]->setFromNormalized(0.10470192026992775);
      value[ID::decay0 + 10]->setFromNormalized(0.20668295527414857);
      value[ID::decay0 + 11]->setFromNormalized(0.012130639627447246);
      value[ID::decay0 + 12]->setFromNormalized(0.8027176179764999);
      value[ID::decay0 + 13]->setFromNormalized(1.0);
      value[ID::decay0 + 14]->setFromNormalized(0.08508755055034878);
      value[ID::decay0 + 15]->setFromNormalized(0.29062545580001475);
      value[ID::decay0 + 16]->setFromNormalized(0.8536338302806181);
      value[ID::decay0 + 17]->setFromNormalized(0.057096103797708464);
      value[ID::decay0 + 18]->setFromNormalized(0.6012790804162991);
      value[ID::decay0 + 19]->setFromNormalized(0.036472787640292284);
      value[ID::decay0 + 20]->setFromNormalized(0.13240778717593657);
      value[ID::decay0 + 21]->setFromNormalized(0.6247169103299475);
      value[ID::decay0 + 22]->setFromNormalized(0.595493089449809);
      value[ID::decay0 + 23]->setFromNormalized(0.010832098109307006);
      value[ID::decay0 + 24]->setFromNormalized(0.14030313263923389);
      value[ID::decay0 + 25]->setFromNormalized(0.7099815580441632);
      value[ID::decay0 + 26]->setFromNormalized(0.20968054504549313);
      value[ID::decay0 + 27]->setFromNormalized(0.25485612294557636);
      value[ID::decay0 + 28]->setFromNormalized(0.8139803031477395);
      value[ID::decay0 + 29]->setFromNormalized(0.02258384153830176);
      value[ID::decay0 + 30]->setFromNormalized(0.7919165094874975);
      value[ID::decay0 + 31]->setFromNormalized(0.17014005507988791);
      value[ID::decay0 + 32]->setFromNormalized(0.16080266685000588);
      value[ID::decay0 + 33]->setFromNormalized(0.809925042546874);
      value[ID::decay0 + 34]->setFromNormalized(0.2027276166368919);
      value[ID::decay0 + 35]->setFromNormalized(0.015398190933745061);
      value[ID::decay0 + 36]->setFromNormalized(0.7752644409238992);
      value[ID::decay0 + 37]->setFromNormalized(0.5095940968732243);
      value[ID::decay0 + 38]->setFromNormalized(0.15313393353455343);
      value[ID::decay0 + 39]->setFromNormalized(0.0798275637437112);
      value[ID::decay0 + 40]->setFromNormalized(0.6300225974553847);
      value[ID::decay0 + 41]->setFromNormalized(0.024691332338844827);
      value[ID::decay0 + 42]->setFromNormalized(0.3560837838740118);
      value[ID::decay0 + 43]->setFromNormalized(0.22196997698199294);
      value[ID::decay0 + 44]->setFromNormalized(0.0648836519616245);
      value[ID::decay0 + 45]->setFromNormalized(0.7220282429836928);
      value[ID::decay0 + 46]->setFromNormalized(0.7225296290237287);
      value[ID::decay0 + 47]->setFromNormalized(0.018327970139648625);
      value[ID::decay0 + 48]->setFromNormalized(0.7086536566679387);
      value[ID::decay0 + 49]->setFromNormalized(0.12482943811671549);
      value[ID::decay0 + 50]->setFromNormalized(0.11925796915856417);
      value[ID::decay0 + 51]->setFromNormalized(0.15904633685753194);
      value[ID::decay0 + 52]->setFromNormalized(0.5392540591882279);
      value[ID::decay0 + 53]->setFromNormalized(0.05003611626443879);
      value[ID::decay0 + 54]->setFromNormalized(0.14514974615473258);
      value[ID::decay0 + 55]->setFromNormalized(0.053102805156626576);
      value[ID::decay0 + 56]->setFromNormalized(0.07551339975553119);
      value[ID::decay0 + 57]->setFromNormalized(0.6832601401736809);
      value[ID::decay0 + 58]->setFromNormalized(0.9914349073235245);
      value[ID::decay0 + 59]->setFromNormalized(0.006751626879302364);
      value[ID::decay0 + 60]->setFromNormalized(0.5591897801334799);
      value[ID::decay0 + 61]->setFromNormalized(0.6815873809751717);
      value[ID::decay0 + 62]->setFromNormalized(0.18177715894825408);
      value[ID::decay0 + 63]->setFromNormalized(0.07736172516211656);
      value[ID::overtone0 + 0]->setFromNormalized(0.5449690503412695);
      value[ID::overtone0 + 1]->setFromNormalized(0.17860476009234744);
      value[ID::overtone0 + 2]->setFromNormalized(0.6205104375134327);
      value[ID::overtone0 + 3]->setFromNormalized(0.39448607090800714);
      value[ID::overtone0 + 4]->setFromNormalized(0.8570975235209233);
      value[ID::overtone0 + 5]->setFromNormalized(0.2609603691157685);
      value[ID::overtone0 + 6]->setFromNormalized(0.759533397448972);
      value[ID::overtone0 + 7]->setFromNormalized(0.10087042955755976);
      value[ID::overtone0 + 8]->setFromNormalized(0.23755085510569884);
      value[ID::overtone0 + 9]->setFromNormalized(0.37650811880892343);
      value[ID::overtone0 + 10]->setFromNormalized(0.845716207445555);
      value[ID::overtone0 + 11]->setFromNormalized(0.24210657936699498);
      value[ID::overtone0 + 12]->setFromNormalized(0.7697276309699561);
      value[ID::overtone0 + 13]->setFromNormalized(0.2543820942335316);
      value[ID::overtone0 + 14]->setFromNormalized(0.6435223931096541);
      value[ID::overtone0 + 15]->setFromNormalized(0.12462233713881457);
      value[ID::overtone0 + 16]->setFromNormalized(0.4820712611481036);
      value[ID::overtone0 + 17]->setFromNormalized(0.10539791836412907);
      value[ID::overtone0 + 18]->setFromNormalized(0.6634851145765742);
      value[ID::overtone0 + 19]->setFromNormalized(0.23909659697814317);
      value[ID::overtone0 + 20]->setFromNormalized(0.9210865027809451);
      value[ID::overtone0 + 21]->setFromNormalized(0.3325493928700256);
      value[ID::overtone0 + 22]->setFromNormalized(0.4257254223258099);
      value[ID::overtone0 + 23]->setFromNormalized(0.039337729141241694);
      value[ID::overtone0 + 24]->setFromNormalized(0.6869660223893752);
      value[ID::overtone0 + 25]->setFromNormalized(0.29103733712733676);
      value[ID::overtone0 + 26]->setFromNormalized(0.35908879868205856);
      value[ID::overtone0 + 27]->setFromNormalized(0.4621083649097103);
      value[ID::overtone0 + 28]->setFromNormalized(0.8779771350739477);
      value[ID::overtone0 + 29]->setFromNormalized(0.21427422464926843);
      value[ID::overtone0 + 30]->setFromNormalized(0.8283248847614161);
      value[ID::overtone0 + 31]->setFromNormalized(0.14914931991719965);
      value[ID::overtone0 + 32]->setFromNormalized(0.5589124489318769);
      value[ID::overtone0 + 33]->setFromNormalized(0.280637630174904);
      value[ID::overtone0 + 34]->setFromNormalized(1.0);
      value[ID::overtone0 + 35]->setFromNormalized(0.11526330618995324);
      value[ID::overtone0 + 36]->setFromNormalized(0.6410477725540535);
      value[ID::overtone0 + 37]->setFromNormalized(0.23486918722018846);
      value[ID::overtone0 + 38]->setFromNormalized(0.3178612465759786);
      value[ID::overtone0 + 39]->setFromNormalized(0.09415117221337166);
      value[ID::overtone0 + 40]->setFromNormalized(0.5042674655652772);
      value[ID::overtone0 + 41]->setFromNormalized(0.0994488079606688);
      value[ID::overtone0 + 42]->setFromNormalized(0.38547949759818023);
      value[ID::overtone0 + 43]->setFromNormalized(0.20582142112953594);
      value[ID::overtone0 + 44]->setFromNormalized(0.16011774625997183);
      value[ID::overtone0 + 45]->setFromNormalized(0.13500723390998423);
      value[ID::overtone0 + 46]->setFromNormalized(0.432781616831749);
      value[ID::overtone0 + 47]->setFromNormalized(0.13097483737211704);
      value[ID::overtone0 + 48]->setFromNormalized(0.7367732287075212);
      value[ID::overtone0 + 49]->setFromNormalized(0.2638475774938551);
      value[ID::overtone0 + 50]->setFromNormalized(0.6695987876032674);
      value[ID::overtone0 + 51]->setFromNormalized(0.17900830916756086);
      value[ID::overtone0 + 52]->setFromNormalized(0.5275822091408234);
      value[ID::overtone0 + 53]->setFromNormalized(0.11696773474595368);
      value[ID::overtone0 + 54]->setFromNormalized(0.8199907783305591);
      value[ID::overtone0 + 55]->setFromNormalized(0.14523956596168902);
      value[ID::overtone0 + 56]->setFromNormalized(0.6363747389375876);
      value[ID::overtone0 + 57]->setFromNormalized(0.21051337891298427);
      value[ID::overtone0 + 58]->setFromNormalized(0.4659191933554713);
      value[ID::overtone0 + 59]->setFromNormalized(0.11199248980995051);
      value[ID::overtone0 + 60]->setFromNormalized(0.6365604155777271);
      value[ID::overtone0 + 61]->setFromNormalized(0.2711520307920684);
      value[ID::overtone0 + 62]->setFromNormalized(0.11361471882230774);
      value[ID::overtone0 + 63]->setFromNormalized(0.01845500654556389);
      value[ID::saturation0 + 0]->setFromNormalized(0.35110787325629955);
      value[ID::saturation0 + 1]->setFromNormalized(0.6302947878629865);
      value[ID::saturation0 + 2]->setFromNormalized(0.30168195380829205);
      value[ID::saturation0 + 3]->setFromNormalized(0.7384118180747652);
      value[ID::saturation0 + 4]->setFromNormalized(0.36053369176350564);
      value[ID::saturation0 + 5]->setFromNormalized(0.37573314653595274);
      value[ID::saturation0 + 6]->setFromNormalized(0.28308383933196907);
      value[ID::saturation0 + 7]->setFromNormalized(0.9098511488284806);
      value[ID::saturation0 + 8]->setFromNormalized(0.13938663364814677);
      value[ID::saturation0 + 9]->setFromNormalized(0.3015272083039491);
      value[ID::saturation0 + 10]->setFromNormalized(0.6100208519484452);
      value[ID::saturation0 + 11]->setFromNormalized(0.27789865613369535);
      value[ID::saturation0 + 12]->setFromNormalized(0.8098394575273433);
      value[ID::saturation0 + 13]->setFromNormalized(0.3157642650792394);
      value[ID::saturation0 + 14]->setFromNormalized(0.20081714102694098);
      value[ID::saturation0 + 15]->setFromNormalized(0.9696188253714558);
      value[ID::saturation0 + 16]->setFromNormalized(0.6975503579050129);
      value[ID::saturation0 + 17]->setFromNormalized(0.08270654738409945);
      value[ID::saturation0 + 18]->setFromNormalized(0.5446773638067576);
      value[ID::saturation0 + 19]->setFromNormalized(0.2987804097084424);
      value[ID::saturation0 + 20]->setFromNormalized(0.09327627368123773);
      value[ID::saturation0 + 21]->setFromNormalized(0.5985279741468655);
      value[ID::saturation0 + 22]->setFromNormalized(0.5670562749104093);
      value[ID::saturation0 + 23]->setFromNormalized(0.2610081912512269);
      value[ID::saturation0 + 24]->setFromNormalized(0.31481520963324566);
      value[ID::saturation0 + 25]->setFromNormalized(0.8071021016280036);
      value[ID::saturation0 + 26]->setFromNormalized(0.18587445481228582);
      value[ID::saturation0 + 27]->setFromNormalized(0.19352957686005096);
      value[ID::saturation0 + 28]->setFromNormalized(0.413693246933966);
      value[ID::saturation0 + 29]->setFromNormalized(0.04943848954662039);
      value[ID::saturation0 + 30]->setFromNormalized(0.3400072418753485);
      value[ID::saturation0 + 31]->setFromNormalized(0.540158654577126);
      value[ID::saturation0 + 32]->setFromNormalized(0.2762241711254389);
      value[ID::saturation0 + 33]->setFromNormalized(0.6884444752288621);
      value[ID::saturation0 + 34]->setFromNormalized(0.09696938808640898);
      value[ID::saturation0 + 35]->setFromNormalized(0.11986321861182751);
      value[ID::saturation0 + 36]->setFromNormalized(0.6725260095353665);
      value[ID::saturation0 + 37]->setFromNormalized(0.6578451607551526);
      value[ID::saturation0 + 38]->setFromNormalized(0.3204853501384213);
      value[ID::saturation0 + 39]->setFromNormalized(0.3567698507933618);
      value[ID::saturation0 + 40]->setFromNormalized(0.9285322542410506);
      value[ID::saturation0 + 41]->setFromNormalized(0.12935007940885915);
      value[ID::saturation0 + 42]->setFromNormalized(0.7711026245459549);
      value[ID::saturation0 + 43]->setFromNormalized(0.6529997733956135);
      value[ID::saturation0 + 44]->setFromNormalized(0.05946534577195476);
      value[ID::saturation0 + 45]->setFromNormalized(1.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.9849958100929709);
      value[ID::saturation0 + 47]->setFromNormalized(0.42094187748667344);
      value[ID::saturation0 + 48]->setFromNormalized(0.34268872658712207);
      value[ID::saturation0 + 49]->setFromNormalized(0.5252917122721061);
      value[ID::saturation0 + 50]->setFromNormalized(0.503310659538031);
      value[ID::saturation0 + 51]->setFromNormalized(0.9292069855324665);
      value[ID::saturation0 + 52]->setFromNormalized(0.7442516335628921);
      value[ID::saturation0 + 53]->setFromNormalized(0.11120858635916311);
      value[ID::saturation0 + 54]->setFromNormalized(0.2938629558460581);
      value[ID::saturation0 + 55]->setFromNormalized(0.27374127862158737);
      value[ID::saturation0 + 56]->setFromNormalized(0.4352465953186189);
      value[ID::saturation0 + 57]->setFromNormalized(0.8978961048741425);
      value[ID::saturation0 + 58]->setFromNormalized(0.8034280905399112);
      value[ID::saturation0 + 59]->setFromNormalized(0.1530883914359344);
      value[ID::saturation0 + 60]->setFromNormalized(0.793655385250562);
      value[ID::saturation0 + 61]->setFromNormalized(0.7631280564170471);
      value[ID::saturation0 + 62]->setFromNormalized(0.034947959225767655);
      value[ID::saturation0 + 63]->setFromNormalized(0.37763045356699626);
      value[ID::gain]->setFromNormalized(0.6719998717308044);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.6020005345344543);
      value[ID::pitchMultiply]->setFromNormalized(0.04200000315904617);
      value[ID::pitchModulo]->setFromNormalized(0.0);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.2679999768733978);
      value[ID::randomFrequency]->setFromNormalized(0.3319999873638153);
      value[ID::randomAttack]->setFromNormalized(0.0);
      value[ID::randomDecay]->setFromNormalized(0.0);
      value[ID::randomSaturation]->setFromNormalized(0.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.4000000059604645);
      value[ID::overtoneShift]->setFromNormalized(0.12199999392032623);
      value[ID::attackMultiplier]->setFromNormalized(0.18800000846385956);
      value[ID::decayMultiplier]->setFromNormalized(0.42800000309944153);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.062441402587661725);
      value[ID::saturationMix]->setFromNormalized(0.0);
      value[ID::phaserMix]->setFromNormalized(0.0);
      value[ID::phaserFrequency]->setFromNormalized(0.5);
      value[ID::phaserFeedback]->setFromNormalized(0.5);
      value[ID::phaserRange]->setFromNormalized(1.0);
      value[ID::phaserMin]->setFromNormalized(0.0);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.5);
      value[ID::phaserStage]->setFromInt(15);
      value[ID::unison]->setFromInt(0);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;

    case presetWhereIsThisGoing: {
      value[ID::bypass]->setFromInt(0);
      value[ID::attack0 + 0]->setFromNormalized(0.8571428571428572);
      value[ID::attack0 + 1]->setFromNormalized(0.41428571428571426);
      value[ID::attack0 + 2]->setFromNormalized(0.3642857142857143);
      value[ID::attack0 + 3]->setFromNormalized(0.34285714285714286);
      value[ID::attack0 + 4]->setFromNormalized(0.3142857142857143);
      value[ID::attack0 + 5]->setFromNormalized(0.14285714285714288);
      value[ID::attack0 + 6]->setFromNormalized(0.12142857142857143);
      value[ID::attack0 + 7]->setFromNormalized(0.09999999999999996);
      value[ID::attack0 + 8]->setFromNormalized(0.09999999999999996);
      value[ID::attack0 + 9]->setFromNormalized(0.09999999999999996);
      value[ID::attack0 + 10]->setFromNormalized(0.09999999999999996);
      value[ID::attack0 + 11]->setFromNormalized(0.09999999999999996);
      value[ID::attack0 + 12]->setFromNormalized(0.09999999999999996);
      value[ID::attack0 + 13]->setFromNormalized(0.09999999999999996);
      value[ID::attack0 + 14]->setFromNormalized(0.07142857142857138);
      value[ID::attack0 + 15]->setFromNormalized(0.09285714285714285);
      value[ID::attack0 + 16]->setFromNormalized(0.10714285714285708);
      value[ID::attack0 + 17]->setFromNormalized(0.15);
      value[ID::attack0 + 18]->setFromNormalized(0.1571428571428571);
      value[ID::attack0 + 19]->setFromNormalized(0.2571428571428571);
      value[ID::attack0 + 20]->setFromNormalized(0.19999999999999993);
      value[ID::attack0 + 21]->setFromNormalized(0.2214285714285714);
      value[ID::attack0 + 22]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 23]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 24]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 25]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 26]->setFromNormalized(0.2857142857142857);
      value[ID::attack0 + 27]->setFromNormalized(0.30714285714285716);
      value[ID::attack0 + 28]->setFromNormalized(0.35);
      value[ID::attack0 + 29]->setFromNormalized(0.37857142857142856);
      value[ID::attack0 + 30]->setFromNormalized(0.44285714285714284);
      value[ID::attack0 + 31]->setFromNormalized(0.48571428571428577);
      value[ID::attack0 + 32]->setFromNormalized(0.5142857142857142);
      value[ID::attack0 + 33]->setFromNormalized(0.5642857142857143);
      value[ID::attack0 + 34]->setFromNormalized(0.6071428571428572);
      value[ID::attack0 + 35]->setFromNormalized(0.6214285714285714);
      value[ID::attack0 + 36]->setFromNormalized(0.6642857142857144);
      value[ID::attack0 + 37]->setFromNormalized(0.6857142857142857);
      value[ID::attack0 + 38]->setFromNormalized(0.7071428571428571);
      value[ID::attack0 + 39]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 40]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 41]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 42]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 43]->setFromNormalized(0.7142857142857143);
      value[ID::attack0 + 44]->setFromNormalized(0.7);
      value[ID::attack0 + 45]->setFromNormalized(0.6785714285714286);
      value[ID::attack0 + 46]->setFromNormalized(0.6428571428571428);
      value[ID::attack0 + 47]->setFromNormalized(0.6285714285714286);
      value[ID::attack0 + 48]->setFromNormalized(0.5857142857142856);
      value[ID::attack0 + 49]->setFromNormalized(0.5714285714285714);
      value[ID::attack0 + 50]->setFromNormalized(0.5428571428571429);
      value[ID::attack0 + 51]->setFromNormalized(0.5357142857142857);
      value[ID::attack0 + 52]->setFromNormalized(0.4928571428571429);
      value[ID::attack0 + 53]->setFromNormalized(0.4714285714285714);
      value[ID::attack0 + 54]->setFromNormalized(0.4357142857142857);
      value[ID::attack0 + 55]->setFromNormalized(0.41428571428571426);
      value[ID::attack0 + 56]->setFromNormalized(0.3928571428571429);
      value[ID::attack0 + 57]->setFromNormalized(0.37142857142857144);
      value[ID::attack0 + 58]->setFromNormalized(0.3642857142857143);
      value[ID::attack0 + 59]->setFromNormalized(0.33571428571428574);
      value[ID::attack0 + 60]->setFromNormalized(0.3142857142857143);
      value[ID::attack0 + 61]->setFromNormalized(0.2928571428571428);
      value[ID::attack0 + 62]->setFromNormalized(0.27142857142857146);
      value[ID::attack0 + 63]->setFromNormalized(0.26428571428571423);
      value[ID::decay0 + 0]->setFromNormalized(0.29540201396813903);
      value[ID::decay0 + 1]->setFromNormalized(0.3912937723366884);
      value[ID::decay0 + 2]->setFromNormalized(0.22959596590673648);
      value[ID::decay0 + 3]->setFromNormalized(0.10352529087281731);
      value[ID::decay0 + 4]->setFromNormalized(0.3615891137108101);
      value[ID::decay0 + 5]->setFromNormalized(0.20258225040414005);
      value[ID::decay0 + 6]->setFromNormalized(0.6780237387600356);
      value[ID::decay0 + 7]->setFromNormalized(0.7502486257414578);
      value[ID::decay0 + 8]->setFromNormalized(0.8863787893261196);
      value[ID::decay0 + 9]->setFromNormalized(0.2898218924358996);
      value[ID::decay0 + 10]->setFromNormalized(0.11477398253623962);
      value[ID::decay0 + 11]->setFromNormalized(0.33878894504253976);
      value[ID::decay0 + 12]->setFromNormalized(0.48257531899963046);
      value[ID::decay0 + 13]->setFromNormalized(0.5415527011074246);
      value[ID::decay0 + 14]->setFromNormalized(0.5264429558634564);
      value[ID::decay0 + 15]->setFromNormalized(0.39597494715529236);
      value[ID::decay0 + 16]->setFromNormalized(0.7443743372348375);
      value[ID::decay0 + 17]->setFromNormalized(0.45488370329821864);
      value[ID::decay0 + 18]->setFromNormalized(0.3672331417261667);
      value[ID::decay0 + 19]->setFromNormalized(0.06572250989625751);
      value[ID::decay0 + 20]->setFromNormalized(0.9908165724215842);
      value[ID::decay0 + 21]->setFromNormalized(0.6832487466121181);
      value[ID::decay0 + 22]->setFromNormalized(0.9214285714285715);
      value[ID::decay0 + 23]->setFromNormalized(0.23964792574381366);
      value[ID::decay0 + 24]->setFromNormalized(0.35);
      value[ID::decay0 + 25]->setFromNormalized(0.6785714285714286);
      value[ID::decay0 + 26]->setFromNormalized(0.85);
      value[ID::decay0 + 27]->setFromNormalized(0.7142857142857143);
      value[ID::decay0 + 28]->setFromNormalized(0.5357142857142857);
      value[ID::decay0 + 29]->setFromNormalized(0.5);
      value[ID::decay0 + 30]->setFromNormalized(0.30000000000000004);
      value[ID::decay0 + 31]->setFromNormalized(0.10291005392430937);
      value[ID::decay0 + 32]->setFromNormalized(0.2557511148432404);
      value[ID::decay0 + 33]->setFromNormalized(0.25381812834643236);
      value[ID::decay0 + 34]->setFromNormalized(0.23219638758653044);
      value[ID::decay0 + 35]->setFromNormalized(0.2765595370190401);
      value[ID::decay0 + 36]->setFromNormalized(0.22903745022957145);
      value[ID::decay0 + 37]->setFromNormalized(0.4285714285714286);
      value[ID::decay0 + 38]->setFromNormalized(0.3365613081678373);
      value[ID::decay0 + 39]->setFromNormalized(0.2831950840015498);
      value[ID::decay0 + 40]->setFromNormalized(0.25);
      value[ID::decay0 + 41]->setFromNormalized(0.06719811297920097);
      value[ID::decay0 + 42]->setFromNormalized(0.22142857142857142);
      value[ID::decay0 + 43]->setFromNormalized(0.06699366124274037);
      value[ID::decay0 + 44]->setFromNormalized(0.4324491596190518);
      value[ID::decay0 + 45]->setFromNormalized(0.28026524549836623);
      value[ID::decay0 + 46]->setFromNormalized(0.4214285714285714);
      value[ID::decay0 + 47]->setFromNormalized(0.0714563445049712);
      value[ID::decay0 + 48]->setFromNormalized(0.37857142857142856);
      value[ID::decay0 + 49]->setFromNormalized(0.1493512555085289);
      value[ID::decay0 + 50]->setFromNormalized(0.1785714285714286);
      value[ID::decay0 + 51]->setFromNormalized(0.1785714285714286);
      value[ID::decay0 + 52]->setFromNormalized(0.22857142857142854);
      value[ID::decay0 + 53]->setFromNormalized(0.21428571428571433);
      value[ID::decay0 + 54]->setFromNormalized(0.19285714285714284);
      value[ID::decay0 + 55]->setFromNormalized(0.17142857142857137);
      value[ID::decay0 + 56]->setFromNormalized(0.16428571428571428);
      value[ID::decay0 + 57]->setFromNormalized(0.1428571428571429);
      value[ID::decay0 + 58]->setFromNormalized(0.1428571428571429);
      value[ID::decay0 + 59]->setFromNormalized(0.12142857142857146);
      value[ID::decay0 + 60]->setFromNormalized(0.12142857142857146);
      value[ID::decay0 + 61]->setFromNormalized(0.11428571428571434);
      value[ID::decay0 + 62]->setFromNormalized(0.11428571428571434);
      value[ID::decay0 + 63]->setFromNormalized(0.09999999999999999);
      value[ID::overtone0 + 0]->setFromNormalized(0.1928571428571429);
      value[ID::overtone0 + 1]->setFromNormalized(0.26428571428571423);
      value[ID::overtone0 + 2]->setFromNormalized(0.31428571428571417);
      value[ID::overtone0 + 3]->setFromNormalized(0.37142857142857144);
      value[ID::overtone0 + 4]->setFromNormalized(0.4571428571428572);
      value[ID::overtone0 + 5]->setFromNormalized(0.6);
      value[ID::overtone0 + 6]->setFromNormalized(1.0);
      value[ID::overtone0 + 7]->setFromNormalized(0.10394803967493686);
      value[ID::overtone0 + 8]->setFromNormalized(0.8785714285714284);
      value[ID::overtone0 + 9]->setFromNormalized(0.1);
      value[ID::overtone0 + 10]->setFromNormalized(0.12142857142857136);
      value[ID::overtone0 + 11]->setFromNormalized(0.17857142857142866);
      value[ID::overtone0 + 12]->setFromNormalized(0.3999999999999999);
      value[ID::overtone0 + 13]->setFromNormalized(0.7571428571428571);
      value[ID::overtone0 + 14]->setFromNormalized(1.0);
      value[ID::overtone0 + 15]->setFromNormalized(0.08909831972137443);
      value[ID::overtone0 + 16]->setFromNormalized(0.5642857142857143);
      value[ID::overtone0 + 17]->setFromNormalized(0.45);
      value[ID::overtone0 + 18]->setFromNormalized(0.26428571428571423);
      value[ID::overtone0 + 19]->setFromNormalized(0.2);
      value[ID::overtone0 + 20]->setFromNormalized(0.20714285714285713);
      value[ID::overtone0 + 21]->setFromNormalized(0.6285714285714286);
      value[ID::overtone0 + 22]->setFromNormalized(0.8857142857142858);
      value[ID::overtone0 + 23]->setFromNormalized(0.10941898913151249);
      value[ID::overtone0 + 24]->setFromNormalized(0.47857142857142854);
      value[ID::overtone0 + 25]->setFromNormalized(0.40714285714285714);
      value[ID::overtone0 + 26]->setFromNormalized(0.16428571428571423);
      value[ID::overtone0 + 27]->setFromNormalized(0.16428571428571423);
      value[ID::overtone0 + 28]->setFromNormalized(0.2928571428571427);
      value[ID::overtone0 + 29]->setFromNormalized(0.40714285714285714);
      value[ID::overtone0 + 30]->setFromNormalized(0.5928571428571429);
      value[ID::overtone0 + 31]->setFromNormalized(0.08909831972137443);
      value[ID::overtone0 + 32]->setFromNormalized(0.40714285714285714);
      value[ID::overtone0 + 33]->setFromNormalized(0.2928571428571427);
      value[ID::overtone0 + 34]->setFromNormalized(0.1357142857142856);
      value[ID::overtone0 + 35]->setFromNormalized(0.12857142857142848);
      value[ID::overtone0 + 36]->setFromNormalized(0.15);
      value[ID::overtone0 + 37]->setFromNormalized(0.30714285714285705);
      value[ID::overtone0 + 38]->setFromNormalized(0.3857142857142857);
      value[ID::overtone0 + 39]->setFromNormalized(0.06018044402233187);
      value[ID::overtone0 + 40]->setFromNormalized(0.42857142857142866);
      value[ID::overtone0 + 41]->setFromNormalized(0.2);
      value[ID::overtone0 + 42]->setFromNormalized(0.11428571428571424);
      value[ID::overtone0 + 43]->setFromNormalized(0.06428571428571424);
      value[ID::overtone0 + 44]->setFromNormalized(0.05);
      value[ID::overtone0 + 45]->setFromNormalized(0.05714285714285712);
      value[ID::overtone0 + 46]->setFromNormalized(0.27857142857142847);
      value[ID::overtone0 + 47]->setFromNormalized(0.044549159860687124);
      value[ID::overtone0 + 48]->setFromNormalized(0.29999999999999993);
      value[ID::overtone0 + 49]->setFromNormalized(0.12142857142857136);
      value[ID::overtone0 + 50]->setFromNormalized(0.1);
      value[ID::overtone0 + 51]->setFromNormalized(0.07857142857142865);
      value[ID::overtone0 + 52]->setFromNormalized(0.09285714285714289);
      value[ID::overtone0 + 53]->setFromNormalized(0.1357142857142856);
      value[ID::overtone0 + 54]->setFromNormalized(0.22142857142857136);
      value[ID::overtone0 + 55]->setFromNormalized(0.03751508198794706);
      value[ID::overtone0 + 56]->setFromNormalized(0.2571428571428571);
      value[ID::overtone0 + 57]->setFromNormalized(0.15714285714285695);
      value[ID::overtone0 + 58]->setFromNormalized(0.1);
      value[ID::overtone0 + 59]->setFromNormalized(0.07142857142857136);
      value[ID::overtone0 + 60]->setFromNormalized(0.05);
      value[ID::overtone0 + 61]->setFromNormalized(0.05);
      value[ID::overtone0 + 62]->setFromNormalized(0.12857142857142848);
      value[ID::overtone0 + 63]->setFromNormalized(0.022665362034384805);
      value[ID::saturation0 + 0]->setFromNormalized(0.0);
      value[ID::saturation0 + 1]->setFromNormalized(0.0);
      value[ID::saturation0 + 2]->setFromNormalized(0.0);
      value[ID::saturation0 + 3]->setFromNormalized(0.0);
      value[ID::saturation0 + 4]->setFromNormalized(0.0);
      value[ID::saturation0 + 5]->setFromNormalized(0.0);
      value[ID::saturation0 + 6]->setFromNormalized(0.47857142857142854);
      value[ID::saturation0 + 7]->setFromNormalized(0.0);
      value[ID::saturation0 + 8]->setFromNormalized(0.5714285714285714);
      value[ID::saturation0 + 9]->setFromNormalized(0.0);
      value[ID::saturation0 + 10]->setFromNormalized(0.0);
      value[ID::saturation0 + 11]->setFromNormalized(0.0);
      value[ID::saturation0 + 12]->setFromNormalized(0.0);
      value[ID::saturation0 + 13]->setFromNormalized(0.0);
      value[ID::saturation0 + 14]->setFromNormalized(1.0);
      value[ID::saturation0 + 15]->setFromNormalized(0.0);
      value[ID::saturation0 + 16]->setFromNormalized(1.0);
      value[ID::saturation0 + 17]->setFromNormalized(0.0);
      value[ID::saturation0 + 18]->setFromNormalized(0.0);
      value[ID::saturation0 + 19]->setFromNormalized(0.0);
      value[ID::saturation0 + 20]->setFromNormalized(0.0);
      value[ID::saturation0 + 21]->setFromNormalized(0.0);
      value[ID::saturation0 + 22]->setFromNormalized(0.40714285714285714);
      value[ID::saturation0 + 23]->setFromNormalized(0.0);
      value[ID::saturation0 + 24]->setFromNormalized(0.32857142857142857);
      value[ID::saturation0 + 25]->setFromNormalized(0.0);
      value[ID::saturation0 + 26]->setFromNormalized(0.0);
      value[ID::saturation0 + 27]->setFromNormalized(0.0);
      value[ID::saturation0 + 28]->setFromNormalized(0.0);
      value[ID::saturation0 + 29]->setFromNormalized(0.0);
      value[ID::saturation0 + 30]->setFromNormalized(0.3357142857142857);
      value[ID::saturation0 + 31]->setFromNormalized(0.0);
      value[ID::saturation0 + 32]->setFromNormalized(0.35);
      value[ID::saturation0 + 33]->setFromNormalized(0.0);
      value[ID::saturation0 + 34]->setFromNormalized(0.0);
      value[ID::saturation0 + 35]->setFromNormalized(0.0);
      value[ID::saturation0 + 36]->setFromNormalized(0.0);
      value[ID::saturation0 + 37]->setFromNormalized(0.0);
      value[ID::saturation0 + 38]->setFromNormalized(0.30714285714285716);
      value[ID::saturation0 + 39]->setFromNormalized(0.0);
      value[ID::saturation0 + 40]->setFromNormalized(0.2928571428571428);
      value[ID::saturation0 + 41]->setFromNormalized(0.0);
      value[ID::saturation0 + 42]->setFromNormalized(0.0);
      value[ID::saturation0 + 43]->setFromNormalized(0.0);
      value[ID::saturation0 + 44]->setFromNormalized(0.0);
      value[ID::saturation0 + 45]->setFromNormalized(0.0);
      value[ID::saturation0 + 46]->setFromNormalized(0.41428571428571426);
      value[ID::saturation0 + 47]->setFromNormalized(0.0);
      value[ID::saturation0 + 48]->setFromNormalized(0.3357142857142857);
      value[ID::saturation0 + 49]->setFromNormalized(0.0);
      value[ID::saturation0 + 50]->setFromNormalized(0.0);
      value[ID::saturation0 + 51]->setFromNormalized(0.0);
      value[ID::saturation0 + 52]->setFromNormalized(0.0);
      value[ID::saturation0 + 53]->setFromNormalized(0.0);
      value[ID::saturation0 + 54]->setFromNormalized(0.2928571428571428);
      value[ID::saturation0 + 55]->setFromNormalized(0.0);
      value[ID::saturation0 + 56]->setFromNormalized(0.27142857142857146);
      value[ID::saturation0 + 57]->setFromNormalized(0.0);
      value[ID::saturation0 + 58]->setFromNormalized(0.0);
      value[ID::saturation0 + 59]->setFromNormalized(0.0);
      value[ID::saturation0 + 60]->setFromNormalized(0.0);
      value[ID::saturation0 + 61]->setFromNormalized(0.0);
      value[ID::saturation0 + 62]->setFromNormalized(0.37857142857142856);
      value[ID::saturation0 + 63]->setFromNormalized(0.0);
      value[ID::gain]->setFromNormalized(0.5);
      value[ID::gainBoost]->setFromNormalized(0.0);
      value[ID::aliasing]->setFromInt(0);
      value[ID::masterOctave]->setFromNormalized(0.1620008647441864);
      value[ID::pitchMultiply]->setFromNormalized(0.20781244337558746);
      value[ID::pitchModulo]->setFromNormalized(0.17799998819828033);
      value[ID::seed]->setFromInt(0);
      value[ID::randomRetrigger]->setFromInt(0);
      value[ID::randomGain]->setFromNormalized(0.2640000283718109);
      value[ID::randomFrequency]->setFromNormalized(0.08800004422664642);
      value[ID::randomAttack]->setFromNormalized(0.43999990820884705);
      value[ID::randomDecay]->setFromNormalized(0.3400000035762787);
      value[ID::randomSaturation]->setFromNormalized(1.0);
      value[ID::randomPhase]->setFromNormalized(0.0);
      value[ID::overtoneExpand]->setFromNormalized(0.39999999999999997);
      value[ID::overtoneShift]->setFromNormalized(0.056000005453825);
      value[ID::attackMultiplier]->setFromNormalized(0.39999999999999997);
      value[ID::decayMultiplier]->setFromNormalized(0.4000000059604644);
      value[ID::declick]->setFromInt(1);
      value[ID::gainPower]->setFromNormalized(0.27444136142730713);
      value[ID::saturationMix]->setFromNormalized(1.0);
      value[ID::phaserMix]->setFromNormalized(0.6840002536773682);
      value[ID::phaserFrequency]->setFromNormalized(0.2360000312328339);
      value[ID::phaserFeedback]->setFromNormalized(0.7679998278617859);
      value[ID::phaserRange]->setFromNormalized(0.2240000218153);
      value[ID::phaserMin]->setFromNormalized(0.1599999964237213);
      value[ID::phaserPhase]->setFromNormalized(0.0);
      value[ID::phaserOffset]->setFromNormalized(0.1520000696182251);
      value[ID::phaserStage]->setFromInt(4);
      value[ID::unison]->setFromInt(1);
      value[ID::nVoice]->setFromInt(5);
      value[ID::smoothness]->setFromNormalized(0.10000000000000003);
      value[ID::pitchBend]->setFromNormalized(0.5);
    } break;
  }
}
#endif
